Class: Aws::DataZone::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DataZone::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-datazone/client.rb
Overview
An API client for DataZone. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DataZone::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_predictions(params = {}) ⇒ Types::AcceptPredictionsOutput
Accepts automatically generated business-friendly metadata for your Amazon DataZone assets.
-
#accept_subscription_request(params = {}) ⇒ Types::AcceptSubscriptionRequestOutput
Accepts a subscription request to a specific asset.
-
#associate_environment_role(params = {}) ⇒ Struct
Associates the environment role in Amazon DataZone.
-
#cancel_metadata_generation_run(params = {}) ⇒ Struct
Cancels the metadata generation run.
-
#cancel_subscription(params = {}) ⇒ Types::CancelSubscriptionOutput
Cancels the subscription to the specified asset.
-
#create_asset(params = {}) ⇒ Types::CreateAssetOutput
Creates an asset in Amazon DataZone catalog.
-
#create_asset_revision(params = {}) ⇒ Types::CreateAssetRevisionOutput
Creates a revision of the asset.
-
#create_asset_type(params = {}) ⇒ Types::CreateAssetTypeOutput
Creates a custom asset type.
-
#create_data_source(params = {}) ⇒ Types::CreateDataSourceOutput
Creates an Amazon DataZone data source.
-
#create_domain(params = {}) ⇒ Types::CreateDomainOutput
Creates an Amazon DataZone domain.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Create an Amazon DataZone environment.
-
#create_environment_action(params = {}) ⇒ Types::CreateEnvironmentActionOutput
Creates an action for the environment, for example, creates a console link for an analytics tool that is available in this environment.
-
#create_environment_profile(params = {}) ⇒ Types::CreateEnvironmentProfileOutput
Creates an Amazon DataZone environment profile.
-
#create_form_type(params = {}) ⇒ Types::CreateFormTypeOutput
Creates a metadata form type.
-
#create_glossary(params = {}) ⇒ Types::CreateGlossaryOutput
Creates an Amazon DataZone business glossary.
-
#create_glossary_term(params = {}) ⇒ Types::CreateGlossaryTermOutput
Creates a business glossary term.
-
#create_group_profile(params = {}) ⇒ Types::CreateGroupProfileOutput
Creates a group profile in Amazon DataZone.
-
#create_listing_change_set(params = {}) ⇒ Types::CreateListingChangeSetOutput
Publishes a listing (a record of an asset at a given time) or removes a listing from the catalog.
-
#create_project(params = {}) ⇒ Types::CreateProjectOutput
Creates an Amazon DataZone project.
-
#create_project_membership(params = {}) ⇒ Struct
Creates a project membership in Amazon DataZone.
-
#create_subscription_grant(params = {}) ⇒ Types::CreateSubscriptionGrantOutput
Creates a subsscription grant in Amazon DataZone.
-
#create_subscription_request(params = {}) ⇒ Types::CreateSubscriptionRequestOutput
Creates a subscription request in Amazon DataZone.
-
#create_subscription_target(params = {}) ⇒ Types::CreateSubscriptionTargetOutput
Creates a subscription target in Amazon DataZone.
-
#create_user_profile(params = {}) ⇒ Types::CreateUserProfileOutput
Creates a user profile in Amazon DataZone.
-
#delete_asset(params = {}) ⇒ Struct
Delets an asset in Amazon DataZone.
-
#delete_asset_type(params = {}) ⇒ Struct
Deletes an asset type in Amazon DataZone.
-
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceOutput
Deletes a data source in Amazon DataZone.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainOutput
Deletes a Amazon DataZone domain.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an environment in Amazon DataZone.
-
#delete_environment_action(params = {}) ⇒ Struct
Deletes an action for the environment, for example, deletes a console link for an analytics tool that is available in this environment.
-
#delete_environment_blueprint_configuration(params = {}) ⇒ Struct
Deletes the blueprint configuration in Amazon DataZone.
-
#delete_environment_profile(params = {}) ⇒ Struct
Deletes an environment profile in Amazon DataZone.
-
#delete_form_type(params = {}) ⇒ Struct
Delets and metadata form type in Amazon DataZone.
-
#delete_glossary(params = {}) ⇒ Struct
Deletes a business glossary in Amazon DataZone.
-
#delete_glossary_term(params = {}) ⇒ Struct
Deletes a business glossary term in Amazon DataZone.
-
#delete_listing(params = {}) ⇒ Struct
Deletes a listing (a record of an asset at a given time).
-
#delete_project(params = {}) ⇒ Struct
Deletes a project in Amazon DataZone.
-
#delete_project_membership(params = {}) ⇒ Struct
Deletes project membership in Amazon DataZone.
-
#delete_subscription_grant(params = {}) ⇒ Types::DeleteSubscriptionGrantOutput
Deletes and subscription grant in Amazon DataZone.
-
#delete_subscription_request(params = {}) ⇒ Struct
Deletes a subscription request in Amazon DataZone.
-
#delete_subscription_target(params = {}) ⇒ Struct
Deletes a subscription target in Amazon DataZone.
-
#delete_time_series_data_points(params = {}) ⇒ Struct
Deletes the specified time series form for the specified asset.
-
#disassociate_environment_role(params = {}) ⇒ Struct
Disassociates the environment role in Amazon DataZone.
-
#get_asset(params = {}) ⇒ Types::GetAssetOutput
Gets an Amazon DataZone asset.
-
#get_asset_type(params = {}) ⇒ Types::GetAssetTypeOutput
Gets an Amazon DataZone asset type.
-
#get_data_source(params = {}) ⇒ Types::GetDataSourceOutput
Gets an Amazon DataZone data source.
-
#get_data_source_run(params = {}) ⇒ Types::GetDataSourceRunOutput
Gets an Amazon DataZone data source run.
-
#get_domain(params = {}) ⇒ Types::GetDomainOutput
Gets an Amazon DataZone domain.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Gets an Amazon DataZone environment.
-
#get_environment_action(params = {}) ⇒ Types::GetEnvironmentActionOutput
Gets the specified environment action.
-
#get_environment_blueprint(params = {}) ⇒ Types::GetEnvironmentBlueprintOutput
Gets an Amazon DataZone blueprint.
-
#get_environment_blueprint_configuration(params = {}) ⇒ Types::GetEnvironmentBlueprintConfigurationOutput
Gets the blueprint configuration in Amazon DataZone.
-
#get_environment_profile(params = {}) ⇒ Types::GetEnvironmentProfileOutput
Gets an evinronment profile in Amazon DataZone.
-
#get_form_type(params = {}) ⇒ Types::GetFormTypeOutput
Gets a metadata form type in Amazon DataZone.
-
#get_glossary(params = {}) ⇒ Types::GetGlossaryOutput
Gets a business glossary in Amazon DataZone.
-
#get_glossary_term(params = {}) ⇒ Types::GetGlossaryTermOutput
Gets a business glossary term in Amazon DataZone.
-
#get_group_profile(params = {}) ⇒ Types::GetGroupProfileOutput
Gets a group profile in Amazon DataZone.
-
#get_iam_portal_login_url(params = {}) ⇒ Types::GetIamPortalLoginUrlOutput
Gets the data portal URL for the specified Amazon DataZone domain.
-
#get_lineage_node(params = {}) ⇒ Types::GetLineageNodeOutput
Gets the data lineage node.
-
#get_listing(params = {}) ⇒ Types::GetListingOutput
Gets a listing (a record of an asset at a given time).
-
#get_metadata_generation_run(params = {}) ⇒ Types::GetMetadataGenerationRunOutput
Gets a metadata generation run in Amazon DataZone.
-
#get_project(params = {}) ⇒ Types::GetProjectOutput
Gets a project in Amazon DataZone.
-
#get_subscription(params = {}) ⇒ Types::GetSubscriptionOutput
Gets a subscription in Amazon DataZone.
-
#get_subscription_grant(params = {}) ⇒ Types::GetSubscriptionGrantOutput
Gets the subscription grant in Amazon DataZone.
-
#get_subscription_request_details(params = {}) ⇒ Types::GetSubscriptionRequestDetailsOutput
Gets the details of the specified subscription request.
-
#get_subscription_target(params = {}) ⇒ Types::GetSubscriptionTargetOutput
Gets the subscription target in Amazon DataZone.
-
#get_time_series_data_point(params = {}) ⇒ Types::GetTimeSeriesDataPointOutput
Gets the existing data point for the asset.
-
#get_user_profile(params = {}) ⇒ Types::GetUserProfileOutput
Gets a user profile in Amazon DataZone.
-
#list_asset_revisions(params = {}) ⇒ Types::ListAssetRevisionsOutput
Lists the revisions for the asset.
-
#list_data_source_run_activities(params = {}) ⇒ Types::ListDataSourceRunActivitiesOutput
Lists data source run activities.
-
#list_data_source_runs(params = {}) ⇒ Types::ListDataSourceRunsOutput
Lists data source runs in Amazon DataZone.
-
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesOutput
Lists data sources in Amazon DataZone.
-
#list_domains(params = {}) ⇒ Types::ListDomainsOutput
Lists Amazon DataZone domains.
-
#list_environment_actions(params = {}) ⇒ Types::ListEnvironmentActionsOutput
Lists existing environment actions.
-
#list_environment_blueprint_configurations(params = {}) ⇒ Types::ListEnvironmentBlueprintConfigurationsOutput
Lists blueprint configurations for a Amazon DataZone environment.
-
#list_environment_blueprints(params = {}) ⇒ Types::ListEnvironmentBlueprintsOutput
Lists blueprints in an Amazon DataZone environment.
-
#list_environment_profiles(params = {}) ⇒ Types::ListEnvironmentProfilesOutput
Lists Amazon DataZone environment profiles.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists Amazon DataZone environments.
-
#list_lineage_node_history(params = {}) ⇒ Types::ListLineageNodeHistoryOutput
Lists the history of the specified data lineage node.
-
#list_metadata_generation_runs(params = {}) ⇒ Types::ListMetadataGenerationRunsOutput
Lists all metadata generation runs.
-
#list_notifications(params = {}) ⇒ Types::ListNotificationsOutput
Lists all Amazon DataZone notifications.
-
#list_project_memberships(params = {}) ⇒ Types::ListProjectMembershipsOutput
Lists all members of the specified project.
-
#list_projects(params = {}) ⇒ Types::ListProjectsOutput
Lists Amazon DataZone projects.
-
#list_subscription_grants(params = {}) ⇒ Types::ListSubscriptionGrantsOutput
Lists subscription grants.
-
#list_subscription_requests(params = {}) ⇒ Types::ListSubscriptionRequestsOutput
Lists Amazon DataZone subscription requests.
-
#list_subscription_targets(params = {}) ⇒ Types::ListSubscriptionTargetsOutput
Lists subscription targets in Amazon DataZone.
-
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsOutput
Lists subscriptions in Amazon DataZone.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified resource in Amazon DataZone.
-
#list_time_series_data_points(params = {}) ⇒ Types::ListTimeSeriesDataPointsOutput
Lists time series data points.
-
#post_lineage_event(params = {}) ⇒ Struct
Posts a data lineage event.
-
#post_time_series_data_points(params = {}) ⇒ Types::PostTimeSeriesDataPointsOutput
Posts time series data points to Amazon DataZone for the specified asset.
-
#put_environment_blueprint_configuration(params = {}) ⇒ Types::PutEnvironmentBlueprintConfigurationOutput
Writes the configuration for the specified environment blueprint in Amazon DataZone.
-
#reject_predictions(params = {}) ⇒ Types::RejectPredictionsOutput
Rejects automatically generated business-friendly metadata for your Amazon DataZone assets.
-
#reject_subscription_request(params = {}) ⇒ Types::RejectSubscriptionRequestOutput
Rejects the specified subscription request.
-
#revoke_subscription(params = {}) ⇒ Types::RevokeSubscriptionOutput
Revokes a specified subscription in Amazon DataZone.
-
#search(params = {}) ⇒ Types::SearchOutput
Searches for assets in Amazon DataZone.
-
#search_group_profiles(params = {}) ⇒ Types::SearchGroupProfilesOutput
Searches group profiles in Amazon DataZone.
-
#search_listings(params = {}) ⇒ Types::SearchListingsOutput
Searches listings (records of an asset at a given time) in Amazon DataZone.
-
#search_types(params = {}) ⇒ Types::SearchTypesOutput
Searches for types in Amazon DataZone.
-
#search_user_profiles(params = {}) ⇒ Types::SearchUserProfilesOutput
Searches user profiles in Amazon DataZone.
-
#start_data_source_run(params = {}) ⇒ Types::StartDataSourceRunOutput
Start the run of the specified data source in Amazon DataZone.
-
#start_metadata_generation_run(params = {}) ⇒ Types::StartMetadataGenerationRunOutput
Starts the metadata generation run.
-
#tag_resource(params = {}) ⇒ Struct
Tags a resource in Amazon DataZone.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource in Amazon DataZone.
-
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceOutput
Updates the specified data source in Amazon DataZone.
-
#update_domain(params = {}) ⇒ Types::UpdateDomainOutput
Updates a Amazon DataZone domain.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates the specified environment in Amazon DataZone.
-
#update_environment_action(params = {}) ⇒ Types::UpdateEnvironmentActionOutput
Updates an environment action.
-
#update_environment_profile(params = {}) ⇒ Types::UpdateEnvironmentProfileOutput
Updates the specified environment profile in Amazon DataZone.
-
#update_glossary(params = {}) ⇒ Types::UpdateGlossaryOutput
Updates the business glossary in Amazon DataZone.
-
#update_glossary_term(params = {}) ⇒ Types::UpdateGlossaryTermOutput
Updates a business glossary term in Amazon DataZone.
-
#update_group_profile(params = {}) ⇒ Types::UpdateGroupProfileOutput
Updates the specified group profile in Amazon DataZone.
-
#update_project(params = {}) ⇒ Types::UpdateProjectOutput
Updates the specified project in Amazon DataZone.
-
#update_subscription_grant_status(params = {}) ⇒ Types::UpdateSubscriptionGrantStatusOutput
Updates the status of the specified subscription grant status in Amazon DataZone.
-
#update_subscription_request(params = {}) ⇒ Types::UpdateSubscriptionRequestOutput
Updates a specified subscription request in Amazon DataZone.
-
#update_subscription_target(params = {}) ⇒ Types::UpdateSubscriptionTargetOutput
Updates the specified subscription target in Amazon DataZone.
-
#update_user_profile(params = {}) ⇒ Types::UpdateUserProfileOutput
Updates the specified user profile in Amazon DataZone.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
422 423 424 |
# File 'lib/aws-sdk-datazone/client.rb', line 422 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8477 8478 8479 |
# File 'lib/aws-sdk-datazone/client.rb', line 8477 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8480 8481 8482 |
# File 'lib/aws-sdk-datazone/client.rb', line 8480 def errors_module Errors end |
Instance Method Details
#accept_predictions(params = {}) ⇒ Types::AcceptPredictionsOutput
Accepts automatically generated business-friendly metadata for your Amazon DataZone assets.
492 493 494 495 |
# File 'lib/aws-sdk-datazone/client.rb', line 492 def accept_predictions(params = {}, = {}) req = build_request(:accept_predictions, params) req.send_request() end |
#accept_subscription_request(params = {}) ⇒ Types::AcceptSubscriptionRequestOutput
Accepts a subscription request to a specific asset.
568 569 570 571 |
# File 'lib/aws-sdk-datazone/client.rb', line 568 def accept_subscription_request(params = {}, = {}) req = build_request(:accept_subscription_request, params) req.send_request() end |
#associate_environment_role(params = {}) ⇒ Struct
Associates the environment role in Amazon DataZone.
599 600 601 602 |
# File 'lib/aws-sdk-datazone/client.rb', line 599 def associate_environment_role(params = {}, = {}) req = build_request(:associate_environment_role, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8455 8456 8457 8458 8459 8460 8461 8462 8463 8464 8465 8466 |
# File 'lib/aws-sdk-datazone/client.rb', line 8455 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-datazone' context[:gem_version] = '1.13.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_metadata_generation_run(params = {}) ⇒ Struct
Cancels the metadata generation run.
626 627 628 629 |
# File 'lib/aws-sdk-datazone/client.rb', line 626 def (params = {}, = {}) req = build_request(:cancel_metadata_generation_run, params) req.send_request() end |
#cancel_subscription(params = {}) ⇒ Types::CancelSubscriptionOutput
Cancels the subscription to the specified asset.
692 693 694 695 |
# File 'lib/aws-sdk-datazone/client.rb', line 692 def cancel_subscription(params = {}, = {}) req = build_request(:cancel_subscription, params) req.send_request() end |
#create_asset(params = {}) ⇒ Types::CreateAssetOutput
Creates an asset in Amazon DataZone catalog.
828 829 830 831 |
# File 'lib/aws-sdk-datazone/client.rb', line 828 def create_asset(params = {}, = {}) req = build_request(:create_asset, params) req.send_request() end |
#create_asset_revision(params = {}) ⇒ Types::CreateAssetRevisionOutput
Creates a revision of the asset.
958 959 960 961 |
# File 'lib/aws-sdk-datazone/client.rb', line 958 def create_asset_revision(params = {}, = {}) req = build_request(:create_asset_revision, params) req.send_request() end |
#create_asset_type(params = {}) ⇒ Types::CreateAssetTypeOutput
Creates a custom asset type.
1035 1036 1037 1038 |
# File 'lib/aws-sdk-datazone/client.rb', line 1035 def create_asset_type(params = {}, = {}) req = build_request(:create_asset_type, params) req.send_request() end |
#create_data_source(params = {}) ⇒ Types::CreateDataSourceOutput
Creates an Amazon DataZone data source.
1242 1243 1244 1245 |
# File 'lib/aws-sdk-datazone/client.rb', line 1242 def create_data_source(params = {}, = {}) req = build_request(:create_data_source, params) req.send_request() end |
#create_domain(params = {}) ⇒ Types::CreateDomainOutput
Creates an Amazon DataZone domain.
1327 1328 1329 1330 |
# File 'lib/aws-sdk-datazone/client.rb', line 1327 def create_domain(params = {}, = {}) req = build_request(:create_domain, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Create an Amazon DataZone environment.
1464 1465 1466 1467 |
# File 'lib/aws-sdk-datazone/client.rb', line 1464 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#create_environment_action(params = {}) ⇒ Types::CreateEnvironmentActionOutput
Creates an action for the environment, for example, creates a console link for an analytics tool that is available in this environment.
1525 1526 1527 1528 |
# File 'lib/aws-sdk-datazone/client.rb', line 1525 def create_environment_action(params = {}, = {}) req = build_request(:create_environment_action, params) req.send_request() end |
#create_environment_profile(params = {}) ⇒ Types::CreateEnvironmentProfileOutput
Creates an Amazon DataZone environment profile.
1619 1620 1621 1622 |
# File 'lib/aws-sdk-datazone/client.rb', line 1619 def create_environment_profile(params = {}, = {}) req = build_request(:create_environment_profile, params) req.send_request() end |
#create_form_type(params = {}) ⇒ Types::CreateFormTypeOutput
Creates a metadata form type.
1683 1684 1685 1686 |
# File 'lib/aws-sdk-datazone/client.rb', line 1683 def create_form_type(params = {}, = {}) req = build_request(:create_form_type, params) req.send_request() end |
#create_glossary(params = {}) ⇒ Types::CreateGlossaryOutput
Creates an Amazon DataZone business glossary.
1746 1747 1748 1749 |
# File 'lib/aws-sdk-datazone/client.rb', line 1746 def create_glossary(params = {}, = {}) req = build_request(:create_glossary, params) req.send_request() end |
#create_glossary_term(params = {}) ⇒ Types::CreateGlossaryTermOutput
Creates a business glossary term.
1827 1828 1829 1830 |
# File 'lib/aws-sdk-datazone/client.rb', line 1827 def create_glossary_term(params = {}, = {}) req = build_request(:create_glossary_term, params) req.send_request() end |
#create_group_profile(params = {}) ⇒ Types::CreateGroupProfileOutput
Creates a group profile in Amazon DataZone.
1874 1875 1876 1877 |
# File 'lib/aws-sdk-datazone/client.rb', line 1874 def create_group_profile(params = {}, = {}) req = build_request(:create_group_profile, params) req.send_request() end |
#create_listing_change_set(params = {}) ⇒ Types::CreateListingChangeSetOutput
Publishes a listing (a record of an asset at a given time) or removes a listing from the catalog.
1931 1932 1933 1934 |
# File 'lib/aws-sdk-datazone/client.rb', line 1931 def create_listing_change_set(params = {}, = {}) req = build_request(:create_listing_change_set, params) req.send_request() end |
#create_project(params = {}) ⇒ Types::CreateProjectOutput
Creates an Amazon DataZone project.
1992 1993 1994 1995 |
# File 'lib/aws-sdk-datazone/client.rb', line 1992 def create_project(params = {}, = {}) req = build_request(:create_project, params) req.send_request() end |
#create_project_membership(params = {}) ⇒ Struct
Creates a project membership in Amazon DataZone.
2030 2031 2032 2033 |
# File 'lib/aws-sdk-datazone/client.rb', line 2030 def create_project_membership(params = {}, = {}) req = build_request(:create_project_membership, params) req.send_request() end |
#create_subscription_grant(params = {}) ⇒ Types::CreateSubscriptionGrantOutput
Creates a subsscription grant in Amazon DataZone.
2122 2123 2124 2125 |
# File 'lib/aws-sdk-datazone/client.rb', line 2122 def create_subscription_grant(params = {}, = {}) req = build_request(:create_subscription_grant, params) req.send_request() end |
#create_subscription_request(params = {}) ⇒ Types::CreateSubscriptionRequestOutput
Creates a subscription request in Amazon DataZone.
2219 2220 2221 2222 |
# File 'lib/aws-sdk-datazone/client.rb', line 2219 def create_subscription_request(params = {}, = {}) req = build_request(:create_subscription_request, params) req.send_request() end |
#create_subscription_target(params = {}) ⇒ Types::CreateSubscriptionTargetOutput
Creates a subscription target in Amazon DataZone.
2325 2326 2327 2328 |
# File 'lib/aws-sdk-datazone/client.rb', line 2325 def create_subscription_target(params = {}, = {}) req = build_request(:create_subscription_target, params) req.send_request() end |
#create_user_profile(params = {}) ⇒ Types::CreateUserProfileOutput
Creates a user profile in Amazon DataZone.
2381 2382 2383 2384 |
# File 'lib/aws-sdk-datazone/client.rb', line 2381 def create_user_profile(params = {}, = {}) req = build_request(:create_user_profile, params) req.send_request() end |
#delete_asset(params = {}) ⇒ Struct
Delets an asset in Amazon DataZone.
2407 2408 2409 2410 |
# File 'lib/aws-sdk-datazone/client.rb', line 2407 def delete_asset(params = {}, = {}) req = build_request(:delete_asset, params) req.send_request() end |
#delete_asset_type(params = {}) ⇒ Struct
Deletes an asset type in Amazon DataZone.
2434 2435 2436 2437 |
# File 'lib/aws-sdk-datazone/client.rb', line 2434 def delete_asset_type(params = {}, = {}) req = build_request(:delete_asset_type, params) req.send_request() end |
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceOutput
Deletes a data source in Amazon DataZone.
2557 2558 2559 2560 |
# File 'lib/aws-sdk-datazone/client.rb', line 2557 def delete_data_source(params = {}, = {}) req = build_request(:delete_data_source, params) req.send_request() end |
#delete_domain(params = {}) ⇒ Types::DeleteDomainOutput
Deletes a Amazon DataZone domain.
2599 2600 2601 2602 |
# File 'lib/aws-sdk-datazone/client.rb', line 2599 def delete_domain(params = {}, = {}) req = build_request(:delete_domain, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Struct
Deletes an environment in Amazon DataZone.
2626 2627 2628 2629 |
# File 'lib/aws-sdk-datazone/client.rb', line 2626 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#delete_environment_action(params = {}) ⇒ Struct
Deletes an action for the environment, for example, deletes a console link for an analytics tool that is available in this environment.
2658 2659 2660 2661 |
# File 'lib/aws-sdk-datazone/client.rb', line 2658 def delete_environment_action(params = {}, = {}) req = build_request(:delete_environment_action, params) req.send_request() end |
#delete_environment_blueprint_configuration(params = {}) ⇒ Struct
Deletes the blueprint configuration in Amazon DataZone.
2685 2686 2687 2688 |
# File 'lib/aws-sdk-datazone/client.rb', line 2685 def delete_environment_blueprint_configuration(params = {}, = {}) req = build_request(:delete_environment_blueprint_configuration, params) req.send_request() end |
#delete_environment_profile(params = {}) ⇒ Struct
Deletes an environment profile in Amazon DataZone.
2712 2713 2714 2715 |
# File 'lib/aws-sdk-datazone/client.rb', line 2712 def delete_environment_profile(params = {}, = {}) req = build_request(:delete_environment_profile, params) req.send_request() end |
#delete_form_type(params = {}) ⇒ Struct
Delets and metadata form type in Amazon DataZone.
2739 2740 2741 2742 |
# File 'lib/aws-sdk-datazone/client.rb', line 2739 def delete_form_type(params = {}, = {}) req = build_request(:delete_form_type, params) req.send_request() end |
#delete_glossary(params = {}) ⇒ Struct
Deletes a business glossary in Amazon DataZone.
2766 2767 2768 2769 |
# File 'lib/aws-sdk-datazone/client.rb', line 2766 def delete_glossary(params = {}, = {}) req = build_request(:delete_glossary, params) req.send_request() end |
#delete_glossary_term(params = {}) ⇒ Struct
Deletes a business glossary term in Amazon DataZone.
2793 2794 2795 2796 |
# File 'lib/aws-sdk-datazone/client.rb', line 2793 def delete_glossary_term(params = {}, = {}) req = build_request(:delete_glossary_term, params) req.send_request() end |
#delete_listing(params = {}) ⇒ Struct
Deletes a listing (a record of an asset at a given time).
2819 2820 2821 2822 |
# File 'lib/aws-sdk-datazone/client.rb', line 2819 def delete_listing(params = {}, = {}) req = build_request(:delete_listing, params) req.send_request() end |
#delete_project(params = {}) ⇒ Struct
Deletes a project in Amazon DataZone.
2850 2851 2852 2853 |
# File 'lib/aws-sdk-datazone/client.rb', line 2850 def delete_project(params = {}, = {}) req = build_request(:delete_project, params) req.send_request() end |
#delete_project_membership(params = {}) ⇒ Struct
Deletes project membership in Amazon DataZone.
2885 2886 2887 2888 |
# File 'lib/aws-sdk-datazone/client.rb', line 2885 def delete_project_membership(params = {}, = {}) req = build_request(:delete_project_membership, params) req.send_request() end |
#delete_subscription_grant(params = {}) ⇒ Types::DeleteSubscriptionGrantOutput
Deletes and subscription grant in Amazon DataZone.
2946 2947 2948 2949 |
# File 'lib/aws-sdk-datazone/client.rb', line 2946 def delete_subscription_grant(params = {}, = {}) req = build_request(:delete_subscription_grant, params) req.send_request() end |
#delete_subscription_request(params = {}) ⇒ Struct
Deletes a subscription request in Amazon DataZone.
2973 2974 2975 2976 |
# File 'lib/aws-sdk-datazone/client.rb', line 2973 def delete_subscription_request(params = {}, = {}) req = build_request(:delete_subscription_request, params) req.send_request() end |
#delete_subscription_target(params = {}) ⇒ Struct
Deletes a subscription target in Amazon DataZone.
3005 3006 3007 3008 |
# File 'lib/aws-sdk-datazone/client.rb', line 3005 def delete_subscription_target(params = {}, = {}) req = build_request(:delete_subscription_target, params) req.send_request() end |
#delete_time_series_data_points(params = {}) ⇒ Struct
Deletes the specified time series form for the specified asset.
3048 3049 3050 3051 |
# File 'lib/aws-sdk-datazone/client.rb', line 3048 def delete_time_series_data_points(params = {}, = {}) req = build_request(:delete_time_series_data_points, params) req.send_request() end |
#disassociate_environment_role(params = {}) ⇒ Struct
Disassociates the environment role in Amazon DataZone.
3079 3080 3081 3082 |
# File 'lib/aws-sdk-datazone/client.rb', line 3079 def disassociate_environment_role(params = {}, = {}) req = build_request(:disassociate_environment_role, params) req.send_request() end |
#get_asset(params = {}) ⇒ Types::GetAssetOutput
Gets an Amazon DataZone asset.
3165 3166 3167 3168 |
# File 'lib/aws-sdk-datazone/client.rb', line 3165 def get_asset(params = {}, = {}) req = build_request(:get_asset, params) req.send_request() end |
#get_asset_type(params = {}) ⇒ Types::GetAssetTypeOutput
Gets an Amazon DataZone asset type.
3226 3227 3228 3229 |
# File 'lib/aws-sdk-datazone/client.rb', line 3226 def get_asset_type(params = {}, = {}) req = build_request(:get_asset_type, params) req.send_request() end |
#get_data_source(params = {}) ⇒ Types::GetDataSourceOutput
Gets an Amazon DataZone data source.
3337 3338 3339 3340 |
# File 'lib/aws-sdk-datazone/client.rb', line 3337 def get_data_source(params = {}, = {}) req = build_request(:get_data_source, params) req.send_request() end |
#get_data_source_run(params = {}) ⇒ Types::GetDataSourceRunOutput
Gets an Amazon DataZone data source run.
3398 3399 3400 3401 |
# File 'lib/aws-sdk-datazone/client.rb', line 3398 def get_data_source_run(params = {}, = {}) req = build_request(:get_data_source_run, params) req.send_request() end |
#get_domain(params = {}) ⇒ Types::GetDomainOutput
Gets an Amazon DataZone domain.
3450 3451 3452 3453 |
# File 'lib/aws-sdk-datazone/client.rb', line 3450 def get_domain(params = {}, = {}) req = build_request(:get_domain, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Gets an Amazon DataZone environment.
3546 3547 3548 3549 |
# File 'lib/aws-sdk-datazone/client.rb', line 3546 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#get_environment_action(params = {}) ⇒ Types::GetEnvironmentActionOutput
Gets the specified environment action.
3593 3594 3595 3596 |
# File 'lib/aws-sdk-datazone/client.rb', line 3593 def get_environment_action(params = {}, = {}) req = build_request(:get_environment_action, params) req.send_request() end |
#get_environment_blueprint(params = {}) ⇒ Types::GetEnvironmentBlueprintOutput
Gets an Amazon DataZone blueprint.
3651 3652 3653 3654 |
# File 'lib/aws-sdk-datazone/client.rb', line 3651 def get_environment_blueprint(params = {}, = {}) req = build_request(:get_environment_blueprint, params) req.send_request() end |
#get_environment_blueprint_configuration(params = {}) ⇒ Types::GetEnvironmentBlueprintConfigurationOutput
Gets the blueprint configuration in Amazon DataZone.
3700 3701 3702 3703 |
# File 'lib/aws-sdk-datazone/client.rb', line 3700 def get_environment_blueprint_configuration(params = {}, = {}) req = build_request(:get_environment_blueprint_configuration, params) req.send_request() end |
#get_environment_profile(params = {}) ⇒ Types::GetEnvironmentProfileOutput
Gets an evinronment profile in Amazon DataZone.
3761 3762 3763 3764 |
# File 'lib/aws-sdk-datazone/client.rb', line 3761 def get_environment_profile(params = {}, = {}) req = build_request(:get_environment_profile, params) req.send_request() end |
#get_form_type(params = {}) ⇒ Types::GetFormTypeOutput
Gets a metadata form type in Amazon DataZone.
3822 3823 3824 3825 |
# File 'lib/aws-sdk-datazone/client.rb', line 3822 def get_form_type(params = {}, = {}) req = build_request(:get_form_type, params) req.send_request() end |
#get_glossary(params = {}) ⇒ Types::GetGlossaryOutput
Gets a business glossary in Amazon DataZone.
3873 3874 3875 3876 |
# File 'lib/aws-sdk-datazone/client.rb', line 3873 def get_glossary(params = {}, = {}) req = build_request(:get_glossary, params) req.send_request() end |
#get_glossary_term(params = {}) ⇒ Types::GetGlossaryTermOutput
Gets a business glossary term in Amazon DataZone.
3931 3932 3933 3934 |
# File 'lib/aws-sdk-datazone/client.rb', line 3931 def get_glossary_term(params = {}, = {}) req = build_request(:get_glossary_term, params) req.send_request() end |
#get_group_profile(params = {}) ⇒ Types::GetGroupProfileOutput
Gets a group profile in Amazon DataZone.
3970 3971 3972 3973 |
# File 'lib/aws-sdk-datazone/client.rb', line 3970 def get_group_profile(params = {}, = {}) req = build_request(:get_group_profile, params) req.send_request() end |
#get_iam_portal_login_url(params = {}) ⇒ Types::GetIamPortalLoginUrlOutput
Gets the data portal URL for the specified Amazon DataZone domain.
4001 4002 4003 4004 |
# File 'lib/aws-sdk-datazone/client.rb', line 4001 def get_iam_portal_login_url(params = {}, = {}) req = build_request(:get_iam_portal_login_url, params) req.send_request() end |
#get_lineage_node(params = {}) ⇒ Types::GetLineageNodeOutput
Gets the data lineage node.
4079 4080 4081 4082 |
# File 'lib/aws-sdk-datazone/client.rb', line 4079 def get_lineage_node(params = {}, = {}) req = build_request(:get_lineage_node, params) req.send_request() end |
#get_listing(params = {}) ⇒ Types::GetListingOutput
Gets a listing (a record of an asset at a given time).
4150 4151 4152 4153 |
# File 'lib/aws-sdk-datazone/client.rb', line 4150 def get_listing(params = {}, = {}) req = build_request(:get_listing, params) req.send_request() end |
#get_metadata_generation_run(params = {}) ⇒ Types::GetMetadataGenerationRunOutput
Gets a metadata generation run in Amazon DataZone.
4199 4200 4201 4202 |
# File 'lib/aws-sdk-datazone/client.rb', line 4199 def (params = {}, = {}) req = build_request(:get_metadata_generation_run, params) req.send_request() end |
#get_project(params = {}) ⇒ Types::GetProjectOutput
Gets a project in Amazon DataZone.
4252 4253 4254 4255 |
# File 'lib/aws-sdk-datazone/client.rb', line 4252 def get_project(params = {}, = {}) req = build_request(:get_project, params) req.send_request() end |
#get_subscription(params = {}) ⇒ Types::GetSubscriptionOutput
Gets a subscription in Amazon DataZone.
4317 4318 4319 4320 |
# File 'lib/aws-sdk-datazone/client.rb', line 4317 def get_subscription(params = {}, = {}) req = build_request(:get_subscription, params) req.send_request() end |
#get_subscription_grant(params = {}) ⇒ Types::GetSubscriptionGrantOutput
Gets the subscription grant in Amazon DataZone.
4378 4379 4380 4381 |
# File 'lib/aws-sdk-datazone/client.rb', line 4378 def get_subscription_grant(params = {}, = {}) req = build_request(:get_subscription_grant, params) req.send_request() end |
#get_subscription_request_details(params = {}) ⇒ Types::GetSubscriptionRequestDetailsOutput
Gets the details of the specified subscription request.
4449 4450 4451 4452 |
# File 'lib/aws-sdk-datazone/client.rb', line 4449 def get_subscription_request_details(params = {}, = {}) req = build_request(:get_subscription_request_details, params) req.send_request() end |
#get_subscription_target(params = {}) ⇒ Types::GetSubscriptionTargetOutput
Gets the subscription target in Amazon DataZone.
4518 4519 4520 4521 |
# File 'lib/aws-sdk-datazone/client.rb', line 4518 def get_subscription_target(params = {}, = {}) req = build_request(:get_subscription_target, params) req.send_request() end |
#get_time_series_data_point(params = {}) ⇒ Types::GetTimeSeriesDataPointOutput
Gets the existing data point for the asset.
4577 4578 4579 4580 |
# File 'lib/aws-sdk-datazone/client.rb', line 4577 def get_time_series_data_point(params = {}, = {}) req = build_request(:get_time_series_data_point, params) req.send_request() end |
#get_user_profile(params = {}) ⇒ Types::GetUserProfileOutput
Gets a user profile in Amazon DataZone.
4625 4626 4627 4628 |
# File 'lib/aws-sdk-datazone/client.rb', line 4625 def get_user_profile(params = {}, = {}) req = build_request(:get_user_profile, params) req.send_request() end |
#list_asset_revisions(params = {}) ⇒ Types::ListAssetRevisionsOutput
Lists the revisions for the asset.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4683 4684 4685 4686 |
# File 'lib/aws-sdk-datazone/client.rb', line 4683 def list_asset_revisions(params = {}, = {}) req = build_request(:list_asset_revisions, params) req.send_request() end |
#list_data_source_run_activities(params = {}) ⇒ Types::ListDataSourceRunActivitiesOutput
Lists data source run activities.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4752 4753 4754 4755 |
# File 'lib/aws-sdk-datazone/client.rb', line 4752 def list_data_source_run_activities(params = {}, = {}) req = build_request(:list_data_source_run_activities, params) req.send_request() end |
#list_data_source_runs(params = {}) ⇒ Types::ListDataSourceRunsOutput
Lists data source runs in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4826 4827 4828 4829 |
# File 'lib/aws-sdk-datazone/client.rb', line 4826 def list_data_source_runs(params = {}, = {}) req = build_request(:list_data_source_runs, params) req.send_request() end |
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesOutput
Lists data sources in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4912 4913 4914 4915 |
# File 'lib/aws-sdk-datazone/client.rb', line 4912 def list_data_sources(params = {}, = {}) req = build_request(:list_data_sources, params) req.send_request() end |
#list_domains(params = {}) ⇒ Types::ListDomainsOutput
Lists Amazon DataZone domains.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4970 4971 4972 4973 |
# File 'lib/aws-sdk-datazone/client.rb', line 4970 def list_domains(params = {}, = {}) req = build_request(:list_domains, params) req.send_request() end |
#list_environment_actions(params = {}) ⇒ Types::ListEnvironmentActionsOutput
Lists existing environment actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5030 5031 5032 5033 |
# File 'lib/aws-sdk-datazone/client.rb', line 5030 def list_environment_actions(params = {}, = {}) req = build_request(:list_environment_actions, params) req.send_request() end |
#list_environment_blueprint_configurations(params = {}) ⇒ Types::ListEnvironmentBlueprintConfigurationsOutput
Lists blueprint configurations for a Amazon DataZone environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5092 5093 5094 5095 |
# File 'lib/aws-sdk-datazone/client.rb', line 5092 def list_environment_blueprint_configurations(params = {}, = {}) req = build_request(:list_environment_blueprint_configurations, params) req.send_request() end |
#list_environment_blueprints(params = {}) ⇒ Types::ListEnvironmentBlueprintsOutput
Lists blueprints in an Amazon DataZone environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5158 5159 5160 5161 |
# File 'lib/aws-sdk-datazone/client.rb', line 5158 def list_environment_blueprints(params = {}, = {}) req = build_request(:list_environment_blueprints, params) req.send_request() end |
#list_environment_profiles(params = {}) ⇒ Types::ListEnvironmentProfilesOutput
Lists Amazon DataZone environment profiles.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5242 5243 5244 5245 |
# File 'lib/aws-sdk-datazone/client.rb', line 5242 def list_environment_profiles(params = {}, = {}) req = build_request(:list_environment_profiles, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists Amazon DataZone environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5337 5338 5339 5340 |
# File 'lib/aws-sdk-datazone/client.rb', line 5337 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_lineage_node_history(params = {}) ⇒ Types::ListLineageNodeHistoryOutput
Lists the history of the specified data lineage node.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5424 5425 5426 5427 |
# File 'lib/aws-sdk-datazone/client.rb', line 5424 def list_lineage_node_history(params = {}, = {}) req = build_request(:list_lineage_node_history, params) req.send_request() end |
#list_metadata_generation_runs(params = {}) ⇒ Types::ListMetadataGenerationRunsOutput
Lists all metadata generation runs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5493 5494 5495 5496 |
# File 'lib/aws-sdk-datazone/client.rb', line 5493 def (params = {}, = {}) req = build_request(:list_metadata_generation_runs, params) req.send_request() end |
#list_notifications(params = {}) ⇒ Types::ListNotificationsOutput
Lists all Amazon DataZone notifications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5578 5579 5580 5581 |
# File 'lib/aws-sdk-datazone/client.rb', line 5578 def list_notifications(params = {}, = {}) req = build_request(:list_notifications, params) req.send_request() end |
#list_project_memberships(params = {}) ⇒ Types::ListProjectMembershipsOutput
Lists all members of the specified project.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5643 5644 5645 5646 |
# File 'lib/aws-sdk-datazone/client.rb', line 5643 def list_project_memberships(params = {}, = {}) req = build_request(:list_project_memberships, params) req.send_request() end |
#list_projects(params = {}) ⇒ Types::ListProjectsOutput
Lists Amazon DataZone projects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5715 5716 5717 5718 |
# File 'lib/aws-sdk-datazone/client.rb', line 5715 def list_projects(params = {}, = {}) req = build_request(:list_projects, params) req.send_request() end |
#list_subscription_grants(params = {}) ⇒ Types::ListSubscriptionGrantsOutput
Lists subscription grants.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5807 5808 5809 5810 |
# File 'lib/aws-sdk-datazone/client.rb', line 5807 def list_subscription_grants(params = {}, = {}) req = build_request(:list_subscription_grants, params) req.send_request() end |
#list_subscription_requests(params = {}) ⇒ Types::ListSubscriptionRequestsOutput
Lists Amazon DataZone subscription requests.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5909 5910 5911 5912 |
# File 'lib/aws-sdk-datazone/client.rb', line 5909 def list_subscription_requests(params = {}, = {}) req = build_request(:list_subscription_requests, params) req.send_request() end |
#list_subscription_targets(params = {}) ⇒ Types::ListSubscriptionTargetsOutput
Lists subscription targets in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5994 5995 5996 5997 |
# File 'lib/aws-sdk-datazone/client.rb', line 5994 def list_subscription_targets(params = {}, = {}) req = build_request(:list_subscription_targets, params) req.send_request() end |
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsOutput
Lists subscriptions in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6098 6099 6100 6101 |
# File 'lib/aws-sdk-datazone/client.rb', line 6098 def list_subscriptions(params = {}, = {}) req = build_request(:list_subscriptions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified resource in Amazon DataZone.
6127 6128 6129 6130 |
# File 'lib/aws-sdk-datazone/client.rb', line 6127 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_time_series_data_points(params = {}) ⇒ Types::ListTimeSeriesDataPointsOutput
Lists time series data points.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6203 6204 6205 6206 |
# File 'lib/aws-sdk-datazone/client.rb', line 6203 def list_time_series_data_points(params = {}, = {}) req = build_request(:list_time_series_data_points, params) req.send_request() end |
#post_lineage_event(params = {}) ⇒ Struct
Posts a data lineage event.
6238 6239 6240 6241 |
# File 'lib/aws-sdk-datazone/client.rb', line 6238 def post_lineage_event(params = {}, = {}) req = build_request(:post_lineage_event, params) req.send_request() end |
#post_time_series_data_points(params = {}) ⇒ Types::PostTimeSeriesDataPointsOutput
Posts time series data points to Amazon DataZone for the specified asset.
6309 6310 6311 6312 |
# File 'lib/aws-sdk-datazone/client.rb', line 6309 def post_time_series_data_points(params = {}, = {}) req = build_request(:post_time_series_data_points, params) req.send_request() end |
#put_environment_blueprint_configuration(params = {}) ⇒ Types::PutEnvironmentBlueprintConfigurationOutput
Writes the configuration for the specified environment blueprint in Amazon DataZone.
6379 6380 6381 6382 |
# File 'lib/aws-sdk-datazone/client.rb', line 6379 def put_environment_blueprint_configuration(params = {}, = {}) req = build_request(:put_environment_blueprint_configuration, params) req.send_request() end |
#reject_predictions(params = {}) ⇒ Types::RejectPredictionsOutput
Rejects automatically generated business-friendly metadata for your Amazon DataZone assets.
6447 6448 6449 6450 |
# File 'lib/aws-sdk-datazone/client.rb', line 6447 def reject_predictions(params = {}, = {}) req = build_request(:reject_predictions, params) req.send_request() end |
#reject_subscription_request(params = {}) ⇒ Types::RejectSubscriptionRequestOutput
Rejects the specified subscription request.
6521 6522 6523 6524 |
# File 'lib/aws-sdk-datazone/client.rb', line 6521 def reject_subscription_request(params = {}, = {}) req = build_request(:reject_subscription_request, params) req.send_request() end |
#revoke_subscription(params = {}) ⇒ Types::RevokeSubscriptionOutput
Revokes a specified subscription in Amazon DataZone.
6592 6593 6594 6595 |
# File 'lib/aws-sdk-datazone/client.rb', line 6592 def revoke_subscription(params = {}, = {}) req = build_request(:revoke_subscription, params) req.send_request() end |
#search(params = {}) ⇒ Types::SearchOutput
Searches for assets in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6762 6763 6764 6765 |
# File 'lib/aws-sdk-datazone/client.rb', line 6762 def search(params = {}, = {}) req = build_request(:search, params) req.send_request() end |
#search_group_profiles(params = {}) ⇒ Types::SearchGroupProfilesOutput
Searches group profiles in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6824 6825 6826 6827 |
# File 'lib/aws-sdk-datazone/client.rb', line 6824 def search_group_profiles(params = {}, = {}) req = build_request(:search_group_profiles, params) req.send_request() end |
#search_listings(params = {}) ⇒ Types::SearchListingsOutput
Searches listings (records of an asset at a given time) in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6940 6941 6942 6943 |
# File 'lib/aws-sdk-datazone/client.rb', line 6940 def search_listings(params = {}, = {}) req = build_request(:search_listings, params) req.send_request() end |
#search_types(params = {}) ⇒ Types::SearchTypesOutput
Searches for types in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
7079 7080 7081 7082 |
# File 'lib/aws-sdk-datazone/client.rb', line 7079 def search_types(params = {}, = {}) req = build_request(:search_types, params) req.send_request() end |
#search_user_profiles(params = {}) ⇒ Types::SearchUserProfilesOutput
Searches user profiles in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
7145 7146 7147 7148 |
# File 'lib/aws-sdk-datazone/client.rb', line 7145 def search_user_profiles(params = {}, = {}) req = build_request(:search_user_profiles, params) req.send_request() end |
#start_data_source_run(params = {}) ⇒ Types::StartDataSourceRunOutput
Start the run of the specified data source in Amazon DataZone.
7215 7216 7217 7218 |
# File 'lib/aws-sdk-datazone/client.rb', line 7215 def start_data_source_run(params = {}, = {}) req = build_request(:start_data_source_run, params) req.send_request() end |
#start_metadata_generation_run(params = {}) ⇒ Types::StartMetadataGenerationRunOutput
Starts the metadata generation run.
7281 7282 7283 7284 |
# File 'lib/aws-sdk-datazone/client.rb', line 7281 def (params = {}, = {}) req = build_request(:start_metadata_generation_run, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags a resource in Amazon DataZone.
7309 7310 7311 7312 |
# File 'lib/aws-sdk-datazone/client.rb', line 7309 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untags a resource in Amazon DataZone.
7335 7336 7337 7338 |
# File 'lib/aws-sdk-datazone/client.rb', line 7335 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceOutput
Updates the specified data source in Amazon DataZone.
7544 7545 7546 7547 |
# File 'lib/aws-sdk-datazone/client.rb', line 7544 def update_data_source(params = {}, = {}) req = build_request(:update_data_source, params) req.send_request() end |
#update_domain(params = {}) ⇒ Types::UpdateDomainOutput
Updates a Amazon DataZone domain.
7612 7613 7614 7615 |
# File 'lib/aws-sdk-datazone/client.rb', line 7612 def update_domain(params = {}, = {}) req = build_request(:update_domain, params) req.send_request() end |
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates the specified environment in Amazon DataZone.
7723 7724 7725 7726 |
# File 'lib/aws-sdk-datazone/client.rb', line 7723 def update_environment(params = {}, = {}) req = build_request(:update_environment, params) req.send_request() end |
#update_environment_action(params = {}) ⇒ Types::UpdateEnvironmentActionOutput
Updates an environment action.
7785 7786 7787 7788 |
# File 'lib/aws-sdk-datazone/client.rb', line 7785 def update_environment_action(params = {}, = {}) req = build_request(:update_environment_action, params) req.send_request() end |
#update_environment_profile(params = {}) ⇒ Types::UpdateEnvironmentProfileOutput
Updates the specified environment profile in Amazon DataZone.
7876 7877 7878 7879 |
# File 'lib/aws-sdk-datazone/client.rb', line 7876 def update_environment_profile(params = {}, = {}) req = build_request(:update_environment_profile, params) req.send_request() end |
#update_glossary(params = {}) ⇒ Types::UpdateGlossaryOutput
Updates the business glossary in Amazon DataZone.
7939 7940 7941 7942 |
# File 'lib/aws-sdk-datazone/client.rb', line 7939 def update_glossary(params = {}, = {}) req = build_request(:update_glossary, params) req.send_request() end |
#update_glossary_term(params = {}) ⇒ Types::UpdateGlossaryTermOutput
Updates a business glossary term in Amazon DataZone.
8020 8021 8022 8023 |
# File 'lib/aws-sdk-datazone/client.rb', line 8020 def update_glossary_term(params = {}, = {}) req = build_request(:update_glossary_term, params) req.send_request() end |
#update_group_profile(params = {}) ⇒ Types::UpdateGroupProfileOutput
Updates the specified group profile in Amazon DataZone.
8063 8064 8065 8066 |
# File 'lib/aws-sdk-datazone/client.rb', line 8063 def update_group_profile(params = {}, = {}) req = build_request(:update_group_profile, params) req.send_request() end |
#update_project(params = {}) ⇒ Types::UpdateProjectOutput
Updates the specified project in Amazon DataZone.
8130 8131 8132 8133 |
# File 'lib/aws-sdk-datazone/client.rb', line 8130 def update_project(params = {}, = {}) req = build_request(:update_project, params) req.send_request() end |
#update_subscription_grant_status(params = {}) ⇒ Types::UpdateSubscriptionGrantStatusOutput
Updates the status of the specified subscription grant status in Amazon DataZone.
8215 8216 8217 8218 |
# File 'lib/aws-sdk-datazone/client.rb', line 8215 def update_subscription_grant_status(params = {}, = {}) req = build_request(:update_subscription_grant_status, params) req.send_request() end |
#update_subscription_request(params = {}) ⇒ Types::UpdateSubscriptionRequestOutput
Updates a specified subscription request in Amazon DataZone.
8289 8290 8291 8292 |
# File 'lib/aws-sdk-datazone/client.rb', line 8289 def update_subscription_request(params = {}, = {}) req = build_request(:update_subscription_request, params) req.send_request() end |
#update_subscription_target(params = {}) ⇒ Types::UpdateSubscriptionTargetOutput
Updates the specified subscription target in Amazon DataZone.
8394 8395 8396 8397 |
# File 'lib/aws-sdk-datazone/client.rb', line 8394 def update_subscription_target(params = {}, = {}) req = build_request(:update_subscription_target, params) req.send_request() end |
#update_user_profile(params = {}) ⇒ Types::UpdateUserProfileOutput
Updates the specified user profile in Amazon DataZone.
8446 8447 8448 8449 |
# File 'lib/aws-sdk-datazone/client.rb', line 8446 def update_user_profile(params = {}, = {}) req = build_request(:update_user_profile, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8470 8471 8472 |
# File 'lib/aws-sdk-datazone/client.rb', line 8470 def waiter_names [] end |