Module: Aws::DataZone::Types

Defined in:
lib/aws-sdk-datazone/types.rb

Defined Under Namespace

Classes: AcceptChoice, AcceptPredictionsInput, AcceptPredictionsOutput, AcceptRule, AcceptSubscriptionRequestInput, AcceptSubscriptionRequestOutput, AccessDeniedException, ActionParameters, AssetItem, AssetItemAdditionalAttributes, AssetListing, AssetListingDetails, AssetListingItem, AssetListingItemAdditionalAttributes, AssetRevision, AssetTargetNameMap, AssetTypeItem, AssociateEnvironmentRoleInput, AssociateEnvironmentRoleOutput, AwsConsoleLinkParameters, BusinessNameGenerationConfiguration, CancelMetadataGenerationRunInput, CancelMetadataGenerationRunOutput, CancelSubscriptionInput, CancelSubscriptionOutput, CloudFormationProperties, ConfigurableActionParameter, ConfigurableEnvironmentAction, ConflictException, CreateAssetInput, CreateAssetOutput, CreateAssetRevisionInput, CreateAssetRevisionOutput, CreateAssetTypeInput, CreateAssetTypeOutput, CreateDataSourceInput, CreateDataSourceOutput, CreateDomainInput, CreateDomainOutput, CreateEnvironmentActionInput, CreateEnvironmentActionOutput, CreateEnvironmentInput, CreateEnvironmentOutput, CreateEnvironmentProfileInput, CreateEnvironmentProfileOutput, CreateFormTypeInput, CreateFormTypeOutput, CreateGlossaryInput, CreateGlossaryOutput, CreateGlossaryTermInput, CreateGlossaryTermOutput, CreateGroupProfileInput, CreateGroupProfileOutput, CreateListingChangeSetInput, CreateListingChangeSetOutput, CreateProjectInput, CreateProjectMembershipInput, CreateProjectMembershipOutput, CreateProjectOutput, CreateSubscriptionGrantInput, CreateSubscriptionGrantOutput, CreateSubscriptionRequestInput, CreateSubscriptionRequestOutput, CreateSubscriptionTargetInput, CreateSubscriptionTargetOutput, CreateUserProfileInput, CreateUserProfileOutput, CustomParameter, DataProductItem, DataProductSummary, DataSourceConfigurationInput, DataSourceConfigurationOutput, DataSourceErrorMessage, DataSourceRunActivity, DataSourceRunSummary, DataSourceSummary, DeleteAssetInput, DeleteAssetOutput, DeleteAssetTypeInput, DeleteAssetTypeOutput, DeleteDataSourceInput, DeleteDataSourceOutput, DeleteDomainInput, DeleteDomainOutput, DeleteEnvironmentActionInput, DeleteEnvironmentBlueprintConfigurationInput, DeleteEnvironmentBlueprintConfigurationOutput, DeleteEnvironmentInput, DeleteEnvironmentProfileInput, DeleteFormTypeInput, DeleteFormTypeOutput, DeleteGlossaryInput, DeleteGlossaryOutput, DeleteGlossaryTermInput, DeleteGlossaryTermOutput, DeleteListingInput, DeleteListingOutput, DeleteProjectInput, DeleteProjectMembershipInput, DeleteProjectMembershipOutput, DeleteProjectOutput, DeleteSubscriptionGrantInput, DeleteSubscriptionGrantOutput, DeleteSubscriptionRequestInput, DeleteSubscriptionTargetInput, DeleteTimeSeriesDataPointsInput, DeleteTimeSeriesDataPointsOutput, Deployment, DeploymentProperties, DetailedGlossaryTerm, DisassociateEnvironmentRoleInput, DisassociateEnvironmentRoleOutput, DomainSummary, EnvironmentActionSummary, EnvironmentBlueprintConfigurationItem, EnvironmentBlueprintSummary, EnvironmentError, EnvironmentParameter, EnvironmentProfileSummary, EnvironmentSummary, FailureCause, Filter, FilterClause, FilterExpression, FormEntryInput, FormEntryOutput, FormInput, FormOutput, FormTypeData, GetAssetInput, GetAssetOutput, GetAssetTypeInput, GetAssetTypeOutput, GetDataSourceInput, GetDataSourceOutput, GetDataSourceRunInput, GetDataSourceRunOutput, GetDomainInput, GetDomainOutput, GetEnvironmentActionInput, GetEnvironmentActionOutput, GetEnvironmentBlueprintConfigurationInput, GetEnvironmentBlueprintConfigurationOutput, GetEnvironmentBlueprintInput, GetEnvironmentBlueprintOutput, GetEnvironmentInput, GetEnvironmentOutput, GetEnvironmentProfileInput, GetEnvironmentProfileOutput, GetFormTypeInput, GetFormTypeOutput, GetGlossaryInput, GetGlossaryOutput, GetGlossaryTermInput, GetGlossaryTermOutput, GetGroupProfileInput, GetGroupProfileOutput, GetIamPortalLoginUrlInput, GetIamPortalLoginUrlOutput, GetLineageNodeInput, GetLineageNodeOutput, GetListingInput, GetListingOutput, GetMetadataGenerationRunInput, GetMetadataGenerationRunOutput, GetProjectInput, GetProjectOutput, GetSubscriptionGrantInput, GetSubscriptionGrantOutput, GetSubscriptionInput, GetSubscriptionOutput, GetSubscriptionRequestDetailsInput, GetSubscriptionRequestDetailsOutput, GetSubscriptionTargetInput, GetSubscriptionTargetOutput, GetTimeSeriesDataPointInput, GetTimeSeriesDataPointOutput, GetUserProfileInput, GetUserProfileOutput, GlossaryItem, GlossaryTermItem, GlueRunConfigurationInput, GlueRunConfigurationOutput, GlueSelfGrantStatusOutput, GrantedEntity, GrantedEntityInput, GroupDetails, GroupProfileSummary, IamUserProfileDetails, Import, InternalServerException, LineageNodeReference, LineageNodeSummary, LineageNodeTypeItem, ListAssetRevisionsInput, ListAssetRevisionsOutput, ListDataSourceRunActivitiesInput, ListDataSourceRunActivitiesOutput, ListDataSourceRunsInput, ListDataSourceRunsOutput, ListDataSourcesInput, ListDataSourcesOutput, ListDomainsInput, ListDomainsOutput, ListEnvironmentActionsInput, ListEnvironmentActionsOutput, ListEnvironmentBlueprintConfigurationsInput, ListEnvironmentBlueprintConfigurationsOutput, ListEnvironmentBlueprintsInput, ListEnvironmentBlueprintsOutput, ListEnvironmentProfilesInput, ListEnvironmentProfilesOutput, ListEnvironmentsInput, ListEnvironmentsOutput, ListLineageNodeHistoryInput, ListLineageNodeHistoryOutput, ListMetadataGenerationRunsInput, ListMetadataGenerationRunsOutput, ListNotificationsInput, ListNotificationsOutput, ListProjectMembershipsInput, ListProjectMembershipsOutput, ListProjectsInput, ListProjectsOutput, ListSubscriptionGrantsInput, ListSubscriptionGrantsOutput, ListSubscriptionRequestsInput, ListSubscriptionRequestsOutput, ListSubscriptionTargetsInput, ListSubscriptionTargetsOutput, ListSubscriptionsInput, ListSubscriptionsOutput, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTimeSeriesDataPointsInput, ListTimeSeriesDataPointsOutput, ListingItem, ListingRevision, ListingRevisionInput, Member, MemberDetails, MetadataGenerationRunItem, MetadataGenerationRunTarget, Model, NotificationOutput, NotificationResource, PostLineageEventInput, PostLineageEventOutput, PostTimeSeriesDataPointsInput, PostTimeSeriesDataPointsOutput, PredictionConfiguration, ProjectDeletionError, ProjectMember, ProjectSummary, ProvisioningProperties, PutEnvironmentBlueprintConfigurationInput, PutEnvironmentBlueprintConfigurationOutput, RecommendationConfiguration, RedshiftClusterStorage, RedshiftCredentialConfiguration, RedshiftRunConfigurationInput, RedshiftRunConfigurationOutput, RedshiftSelfGrantStatusOutput, RedshiftServerlessStorage, RedshiftStorage, RejectChoice, RejectPredictionsInput, RejectPredictionsOutput, RejectRule, RejectSubscriptionRequestInput, RejectSubscriptionRequestOutput, RelationalFilterConfiguration, Resource, ResourceNotFoundException, RevokeSubscriptionInput, RevokeSubscriptionOutput, RunStatisticsForAssets, ScheduleConfiguration, SearchGroupProfilesInput, SearchGroupProfilesOutput, SearchInItem, SearchInput, SearchInventoryResultItem, SearchListingsInput, SearchListingsOutput, SearchOutput, SearchResultItem, SearchSort, SearchTypesInput, SearchTypesOutput, SearchTypesResultItem, SearchUserProfilesInput, SearchUserProfilesOutput, SelfGrantStatusDetail, SelfGrantStatusOutput, ServiceQuotaExceededException, SingleSignOn, SsoUserProfileDetails, StartDataSourceRunInput, StartDataSourceRunOutput, StartMetadataGenerationRunInput, StartMetadataGenerationRunOutput, SubscribedAsset, SubscribedAssetListing, SubscribedListing, SubscribedListingInput, SubscribedListingItem, SubscribedPrincipal, SubscribedPrincipalInput, SubscribedProject, SubscribedProjectInput, SubscriptionGrantSummary, SubscriptionRequestSummary, SubscriptionSummary, SubscriptionTargetForm, SubscriptionTargetSummary, TagResourceRequest, TagResourceResponse, TermRelations, ThrottlingException, TimeSeriesDataPointFormInput, TimeSeriesDataPointFormOutput, TimeSeriesDataPointSummaryFormOutput, Topic, UnauthorizedException, UntagResourceRequest, UntagResourceResponse, UpdateDataSourceInput, UpdateDataSourceOutput, UpdateDomainInput, UpdateDomainOutput, UpdateEnvironmentActionInput, UpdateEnvironmentActionOutput, UpdateEnvironmentInput, UpdateEnvironmentOutput, UpdateEnvironmentProfileInput, UpdateEnvironmentProfileOutput, UpdateGlossaryInput, UpdateGlossaryOutput, UpdateGlossaryTermInput, UpdateGlossaryTermOutput, UpdateGroupProfileInput, UpdateGroupProfileOutput, UpdateProjectInput, UpdateProjectOutput, UpdateSubscriptionGrantStatusInput, UpdateSubscriptionGrantStatusOutput, UpdateSubscriptionRequestInput, UpdateSubscriptionRequestOutput, UpdateSubscriptionTargetInput, UpdateSubscriptionTargetOutput, UpdateUserProfileInput, UpdateUserProfileOutput, UserDetails, UserProfileDetails, UserProfileSummary, ValidationException

Instance Attribute Summary collapse

Instance Attribute Details

#andArray<Types::FilterClause>

The ‘and’ search filter clause in Amazon DataZone.

Returns:



4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
# File 'lib/aws-sdk-datazone/types.rb', line 4528

class FilterClause < Struct.new(
  :and,
  :filter,
  :or,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class And < FilterClause; end
  class Filter < FilterClause; end
  class Or < FilterClause; end
  class Unknown < FilterClause; end
end

#asset_itemTypes::AssetItem

The asset item included in the search results.

Returns:



10196
10197
10198
10199
10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
10211
# File 'lib/aws-sdk-datazone/types.rb', line 10196

class SearchInventoryResultItem < Struct.new(
  :asset_item,
  :data_product_item,
  :glossary_item,
  :glossary_term_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetItem < SearchInventoryResultItem; end
  class DataProductItem < SearchInventoryResultItem; end
  class GlossaryItem < SearchInventoryResultItem; end
  class GlossaryTermItem < SearchInventoryResultItem; end
  class Unknown < SearchInventoryResultItem; end
end

#asset_listingTypes::SubscribedAssetListing

The asset for which the subscription grant is created.



8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
# File 'lib/aws-sdk-datazone/types.rb', line 8823

class ListingItem < Struct.new(
  :asset_listing,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetListing < ListingItem; end
  class Unknown < ListingItem; end
end

#asset_type_itemTypes::AssetTypeItem

The asset type included in the results of the ‘SearchTypes` action.



10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
# File 'lib/aws-sdk-datazone/types.rb', line 10471

class SearchTypesResultItem < Struct.new(
  :asset_type_item,
  :form_type_item,
  :lineage_node_type_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetTypeItem < SearchTypesResultItem; end
  class FormTypeItem < SearchTypesResultItem; end
  class LineageNodeTypeItem < SearchTypesResultItem; end
  class Unknown < SearchTypesResultItem; end
end

The console link specified as part of the environment action.



252
253
254
255
256
257
258
259
260
261
# File 'lib/aws-sdk-datazone/types.rb', line 252

class ActionParameters < Struct.new(
  :aws_console_link,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AwsConsoleLink < ActionParameters; end
  class Unknown < ActionParameters; end
end

#cloud_formationTypes::CloudFormationProperties

The cloud formation properties included as part of the provisioning properties of an environment blueprint.



9335
9336
9337
9338
9339
9340
9341
9342
9343
9344
# File 'lib/aws-sdk-datazone/types.rb', line 9335

class ProvisioningProperties < Struct.new(
  :cloud_formation,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CloudFormation < ProvisioningProperties; end
  class Unknown < ProvisioningProperties; end
end

#data_product_itemTypes::DataProductSummary

The data product item included in the search results.



10196
10197
10198
10199
10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
10211
# File 'lib/aws-sdk-datazone/types.rb', line 10196

class SearchInventoryResultItem < Struct.new(
  :asset_item,
  :data_product_item,
  :glossary_item,
  :glossary_term_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetItem < SearchInventoryResultItem; end
  class DataProductItem < SearchInventoryResultItem; end
  class GlossaryItem < SearchInventoryResultItem; end
  class GlossaryTermItem < SearchInventoryResultItem; end
  class Unknown < SearchInventoryResultItem; end
end

#filterTypes::Filter

A search filter in Amazon DataZone.

Returns:



4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
# File 'lib/aws-sdk-datazone/types.rb', line 4528

class FilterClause < Struct.new(
  :and,
  :filter,
  :or,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class And < FilterClause; end
  class Filter < FilterClause; end
  class Or < FilterClause; end
  class Unknown < FilterClause; end
end

#form_type_itemTypes::FormTypeData

The form type included in the results of the ‘SearchTypes` action.

Returns:



10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
# File 'lib/aws-sdk-datazone/types.rb', line 10471

class SearchTypesResultItem < Struct.new(
  :asset_type_item,
  :form_type_item,
  :lineage_node_type_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetTypeItem < SearchTypesResultItem; end
  class FormTypeItem < SearchTypesResultItem; end
  class LineageNodeTypeItem < SearchTypesResultItem; end
  class Unknown < SearchTypesResultItem; end
end

#glossary_itemTypes::GlossaryItem

The glossary item included in the search results.

Returns:



10196
10197
10198
10199
10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
10211
# File 'lib/aws-sdk-datazone/types.rb', line 10196

class SearchInventoryResultItem < Struct.new(
  :asset_item,
  :data_product_item,
  :glossary_item,
  :glossary_term_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetItem < SearchInventoryResultItem; end
  class DataProductItem < SearchInventoryResultItem; end
  class GlossaryItem < SearchInventoryResultItem; end
  class GlossaryTermItem < SearchInventoryResultItem; end
  class Unknown < SearchInventoryResultItem; end
end

#glossary_term_itemTypes::GlossaryTermItem

The glossary term item included in the search results.



10196
10197
10198
10199
10200
10201
10202
10203
10204
10205
10206
10207
10208
10209
10210
10211
# File 'lib/aws-sdk-datazone/types.rb', line 10196

class SearchInventoryResultItem < Struct.new(
  :asset_item,
  :data_product_item,
  :glossary_item,
  :glossary_term_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetItem < SearchInventoryResultItem; end
  class DataProductItem < SearchInventoryResultItem; end
  class GlossaryItem < SearchInventoryResultItem; end
  class GlossaryTermItem < SearchInventoryResultItem; end
  class Unknown < SearchInventoryResultItem; end
end

#glue_run_configurationTypes::GlueRunConfigurationOutput

The configuration of the Amazon Web Services Glue data source.



3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
# File 'lib/aws-sdk-datazone/types.rb', line 3092

class DataSourceConfigurationInput < Struct.new(
  :glue_run_configuration,
  :redshift_run_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class GlueRunConfiguration < DataSourceConfigurationInput; end
  class RedshiftRunConfiguration < DataSourceConfigurationInput; end
  class Unknown < DataSourceConfigurationInput; end
end

#glue_self_grant_statusTypes::GlueSelfGrantStatusOutput

The details for the self granting status for a Glue data source.



10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
10604
10605
# File 'lib/aws-sdk-datazone/types.rb', line 10594

class SelfGrantStatusOutput < Struct.new(
  :glue_self_grant_status,
  :redshift_self_grant_status,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class GlueSelfGrantStatus < SelfGrantStatusOutput; end
  class RedshiftSelfGrantStatus < SelfGrantStatusOutput; end
  class Unknown < SelfGrantStatusOutput; end
end

#groupTypes::GroupDetails

The group details of a project member.

Returns:



8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
# File 'lib/aws-sdk-datazone/types.rb', line 8918

class MemberDetails < Struct.new(
  :group,
  :user,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Group < MemberDetails; end
  class User < MemberDetails; end
  class Unknown < MemberDetails; end
end

#group_identifierString

The ID of the group of a project member.

Returns:

  • (String)


8891
8892
8893
8894
8895
8896
8897
8898
8899
8900
8901
8902
# File 'lib/aws-sdk-datazone/types.rb', line 8891

class Member < Struct.new(
  :group_identifier,
  :user_identifier,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class GroupIdentifier < Member; end
  class UserIdentifier < Member; end
  class Unknown < Member; end
end

#iamTypes::IamUserProfileDetails

The IAM details included in the user profile details.



13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
# File 'lib/aws-sdk-datazone/types.rb', line 13036

class UserProfileDetails < Struct.new(
  :iam,
  :sso,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Iam < UserProfileDetails; end
  class Sso < UserProfileDetails; end
  class Unknown < UserProfileDetails; end
end

#lineage_node_type_itemTypes::LineageNodeTypeItem

The details of a data lineage node type.



10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
# File 'lib/aws-sdk-datazone/types.rb', line 10471

class SearchTypesResultItem < Struct.new(
  :asset_type_item,
  :form_type_item,
  :lineage_node_type_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetTypeItem < SearchTypesResultItem; end
  class FormTypeItem < SearchTypesResultItem; end
  class LineageNodeTypeItem < SearchTypesResultItem; end
  class Unknown < SearchTypesResultItem; end
end

#listingTypes::ListingRevisionInput

The listing for which a subscription is to be granted.



7061
7062
7063
7064
7065
7066
7067
7068
7069
7070
# File 'lib/aws-sdk-datazone/types.rb', line 7061

class GrantedEntity < Struct.new(
  :listing,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Listing < GrantedEntity; end
  class Unknown < GrantedEntity; end
end

#orArray<Types::FilterClause>

The ‘or’ search filter clause in Amazon DataZone.

Returns:



4528
4529
4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
# File 'lib/aws-sdk-datazone/types.rb', line 4528

class FilterClause < Struct.new(
  :and,
  :filter,
  :or,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class And < FilterClause; end
  class Filter < FilterClause; end
  class Or < FilterClause; end
  class Unknown < FilterClause; end
end

#projectTypes::SubscribedProjectInput

The project that is to be given a subscription grant.



11036
11037
11038
11039
11040
11041
11042
11043
11044
11045
# File 'lib/aws-sdk-datazone/types.rb', line 11036

class SubscribedPrincipal < Struct.new(
  :project,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Project < SubscribedPrincipal; end
  class Unknown < SubscribedPrincipal; end
end

#redshift_cluster_sourceTypes::RedshiftClusterStorage

The details of the Amazon Redshift cluster source.



9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
# File 'lib/aws-sdk-datazone/types.rb', line 9600

class RedshiftStorage < Struct.new(
  :redshift_cluster_source,
  :redshift_serverless_source,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RedshiftClusterSource < RedshiftStorage; end
  class RedshiftServerlessSource < RedshiftStorage; end
  class Unknown < RedshiftStorage; end
end

#redshift_run_configurationTypes::RedshiftRunConfigurationOutput

The configuration of the Amazon Redshift data source.



3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
# File 'lib/aws-sdk-datazone/types.rb', line 3092

class DataSourceConfigurationInput < Struct.new(
  :glue_run_configuration,
  :redshift_run_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class GlueRunConfiguration < DataSourceConfigurationInput; end
  class RedshiftRunConfiguration < DataSourceConfigurationInput; end
  class Unknown < DataSourceConfigurationInput; end
end

#redshift_self_grant_statusTypes::RedshiftSelfGrantStatusOutput

The details for the self granting status for an Amazon Redshift data source.



10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
10604
10605
# File 'lib/aws-sdk-datazone/types.rb', line 10594

class SelfGrantStatusOutput < Struct.new(
  :glue_self_grant_status,
  :redshift_self_grant_status,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class GlueSelfGrantStatus < SelfGrantStatusOutput; end
  class RedshiftSelfGrantStatus < SelfGrantStatusOutput; end
  class Unknown < SelfGrantStatusOutput; end
end

#redshift_serverless_sourceTypes::RedshiftServerlessStorage

The details of the Amazon Redshift Serverless workgroup source.



9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
# File 'lib/aws-sdk-datazone/types.rb', line 9600

class RedshiftStorage < Struct.new(
  :redshift_cluster_source,
  :redshift_serverless_source,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RedshiftClusterSource < RedshiftStorage; end
  class RedshiftServerlessSource < RedshiftStorage; end
  class Unknown < RedshiftStorage; end
end

#smithyString

Indicates the smithy model of the API.

Returns:

  • (String)


9018
9019
9020
9021
9022
9023
9024
9025
9026
9027
# File 'lib/aws-sdk-datazone/types.rb', line 9018

class Model < Struct.new(
  :smithy,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Smithy < Model; end
  class Unknown < Model; end
end

#ssoTypes::SsoUserProfileDetails

The single sign-on details included in the user profile details.



13036
13037
13038
13039
13040
13041
13042
13043
13044
13045
13046
13047
# File 'lib/aws-sdk-datazone/types.rb', line 13036

class UserProfileDetails < Struct.new(
  :iam,
  :sso,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Iam < UserProfileDetails; end
  class Sso < UserProfileDetails; end
  class Unknown < UserProfileDetails; end
end

#userTypes::UserDetails

The user details of a project member.

Returns:



8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
# File 'lib/aws-sdk-datazone/types.rb', line 8918

class MemberDetails < Struct.new(
  :group,
  :user,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Group < MemberDetails; end
  class User < MemberDetails; end
  class Unknown < MemberDetails; end
end

#user_identifierString

The user ID of a project member.

Returns:

  • (String)


8891
8892
8893
8894
8895
8896
8897
8898
8899
8900
8901
8902
# File 'lib/aws-sdk-datazone/types.rb', line 8891

class Member < Struct.new(
  :group_identifier,
  :user_identifier,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class GroupIdentifier < Member; end
  class UserIdentifier < Member; end
  class Unknown < Member; end
end