Class: Aws::DataZone::Types::AdditionalAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::AdditionalAttributes
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Additional details on the queried entity that can be requested in the response.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#form_names ⇒ Array<String>
Names of forms on the query entity that can be requested in the response.
Instance Attribute Details
#form_names ⇒ Array<String>
Names of forms on the query entity that can be requested in the response.
526 527 528 529 530 |
# File 'lib/aws-sdk-datazone/types.rb', line 526 class AdditionalAttributes < Struct.new( :form_names) SENSITIVE = [] include Aws::Structure end |