Class: Aws::DataZone::Types::AssetTypeItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::AssetTypeItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the asset type.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the asset type was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the asset type.
-
#description ⇒ String
The description of the asset type.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain where the asset type exists.
-
#forms_output ⇒ Hash<String,Types::FormEntryOutput>
The forms included in the details of the asset type.
-
#name ⇒ String
The name of the asset type.
-
#origin_domain_id ⇒ String
The identifier of the Amazon DataZone domain where the asset type was originally created.
-
#origin_project_id ⇒ String
The identifier of the Amazon DataZone project where the asset type exists.
-
#owning_project_id ⇒ String
The identifier of the Amazon DataZone project that owns the asset type.
-
#revision ⇒ String
The revision of the asset type.
-
#updated_at ⇒ Time
The timestamp of when the asset type was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the asset type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the asset type was created.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the asset type.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the asset type.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain where the asset type exists.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#forms_output ⇒ Hash<String,Types::FormEntryOutput>
The forms included in the details of the asset type.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the asset type.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#origin_domain_id ⇒ String
The identifier of the Amazon DataZone domain where the asset type was originally created.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#origin_project_id ⇒ String
The identifier of the Amazon DataZone project where the asset type exists.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the Amazon DataZone project that owns the asset type.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#revision ⇒ String
The revision of the asset type.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the asset type was updated.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the asset type.
889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/aws-sdk-datazone/types.rb', line 889 class AssetTypeItem < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |