Class: Aws::DataZone::Types::AttributeError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The attribute error.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_identifierString

The attribute ID as part of the attribute error.

Returns:

  • (String)


1423
1424
1425
1426
1427
1428
1429
# File 'lib/aws-sdk-datazone/types.rb', line 1423

class AttributeError < Struct.new(
  :attribute_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#codeString

The code generated as part of the attribute error.

Returns:

  • (String)


1423
1424
1425
1426
1427
1428
1429
# File 'lib/aws-sdk-datazone/types.rb', line 1423

class AttributeError < Struct.new(
  :attribute_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The message generated as part of the attribute error.

Returns:

  • (String)


1423
1424
1425
1426
1427
1428
1429
# File 'lib/aws-sdk-datazone/types.rb', line 1423

class AttributeError < Struct.new(
  :attribute_identifier,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end