Class: Aws::DataZone::Types::CancelSubscriptionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_identifierString

The unique identifier of the Amazon DataZone domain where the subscription request is being cancelled.

Returns:

  • (String)


996
997
998
999
1000
1001
# File 'lib/aws-sdk-datazone/types.rb', line 996

class CancelSubscriptionInput < Struct.new(
  :domain_identifier,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The unique identifier of the subscription that is being cancelled.

Returns:

  • (String)


996
997
998
999
1000
1001
# File 'lib/aws-sdk-datazone/types.rb', line 996

class CancelSubscriptionInput < Struct.new(
  :domain_identifier,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end