Class: Aws::DataZone::Types::CloudFormationProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Part of the provisioning properties of the environment blueprint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#template_urlString

The template URL of the cloud formation provisioning properties of the environment blueprint.

Returns:

  • (String)


1913
1914
1915
1916
1917
# File 'lib/aws-sdk-datazone/types.rb', line 1913

class CloudFormationProperties < Struct.new(
  :template_url)
  SENSITIVE = []
  include Aws::Structure
end