Class: Aws::DataZone::Types::ConfigurableEnvironmentAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The configurable action of a Amazon DataZone environment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authString

The authentication type of a configurable action of a Amazon DataZone environment.

Returns:

  • (String)


2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-datazone/types.rb', line 2004

class ConfigurableEnvironmentAction < Struct.new(
  :type,
  :auth,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersArray<Types::ConfigurableActionParameter>

The parameters of a configurable action in a Amazon DataZone environment.



2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-datazone/types.rb', line 2004

class ConfigurableEnvironmentAction < Struct.new(
  :type,
  :auth,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of a configurable action in a Amazon DataZone environment.

Returns:

  • (String)


2004
2005
2006
2007
2008
2009
2010
# File 'lib/aws-sdk-datazone/types.rb', line 2004

class ConfigurableEnvironmentAction < Struct.new(
  :type,
  :auth,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end