Class: Aws::DataZone::Types::ConnectionPropertiesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

ConnectionPropertiesInput is a union - when making an API calls you must set exactly one of the members.

The properties of a connection.

Defined Under Namespace

Classes: AmazonQProperties, AthenaProperties, GlueProperties, HyperPodProperties, IamProperties, LakehouseProperties, MlflowProperties, RedshiftProperties, S3Properties, SparkEmrProperties, SparkGlueProperties, Unknown, WorkflowsMwaaProperties, WorkflowsServerlessProperties

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_q_propertiesTypes::AmazonQPropertiesInput

The Amazon Q properties of the connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#athena_propertiesTypes::AthenaPropertiesInput

The Amazon Athena properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#glue_propertiesTypes::GluePropertiesInput

The Amazon Web Services Glue properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#hyper_pod_propertiesTypes::HyperPodPropertiesInput

The hyper pod properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#iam_propertiesTypes::IamPropertiesInput

The IAM properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#lakehouse_propertiesTypes::LakehousePropertiesInput

The lakehouse properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#mlflow_propertiesTypes::MlflowPropertiesInput

The MLflow properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#redshift_propertiesTypes::RedshiftPropertiesInput

The Amazon Redshift properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#s3_propertiesTypes::S3PropertiesInput

The Amazon S3 properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#spark_emr_propertiesTypes::SparkEmrPropertiesInput

The Spark EMR properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#spark_glue_propertiesTypes::SparkGluePropertiesInput

The Spark Amazon Web Services Glue properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2122

def unknown
  @unknown
end

#workflows_mwaa_propertiesTypes::WorkflowsMwaaPropertiesInput

The Amazon MWAA properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#workflows_serverless_propertiesTypes::WorkflowsServerlessPropertiesInput

The MWAA serverless properties of a connection.



2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
# File 'lib/aws-sdk-datazone/types.rb', line 2122

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class LakehouseProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end