Class: Aws::DataZone::Types::ConnectionPropertiesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

ConnectionPropertiesOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConnectionPropertiesOutput corresponding to the set member.

The properties of a connection.

Defined Under Namespace

Classes: AmazonQProperties, AthenaProperties, GitProperties, GlueProperties, HyperPodProperties, IamProperties, LakehouseProperties, MlflowProperties, RedshiftProperties, S3Properties, SnowflakeProperties, SparkEmrProperties, SparkGlueProperties, Unknown, VpcProperties, WorkflowsMwaaProperties, WorkflowsServerlessProperties

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_q_propertiesTypes::AmazonQPropertiesOutput

The Amazon Q properties of the connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#athena_propertiesTypes::AthenaPropertiesOutput

The Amazon Athena properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#git_propertiesTypes::GitPropertiesOutput

The Git properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#glue_propertiesTypes::GluePropertiesOutput

The Amazon Web Services Glue properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#hyper_pod_propertiesTypes::HyperPodPropertiesOutput

The hyper pod properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#iam_propertiesTypes::IamPropertiesOutput

The IAM properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#lakehouse_propertiesTypes::LakehousePropertiesOutput

The lakehouse properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#mlflow_propertiesTypes::MlflowPropertiesOutput

The MLflow properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#redshift_propertiesTypes::RedshiftPropertiesOutput

The Amazon Redshift properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#s3_propertiesTypes::S3PropertiesOutput

The Amazon S3 properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#snowflake_propertiesTypes::SnowflakePropertiesOutput

The Snowflake-specific connection properties for an existing connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#spark_emr_propertiesTypes::SparkEmrPropertiesOutput

The Spark EMR properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#spark_glue_propertiesTypes::SparkGluePropertiesOutput

The Spark Amazon Web Services Glue properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2251
2252
2253
# File 'lib/aws-sdk-datazone/types.rb', line 2251

def unknown
  @unknown
end

#vpc_propertiesTypes::VpcPropertiesOutput

The VPC properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#workflows_mwaa_propertiesTypes::WorkflowsMwaaPropertiesOutput

The Amazon MWAA properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#workflows_serverless_propertiesTypes::WorkflowsServerlessPropertiesOutput

The MWAA serverless properties of a connection.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
# File 'lib/aws-sdk-datazone/types.rb', line 2251

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SnowflakeProperties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class VpcProperties < ConnectionPropertiesOutput; end
  class GitProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end