Class: Aws::DataZone::Types::ConnectionPropertiesPatch

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

ConnectionPropertiesPatch is a union - when making an API calls you must set exactly one of the members.

The connection properties patch.

Defined Under Namespace

Classes: AmazonQProperties, AthenaProperties, GitProperties, GlueProperties, IamProperties, LakehouseProperties, MlflowProperties, RedshiftProperties, S3Properties, SnowflakeProperties, SparkEmrProperties, Unknown, VpcProperties

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_q_propertiesTypes::AmazonQPropertiesPatch

The Amazon Q properties of the connection.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#athena_propertiesTypes::AthenaPropertiesPatch

The Amazon Athena properties of a connection properties patch.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#git_propertiesTypes::GitPropertiesPatch

The Git properties of a connection properties patch.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#glue_propertiesTypes::GluePropertiesPatch

The Amazon Web Services Glue properties of a connection properties patch.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#iam_propertiesTypes::IamPropertiesPatch

The IAM properties of a connection properties patch.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#lakehouse_propertiesTypes::LakehousePropertiesPatch

The lakehouse properties of a connection properties patch.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#mlflow_propertiesTypes::MlflowPropertiesPatch

The MLflow properties of a connection.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#redshift_propertiesTypes::RedshiftPropertiesPatch

The Amazon Redshift properties of a connection properties patch.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#s3_propertiesTypes::S3PropertiesPatch

The Amazon S3 properties of a connection properties patch.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#snowflake_propertiesTypes::SnowflakePropertiesPatch

The Snowflake-specific connection properties to update.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#spark_emr_propertiesTypes::SparkEmrPropertiesPatch

The Spark EMR properties of a connection properties patch.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2347
2348
2349
# File 'lib/aws-sdk-datazone/types.rb', line 2347

def unknown
  @unknown
end

#vpc_propertiesTypes::VpcPropertiesPatch

The VPC properties of a connection properties patch.



2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-datazone/types.rb', line 2347

class ConnectionPropertiesPatch < Struct.new(
  :athena_properties,
  :glue_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :s3_properties,
  :snowflake_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :lakehouse_properties,
  :vpc_properties,
  :git_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesPatch; end
  class GlueProperties < ConnectionPropertiesPatch; end
  class IamProperties < ConnectionPropertiesPatch; end
  class RedshiftProperties < ConnectionPropertiesPatch; end
  class SparkEmrProperties < ConnectionPropertiesPatch; end
  class S3Properties < ConnectionPropertiesPatch; end
  class SnowflakeProperties < ConnectionPropertiesPatch; end
  class AmazonQProperties < ConnectionPropertiesPatch; end
  class MlflowProperties < ConnectionPropertiesPatch; end
  class LakehouseProperties < ConnectionPropertiesPatch; end
  class VpcProperties < ConnectionPropertiesPatch; end
  class GitProperties < ConnectionPropertiesPatch; end
  class Unknown < ConnectionPropertiesPatch; end
end