Class: Aws::DataZone::Types::ConnectivityProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Contains the network and authentication settings for a connection, including connection credentials, physical network requirements, and compute-environment validation options.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#athena_propertiesHash<String,String>

The Athena properties for this configuration.

Returns:

  • (Hash<String,String>)


2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_configurationTypes::AuthenticationConfigurationInput

The authentication settings for this configuration.



2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#connection_propertiesHash<String,String>

The connection properties for this configuration.

Returns:

  • (Hash<String,String>)


2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the connectivity configuration.

Returns:

  • (String)


2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the connectivity configuration.

Returns:

  • (String)


2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#physical_connection_requirementsTypes::PhysicalConnectionRequirements

The physical network requirements for the connection, such as the subnet, security group, and VPC settings needed to reach the data source.



2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#python_propertiesHash<String,String>

The Python properties for this configuration.

Returns:

  • (Hash<String,String>)


2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#spark_propertiesHash<String,String>

The Spark properties for this configuration.

Returns:

  • (Hash<String,String>)


2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#validate_credentialsBoolean

Specifies whether to validate credentials for the connectivity configuration. Defaults to true if not specified.

Returns:

  • (Boolean)


2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#validate_for_compute_environmentsArray<String>

The compute environments to use when validating connectivity. The service validates that the connection is reachable from each specified environment.

Returns:

  • (Array<String>)


2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
# File 'lib/aws-sdk-datazone/types.rb', line 2495

class ConnectivityProperties < Struct.new(
  :connection_properties,
  :physical_connection_requirements,
  :name,
  :description,
  :validate_credentials,
  :validate_for_compute_environments,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end