Class: Aws::DataZone::Types::CreateAccountPoolInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateAccountPoolInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#account_source ⇒ Types::AccountSource
The source of accounts for the account pool.
-
#description ⇒ String
The description of the account pool.
-
#domain_identifier ⇒ String
The ID of the domain where the account pool is created.
-
#name ⇒ String
The name of the account pool.
-
#resolution_strategy ⇒ String
The mechanism used to resolve the account selection from the account pool.
Instance Attribute Details
#account_source ⇒ Types::AccountSource
The source of accounts for the account pool. In the current release, it’s either a static list of accounts provided by the customer or a custom Amazon Web Services Lambda handler.
2384 2385 2386 2387 2388 2389 2390 2391 2392 |
# File 'lib/aws-sdk-datazone/types.rb', line 2384 class CreateAccountPoolInput < Struct.new( :domain_identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the account pool.
2384 2385 2386 2387 2388 2389 2390 2391 2392 |
# File 'lib/aws-sdk-datazone/types.rb', line 2384 class CreateAccountPoolInput < Struct.new( :domain_identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_identifier ⇒ String
The ID of the domain where the account pool is created.
2384 2385 2386 2387 2388 2389 2390 2391 2392 |
# File 'lib/aws-sdk-datazone/types.rb', line 2384 class CreateAccountPoolInput < Struct.new( :domain_identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the account pool.
2384 2385 2386 2387 2388 2389 2390 2391 2392 |
# File 'lib/aws-sdk-datazone/types.rb', line 2384 class CreateAccountPoolInput < Struct.new( :domain_identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |
#resolution_strategy ⇒ String
The mechanism used to resolve the account selection from the account pool.
2384 2385 2386 2387 2388 2389 2390 2391 2392 |
# File 'lib/aws-sdk-datazone/types.rb', line 2384 class CreateAccountPoolInput < Struct.new( :domain_identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |