Class: Aws::DataZone::Types::CreateAccountPoolOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#account_sourceTypes::AccountSource

The source of accounts for the account pool. In the current release, it’s either a static list of accounts provided by the customer or a custom Amazon Web Services Lambda handler.



2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_atTime

The timestamp at which the account pool was created.

Returns:

  • (Time)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_byString

The user who created the account pool.

Returns:

  • (String)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the account pool.

Returns:

  • (String)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The ID of the domain where the account pool is created.

Returns:

  • (String)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_unit_idString

The ID of the domain where the account pool is created.

Returns:

  • (String)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The ID of the account pool.

Returns:

  • (String)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#last_updated_atTime

The timestamp at which the account pool was last updated.

Returns:

  • (Time)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the account pool.

Returns:

  • (String)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#resolution_strategyString

The mechanism used to resolve the account selection from the account pool.

Returns:

  • (String)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_byString

The user who last updated the account pool.

Returns:

  • (String)


2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
# File 'lib/aws-sdk-datazone/types.rb', line 2425

class CreateAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end