Class: Aws::DataZone::Types::CreateAssetInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description, :forms_input]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#descriptionString

Asset description.

Returns:

  • (String)


2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#domain_identifierString

Amazon DataZone domain where the asset is created.

Returns:

  • (String)


2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#external_identifierString

The external identifier of the asset.

If the value for the ‘externalIdentifier` parameter is specified, it must be a unique value.

Returns:

  • (String)


2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#forms_inputArray<Types::FormInput>

Metadata forms attached to the asset.

Returns:



2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#glossary_termsArray<String>

Glossary terms attached to the asset.

Returns:

  • (Array<String>)


2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#nameString

Asset name.

Returns:

  • (String)


2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#owning_project_identifierString

The unique identifier of the project that owns this asset.

Returns:

  • (String)


2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#prediction_configurationTypes::PredictionConfiguration

The configuration of the automatically generated business-friendly metadata for the asset.



2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#type_identifierString

The unique identifier of this asset’s type.

Returns:

  • (String)


2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#type_revisionString

The revision of this asset’s type.

Returns:

  • (String)


2599
2600
2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
# File 'lib/aws-sdk-datazone/types.rb', line 2599

class CreateAssetInput < Struct.new(
  :name,
  :domain_identifier,
  :external_identifier,
  :type_identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :owning_project_identifier,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end