Class: Aws::DataZone::Types::CreateAssetOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the asset was created.

Returns:

  • (Time)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user that created this asset in the catalog.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the created asset.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which the asset was created.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#external_identifierString

The external identifier of the asset.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#first_revision_created_atTime

The timestamp of when the first revision of the asset took place.

Returns:

  • (Time)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#first_revision_created_byString

The Amazon DataZone user that made the first revision of the asset.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#forms_outputArray<Types::FormOutput>

The metadata forms that are attached to the created asset.

Returns:



2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms that are attached to the created asset.

Returns:

  • (Array<String>)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#governed_glossary_termsArray<String>

The glossary terms in a restricted glossary.

Returns:

  • (Array<String>)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The unique identifier of the created asset.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#latest_time_series_data_point_forms_outputArray<Types::TimeSeriesDataPointSummaryFormOutput>

The latest data point that was imported into the time series form for the asset.



2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#listingTypes::AssetListingDetails

The details of an asset published in an Amazon DataZone catalog.



2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the created asset.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#owning_project_idString

The ID of the Amazon DataZone project that owns the created asset.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#prediction_configurationTypes::PredictionConfiguration

The configuration of the automatically generated business-friendly metadata for the asset.



2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#read_only_forms_outputArray<Types::FormOutput>

The read-only metadata forms that are attached to the created asset.

Returns:



2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#revisionString

The revision of the asset.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#type_identifierString

The identifier of the created asset type.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#type_revisionString

The revision type of the asset.

Returns:

  • (String)


2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/aws-sdk-datazone/types.rb', line 2893

class CreateAssetOutput < Struct.new(
  :id,
  :name,
  :type_identifier,
  :type_revision,
  :external_identifier,
  :revision,
  :description,
  :created_at,
  :created_by,
  :first_revision_created_at,
  :first_revision_created_by,
  :glossary_terms,
  :governed_glossary_terms,
  :owning_project_id,
  :domain_id,
  :listing,
  :forms_output,
  :read_only_forms_output,
  :latest_time_series_data_point_forms_output,
  :prediction_configuration)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end