Class: Aws::DataZone::Types::CreateAssetRevisionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description, :forms_input]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
# File 'lib/aws-sdk-datazone/types.rb', line 2770

class CreateAssetRevisionInput < Struct.new(
  :name,
  :domain_identifier,
  :identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#descriptionString

The revised description of the asset.

Returns:

  • (String)


2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
# File 'lib/aws-sdk-datazone/types.rb', line 2770

class CreateAssetRevisionInput < Struct.new(
  :name,
  :domain_identifier,
  :identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#domain_identifierString

The unique identifier of the domain where the asset is being revised.

Returns:

  • (String)


2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
# File 'lib/aws-sdk-datazone/types.rb', line 2770

class CreateAssetRevisionInput < Struct.new(
  :name,
  :domain_identifier,
  :identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#forms_inputArray<Types::FormInput>

The metadata forms to be attached to the asset as part of asset revision.

Returns:



2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
# File 'lib/aws-sdk-datazone/types.rb', line 2770

class CreateAssetRevisionInput < Struct.new(
  :name,
  :domain_identifier,
  :identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms to be attached to the asset as part of asset revision.

Returns:

  • (Array<String>)


2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
# File 'lib/aws-sdk-datazone/types.rb', line 2770

class CreateAssetRevisionInput < Struct.new(
  :name,
  :domain_identifier,
  :identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#identifierString

The identifier of the asset.

Returns:

  • (String)


2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
# File 'lib/aws-sdk-datazone/types.rb', line 2770

class CreateAssetRevisionInput < Struct.new(
  :name,
  :domain_identifier,
  :identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#nameString

Te revised name of the asset.

Returns:

  • (String)


2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
# File 'lib/aws-sdk-datazone/types.rb', line 2770

class CreateAssetRevisionInput < Struct.new(
  :name,
  :domain_identifier,
  :identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#prediction_configurationTypes::PredictionConfiguration

The configuration of the automatically generated business-friendly metadata for the asset.



2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
# File 'lib/aws-sdk-datazone/types.rb', line 2770

class CreateAssetRevisionInput < Struct.new(
  :name,
  :domain_identifier,
  :identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end

#type_revisionString

The revision type of the asset.

Returns:

  • (String)


2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
# File 'lib/aws-sdk-datazone/types.rb', line 2770

class CreateAssetRevisionInput < Struct.new(
  :name,
  :domain_identifier,
  :identifier,
  :type_revision,
  :description,
  :glossary_terms,
  :forms_input,
  :prediction_configuration,
  :client_token)
  SENSITIVE = [:name, :description, :forms_input]
  include Aws::Structure
end