Class: Aws::DataZone::Types::CreateAssetTypeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateAssetTypeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the asset type is to be created.
-
#created_by ⇒ String
The Amazon DataZone user who creates this custom asset type.
-
#description ⇒ String
The description of the custom asset type.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type was created.
-
#forms_output ⇒ Hash<String,Types::FormEntryOutput>
The metadata forms that are attached to the asset type.
-
#name ⇒ String
The name of the asset type.
-
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain where the asset type was originally created.
-
#origin_project_id ⇒ String
The ID of the Amazon DataZone project where the asset type was originally created.
-
#owning_project_id ⇒ String
The ID of the Amazon DataZone project that currently owns this asset type.
-
#revision ⇒ String
The revision of the custom asset type.
-
#updated_at ⇒ Time
The timestamp of when the custom type was created.
-
#updated_by ⇒ String
The Amazon DataZone user that created the custom asset type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the asset type is to be created.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who creates this custom asset type.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the custom asset type.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type was created.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#forms_output ⇒ Hash<String,Types::FormEntryOutput>
The metadata forms that are attached to the asset type.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the asset type.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain where the asset type was originally created.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#origin_project_id ⇒ String
The ID of the Amazon DataZone project where the asset type was originally created.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the Amazon DataZone project that currently owns this asset type.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#revision ⇒ String
The revision of the custom asset type.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the custom type was created.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user that created the custom asset type.
3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 |
# File 'lib/aws-sdk-datazone/types.rb', line 3050 class CreateAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |