Class: Aws::DataZone::Types::CreateConnectionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateConnectionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#aws_location ⇒ Types::AwsLocation
The location where the connection is created.
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#configurations ⇒ Array<Types::Configuration>
The configurations of the connection.
-
#description ⇒ String
A connection description.
-
#domain_identifier ⇒ String
The ID of the domain where the connection is created.
-
#enable_trusted_identity_propagation ⇒ Boolean
Specifies whether the trusted identity propagation is enabled.
-
#environment_identifier ⇒ String
The ID of the environment where the connection is created.
-
#name ⇒ String
The connection name.
-
#props ⇒ Types::ConnectionPropertiesInput
The connection props.
-
#scope ⇒ String
The scope of the connection.
Instance Attribute Details
#aws_location ⇒ Types::AwsLocation
The location where the connection is created.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |
#configurations ⇒ Array<Types::Configuration>
The configurations of the connection.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A connection description.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |
#domain_identifier ⇒ String
The ID of the domain where the connection is created.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |
#enable_trusted_identity_propagation ⇒ Boolean
Specifies whether the trusted identity propagation is enabled.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |
#environment_identifier ⇒ String
The ID of the environment where the connection is created.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The connection name.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |
#props ⇒ Types::ConnectionPropertiesInput
The connection props.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |
#scope ⇒ String
The scope of the connection.
3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 |
# File 'lib/aws-sdk-datazone/types.rb', line 3080 class CreateConnectionInput < Struct.new( :aws_location, :client_token, :configurations, :description, :domain_identifier, :environment_identifier, :name, :props, :enable_trusted_identity_propagation, :scope) SENSITIVE = [:description] include Aws::Structure end |