Class: Aws::DataZone::Types::CreateDataSourceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateDataSourceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :schedule, :asset_forms_input]
Instance Attribute Summary collapse
-
#asset_forms_input ⇒ Array<Types::FormInput>
The metadata forms that are to be attached to the assets that this data source works with.
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#configuration ⇒ Types::DataSourceConfigurationInput
Specifies the configuration of the data source.
-
#connection_identifier ⇒ String
The ID of the connection.
-
#description ⇒ String
The description of the data source.
-
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain where the data source is created.
-
#enable_setting ⇒ String
Specifies whether the data source is enabled.
-
#environment_identifier ⇒ String
The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
-
#name ⇒ String
The name of the data source.
-
#project_identifier ⇒ String
The identifier of the Amazon DataZone project in which you want to add this data source.
-
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
-
#recommendation ⇒ Types::RecommendationConfiguration
Specifies whether the business name generation is to be enabled for this data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
-
#type ⇒ String
The type of the data source.
Instance Attribute Details
#asset_forms_input ⇒ Array<Types::FormInput>
The metadata forms that are to be attached to the assets that this data source works with.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#configuration ⇒ Types::DataSourceConfigurationInput
Specifies the configuration of the data source. It can be set to either ‘glueRunConfiguration` or `redshiftRunConfiguration`.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#connection_identifier ⇒ String
The ID of the connection.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#description ⇒ String
The description of the data source.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain where the data source is created.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#enable_setting ⇒ String
Specifies whether the data source is enabled.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#environment_identifier ⇒ String
The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#name ⇒ String
The name of the data source.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#project_identifier ⇒ String
The identifier of the Amazon DataZone project in which you want to add this data source.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#recommendation ⇒ Types::RecommendationConfiguration
Specifies whether the business name generation is to be enabled for this data source.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |
#type ⇒ String
The type of the data source. In Amazon DataZone, you can use data sources to import technical metadata of assets (data) from the source databases or data warehouses into Amazon DataZone. In the current release of Amazon DataZone, you can create and run data sources for Amazon Web Services Glue and Amazon Redshift.
3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-datazone/types.rb', line 3493 class CreateDataSourceInput < Struct.new( :name, :description, :domain_identifier, :project_identifier, :environment_identifier, :connection_identifier, :type, :configuration, :recommendation, :enable_setting, :schedule, :publish_on_import, :asset_forms_input, :client_token) SENSITIVE = [:name, :description, :schedule, :asset_forms_input] include Aws::Structure end |