Class: Aws::DataZone::Types::CreateDomainInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateDomainInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#description ⇒ String
The description of the Amazon DataZone domain.
-
#domain_execution_role ⇒ String
The domain execution role that is created when an Amazon DataZone domain is created.
-
#domain_version ⇒ String
The version of the domain that is created.
-
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
-
#name ⇒ String
The name of the Amazon DataZone domain.
-
#service_role ⇒ String
The service role of the domain that is created.
-
#single_sign_on ⇒ Types::SingleSignOn
The single-sign on configuration of the Amazon DataZone domain.
-
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/aws-sdk-datazone/types.rb', line 3726 class CreateDomainInput < Struct.new( :name, :description, :single_sign_on, :domain_execution_role, :kms_key_identifier, :tags, :domain_version, :service_role, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone domain.
3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/aws-sdk-datazone/types.rb', line 3726 class CreateDomainInput < Struct.new( :name, :description, :single_sign_on, :domain_execution_role, :kms_key_identifier, :tags, :domain_version, :service_role, :client_token) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role ⇒ String
The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the Amazon Web Services account that houses the Amazon DataZone domain.
3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/aws-sdk-datazone/types.rb', line 3726 class CreateDomainInput < Struct.new( :name, :description, :single_sign_on, :domain_execution_role, :kms_key_identifier, :tags, :domain_version, :service_role, :client_token) SENSITIVE = [] include Aws::Structure end |
#domain_version ⇒ String
The version of the domain that is created.
3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/aws-sdk-datazone/types.rb', line 3726 class CreateDomainInput < Struct.new( :name, :description, :single_sign_on, :domain_execution_role, :kms_key_identifier, :tags, :domain_version, :service_role, :client_token) SENSITIVE = [] include Aws::Structure end |
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/aws-sdk-datazone/types.rb', line 3726 class CreateDomainInput < Struct.new( :name, :description, :single_sign_on, :domain_execution_role, :kms_key_identifier, :tags, :domain_version, :service_role, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone domain.
3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/aws-sdk-datazone/types.rb', line 3726 class CreateDomainInput < Struct.new( :name, :description, :single_sign_on, :domain_execution_role, :kms_key_identifier, :tags, :domain_version, :service_role, :client_token) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The service role of the domain that is created.
3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/aws-sdk-datazone/types.rb', line 3726 class CreateDomainInput < Struct.new( :name, :description, :single_sign_on, :domain_execution_role, :kms_key_identifier, :tags, :domain_version, :service_role, :client_token) SENSITIVE = [] include Aws::Structure end |
#single_sign_on ⇒ Types::SingleSignOn
The single-sign on configuration of the Amazon DataZone domain.
3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/aws-sdk-datazone/types.rb', line 3726 class CreateDomainInput < Struct.new( :name, :description, :single_sign_on, :domain_execution_role, :kms_key_identifier, :tags, :domain_version, :service_role, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 |
# File 'lib/aws-sdk-datazone/types.rb', line 3726 class CreateDomainInput < Struct.new( :name, :description, :single_sign_on, :domain_execution_role, :kms_key_identifier, :tags, :domain_version, :service_role, :client_token) SENSITIVE = [] include Aws::Structure end |