Class: Aws::DataZone::Types::CreateDomainUnitInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3795
3796
3797
3798
3799
3800
3801
3802
3803
# File 'lib/aws-sdk-datazone/types.rb', line 3795

class CreateDomainUnitInput < Struct.new(
  :domain_identifier,
  :name,
  :parent_domain_unit_identifier,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the domain unit.

Returns:

  • (String)


3795
3796
3797
3798
3799
3800
3801
3802
3803
# File 'lib/aws-sdk-datazone/types.rb', line 3795

class CreateDomainUnitInput < Struct.new(
  :domain_identifier,
  :name,
  :parent_domain_unit_identifier,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_identifierString

The ID of the domain where you want to crate a domain unit.

Returns:

  • (String)


3795
3796
3797
3798
3799
3800
3801
3802
3803
# File 'lib/aws-sdk-datazone/types.rb', line 3795

class CreateDomainUnitInput < Struct.new(
  :domain_identifier,
  :name,
  :parent_domain_unit_identifier,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the domain unit.

Returns:

  • (String)


3795
3796
3797
3798
3799
3800
3801
3802
3803
# File 'lib/aws-sdk-datazone/types.rb', line 3795

class CreateDomainUnitInput < Struct.new(
  :domain_identifier,
  :name,
  :parent_domain_unit_identifier,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#parent_domain_unit_identifierString

The ID of the parent domain unit.

Returns:

  • (String)


3795
3796
3797
3798
3799
3800
3801
3802
3803
# File 'lib/aws-sdk-datazone/types.rb', line 3795

class CreateDomainUnitInput < Struct.new(
  :domain_identifier,
  :name,
  :parent_domain_unit_identifier,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end