Class: Aws::DataZone::Types::CreateEnvironmentBlueprintOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateEnvironmentBlueprintOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp at which the environment blueprint was created.
-
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties of this Amazon DataZone blueprint.
-
#description ⇒ String
The description of this Amazon DataZone blueprint.
-
#glossary_terms ⇒ Array<String>
The glossary terms attached to this Amazon DataZone blueprint.
-
#id ⇒ String
The ID of this Amazon DataZone blueprint.
-
#name ⇒ String
The name of this Amazon DataZone blueprint.
-
#provider ⇒ String
The provider of this Amazon DataZone blueprint.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties of this Amazon DataZone blueprint.
-
#updated_at ⇒ Time
The timestamp of when this blueprint was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone blueprint.
Instance Attribute Details
#created_at ⇒ Time
The timestamp at which the environment blueprint was created.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties of this Amazon DataZone blueprint.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of this Amazon DataZone blueprint.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms attached to this Amazon DataZone blueprint.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#id ⇒ String
The ID of this Amazon DataZone blueprint.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of this Amazon DataZone blueprint.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#provider ⇒ String
The provider of this Amazon DataZone blueprint.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties of this Amazon DataZone blueprint.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this blueprint was updated.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone blueprint.
3999 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 |
# File 'lib/aws-sdk-datazone/types.rb', line 3999 class CreateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |