Class: Aws::DataZone::Types::CreateEnvironmentProfileInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account in which the Amazon DataZone environment is created.

Returns:

  • (String)


1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-datazone/types.rb', line 1732

class CreateEnvironmentProfileInput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :description,
  :domain_identifier,
  :environment_blueprint_identifier,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#aws_account_regionString

The Amazon Web Services region in which this environment profile is created.

Returns:

  • (String)


1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-datazone/types.rb', line 1732

class CreateEnvironmentProfileInput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :description,
  :domain_identifier,
  :environment_blueprint_identifier,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#descriptionString

The description of this Amazon DataZone environment profile.

Returns:

  • (String)


1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-datazone/types.rb', line 1732

class CreateEnvironmentProfileInput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :description,
  :domain_identifier,
  :environment_blueprint_identifier,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#domain_identifierString

The ID of the Amazon DataZone domain in which this environment profile is created.

Returns:

  • (String)


1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-datazone/types.rb', line 1732

class CreateEnvironmentProfileInput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :description,
  :domain_identifier,
  :environment_blueprint_identifier,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_blueprint_identifierString

The ID of the blueprint with which this environment profile is created.

Returns:

  • (String)


1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-datazone/types.rb', line 1732

class CreateEnvironmentProfileInput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :description,
  :domain_identifier,
  :environment_blueprint_identifier,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#nameString

The name of this Amazon DataZone environment profile.

Returns:

  • (String)


1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-datazone/types.rb', line 1732

class CreateEnvironmentProfileInput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :description,
  :domain_identifier,
  :environment_blueprint_identifier,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#project_identifierString

The identifier of the project in which to create the environment profile.

Returns:

  • (String)


1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-datazone/types.rb', line 1732

class CreateEnvironmentProfileInput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :description,
  :domain_identifier,
  :environment_blueprint_identifier,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#user_parametersArray<Types::EnvironmentParameter>

The user parameters of this Amazon DataZone environment profile.

Returns:



1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/aws-sdk-datazone/types.rb', line 1732

class CreateEnvironmentProfileInput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :description,
  :domain_identifier,
  :environment_blueprint_identifier,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end