Class: Aws::DataZone::Types::CreateFormTypeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateFormTypeInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :model, :name]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of this Amazon DataZone metadata form type.
-
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain in which this metadata form type is created.
-
#model ⇒ Types::Model
The model of this Amazon DataZone metadata form type.
-
#name ⇒ String
The name of this Amazon DataZone metadata form type.
-
#owning_project_identifier ⇒ String
The ID of the Amazon DataZone project that owns this metadata form type.
-
#status ⇒ String
The status of this Amazon DataZone metadata form type.
Instance Attribute Details
#description ⇒ String
The description of this Amazon DataZone metadata form type.
1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 |
# File 'lib/aws-sdk-datazone/types.rb', line 1845 class CreateFormTypeInput < Struct.new( :description, :domain_identifier, :model, :name, :owning_project_identifier, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain in which this metadata form type is created.
1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 |
# File 'lib/aws-sdk-datazone/types.rb', line 1845 class CreateFormTypeInput < Struct.new( :description, :domain_identifier, :model, :name, :owning_project_identifier, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#model ⇒ Types::Model
The model of this Amazon DataZone metadata form type.
1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 |
# File 'lib/aws-sdk-datazone/types.rb', line 1845 class CreateFormTypeInput < Struct.new( :description, :domain_identifier, :model, :name, :owning_project_identifier, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#name ⇒ String
The name of this Amazon DataZone metadata form type.
1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 |
# File 'lib/aws-sdk-datazone/types.rb', line 1845 class CreateFormTypeInput < Struct.new( :description, :domain_identifier, :model, :name, :owning_project_identifier, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#owning_project_identifier ⇒ String
The ID of the Amazon DataZone project that owns this metadata form type.
1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 |
# File 'lib/aws-sdk-datazone/types.rb', line 1845 class CreateFormTypeInput < Struct.new( :description, :domain_identifier, :model, :name, :owning_project_identifier, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#status ⇒ String
The status of this Amazon DataZone metadata form type.
1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 |
# File 'lib/aws-sdk-datazone/types.rb', line 1845 class CreateFormTypeInput < Struct.new( :description, :domain_identifier, :model, :name, :owning_project_identifier, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |