Class: Aws::DataZone::Types::CreateGlossaryOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of this business glossary.

Returns:

  • (String)


4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
# File 'lib/aws-sdk-datazone/types.rb', line 4535

class CreateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which this business glossary is created.

Returns:

  • (String)


4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
# File 'lib/aws-sdk-datazone/types.rb', line 4535

class CreateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The ID of this business glossary.

Returns:

  • (String)


4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
# File 'lib/aws-sdk-datazone/types.rb', line 4535

class CreateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of this business glossary.

Returns:

  • (String)


4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
# File 'lib/aws-sdk-datazone/types.rb', line 4535

class CreateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#owning_project_idString

The ID of the project that currently owns this business glossary.

Returns:

  • (String)


4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
# File 'lib/aws-sdk-datazone/types.rb', line 4535

class CreateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#statusString

The status of this business glossary.

Returns:

  • (String)


4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
# File 'lib/aws-sdk-datazone/types.rb', line 4535

class CreateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#usage_restrictionsArray<String>

The usage restriction of the restricted glossary.

Returns:

  • (Array<String>)


4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
# File 'lib/aws-sdk-datazone/types.rb', line 4535

class CreateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end