Class: Aws::DataZone::Types::CreateGlossaryTermInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :short_description, :long_description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/aws-sdk-datazone/types.rb', line 4799

class CreateGlossaryTermInput < Struct.new(
  :domain_identifier,
  :glossary_identifier,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :client_token)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#domain_identifierString

The ID of the Amazon DataZone domain in which this business glossary term is created.

Returns:

  • (String)


4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/aws-sdk-datazone/types.rb', line 4799

class CreateGlossaryTermInput < Struct.new(
  :domain_identifier,
  :glossary_identifier,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :client_token)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#glossary_identifierString

The ID of the business glossary in which this term is created.

Returns:

  • (String)


4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/aws-sdk-datazone/types.rb', line 4799

class CreateGlossaryTermInput < Struct.new(
  :domain_identifier,
  :glossary_identifier,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :client_token)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#long_descriptionString

The long description of this business glossary term.

Returns:

  • (String)


4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/aws-sdk-datazone/types.rb', line 4799

class CreateGlossaryTermInput < Struct.new(
  :domain_identifier,
  :glossary_identifier,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :client_token)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#nameString

The name of this business glossary term.

Returns:

  • (String)


4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/aws-sdk-datazone/types.rb', line 4799

class CreateGlossaryTermInput < Struct.new(
  :domain_identifier,
  :glossary_identifier,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :client_token)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#short_descriptionString

The short description of this business glossary term.

Returns:

  • (String)


4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/aws-sdk-datazone/types.rb', line 4799

class CreateGlossaryTermInput < Struct.new(
  :domain_identifier,
  :glossary_identifier,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :client_token)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#statusString

The status of this business glossary term.

Returns:

  • (String)


4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/aws-sdk-datazone/types.rb', line 4799

class CreateGlossaryTermInput < Struct.new(
  :domain_identifier,
  :glossary_identifier,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :client_token)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#term_relationsTypes::TermRelations

The term relations of this business glossary term.



4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/aws-sdk-datazone/types.rb', line 4799

class CreateGlossaryTermInput < Struct.new(
  :domain_identifier,
  :glossary_identifier,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :client_token)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end