Class: Aws::DataZone::Types::CreateGlossaryTermOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :short_description, :long_description]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_idString

The ID of the Amazon DataZone domain in which this business glossary term is created.

Returns:

  • (String)


4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/aws-sdk-datazone/types.rb', line 4851

class CreateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#glossary_idString

The ID of the business glossary in which this term is created.

Returns:

  • (String)


4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/aws-sdk-datazone/types.rb', line 4851

class CreateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#idString

The ID of this business glossary term.

Returns:

  • (String)


4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/aws-sdk-datazone/types.rb', line 4851

class CreateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#long_descriptionString

The long description of this business glossary term.

Returns:

  • (String)


4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/aws-sdk-datazone/types.rb', line 4851

class CreateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#nameString

The name of this business glossary term.

Returns:

  • (String)


4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/aws-sdk-datazone/types.rb', line 4851

class CreateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#short_descriptionString

The short description of this business glossary term.

Returns:

  • (String)


4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/aws-sdk-datazone/types.rb', line 4851

class CreateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#statusString

The status of this business glossary term.

Returns:

  • (String)


4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/aws-sdk-datazone/types.rb', line 4851

class CreateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#term_relationsTypes::TermRelations

The term relations of this business glossary term.



4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/aws-sdk-datazone/types.rb', line 4851

class CreateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#usage_restrictionsArray<String>

The usage restriction of the restricted glossary.

Returns:

  • (Array<String>)


4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
4861
4862
4863
# File 'lib/aws-sdk-datazone/types.rb', line 4851

class CreateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end