Class: Aws::DataZone::Types::CreateGroupProfileOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:group_name]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_idString

The identifier of the Amazon DataZone domain in which the group profile is created.

Returns:

  • (String)


4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
# File 'lib/aws-sdk-datazone/types.rb', line 4729

class CreateGroupProfileOutput < Struct.new(
  :domain_id,
  :id,
  :status,
  :group_name,
  :role_principal_arn,
  :role_principal_id)
  SENSITIVE = [:group_name]
  include Aws::Structure
end

#group_nameString

The name of the group for which group profile is created.

Returns:

  • (String)


4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
# File 'lib/aws-sdk-datazone/types.rb', line 4729

class CreateGroupProfileOutput < Struct.new(
  :domain_id,
  :id,
  :status,
  :group_name,
  :role_principal_arn,
  :role_principal_id)
  SENSITIVE = [:group_name]
  include Aws::Structure
end

#idString

The identifier of the group profile.

Returns:

  • (String)


4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
# File 'lib/aws-sdk-datazone/types.rb', line 4729

class CreateGroupProfileOutput < Struct.new(
  :domain_id,
  :id,
  :status,
  :group_name,
  :role_principal_arn,
  :role_principal_id)
  SENSITIVE = [:group_name]
  include Aws::Structure
end

#role_principal_arnString

The ARN of the IAM role principal. This role is associated with the group profile.

Returns:

  • (String)


4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
# File 'lib/aws-sdk-datazone/types.rb', line 4729

class CreateGroupProfileOutput < Struct.new(
  :domain_id,
  :id,
  :status,
  :group_name,
  :role_principal_arn,
  :role_principal_id)
  SENSITIVE = [:group_name]
  include Aws::Structure
end

#role_principal_idString

The unique identifier of the IAM role principal. This principal is associated with the group profile.

Returns:

  • (String)


4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
# File 'lib/aws-sdk-datazone/types.rb', line 4729

class CreateGroupProfileOutput < Struct.new(
  :domain_id,
  :id,
  :status,
  :group_name,
  :role_principal_arn,
  :role_principal_id)
  SENSITIVE = [:group_name]
  include Aws::Structure
end

#statusString

The status of the group profile.

Returns:

  • (String)


4729
4730
4731
4732
4733
4734
4735
4736
4737
4738
# File 'lib/aws-sdk-datazone/types.rb', line 4729

class CreateGroupProfileOutput < Struct.new(
  :domain_id,
  :id,
  :status,
  :group_name,
  :role_principal_arn,
  :role_principal_id)
  SENSITIVE = [:group_name]
  include Aws::Structure
end