Class: Aws::DataZone::Types::CreateNotebookInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateNotebookInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :metadata, :parameters]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#description ⇒ String
The description of the notebook.
-
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which to create the notebook.
-
#metadata ⇒ Hash<String,String>
The metadata for the notebook, specified as key-value pairs.
-
#name ⇒ String
The name of the notebook.
-
#owning_project_identifier ⇒ String
The identifier of the project that owns the notebook.
-
#parameters ⇒ Hash<String,String>
The sensitive parameters for the notebook, specified as key-value pairs.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 |
# File 'lib/aws-sdk-datazone/types.rb', line 4908 class CreateNotebookInput < Struct.new( :domain_identifier, :owning_project_identifier, :name, :description, :metadata, :parameters, :client_token) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#description ⇒ String
The description of the notebook.
4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 |
# File 'lib/aws-sdk-datazone/types.rb', line 4908 class CreateNotebookInput < Struct.new( :domain_identifier, :owning_project_identifier, :name, :description, :metadata, :parameters, :client_token) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which to create the notebook.
4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 |
# File 'lib/aws-sdk-datazone/types.rb', line 4908 class CreateNotebookInput < Struct.new( :domain_identifier, :owning_project_identifier, :name, :description, :metadata, :parameters, :client_token) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The metadata for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 |
# File 'lib/aws-sdk-datazone/types.rb', line 4908 class CreateNotebookInput < Struct.new( :domain_identifier, :owning_project_identifier, :name, :description, :metadata, :parameters, :client_token) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#name ⇒ String
The name of the notebook. The name must be between 1 and 256 characters.
4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 |
# File 'lib/aws-sdk-datazone/types.rb', line 4908 class CreateNotebookInput < Struct.new( :domain_identifier, :owning_project_identifier, :name, :description, :metadata, :parameters, :client_token) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#owning_project_identifier ⇒ String
The identifier of the project that owns the notebook.
4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 |
# File 'lib/aws-sdk-datazone/types.rb', line 4908 class CreateNotebookInput < Struct.new( :domain_identifier, :owning_project_identifier, :name, :description, :metadata, :parameters, :client_token) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
The sensitive parameters for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 |
# File 'lib/aws-sdk-datazone/types.rb', line 4908 class CreateNotebookInput < Struct.new( :domain_identifier, :owning_project_identifier, :name, :description, :metadata, :parameters, :client_token) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |