Class: Aws::DataZone::Types::CreateProjectInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateProjectInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the Amazon DataZone project.
-
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain in which this project is created.
-
#domain_unit_id ⇒ String
The ID of the domain unit.
-
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in this Amazon DataZone project.
-
#membership_assignments ⇒ Array<Types::ProjectMembershipAssignment>
The members to be assigned to the project.
-
#name ⇒ String
The name of the Amazon DataZone project.
-
#project_category ⇒ String
The category of the project.
-
#project_execution_role ⇒ String
The default project IAM role that is used to access project resources and run computes such as Glue and Sagemaker.
-
#project_profile_id ⇒ String
The ID of the project profile.
-
#resource_tags ⇒ Hash<String,String>
The resource tags of the project.
-
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of the project.
Instance Attribute Details
#description ⇒ String
The description of the Amazon DataZone project.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain in which this project is created.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_unit_id ⇒ String
The ID of the domain unit. This parameter is not required and if it is not specified, then the project is created at the root domain unit level.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in this Amazon DataZone project.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#membership_assignments ⇒ Array<Types::ProjectMembershipAssignment>
The members to be assigned to the project.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone project.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_category ⇒ String
The category of the project. Set to ‘ADMIN’ designates this as an administrative project for the Amazon DataZone domain.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_execution_role ⇒ String
The default project IAM role that is used to access project resources and run computes such as Glue and Sagemaker.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_profile_id ⇒ String
The ID of the project profile.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#resource_tags ⇒ Hash<String,String>
The resource tags of the project.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of the project.
5077 5078 5079 5080 5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-datazone/types.rb', line 5077 class CreateProjectInput < Struct.new( :domain_identifier, :name, :description, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :project_category, :project_execution_role, :membership_assignments) SENSITIVE = [:name, :description] include Aws::Structure end |