Class: Aws::DataZone::Types::CreateProjectProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateProjectProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :project_resource_tags_description]
Instance Attribute Summary collapse
-
#allow_custom_project_resource_tags ⇒ Boolean
Specifies whether custom project resource tags are supported.
-
#created_at ⇒ Time
A timestamp at which a project profile is created.
-
#created_by ⇒ String
A user who created a project profile.
-
#description ⇒ String
A project profile description.
-
#domain_id ⇒ String
The ID of the domain where a project profile is created.
-
#domain_unit_id ⇒ String
The ID of the domain unit where a project profile is created.
-
#environment_configurations ⇒ Array<Types::EnvironmentConfiguration>
Environment configurations of a project profile.
-
#id ⇒ String
Project profile ID.
-
#last_updated_at ⇒ Time
A timestamp when a project profile was last updated.
-
#name ⇒ String
Project profile name.
-
#project_resource_tags ⇒ Array<Types::ResourceTagParameter>
The resource tags of the project profile.
-
#project_resource_tags_description ⇒ String
Field viewable through the UI that provides a project user with the allowed resource tag specifications.
-
#status ⇒ String
Project profile status.
Instance Attribute Details
#allow_custom_project_resource_tags ⇒ Boolean
Specifies whether custom project resource tags are supported.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#created_at ⇒ Time
A timestamp at which a project profile is created.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#created_by ⇒ String
A user who created a project profile.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#description ⇒ String
A project profile description.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain where a project profile is created.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#domain_unit_id ⇒ String
The ID of the domain unit where a project profile is created.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#environment_configurations ⇒ Array<Types::EnvironmentConfiguration>
Environment configurations of a project profile.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#id ⇒ String
Project profile ID.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#last_updated_at ⇒ Time
A timestamp when a project profile was last updated.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#name ⇒ String
Project profile name.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#project_resource_tags ⇒ Array<Types::ResourceTagParameter>
The resource tags of the project profile.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#project_resource_tags_description ⇒ String
Field viewable through the UI that provides a project user with the allowed resource tag specifications.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#status ⇒ String
Project profile status.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 |
# File 'lib/aws-sdk-datazone/types.rb', line 5135 class CreateProjectProfileOutput < Struct.new( :domain_id, :id, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :created_by, :created_at, :last_updated_at, :domain_unit_id) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |