Class: Aws::DataZone::Types::CreateRuleInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action of the rule.

Returns:

  • (String)


5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
# File 'lib/aws-sdk-datazone/types.rb', line 5234

class CreateRuleInput < Struct.new(
  :domain_identifier,
  :name,
  :target,
  :action,
  :scope,
  :detail,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
# File 'lib/aws-sdk-datazone/types.rb', line 5234

class CreateRuleInput < Struct.new(
  :domain_identifier,
  :name,
  :target,
  :action,
  :scope,
  :detail,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the rule.

Returns:

  • (String)


5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
# File 'lib/aws-sdk-datazone/types.rb', line 5234

class CreateRuleInput < Struct.new(
  :domain_identifier,
  :name,
  :target,
  :action,
  :scope,
  :detail,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#detailTypes::RuleDetail

The detail of the rule.

Returns:



5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
# File 'lib/aws-sdk-datazone/types.rb', line 5234

class CreateRuleInput < Struct.new(
  :domain_identifier,
  :name,
  :target,
  :action,
  :scope,
  :detail,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_identifierString

The ID of the domain where the rule is created.

Returns:

  • (String)


5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
# File 'lib/aws-sdk-datazone/types.rb', line 5234

class CreateRuleInput < Struct.new(
  :domain_identifier,
  :name,
  :target,
  :action,
  :scope,
  :detail,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the rule.

Returns:

  • (String)


5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
# File 'lib/aws-sdk-datazone/types.rb', line 5234

class CreateRuleInput < Struct.new(
  :domain_identifier,
  :name,
  :target,
  :action,
  :scope,
  :detail,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#scopeTypes::RuleScope

The scope of the rule.

Returns:



5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
# File 'lib/aws-sdk-datazone/types.rb', line 5234

class CreateRuleInput < Struct.new(
  :domain_identifier,
  :name,
  :target,
  :action,
  :scope,
  :detail,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#targetTypes::RuleTarget

The target of the rule.

Returns:



5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
5245
# File 'lib/aws-sdk-datazone/types.rb', line 5234

class CreateRuleInput < Struct.new(
  :domain_identifier,
  :name,
  :target,
  :action,
  :scope,
  :detail,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end