Class: Aws::DataZone::Types::CreateSubscriptionGrantInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_target_namesArray<Types::AssetTargetNameMap>

The names of the assets for which the subscription grant is created.

Returns:



5299
5300
5301
5302
5303
5304
5305
5306
5307
5308
# File 'lib/aws-sdk-datazone/types.rb', line 5299

class CreateSubscriptionGrantInput < Struct.new(
  :domain_identifier,
  :environment_identifier,
  :subscription_target_identifier,
  :granted_entity,
  :asset_target_names,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


5299
5300
5301
5302
5303
5304
5305
5306
5307
5308
# File 'lib/aws-sdk-datazone/types.rb', line 5299

class CreateSubscriptionGrantInput < Struct.new(
  :domain_identifier,
  :environment_identifier,
  :subscription_target_identifier,
  :granted_entity,
  :asset_target_names,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The ID of the Amazon DataZone domain in which the subscription grant is created.

Returns:

  • (String)


5299
5300
5301
5302
5303
5304
5305
5306
5307
5308
# File 'lib/aws-sdk-datazone/types.rb', line 5299

class CreateSubscriptionGrantInput < Struct.new(
  :domain_identifier,
  :environment_identifier,
  :subscription_target_identifier,
  :granted_entity,
  :asset_target_names,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#environment_identifierString

The ID of the environment in which the subscription grant is created.

Returns:

  • (String)


5299
5300
5301
5302
5303
5304
5305
5306
5307
5308
# File 'lib/aws-sdk-datazone/types.rb', line 5299

class CreateSubscriptionGrantInput < Struct.new(
  :domain_identifier,
  :environment_identifier,
  :subscription_target_identifier,
  :granted_entity,
  :asset_target_names,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#granted_entityTypes::GrantedEntityInput

The entity to which the subscription is to be granted.



5299
5300
5301
5302
5303
5304
5305
5306
5307
5308
# File 'lib/aws-sdk-datazone/types.rb', line 5299

class CreateSubscriptionGrantInput < Struct.new(
  :domain_identifier,
  :environment_identifier,
  :subscription_target_identifier,
  :granted_entity,
  :asset_target_names,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_target_identifierString

The ID of the subscription target for which the subscription grant is created.

Returns:

  • (String)


5299
5300
5301
5302
5303
5304
5305
5306
5307
5308
# File 'lib/aws-sdk-datazone/types.rb', line 5299

class CreateSubscriptionGrantInput < Struct.new(
  :domain_identifier,
  :environment_identifier,
  :subscription_target_identifier,
  :granted_entity,
  :asset_target_names,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end