Class: Aws::DataZone::Types::CreateUserProfileInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


5701
5702
5703
5704
5705
5706
5707
5708
5709
# File 'lib/aws-sdk-datazone/types.rb', line 5701

class CreateUserProfileInput < Struct.new(
  :domain_identifier,
  :user_identifier,
  :user_type,
  :session_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain in which a user profile is created.

Returns:

  • (String)


5701
5702
5703
5704
5705
5706
5707
5708
5709
# File 'lib/aws-sdk-datazone/types.rb', line 5701

class CreateUserProfileInput < Struct.new(
  :domain_identifier,
  :user_identifier,
  :user_type,
  :session_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#session_nameString

The session name for IAM role sessions.

Returns:

  • (String)


5701
5702
5703
5704
5705
5706
5707
5708
5709
# File 'lib/aws-sdk-datazone/types.rb', line 5701

class CreateUserProfileInput < Struct.new(
  :domain_identifier,
  :user_identifier,
  :user_type,
  :session_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#user_identifierString

The identifier of the user for which the user profile is created.

Returns:

  • (String)


5701
5702
5703
5704
5705
5706
5707
5708
5709
# File 'lib/aws-sdk-datazone/types.rb', line 5701

class CreateUserProfileInput < Struct.new(
  :domain_identifier,
  :user_identifier,
  :user_type,
  :session_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#user_typeString

The user type of the user for which the user profile is created.

Returns:

  • (String)


5701
5702
5703
5704
5705
5706
5707
5708
5709
# File 'lib/aws-sdk-datazone/types.rb', line 5701

class CreateUserProfileInput < Struct.new(
  :domain_identifier,
  :user_identifier,
  :user_type,
  :session_name,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end