Class: Aws::DataZone::Types::CreateUserProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateUserProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#details ⇒ Types::UserProfileDetails
The user profile details.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a user profile is created.
-
#id ⇒ String
The identifier of the user profile.
-
#status ⇒ String
The status of the user profile.
-
#type ⇒ String
The type of the user profile.
Instance Attribute Details
#details ⇒ Types::UserProfileDetails
The user profile details.
5953 5954 5955 5956 5957 5958 5959 5960 5961 |
# File 'lib/aws-sdk-datazone/types.rb', line 5953 class CreateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a user profile is created.
5953 5954 5955 5956 5957 5958 5959 5960 5961 |
# File 'lib/aws-sdk-datazone/types.rb', line 5953 class CreateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the user profile.
5953 5954 5955 5956 5957 5958 5959 5960 5961 |
# File 'lib/aws-sdk-datazone/types.rb', line 5953 class CreateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the user profile.
5953 5954 5955 5956 5957 5958 5959 5960 5961 |
# File 'lib/aws-sdk-datazone/types.rb', line 5953 class CreateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the user profile.
5953 5954 5955 5956 5957 5958 5959 5960 5961 |
# File 'lib/aws-sdk-datazone/types.rb', line 5953 class CreateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |