Class: Aws::DataZone::Types::DataSourceConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceConfigurationInput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
DataSourceConfigurationInput is a union - when making an API calls you must set exactly one of the members.
The configuration of the data source.
Direct Known Subclasses
GlueRunConfiguration, RedshiftRunConfiguration, SageMakerRunConfiguration, Unknown
Defined Under Namespace
Classes: GlueRunConfiguration, RedshiftRunConfiguration, SageMakerRunConfiguration, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#glue_run_configuration ⇒ Types::GlueRunConfigurationInput
The configuration of the Amazon Web Services Glue data source.
-
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationInput
The configuration of the Amazon Redshift data source.
-
#sage_maker_run_configuration ⇒ Types::SageMakerRunConfigurationInput
The Amazon SageMaker run configuration.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#glue_run_configuration ⇒ Types::GlueRunConfigurationInput
The configuration of the Amazon Web Services Glue data source.
6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 |
# File 'lib/aws-sdk-datazone/types.rb', line 6327 class DataSourceConfigurationInput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :sage_maker_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationInput; end class RedshiftRunConfiguration < DataSourceConfigurationInput; end class SageMakerRunConfiguration < DataSourceConfigurationInput; end class Unknown < DataSourceConfigurationInput; end end |
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationInput
The configuration of the Amazon Redshift data source.
6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 |
# File 'lib/aws-sdk-datazone/types.rb', line 6327 class DataSourceConfigurationInput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :sage_maker_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationInput; end class RedshiftRunConfiguration < DataSourceConfigurationInput; end class SageMakerRunConfiguration < DataSourceConfigurationInput; end class Unknown < DataSourceConfigurationInput; end end |
#sage_maker_run_configuration ⇒ Types::SageMakerRunConfigurationInput
The Amazon SageMaker run configuration.
6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 |
# File 'lib/aws-sdk-datazone/types.rb', line 6327 class DataSourceConfigurationInput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :sage_maker_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationInput; end class RedshiftRunConfiguration < DataSourceConfigurationInput; end class SageMakerRunConfiguration < DataSourceConfigurationInput; end class Unknown < DataSourceConfigurationInput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6327 6328 6329 |
# File 'lib/aws-sdk-datazone/types.rb', line 6327 def unknown @unknown end |