Class: Aws::DataZone::Types::DataSourceConfigurationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceConfigurationOutput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
DataSourceConfigurationOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of DataSourceConfigurationOutput corresponding to the set member.
The configuration of the data source.
Direct Known Subclasses
Defined Under Namespace
Classes: GlueRunConfiguration, RedshiftRunConfiguration, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#glue_run_configuration ⇒ Types::GlueRunConfigurationOutput
The configuration of the Amazon Web Services Glue data source.
-
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationOutput
The configuration of the Amazon Redshift data source.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#glue_run_configuration ⇒ Types::GlueRunConfigurationOutput
The configuration of the Amazon Web Services Glue data source.
2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-datazone/types.rb', line 2878 class DataSourceConfigurationOutput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationOutput; end class RedshiftRunConfiguration < DataSourceConfigurationOutput; end class Unknown < DataSourceConfigurationOutput; end end |
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationOutput
The configuration of the Amazon Redshift data source.
2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 |
# File 'lib/aws-sdk-datazone/types.rb', line 2878 class DataSourceConfigurationOutput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationOutput; end class RedshiftRunConfiguration < DataSourceConfigurationOutput; end class Unknown < DataSourceConfigurationOutput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2878 2879 2880 |
# File 'lib/aws-sdk-datazone/types.rb', line 2878 def unknown @unknown end |