Class: Aws::DataZone::Types::DataSourceErrorMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceErrorMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the error message that is returned if the operation cannot be successfully completed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_detail ⇒ String
The details of the error message that is returned if the operation cannot be successfully completed.
-
#error_type ⇒ String
The type of the error message that is returned if the operation cannot be successfully completed.
Instance Attribute Details
#error_detail ⇒ String
The details of the error message that is returned if the operation cannot be successfully completed.
6171 6172 6173 6174 6175 6176 |
# File 'lib/aws-sdk-datazone/types.rb', line 6171 class DataSourceErrorMessage < Struct.new( :error_type, :error_detail) SENSITIVE = [] include Aws::Structure end |
#error_type ⇒ String
The type of the error message that is returned if the operation cannot be successfully completed.
6171 6172 6173 6174 6175 6176 |
# File 'lib/aws-sdk-datazone/types.rb', line 6171 class DataSourceErrorMessage < Struct.new( :error_type, :error_detail) SENSITIVE = [] include Aws::Structure end |