Class: Aws::DataZone::Types::DeleteAssetTypeInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_identifierString

The ID of the Amazon DataZone domain in which the asset type is deleted.

Returns:

  • (String)


6495
6496
6497
6498
6499
6500
# File 'lib/aws-sdk-datazone/types.rb', line 6495

class DeleteAssetTypeInput < Struct.new(
  :domain_identifier,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the asset type that is deleted.

Returns:

  • (String)


6495
6496
6497
6498
6499
6500
# File 'lib/aws-sdk-datazone/types.rb', line 6495

class DeleteAssetTypeInput < Struct.new(
  :domain_identifier,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end