Class: Aws::DataZone::Types::DeleteDataExportConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DeleteDataExportConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_identifier ⇒ String
The domain ID for which you want to delete the data export configuration.
Instance Attribute Details
#domain_identifier ⇒ String
The domain ID for which you want to delete the data export configuration.
6560 6561 6562 6563 6564 |
# File 'lib/aws-sdk-datazone/types.rb', line 6560 class DeleteDataExportConfigurationInput < Struct.new( :domain_identifier) SENSITIVE = [] include Aws::Structure end |