Class: Aws::DataZone::Types::DeleteDataSourceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DeleteDataSourceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain in which the data source is deleted.
-
#identifier ⇒ String
The identifier of the data source that is deleted.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3172 3173 3174 3175 3176 3177 3178 |
# File 'lib/aws-sdk-datazone/types.rb', line 3172 class DeleteDataSourceInput < Struct.new( :client_token, :domain_identifier, :identifier) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain in which the data source is deleted.
3172 3173 3174 3175 3176 3177 3178 |
# File 'lib/aws-sdk-datazone/types.rb', line 3172 class DeleteDataSourceInput < Struct.new( :client_token, :domain_identifier, :identifier) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the data source that is deleted.
3172 3173 3174 3175 3176 3177 3178 |
# File 'lib/aws-sdk-datazone/types.rb', line 3172 class DeleteDataSourceInput < Struct.new( :client_token, :domain_identifier, :identifier) SENSITIVE = [] include Aws::Structure end |