Class: Aws::DataZone::Types::DeleteDomainInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


7091
7092
7093
7094
7095
7096
7097
# File 'lib/aws-sdk-datazone/types.rb', line 7091

class DeleteDomainInput < Struct.new(
  :identifier,
  :client_token,
  :skip_deletion_check)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the Amazon Web Services domain that is to be deleted.

Returns:

  • (String)


7091
7092
7093
7094
7095
7096
7097
# File 'lib/aws-sdk-datazone/types.rb', line 7091

class DeleteDomainInput < Struct.new(
  :identifier,
  :client_token,
  :skip_deletion_check)
  SENSITIVE = []
  include Aws::Structure
end

#skip_deletion_checkBoolean

Specifies the optional flag to delete all child entities within the domain.

Returns:

  • (Boolean)


7091
7092
7093
7094
7095
7096
7097
# File 'lib/aws-sdk-datazone/types.rb', line 7091

class DeleteDomainInput < Struct.new(
  :identifier,
  :client_token,
  :skip_deletion_check)
  SENSITIVE = []
  include Aws::Structure
end