Class: Aws::DataZone::Types::DeleteEnvironmentActionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_identifierString

The ID of the Amazon DataZone domain in which an environment action is deleted.

Returns:

  • (String)


4333
4334
4335
4336
4337
4338
4339
# File 'lib/aws-sdk-datazone/types.rb', line 4333

class DeleteEnvironmentActionInput < Struct.new(
  :domain_identifier,
  :environment_identifier,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#environment_identifierString

The ID of the environment where an environment action is deleted.

Returns:

  • (String)


4333
4334
4335
4336
4337
4338
4339
# File 'lib/aws-sdk-datazone/types.rb', line 4333

class DeleteEnvironmentActionInput < Struct.new(
  :domain_identifier,
  :environment_identifier,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The ID of the environment action that is deleted.

Returns:

  • (String)


4333
4334
4335
4336
4337
4338
4339
# File 'lib/aws-sdk-datazone/types.rb', line 4333

class DeleteEnvironmentActionInput < Struct.new(
  :domain_identifier,
  :environment_identifier,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end