Class: Aws::DataZone::Types::DeleteRuleInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DeleteRuleInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_identifier ⇒ String
The ID of the domain that where the rule is to be deleted.
-
#identifier ⇒ String
The ID of the rule that is to be deleted.
Instance Attribute Details
#domain_identifier ⇒ String
The ID of the domain that where the rule is to be deleted.
7108 7109 7110 7111 7112 7113 |
# File 'lib/aws-sdk-datazone/types.rb', line 7108 class DeleteRuleInput < Struct.new( :domain_identifier, :identifier) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The ID of the rule that is to be deleted.
7108 7109 7110 7111 7112 7113 |
# File 'lib/aws-sdk-datazone/types.rb', line 7108 class DeleteRuleInput < Struct.new( :domain_identifier, :identifier) SENSITIVE = [] include Aws::Structure end |