Class: Aws::DataZone::Types::EnvironmentBlueprintSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::EnvironmentBlueprintSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of an environment blueprint summary.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when an environment blueprint was created.
-
#description ⇒ String
The description of a blueprint.
-
#id ⇒ String
The identifier of the blueprint.
-
#name ⇒ String
The name of the blueprint.
-
#provider ⇒ String
The provider of the blueprint.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties of the blueprint.
-
#updated_at ⇒ Time
The timestamp of when the blueprint was enabled.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when an environment blueprint was created.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-datazone/types.rb', line 7807 class EnvironmentBlueprintSummary < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of a blueprint.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-datazone/types.rb', line 7807 class EnvironmentBlueprintSummary < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#id ⇒ String
The identifier of the blueprint.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-datazone/types.rb', line 7807 class EnvironmentBlueprintSummary < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the blueprint.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-datazone/types.rb', line 7807 class EnvironmentBlueprintSummary < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#provider ⇒ String
The provider of the blueprint.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-datazone/types.rb', line 7807 class EnvironmentBlueprintSummary < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties of the blueprint.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-datazone/types.rb', line 7807 class EnvironmentBlueprintSummary < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the blueprint was enabled.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 |
# File 'lib/aws-sdk-datazone/types.rb', line 7807 class EnvironmentBlueprintSummary < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |