Class: Aws::DataZone::Types::EnvironmentProfileSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::EnvironmentProfileSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of an environment profile.
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The identifier of an Amazon Web Services account in which an environment profile exists.
-
#aws_account_region ⇒ String
The Amazon Web Services Region in which an environment profile exists.
-
#created_at ⇒ Time
The timestamp of when an environment profile was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the environment profile.
-
#description ⇒ String
The description of the environment profile.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the environment profile exists.
-
#environment_blueprint_id ⇒ String
The identifier of a blueprint with which an environment profile is created.
-
#id ⇒ String
The identifier of the environment profile.
-
#name ⇒ String
The name of the environment profile.
-
#project_id ⇒ String
The identifier of a project in which an environment profile exists.
-
#updated_at ⇒ Time
The timestamp of when the environment profile was updated.
Instance Attribute Details
#aws_account_id ⇒ String
The identifier of an Amazon Web Services account in which an environment profile exists.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services Region in which an environment profile exists.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when an environment profile was created.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the environment profile.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the environment profile.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the environment profile exists.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The identifier of a blueprint with which an environment profile is created.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The identifier of the environment profile.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the environment profile.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_id ⇒ String
The identifier of a project in which an environment profile exists.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the environment profile was updated.
8067 8068 8069 8070 8071 8072 8073 8074 8075 8076 8077 8078 8079 8080 8081 |
# File 'lib/aws-sdk-datazone/types.rb', line 8067 class EnvironmentProfileSummary < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id) SENSITIVE = [:name, :description] include Aws::Structure end |