Class: Aws::DataZone::Types::EventSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::EventSummary
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
EventSummary is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of EventSummary corresponding to the set member.
The event summary.
Direct Known Subclasses
Defined Under Namespace
Classes: OpenLineageRunEventSummary, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#open_lineage_run_event_summary ⇒ Types::OpenLineageRunEventSummary
The open lineage run event summary.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#open_lineage_run_event_summary ⇒ Types::OpenLineageRunEventSummary
The open lineage run event summary.
8467 8468 8469 8470 8471 8472 8473 8474 8475 8476 |
# File 'lib/aws-sdk-datazone/types.rb', line 8467 class EventSummary < Struct.new( :open_lineage_run_event_summary, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpenLineageRunEventSummary < EventSummary; end class Unknown < EventSummary; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8467 8468 8469 |
# File 'lib/aws-sdk-datazone/types.rb', line 8467 def unknown @unknown end |