Class: Aws::DataZone::Types::FormTypeData
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::FormTypeData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the metadata form type.
Constant Summary collapse
- SENSITIVE =
[:name, :model, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the metadata form type was created.
-
#created_by ⇒ String
The Amazon DataZone user who created teh metadata form type.
-
#description ⇒ String
The description of the metadata form type.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type exists.
-
#imports ⇒ Array<Types::Import>
The imports specified in the form type.
-
#model ⇒ Types::Model
The model of the form type.
-
#name ⇒ String
The name of the form type.
-
#origin_domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type was originally created.
-
#origin_project_id ⇒ String
The identifier of the project in which the form type was originally created.
-
#owning_project_id ⇒ String
The identifier of the project that owns the form type.
-
#revision ⇒ String
The revision of the form type.
-
#status ⇒ String
The status of the form type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the metadata form type was created.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created teh metadata form type.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#description ⇒ String
The description of the metadata form type.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type exists.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#imports ⇒ Array<Types::Import>
The imports specified in the form type.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#model ⇒ Types::Model
The model of the form type.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#name ⇒ String
The name of the form type.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#origin_domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type was originally created.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#origin_project_id ⇒ String
The identifier of the project in which the form type was originally created.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the form type.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#revision ⇒ String
The revision of the form type.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#status ⇒ String
The status of the form type.
8919 8920 8921 8922 8923 8924 8925 8926 8927 8928 8929 8930 8931 8932 8933 8934 |
# File 'lib/aws-sdk-datazone/types.rb', line 8919 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |