Class: Aws::DataZone::Types::GetAccountPoolOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetAccountPoolOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#account_source ⇒ Types::AccountSource
The source of accounts for the account pool.
-
#created_at ⇒ Time
The timestamp at which the account pool was created.
-
#created_by ⇒ String
The user who created the account pool.
-
#description ⇒ String
The description of the account pool.
-
#domain_id ⇒ String
The ID of the domain in which the account pool lives whose details are to be displayed.
-
#domain_unit_id ⇒ String
The domain unit ID of the account pool.
-
#id ⇒ String
The ID of the account pool.
-
#last_updated_at ⇒ Time
The timestamp at which the account pool was last updated.
-
#name ⇒ String
The name of the account pool.
-
#resolution_strategy ⇒ String
The mechanism used to resolve the account selection from the account pool.
-
#updated_by ⇒ String
The user who last updated the account pool.
Instance Attribute Details
#account_source ⇒ Types::AccountSource
The source of accounts for the account pool. In the current release, it's either a static list of accounts provided by the customer or a custom Amazon Web Services Lambda handler.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp at which the account pool was created.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The user who created the account pool.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the account pool.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain in which the account pool lives whose details are to be displayed.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_unit_id ⇒ String
The domain unit ID of the account pool.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The ID of the account pool.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp at which the account pool was last updated.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the account pool.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#resolution_strategy ⇒ String
The mechanism used to resolve the account selection from the account pool.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_by ⇒ String
The user who last updated the account pool.
9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 |
# File 'lib/aws-sdk-datazone/types.rb', line 9027 class GetAccountPoolOutput < Struct.new( :domain_id, :name, :id, :description, :resolution_strategy, :account_source, :created_by, :created_at, :last_updated_at, :updated_by, :domain_unit_id) SENSITIVE = [:name, :description] include Aws::Structure end |