Class: Aws::DataZone::Types::GetDataExportConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDataExportConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_identifier ⇒ String
The ID of the domain where you want to get the data export configuration details.
Instance Attribute Details
#domain_identifier ⇒ String
The ID of the domain where you want to get the data export configuration details.
8960 8961 8962 8963 8964 |
# File 'lib/aws-sdk-datazone/types.rb', line 8960 class GetDataExportConfigurationInput < Struct.new( :domain_identifier) SENSITIVE = [] include Aws::Structure end |