Class: Aws::DataZone::Types::GetDataExportConfigurationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp at which the data export configuration report was created.

Returns:

  • (Time)


8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
# File 'lib/aws-sdk-datazone/types.rb', line 8996

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The encryption configuration as part of the data export configuration details.



8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
# File 'lib/aws-sdk-datazone/types.rb', line 8996

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#is_export_enabledBoolean

Specifies whether the export is enabled.

Returns:

  • (Boolean)


8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
# File 'lib/aws-sdk-datazone/types.rb', line 8996

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#s3_table_bucket_arnString

The Amazon S3 table bucket ARN as part of the data export configuration details.

Returns:

  • (String)


8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
# File 'lib/aws-sdk-datazone/types.rb', line 8996

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the data export configuration.

Returns:

  • (String)


8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
# File 'lib/aws-sdk-datazone/types.rb', line 8996

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp at which the data export configuration report was updated.

Returns:

  • (Time)


8996
8997
8998
8999
9000
9001
9002
9003
9004
9005
# File 'lib/aws-sdk-datazone/types.rb', line 8996

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end