Class: Aws::DataZone::Types::GetDomainOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDomainOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the specified Amazon DataZone domain.
-
#created_at ⇒ Time
The timestamp of when the Amazon DataZone domain was created.
-
#description ⇒ String
The description of the Amazon DataZone domain.
-
#domain_execution_role ⇒ String
The domain execution role with which the Amazon DataZone domain is created.
-
#domain_version ⇒ String
The version of the domain.
-
#id ⇒ String
The identifier of the specified Amazon DataZone domain.
-
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
-
#last_updated_at ⇒ Time
The timestamp of when the Amazon DataZone domain was last updated.
-
#name ⇒ String
The name of the Amazon DataZone domain.
-
#portal_url ⇒ String
The URL of the data portal for this Amazon DataZone domain.
-
#root_domain_unit_id ⇒ String
The ID of the root domain in Amazon Datazone.
-
#service_role ⇒ String
The service role of the domain.
-
#single_sign_on ⇒ Types::SingleSignOn
The single sing-on option of the specified Amazon DataZone domain.
-
#status ⇒ String
The status of the specified Amazon DataZone domain.
-
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
Instance Attribute Details
#arn ⇒ String
The ARN of the specified Amazon DataZone domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the Amazon DataZone domain was created.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role ⇒ String
The domain execution role with which the Amazon DataZone domain is created.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#domain_version ⇒ String
The version of the domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the specified Amazon DataZone domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the Amazon DataZone domain was last updated.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#portal_url ⇒ String
The URL of the data portal for this Amazon DataZone domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#root_domain_unit_id ⇒ String
The ID of the root domain in Amazon Datazone.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The service role of the domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#single_sign_on ⇒ Types::SingleSignOn
The single sing-on option of the specified Amazon DataZone domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the specified Amazon DataZone domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
9715 9716 9717 9718 9719 9720 9721 9722 9723 9724 9725 9726 9727 9728 9729 9730 9731 9732 9733 |
# File 'lib/aws-sdk-datazone/types.rb', line 9715 class GetDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :created_at, :last_updated_at, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |