Class: Aws::DataZone::Types::GetDomainUnitOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDomainUnitOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time stamp at which the domain unit was created.
-
#created_by ⇒ String
The user who created the domain unit.
-
#description ⇒ String
The description of the domain unit.
-
#domain_id ⇒ String
The ID of the domain in which the domain unit lives.
-
#id ⇒ String
The ID of the domain unit.
-
#last_updated_at ⇒ Time
The timestamp at which the domain unit was last updated.
-
#last_updated_by ⇒ String
The user who last updated the domain unit.
-
#name ⇒ String
The name of the domain unit.
-
#owners ⇒ Array<Types::DomainUnitOwnerProperties>
The owners of the domain unit.
-
#parent_domain_unit_id ⇒ String
The ID of the parent domain unit.
Instance Attribute Details
#created_at ⇒ Time
The time stamp at which the domain unit was created.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The user who created the domain unit.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the domain unit.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain in which the domain unit lives.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The ID of the domain unit.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp at which the domain unit was last updated.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#last_updated_by ⇒ String
The user who last updated the domain unit.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the domain unit.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#owners ⇒ Array<Types::DomainUnitOwnerProperties>
The owners of the domain unit.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#parent_domain_unit_id ⇒ String
The ID of the parent domain unit.
9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 |
# File 'lib/aws-sdk-datazone/types.rb', line 9551 class GetDomainUnitOutput < Struct.new( :id, :domain_id, :name, :parent_domain_unit_id, :description, :owners, :created_at, :last_updated_at, :created_by, :last_updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |