Class: Aws::DataZone::Types::GetEnvironmentProfileOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account where this environment profile exists.

Returns:

  • (String)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#aws_account_regionString

The Amazon Web Services region where this environment profile exists.

Returns:

  • (String)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_atTime

The timestamp of when this environment profile was created.

Returns:

  • (Time)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created this environment profile.

Returns:

  • (String)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the environment profile.

Returns:

  • (String)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which this environment profile exists.

Returns:

  • (String)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#environment_blueprint_idString

The ID of the blueprint with which this environment profile is created.

Returns:

  • (String)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The ID of the environment profile.

Returns:

  • (String)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the environment profile.

Returns:

  • (String)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#project_idString

The ID of the Amazon DataZone project in which this environment profile is created.

Returns:

  • (String)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_atTime

The timestamp of when this environment profile was upated.

Returns:

  • (Time)


10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#user_parametersArray<Types::CustomParameter>

The user parameters of the environment profile.

Returns:



10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
# File 'lib/aws-sdk-datazone/types.rb', line 10498

class GetEnvironmentProfileOutput < Struct.new(
  :id,
  :domain_id,
  :aws_account_id,
  :aws_account_region,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_blueprint_id,
  :project_id,
  :user_parameters)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end