Class: Aws::DataZone::Types::GetGroupProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetGroupProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:group_name]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the group profile exists.
-
#group_name ⇒ String
The name of the group for which the specified group profile exists.
-
#id ⇒ String
The identifier of the group profile.
-
#role_principal_arn ⇒ String
The ARN of the IAM role principal.
-
#role_principal_id ⇒ String
The unique identifier of the IAM role principal.
-
#status ⇒ String
The identifier of the group profile.
Instance Attribute Details
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the group profile exists.
10366 10367 10368 10369 10370 10371 10372 10373 10374 10375 |
# File 'lib/aws-sdk-datazone/types.rb', line 10366 class GetGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#group_name ⇒ String
The name of the group for which the specified group profile exists.
10366 10367 10368 10369 10370 10371 10372 10373 10374 10375 |
# File 'lib/aws-sdk-datazone/types.rb', line 10366 class GetGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#id ⇒ String
The identifier of the group profile.
10366 10367 10368 10369 10370 10371 10372 10373 10374 10375 |
# File 'lib/aws-sdk-datazone/types.rb', line 10366 class GetGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#role_principal_arn ⇒ String
The ARN of the IAM role principal. This role is associated with the group profile.
10366 10367 10368 10369 10370 10371 10372 10373 10374 10375 |
# File 'lib/aws-sdk-datazone/types.rb', line 10366 class GetGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#role_principal_id ⇒ String
The unique identifier of the IAM role principal. This principal is associated with the group profile.
10366 10367 10368 10369 10370 10371 10372 10373 10374 10375 |
# File 'lib/aws-sdk-datazone/types.rb', line 10366 class GetGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#status ⇒ String
The identifier of the group profile.
10366 10367 10368 10369 10370 10371 10372 10373 10374 10375 |
# File 'lib/aws-sdk-datazone/types.rb', line 10366 class GetGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |