Class: Aws::DataZone::Types::GetJobRunOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the job run was created.

Returns:

  • (Time)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The user who created the job run.

Returns:

  • (String)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#detailsTypes::JobRunDetails

The details of the job run.



10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain.

Returns:

  • (String)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The timestamp of when the job run ended.

Returns:

  • (Time)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#errorTypes::JobRunError

The error generated if the action is not completed successfully.

Returns:



10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the job run.

Returns:

  • (String)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The ID of the job run.

Returns:

  • (String)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_typeString

The type of the job run.

Returns:

  • (String)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#run_modeString

The mode of the job run.

Returns:

  • (String)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The timestamp of when the job run started.

Returns:

  • (Time)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the job run.

Returns:

  • (String)


10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
# File 'lib/aws-sdk-datazone/types.rb', line 10492

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end