Class: Aws::DataZone::Types::GetLineageEventOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetLineageEventOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:event]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the lineage event was created.
-
#created_by ⇒ String
The user who created the lineage event.
-
#domain_id ⇒ String
The ID of the domain.
-
#event ⇒ String
The lineage event details.
-
#event_time ⇒ Time
The time of the lineage event.
-
#id ⇒ String
The ID of the lineage event.
-
#processing_status ⇒ String
The progressing status of the lineage event.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the lineage event was created.
10781 10782 10783 10784 10785 10786 10787 10788 10789 10790 10791 |
# File 'lib/aws-sdk-datazone/types.rb', line 10781 class GetLineageEventOutput < Struct.new( :domain_id, :id, :event, :created_by, :processing_status, :event_time, :created_at) SENSITIVE = [:event] include Aws::Structure end |
#created_by ⇒ String
The user who created the lineage event.
10781 10782 10783 10784 10785 10786 10787 10788 10789 10790 10791 |
# File 'lib/aws-sdk-datazone/types.rb', line 10781 class GetLineageEventOutput < Struct.new( :domain_id, :id, :event, :created_by, :processing_status, :event_time, :created_at) SENSITIVE = [:event] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain.
10781 10782 10783 10784 10785 10786 10787 10788 10789 10790 10791 |
# File 'lib/aws-sdk-datazone/types.rb', line 10781 class GetLineageEventOutput < Struct.new( :domain_id, :id, :event, :created_by, :processing_status, :event_time, :created_at) SENSITIVE = [:event] include Aws::Structure end |
#event ⇒ String
The lineage event details.
10781 10782 10783 10784 10785 10786 10787 10788 10789 10790 10791 |
# File 'lib/aws-sdk-datazone/types.rb', line 10781 class GetLineageEventOutput < Struct.new( :domain_id, :id, :event, :created_by, :processing_status, :event_time, :created_at) SENSITIVE = [:event] include Aws::Structure end |
#event_time ⇒ Time
The time of the lineage event.
10781 10782 10783 10784 10785 10786 10787 10788 10789 10790 10791 |
# File 'lib/aws-sdk-datazone/types.rb', line 10781 class GetLineageEventOutput < Struct.new( :domain_id, :id, :event, :created_by, :processing_status, :event_time, :created_at) SENSITIVE = [:event] include Aws::Structure end |
#id ⇒ String
The ID of the lineage event.
10781 10782 10783 10784 10785 10786 10787 10788 10789 10790 10791 |
# File 'lib/aws-sdk-datazone/types.rb', line 10781 class GetLineageEventOutput < Struct.new( :domain_id, :id, :event, :created_by, :processing_status, :event_time, :created_at) SENSITIVE = [:event] include Aws::Structure end |
#processing_status ⇒ String
The progressing status of the lineage event.
10781 10782 10783 10784 10785 10786 10787 10788 10789 10790 10791 |
# File 'lib/aws-sdk-datazone/types.rb', line 10781 class GetLineageEventOutput < Struct.new( :domain_id, :id, :event, :created_by, :processing_status, :event_time, :created_at) SENSITIVE = [:event] include Aws::Structure end |