Class: Aws::DataZone::Types::GetLineageNodeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetLineageNodeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp at which the data lineage node was created.
-
#created_by ⇒ String
The user who created the data lineage node.
-
#description ⇒ String
The description of the data lineage node.
-
#domain_id ⇒ String
The ID of the domain where you're getting the data lineage node.
-
#downstream_nodes ⇒ Array<Types::LineageNodeReference>
The downsteam nodes of the specified data lineage node.
-
#event_timestamp ⇒ Time
The timestamp of the event described in the data lineage node.
-
#forms_output ⇒ Array<Types::FormOutput>
The metadata of the specified data lineage node.
-
#id ⇒ String
The ID of the data lineage node.
-
#name ⇒ String
The name of the data lineage node.
-
#source_identifier ⇒ String
The source identifier of the data lineage node.
-
#type_name ⇒ String
The name of the type of the specified data lineage node.
-
#type_revision ⇒ String
The revision type of the specified data lineage node.
-
#updated_at ⇒ Time
The timestamp at which the data lineage node was updated.
-
#updated_by ⇒ String
The user who updated the data lineage node.
-
#upstream_nodes ⇒ Array<Types::LineageNodeReference>
The upstream nodes of the specified data lineage node.
Instance Attribute Details
#created_at ⇒ Time
The timestamp at which the data lineage node was created.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user who created the data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain where you're getting the data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#downstream_nodes ⇒ Array<Types::LineageNodeReference>
The downsteam nodes of the specified data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#event_timestamp ⇒ Time
The timestamp of the event described in the data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#forms_output ⇒ Array<Types::FormOutput>
The metadata of the specified data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#source_identifier ⇒ String
The source identifier of the data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the type of the specified data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#type_revision ⇒ String
The revision type of the specified data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp at which the data lineage node was updated.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user who updated the data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |
#upstream_nodes ⇒ Array<Types::LineageNodeReference>
The upstream nodes of the specified data lineage node.
11102 11103 11104 11105 11106 11107 11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 |
# File 'lib/aws-sdk-datazone/types.rb', line 11102 class GetLineageNodeOutput < Struct.new( :domain_id, :name, :description, :created_at, :created_by, :updated_at, :updated_by, :id, :type_name, :type_revision, :source_identifier, :event_timestamp, :forms_output, :upstream_nodes, :downstream_nodes) SENSITIVE = [] include Aws::Structure end |