Class: Aws::DataZone::Types::GetNotebookExportInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetNotebookExportInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which the notebook export exists.
-
#identifier ⇒ String
The identifier of the notebook export.
Instance Attribute Details
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which the notebook export exists.
11082 11083 11084 11085 11086 11087 |
# File 'lib/aws-sdk-datazone/types.rb', line 11082 class GetNotebookExportInput < Struct.new( :domain_identifier, :identifier) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the notebook export.
11082 11083 11084 11085 11086 11087 |
# File 'lib/aws-sdk-datazone/types.rb', line 11082 class GetNotebookExportInput < Struct.new( :domain_identifier, :identifier) SENSITIVE = [] include Aws::Structure end |