Class: Aws::DataZone::Types::GetNotebookExportOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completed_atTime

The timestamp of when the notebook export completed.

Returns:

  • (Time)


11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp of when the notebook export was started.

Returns:

  • (Time)


11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The identifier of the user who started the notebook export.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon SageMaker Unified Studio domain.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#errorTypes::NotebookExportError

The error details if the notebook export failed.



11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#file_formatString

The file format of the notebook export.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the notebook export.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#notebook_idString

The identifier of the notebook.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#output_locationTypes::OutputLocation

The output location of the exported notebook in Amazon Simple Storage Service.



11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the notebook.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the notebook export.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
11190
# File 'lib/aws-sdk-datazone/types.rb', line 11176

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end