Class: Aws::DataZone::Types::GetNotebookRunInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetNotebookRunInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which the notebook run exists.
-
#identifier ⇒ String
The identifier of the notebook run.
Instance Attribute Details
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which the notebook run exists.
11362 11363 11364 11365 11366 11367 |
# File 'lib/aws-sdk-datazone/types.rb', line 11362 class GetNotebookRunInput < Struct.new( :domain_identifier, :identifier) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the notebook run.
11362 11363 11364 11365 11366 11367 |
# File 'lib/aws-sdk-datazone/types.rb', line 11362 class GetNotebookRunInput < Struct.new( :domain_identifier, :identifier) SENSITIVE = [] include Aws::Structure end |