Class: Aws::DataZone::Types::GetSubscriptionGrantOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetSubscriptionGrantOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assets ⇒ Array<Types::SubscribedAsset>
The assets for which the subscription grant is created.
-
#created_at ⇒ Time
The timestamp of when the subscription grant is created.
-
#created_by ⇒ String
The Amazon DataZone user who created the subscription grant.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription grant exists.
-
#environment_id ⇒ String
The environment ID of the subscription grant.
-
#granted_entity ⇒ Types::GrantedEntity
The entity to which the subscription is granted.
-
#id ⇒ String
The ID of the subscription grant.
-
#status ⇒ String
The status of the subscription grant.
-
#subscription_id ⇒ String
The identifier of the subscription.
-
#subscription_target_id ⇒ String
The subscription target ID associated with the subscription grant.
-
#updated_at ⇒ Time
The timestamp of when the subscription grant was upated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant.
Instance Attribute Details
#assets ⇒ Array<Types::SubscribedAsset>
The assets for which the subscription grant is created.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the subscription grant is created.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the subscription grant.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription grant exists.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The environment ID of the subscription grant.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#granted_entity ⇒ Types::GrantedEntity
The entity to which the subscription is granted.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the subscription grant.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the subscription grant.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#subscription_id ⇒ String
The identifier of the subscription.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#subscription_target_id ⇒ String
The subscription target ID associated with the subscription grant.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription grant was upated.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant.
11772 11773 11774 11775 11776 11777 11778 11779 11780 11781 11782 11783 11784 11785 11786 11787 |
# File 'lib/aws-sdk-datazone/types.rb', line 11772 class GetSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |