Class: Aws::DataZone::Types::GetSubscriptionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetSubscriptionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the subscription was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the subscription.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription exists.
-
#id ⇒ String
The ID of the subscription.
-
#retain_permissions ⇒ Boolean
The retain permissions of the subscription.
-
#status ⇒ String
The status of the subscription.
-
#subscribed_listing ⇒ Types::SubscribedListing
The details of the published asset for which the subscription grant is created.
-
#subscribed_principal ⇒ Types::SubscribedPrincipal
The principal that owns the subscription.
-
#subscription_request_id ⇒ String
The ID of the subscription request.
-
#updated_at ⇒ Time
The timestamp of when the subscription was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the subscription was created.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the subscription.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription exists.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the subscription.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#retain_permissions ⇒ Boolean
The retain permissions of the subscription.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the subscription.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#subscribed_listing ⇒ Types::SubscribedListing
The details of the published asset for which the subscription grant is created.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#subscribed_principal ⇒ Types::SubscribedPrincipal
The principal that owns the subscription.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#subscription_request_id ⇒ String
The ID of the subscription request.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription was updated.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription.
11292 11293 11294 11295 11296 11297 11298 11299 11300 11301 11302 11303 11304 11305 11306 |
# File 'lib/aws-sdk-datazone/types.rb', line 11292 class GetSubscriptionOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :status, :created_at, :updated_at, :subscribed_principal, :subscribed_listing, :subscription_request_id, :retain_permissions) SENSITIVE = [] include Aws::Structure end |