Class: Aws::DataZone::Types::GetSubscriptionTargetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetSubscriptionTargetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#applicable_asset_types ⇒ Array<String>
The asset types associated with the subscription target.
-
#authorized_principals ⇒ Array<String>
The authorized principals of the subscription target.
-
#created_at ⇒ Time
The timestamp of when the subscription target was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the subscription target.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription target exists.
-
#environment_id ⇒ String
The ID of the environment associated with the subscription target.
-
#id ⇒ String
The ID of the subscription target.
-
#manage_access_role ⇒ String
The manage access role with which the subscription target was created.
-
#name ⇒ String
The name of the subscription target.
-
#project_id ⇒ String
The ID of the project associated with the subscription target.
-
#provider ⇒ String
The provider of the subscription target.
-
#subscription_grant_creation_mode ⇒ String
Determines the subscription grant creation mode for this target, defining if grants are auto-created upon subscription approval or managed manually.
-
#subscription_target_config ⇒ Array<Types::SubscriptionTargetForm>
The configuration of teh subscription target.
-
#type ⇒ String
The type of the subscription target.
-
#updated_at ⇒ Time
The timestamp of when the subscription target was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription target.
Instance Attribute Details
#applicable_asset_types ⇒ Array<String>
The asset types associated with the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#authorized_principals ⇒ Array<String>
The authorized principals of the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the subscription target was created.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription target exists.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment associated with the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#id ⇒ String
The ID of the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#manage_access_role ⇒ String
The manage access role with which the subscription target was created.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
The name of the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#project_id ⇒ String
The ID of the project associated with the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#provider ⇒ String
The provider of the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#subscription_grant_creation_mode ⇒ String
Determines the subscription grant creation mode for this target, defining if grants are auto-created upon subscription approval or managed manually.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#subscription_target_config ⇒ Array<Types::SubscriptionTargetForm>
The configuration of teh subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#type ⇒ String
The type of the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription target was updated.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription target.
12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 |
# File 'lib/aws-sdk-datazone/types.rb', line 12267 class GetSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |