Class: Aws::DataZone::Types::GetTimeSeriesDataPointInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetTimeSeriesDataPointInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain that houses the asset for which you want to get the data point.
-
#entity_identifier ⇒ String
The ID of the asset for which you want to get the data point.
-
#entity_type ⇒ String
The type of the asset for which you want to get the data point.
-
#form_name ⇒ String
The name of the time series form that houses the data point that you want to get.
-
#identifier ⇒ String
The ID of the data point that you want to get.
Instance Attribute Details
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain that houses the asset for which you want to get the data point.
11526 11527 11528 11529 11530 11531 11532 11533 11534 |
# File 'lib/aws-sdk-datazone/types.rb', line 11526 class GetTimeSeriesDataPointInput < Struct.new( :domain_identifier, :entity_identifier, :entity_type, :identifier, :form_name) SENSITIVE = [] include Aws::Structure end |
#entity_identifier ⇒ String
The ID of the asset for which you want to get the data point.
11526 11527 11528 11529 11530 11531 11532 11533 11534 |
# File 'lib/aws-sdk-datazone/types.rb', line 11526 class GetTimeSeriesDataPointInput < Struct.new( :domain_identifier, :entity_identifier, :entity_type, :identifier, :form_name) SENSITIVE = [] include Aws::Structure end |
#entity_type ⇒ String
The type of the asset for which you want to get the data point.
11526 11527 11528 11529 11530 11531 11532 11533 11534 |
# File 'lib/aws-sdk-datazone/types.rb', line 11526 class GetTimeSeriesDataPointInput < Struct.new( :domain_identifier, :entity_identifier, :entity_type, :identifier, :form_name) SENSITIVE = [] include Aws::Structure end |
#form_name ⇒ String
The name of the time series form that houses the data point that you want to get.
11526 11527 11528 11529 11530 11531 11532 11533 11534 |
# File 'lib/aws-sdk-datazone/types.rb', line 11526 class GetTimeSeriesDataPointInput < Struct.new( :domain_identifier, :entity_identifier, :entity_type, :identifier, :form_name) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The ID of the data point that you want to get.
11526 11527 11528 11529 11530 11531 11532 11533 11534 |
# File 'lib/aws-sdk-datazone/types.rb', line 11526 class GetTimeSeriesDataPointInput < Struct.new( :domain_identifier, :entity_identifier, :entity_type, :identifier, :form_name) SENSITIVE = [] include Aws::Structure end |