Class: Aws::DataZone::Types::GetUserProfileInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_identifierString

the ID of the Amazon DataZone domain the data portal of which you want to get.

Returns:

  • (String)


11790
11791
11792
11793
11794
11795
11796
11797
# File 'lib/aws-sdk-datazone/types.rb', line 11790

class GetUserProfileInput < Struct.new(
  :domain_identifier,
  :user_identifier,
  :type,
  :session_name)
  SENSITIVE = []
  include Aws::Structure
end

#session_nameString

The session name for IAM role sessions.

Returns:

  • (String)


11790
11791
11792
11793
11794
11795
11796
11797
# File 'lib/aws-sdk-datazone/types.rb', line 11790

class GetUserProfileInput < Struct.new(
  :domain_identifier,
  :user_identifier,
  :type,
  :session_name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the user profile.

Returns:

  • (String)


11790
11791
11792
11793
11794
11795
11796
11797
# File 'lib/aws-sdk-datazone/types.rb', line 11790

class GetUserProfileInput < Struct.new(
  :domain_identifier,
  :user_identifier,
  :type,
  :session_name)
  SENSITIVE = []
  include Aws::Structure
end

#user_identifierString

The identifier of the user for which you want to get the user profile.

Returns:

  • (String)


11790
11791
11792
11793
11794
11795
11796
11797
# File 'lib/aws-sdk-datazone/types.rb', line 11790

class GetUserProfileInput < Struct.new(
  :domain_identifier,
  :user_identifier,
  :type,
  :session_name)
  SENSITIVE = []
  include Aws::Structure
end