Class: Aws::DataZone::Types::GitPropertiesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Contains the Git connection properties that you specify when creating a Git connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_connection_arnString

The ARN of the CodeConnections connection used to connect to the Git repository.

Returns:

  • (String)


12502
12503
12504
12505
12506
12507
12508
# File 'lib/aws-sdk-datazone/types.rb', line 12502

class GitPropertiesInput < Struct.new(
  :code_connection_arn,
  :repository_id,
  :default_branch)
  SENSITIVE = []
  include Aws::Structure
end

#default_branchString

The default branch of the Git repository.

Returns:

  • (String)


12502
12503
12504
12505
12506
12507
12508
# File 'lib/aws-sdk-datazone/types.rb', line 12502

class GitPropertiesInput < Struct.new(
  :code_connection_arn,
  :repository_id,
  :default_branch)
  SENSITIVE = []
  include Aws::Structure
end

#repository_idString

The ID of the Git repository. This is the owner and repository name, for example, owner/repo-name.

Returns:

  • (String)


12502
12503
12504
12505
12506
12507
12508
# File 'lib/aws-sdk-datazone/types.rb', line 12502

class GitPropertiesInput < Struct.new(
  :code_connection_arn,
  :repository_id,
  :default_branch)
  SENSITIVE = []
  include Aws::Structure
end