Class: Aws::DataZone::Types::GitPropertiesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The properties of a Git connection returned by get and list operations, including connection status and any error details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_connection_arnString

The ARN of the CodeConnections connection used to connect to the Git repository.

Returns:

  • (String)


12539
12540
12541
12542
12543
12544
12545
12546
12547
# File 'lib/aws-sdk-datazone/types.rb', line 12539

class GitPropertiesOutput < Struct.new(
  :code_connection_arn,
  :repository_id,
  :default_branch,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#default_branchString

The default branch of the Git repository.

Returns:

  • (String)


12539
12540
12541
12542
12543
12544
12545
12546
12547
# File 'lib/aws-sdk-datazone/types.rb', line 12539

class GitPropertiesOutput < Struct.new(
  :code_connection_arn,
  :repository_id,
  :default_branch,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

The error message that describes why the Git connection failed. This member is populated when the connection status is CREATE_FAILED or UPDATE_FAILED.

Returns:

  • (String)


12539
12540
12541
12542
12543
12544
12545
12546
12547
# File 'lib/aws-sdk-datazone/types.rb', line 12539

class GitPropertiesOutput < Struct.new(
  :code_connection_arn,
  :repository_id,
  :default_branch,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#repository_idString

The ID of the Git repository. This is the owner and repository name, for example, owner/repo-name.

Returns:

  • (String)


12539
12540
12541
12542
12543
12544
12545
12546
12547
# File 'lib/aws-sdk-datazone/types.rb', line 12539

class GitPropertiesOutput < Struct.new(
  :code_connection_arn,
  :repository_id,
  :default_branch,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Git connection.

Returns:

  • (String)


12539
12540
12541
12542
12543
12544
12545
12546
12547
# File 'lib/aws-sdk-datazone/types.rb', line 12539

class GitPropertiesOutput < Struct.new(
  :code_connection_arn,
  :repository_id,
  :default_branch,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end