Class: Aws::DataZone::Types::GitPropertiesPatch

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The properties used to update an existing Git connection, such as the CodeConnections ARN or the default branch.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_connection_arnString

The ARN of the CodeConnections connection used to connect to the Git repository.

Returns:

  • (String)


12563
12564
12565
12566
12567
12568
# File 'lib/aws-sdk-datazone/types.rb', line 12563

class GitPropertiesPatch < Struct.new(
  :code_connection_arn,
  :default_branch)
  SENSITIVE = []
  include Aws::Structure
end

#default_branchString

The default branch of the Git repository.

Returns:

  • (String)


12563
12564
12565
12566
12567
12568
# File 'lib/aws-sdk-datazone/types.rb', line 12563

class GitPropertiesPatch < Struct.new(
  :code_connection_arn,
  :default_branch)
  SENSITIVE = []
  include Aws::Structure
end