Class: Aws::DataZone::Types::GlossaryItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of a business glossary.

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_attributesTypes::GlossaryItemAdditionalAttributes

The additional attributes of an Amazon DataZone glossary.



11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_atTime

The timestamp of when the glossary was created.

Returns:

  • (Time)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created the glossary.

Returns:

  • (String)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The business glossary description.

Returns:

  • (String)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon DataZone domain in which the business glossary exists.

Returns:

  • (String)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The identifier of the glossary.

Returns:

  • (String)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the glossary.

Returns:

  • (String)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the business glosary.

Returns:

  • (String)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#statusString

The business glossary status.

Returns:

  • (String)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the business glossary was updated.

Returns:

  • (Time)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_byString

The Amazon DataZone user who updated the business glossary.

Returns:

  • (String)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#usage_restrictionsArray<String>

The usage restrictions associated with a goverened glossary term.

Returns:

  • (Array<String>)


11704
11705
11706
11707
11708
11709
11710
11711
11712
11713
11714
11715
11716
11717
11718
11719
# File 'lib/aws-sdk-datazone/types.rb', line 11704

class GlossaryItem < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :additional_attributes)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end