Class: Aws::DataZone::Types::GlueConnectionPatch
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GlueConnectionPatch
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The Amazon Web Services Glue connection patch.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_configuration ⇒ Types::AuthenticationConfigurationPatch
The authentication configuration of the Amazon Web Services Glue connection patch.
-
#connection_properties ⇒ Hash<String,String>
The properties of the Amazon Web Services Glue connection patch.
-
#description ⇒ String
The description of the Amazon Web Services Glue connection patch.
Instance Attribute Details
#authentication_configuration ⇒ Types::AuthenticationConfigurationPatch
The authentication configuration of the Amazon Web Services Glue connection patch.
12603 12604 12605 12606 12607 12608 12609 |
# File 'lib/aws-sdk-datazone/types.rb', line 12603 class GlueConnectionPatch < Struct.new( :description, :connection_properties, :authentication_configuration) SENSITIVE = [] include Aws::Structure end |
#connection_properties ⇒ Hash<String,String>
The properties of the Amazon Web Services Glue connection patch.
12603 12604 12605 12606 12607 12608 12609 |
# File 'lib/aws-sdk-datazone/types.rb', line 12603 class GlueConnectionPatch < Struct.new( :description, :connection_properties, :authentication_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Amazon Web Services Glue connection patch.
12603 12604 12605 12606 12607 12608 12609 |
# File 'lib/aws-sdk-datazone/types.rb', line 12603 class GlueConnectionPatch < Struct.new( :description, :connection_properties, :authentication_configuration) SENSITIVE = [] include Aws::Structure end |