Class: Aws::DataZone::Types::GrantedEntity
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GrantedEntity
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
GrantedEntity is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of GrantedEntity corresponding to the set member.
The details of a listing for which a subscription is granted.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#listing ⇒ Types::ListingRevision
The listing for which a subscription is granted.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#listing ⇒ Types::ListingRevision
The listing for which a subscription is granted.
12867 12868 12869 12870 12871 12872 12873 12874 12875 12876 |
# File 'lib/aws-sdk-datazone/types.rb', line 12867 class GrantedEntity < Struct.new( :listing, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Listing < GrantedEntity; end class Unknown < GrantedEntity; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
12867 12868 12869 |
# File 'lib/aws-sdk-datazone/types.rb', line 12867 def unknown @unknown end |