Class: Aws::DataZone::Types::GrantedEntityInput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

GrantedEntityInput is a union - when making an API calls you must set exactly one of the members.

The details of a listing for which a subscription is to be granted.

Direct Known Subclasses

Listing, Unknown

Defined Under Namespace

Classes: Listing, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#listingTypes::ListingRevisionInput

The listing for which a subscription is to be granted.



12246
12247
12248
12249
12250
12251
12252
12253
12254
12255
# File 'lib/aws-sdk-datazone/types.rb', line 12246

class GrantedEntityInput < Struct.new(
  :listing,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Listing < GrantedEntityInput; end
  class Unknown < GrantedEntityInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



12246
12247
12248
# File 'lib/aws-sdk-datazone/types.rb', line 12246

def unknown
  @unknown
end