Class: Aws::DataZone::Types::IamUserProfileDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of the IAM user profile.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the IAM user.

Returns:

  • (String)


12467
12468
12469
12470
12471
12472
12473
12474
# File 'lib/aws-sdk-datazone/types.rb', line 12467

class IamUserProfileDetails < Struct.new(
  :arn,
  :principal_id,
  :session_name,
  :group_profile_id)
  SENSITIVE = []
  include Aws::Structure
end

#group_profile_idString

The identifier of the group profile associated with the IAM user profile. This links the user to a specific group profile within the Amazon DataZone domain.

Returns:

  • (String)


12467
12468
12469
12470
12471
12472
12473
12474
# File 'lib/aws-sdk-datazone/types.rb', line 12467

class IamUserProfileDetails < Struct.new(
  :arn,
  :principal_id,
  :session_name,
  :group_profile_id)
  SENSITIVE = []
  include Aws::Structure
end

#principal_idString

The principal ID as part of the IAM user profile details.

Returns:

  • (String)


12467
12468
12469
12470
12471
12472
12473
12474
# File 'lib/aws-sdk-datazone/types.rb', line 12467

class IamUserProfileDetails < Struct.new(
  :arn,
  :principal_id,
  :session_name,
  :group_profile_id)
  SENSITIVE = []
  include Aws::Structure
end

#session_nameString

The session name for IAM role sessions.

Returns:

  • (String)


12467
12468
12469
12470
12471
12472
12473
12474
# File 'lib/aws-sdk-datazone/types.rb', line 12467

class IamUserProfileDetails < Struct.new(
  :arn,
  :principal_id,
  :session_name,
  :group_profile_id)
  SENSITIVE = []
  include Aws::Structure
end