Class: Aws::DataZone::Types::IdentityMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::IdentityMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Contains the configuration for mapping user identities to Snowflake users, including the username attribute and optional prefix applied during the mapping.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#prefix ⇒ String
The prefix used for the identity mapping.
-
#username_attribute ⇒ String
The username attribute used for the identity mapping.
Instance Attribute Details
#prefix ⇒ String
The prefix used for the identity mapping.
13322 13323 13324 13325 13326 13327 |
# File 'lib/aws-sdk-datazone/types.rb', line 13322 class IdentityMapping < Struct.new( :username_attribute, :prefix) SENSITIVE = [] include Aws::Structure end |
#username_attribute ⇒ String
The username attribute used for the identity mapping.
13322 13323 13324 13325 13326 13327 |
# File 'lib/aws-sdk-datazone/types.rb', line 13322 class IdentityMapping < Struct.new( :username_attribute, :prefix) SENSITIVE = [] include Aws::Structure end |