Class: Aws::DataZone::Types::LakehousePropertiesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::LakehousePropertiesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The lakehouse properties of a connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#glue_lineage_sync_enabled ⇒ Boolean
Specifies whether to enable Glue lineage sync for tables managed by Glue crawlers.
Instance Attribute Details
#glue_lineage_sync_enabled ⇒ Boolean
Specifies whether to enable Glue lineage sync for tables managed by Glue crawlers.
12704 12705 12706 12707 12708 |
# File 'lib/aws-sdk-datazone/types.rb', line 12704 class LakehousePropertiesInput < Struct.new( :glue_lineage_sync_enabled) SENSITIVE = [] include Aws::Structure end |