Class: Aws::DataZone::Types::LessThanOrEqualToExpression
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::LessThanOrEqualToExpression
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Specifies that a value is less than or equal to an expression.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_name ⇒ String
The name of the column.
-
#value ⇒ String
The value that might be less than or equal to an expression.
Instance Attribute Details
#column_name ⇒ String
The name of the column.
13334 13335 13336 13337 13338 13339 |
# File 'lib/aws-sdk-datazone/types.rb', line 13334 class LessThanOrEqualToExpression < Struct.new( :column_name, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value that might be less than or equal to an expression.
13334 13335 13336 13337 13338 13339 |
# File 'lib/aws-sdk-datazone/types.rb', line 13334 class LessThanOrEqualToExpression < Struct.new( :column_name, :value) SENSITIVE = [] include Aws::Structure end |