Class: Aws::DataZone::Types::LineageEventSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::LineageEventSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The data lineage event summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp at which data lineage event was created.
-
#created_by ⇒ String
The user who created the data lineage event.
-
#domain_id ⇒ String
The domain ID of the lineage event.
-
#event_summary ⇒ Types::EventSummary
The summary of the data lineate event.
-
#event_time ⇒ Time
The time of the data lineage event.
-
#id ⇒ String
The ID of the data lineage event.
-
#processing_status ⇒ String
The processing status of the data lineage event.
Instance Attribute Details
#created_at ⇒ Time
The timestamp at which data lineage event was created.
13010 13011 13012 13013 13014 13015 13016 13017 13018 13019 13020 |
# File 'lib/aws-sdk-datazone/types.rb', line 13010 class LineageEventSummary < Struct.new( :id, :domain_id, :processing_status, :event_time, :event_summary, :created_by, :created_at) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user who created the data lineage event.
13010 13011 13012 13013 13014 13015 13016 13017 13018 13019 13020 |
# File 'lib/aws-sdk-datazone/types.rb', line 13010 class LineageEventSummary < Struct.new( :id, :domain_id, :processing_status, :event_time, :event_summary, :created_by, :created_at) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The domain ID of the lineage event.
13010 13011 13012 13013 13014 13015 13016 13017 13018 13019 13020 |
# File 'lib/aws-sdk-datazone/types.rb', line 13010 class LineageEventSummary < Struct.new( :id, :domain_id, :processing_status, :event_time, :event_summary, :created_by, :created_at) SENSITIVE = [] include Aws::Structure end |
#event_summary ⇒ Types::EventSummary
The summary of the data lineate event.
13010 13011 13012 13013 13014 13015 13016 13017 13018 13019 13020 |
# File 'lib/aws-sdk-datazone/types.rb', line 13010 class LineageEventSummary < Struct.new( :id, :domain_id, :processing_status, :event_time, :event_summary, :created_by, :created_at) SENSITIVE = [] include Aws::Structure end |
#event_time ⇒ Time
The time of the data lineage event.
13010 13011 13012 13013 13014 13015 13016 13017 13018 13019 13020 |
# File 'lib/aws-sdk-datazone/types.rb', line 13010 class LineageEventSummary < Struct.new( :id, :domain_id, :processing_status, :event_time, :event_summary, :created_by, :created_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the data lineage event.
13010 13011 13012 13013 13014 13015 13016 13017 13018 13019 13020 |
# File 'lib/aws-sdk-datazone/types.rb', line 13010 class LineageEventSummary < Struct.new( :id, :domain_id, :processing_status, :event_time, :event_summary, :created_by, :created_at) SENSITIVE = [] include Aws::Structure end |
#processing_status ⇒ String
The processing status of the data lineage event.
13010 13011 13012 13013 13014 13015 13016 13017 13018 13019 13020 |
# File 'lib/aws-sdk-datazone/types.rb', line 13010 class LineageEventSummary < Struct.new( :id, :domain_id, :processing_status, :event_time, :event_summary, :created_by, :created_at) SENSITIVE = [] include Aws::Structure end |