Class: Aws::DataZone::Types::LineageNodeItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The summary and output forms of a LineageNode

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp at which the data lineage node was created.

Returns:

  • (Time)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The user who created the data lineage node.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the data lineage node.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain of the data lineage node.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#downstream_lineage_node_idsArray<String>

The IDs of the downstream data lineage nodes.

Returns:

  • (Array<String>)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#event_timestampTime

The event timestamp of the data lineage node.

Returns:

  • (Time)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#forms_outputArray<Types::FormOutput>

The forms included in the additional attributes of a data lineage node.

Returns:



12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the data lineage node.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data lineage node.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#source_identifierString

The alternate ID of the data lineage node.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#type_nameString

The name of the type of the data lineage node.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#type_revisionString

The type of the revision of the data lineage node.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp at which the data lineage node was updated.

Returns:

  • (Time)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The user who updated the data lineage node.

Returns:

  • (String)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end

#upstream_lineage_node_idsArray<String>

The IDs of the upstream data lineage nodes.

Returns:

  • (Array<String>)


12867
12868
12869
12870
12871
12872
12873
12874
12875
12876
12877
12878
12879
12880
12881
12882
12883
12884
12885
# File 'lib/aws-sdk-datazone/types.rb', line 12867

class LineageNodeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :id,
  :type_name,
  :type_revision,
  :source_identifier,
  :event_timestamp,
  :forms_output,
  :upstream_lineage_node_ids,
  :downstream_lineage_node_ids)
  SENSITIVE = []
  include Aws::Structure
end