Class: Aws::DataZone::Types::LineageNodeTypeItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of a data lineage node type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp at which the data lineage node type was created.

Returns:

  • (Time)


13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-datazone/types.rb', line 13681

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The user who created the data lineage node type.

Returns:

  • (String)


13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-datazone/types.rb', line 13681

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the data lineage node type.

Returns:

  • (String)


13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-datazone/types.rb', line 13681

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain where the data lineage node type lives.

Returns:

  • (String)


13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-datazone/types.rb', line 13681

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#forms_outputHash<String,Types::FormEntryOutput>

The forms output of the data lineage node type.

Returns:



13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-datazone/types.rb', line 13681

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data lineage node type.

Returns:

  • (String)


13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-datazone/types.rb', line 13681

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#revisionString

The revision of the data lineage node type.

Returns:

  • (String)


13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-datazone/types.rb', line 13681

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp at which the data lineage node type was updated.

Returns:

  • (Time)


13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-datazone/types.rb', line 13681

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The user who updated the data lineage node type.

Returns:

  • (String)


13681
13682
13683
13684
13685
13686
13687
13688
13689
13690
13691
13692
13693
# File 'lib/aws-sdk-datazone/types.rb', line 13681

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end