Class: Aws::DataZone::Types::LineageSqlQueryRunDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The SQL query run details of a data lineage run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_messagesArray<String>

The error message of the SQL query run details of a data lineage run.

Returns:

  • (Array<String>)


13072
13073
13074
13075
13076
13077
13078
13079
13080
# File 'lib/aws-sdk-datazone/types.rb', line 13072

class LineageSqlQueryRunDetails < Struct.new(
  :query_start_time,
  :query_end_time,
  :total_queries_processed,
  :num_queries_failed,
  :error_messages)
  SENSITIVE = []
  include Aws::Structure
end

#num_queries_failedInteger

The number of queries that failed in the SQL query run details of a data lineage run.

Returns:

  • (Integer)


13072
13073
13074
13075
13076
13077
13078
13079
13080
# File 'lib/aws-sdk-datazone/types.rb', line 13072

class LineageSqlQueryRunDetails < Struct.new(
  :query_start_time,
  :query_end_time,
  :total_queries_processed,
  :num_queries_failed,
  :error_messages)
  SENSITIVE = []
  include Aws::Structure
end

#query_end_timeTime

The query end time in the SQL query run details of a data lineage run.

Returns:

  • (Time)


13072
13073
13074
13075
13076
13077
13078
13079
13080
# File 'lib/aws-sdk-datazone/types.rb', line 13072

class LineageSqlQueryRunDetails < Struct.new(
  :query_start_time,
  :query_end_time,
  :total_queries_processed,
  :num_queries_failed,
  :error_messages)
  SENSITIVE = []
  include Aws::Structure
end

#query_start_timeTime

The query start time in the SQL query run details of a data lineage run.

Returns:

  • (Time)


13072
13073
13074
13075
13076
13077
13078
13079
13080
# File 'lib/aws-sdk-datazone/types.rb', line 13072

class LineageSqlQueryRunDetails < Struct.new(
  :query_start_time,
  :query_end_time,
  :total_queries_processed,
  :num_queries_failed,
  :error_messages)
  SENSITIVE = []
  include Aws::Structure
end

#total_queries_processedInteger

The total queries processed in the SQL query run details of a data lineage run.

Returns:

  • (Integer)


13072
13073
13074
13075
13076
13077
13078
13079
13080
# File 'lib/aws-sdk-datazone/types.rb', line 13072

class LineageSqlQueryRunDetails < Struct.new(
  :query_start_time,
  :query_end_time,
  :total_queries_processed,
  :num_queries_failed,
  :error_messages)
  SENSITIVE = []
  include Aws::Structure
end