Class: Aws::DataZone::Types::LineageSyncOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Contains the current state of lineage sync for a Snowflake connection, including the schedule, timezone, enabled state, and the ID of the associated lineage job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

Specifies whether lineage sync is enabled.

Returns:

  • (Boolean)


14027
14028
14029
14030
14031
14032
14033
14034
# File 'lib/aws-sdk-datazone/types.rb', line 14027

class LineageSyncOutput < Struct.new(
  :lineage_job_id,
  :timezone,
  :enabled,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_job_idString

The ID of the lineage sync job.

Returns:

  • (String)


14027
14028
14029
14030
14031
14032
14033
14034
# File 'lib/aws-sdk-datazone/types.rb', line 14027

class LineageSyncOutput < Struct.new(
  :lineage_job_id,
  :timezone,
  :enabled,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleString

The schedule of the lineage sync.

Returns:

  • (String)


14027
14028
14029
14030
14031
14032
14033
14034
# File 'lib/aws-sdk-datazone/types.rb', line 14027

class LineageSyncOutput < Struct.new(
  :lineage_job_id,
  :timezone,
  :enabled,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#timezoneString

The timezone of the lineage sync schedule.

Returns:

  • (String)


14027
14028
14029
14030
14031
14032
14033
14034
# File 'lib/aws-sdk-datazone/types.rb', line 14027

class LineageSyncOutput < Struct.new(
  :lineage_job_id,
  :timezone,
  :enabled,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end