Class: Aws::DataZone::Types::MatchClause
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::MatchClause
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
MatchClause is a union - when making an API calls you must set exactly one of the members.
A clause to match a query pattern
Direct Known Subclasses
Defined Under Namespace
Classes: EntityPattern, RelationPattern, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entity_pattern ⇒ Types::EntityPattern
The pattern describing the entities for the query to traverse.
-
#relation_pattern ⇒ Types::RelationPattern
The pattern describing the query’s relational traversal.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#entity_pattern ⇒ Types::EntityPattern
The pattern describing the entities for the query to traverse.
15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-datazone/types.rb', line 15643 class MatchClause < Struct.new( :relation_pattern, :entity_pattern, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RelationPattern < MatchClause; end class EntityPattern < MatchClause; end class Unknown < MatchClause; end end |
#relation_pattern ⇒ Types::RelationPattern
The pattern describing the query’s relational traversal.
15643 15644 15645 15646 15647 15648 15649 15650 15651 15652 15653 15654 |
# File 'lib/aws-sdk-datazone/types.rb', line 15643 class MatchClause < Struct.new( :relation_pattern, :entity_pattern, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RelationPattern < MatchClause; end class EntityPattern < MatchClause; end class Unknown < MatchClause; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
15643 15644 15645 |
# File 'lib/aws-sdk-datazone/types.rb', line 15643 def unknown @unknown end |