Class: Aws::DataZone::Types::MatchRationaleItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::MatchRationaleItem
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
MatchRationaleItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MatchRationaleItem corresponding to the set member.
A rationale indicating why this item was matched by search.
Direct Known Subclasses
Defined Under Namespace
Classes: TextMatches, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text_matches ⇒ Array<Types::TextMatchItem>
A list of TextMatchItems.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text_matches ⇒ Array<Types::TextMatchItem>
A list of TextMatchItems.
15687 15688 15689 15690 15691 15692 15693 15694 15695 15696 |
# File 'lib/aws-sdk-datazone/types.rb', line 15687 class MatchRationaleItem < Struct.new( :text_matches, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class TextMatches < MatchRationaleItem; end class Unknown < MatchRationaleItem; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
15687 15688 15689 |
# File 'lib/aws-sdk-datazone/types.rb', line 15687 def unknown @unknown end |