Class: Aws::DataZone::Types::MetadataGenerationRunTypeStat

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The statistics of the metadata generation run type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_messageString

The error message displayed if the action fails to run.

Returns:

  • (String)


15808
15809
15810
15811
15812
15813
15814
# File 'lib/aws-sdk-datazone/types.rb', line 15808

class MetadataGenerationRunTypeStat < Struct.new(
  :type,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the metadata generation run type statistics.

Returns:

  • (String)


15808
15809
15810
15811
15812
15813
15814
# File 'lib/aws-sdk-datazone/types.rb', line 15808

class MetadataGenerationRunTypeStat < Struct.new(
  :type,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the metadata generation run type statistics.

Returns:

  • (String)


15808
15809
15810
15811
15812
15813
15814
# File 'lib/aws-sdk-datazone/types.rb', line 15808

class MetadataGenerationRunTypeStat < Struct.new(
  :type,
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end