Class: Aws::DataZone::Types::Model
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::Model
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
Model is a union - when making an API calls you must set exactly one of the members.
Note:
Model is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Model corresponding to the set member.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #smithy ⇒ String
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#smithy ⇒ String
7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 |
# File 'lib/aws-sdk-datazone/types.rb', line 7715 class Model < Struct.new( :smithy, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Smithy < Model; end class Unknown < Model; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
7715 7716 7717 |
# File 'lib/aws-sdk-datazone/types.rb', line 7715 def unknown @unknown end |