Class: Aws::DataZone::Types::NotebookRunSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::NotebookRunSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The summary of a notebook run in Amazon SageMaker Unified Studio.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp of when the notebook run completed.
-
#created_at ⇒ Time
The timestamp of when the notebook run was created.
-
#created_by ⇒ String
The identifier of the user who created the notebook run.
-
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
-
#id ⇒ String
The identifier of the notebook run.
-
#notebook_id ⇒ String
The identifier of the notebook.
-
#owning_project_id ⇒ String
The identifier of the project that owns the notebook run.
-
#schedule_id ⇒ String
The identifier of the schedule associated with the notebook run.
-
#started_at ⇒ Time
The timestamp of when the notebook run started executing.
-
#status ⇒ String
The status of the notebook run.
-
#trigger_source ⇒ Types::TriggerSource
The source that triggered the notebook run.
-
#updated_at ⇒ Time
The timestamp of when the notebook run was last updated.
-
#updated_by ⇒ String
The identifier of the user who last updated the notebook run.
Instance Attribute Details
#completed_at ⇒ Time
The timestamp of when the notebook run completed.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the notebook run was created.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who created the notebook run.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the notebook run.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#notebook_id ⇒ String
The identifier of the notebook.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the notebook run.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#schedule_id ⇒ String
The identifier of the schedule associated with the notebook run.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when the notebook run started executing.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the notebook run.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#trigger_source ⇒ Types::TriggerSource
The source that triggered the notebook run.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the notebook run was last updated.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The identifier of the user who last updated the notebook run.
16966 16967 16968 16969 16970 16971 16972 16973 16974 16975 16976 16977 16978 16979 16980 16981 16982 |
# File 'lib/aws-sdk-datazone/types.rb', line 16966 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |