Class: Aws::DataZone::Types::NotebookSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The summary of a notebook in Amazon SageMaker Unified Studio.

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the notebook was created.

Returns:

  • (Time)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_byString

The identifier of the user who created the notebook.

Returns:

  • (String)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the notebook.

Returns:

  • (String)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon SageMaker Unified Studio domain.

Returns:

  • (String)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The identifier of the notebook.

Returns:

  • (String)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the notebook.

Returns:

  • (String)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the notebook.

Returns:

  • (String)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#statusString

The status of the notebook.

Returns:

  • (String)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the notebook was last updated.

Returns:

  • (Time)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_byString

The identifier of the user who last updated the notebook.

Returns:

  • (String)


17107
17108
17109
17110
17111
17112
17113
17114
17115
17116
17117
17118
17119
17120
# File 'lib/aws-sdk-datazone/types.rb', line 17107

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end