Class: Aws::DataZone::Types::NotificationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::NotificationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of a notification generated in Amazon DataZone.
Constant Summary collapse
- SENSITIVE =
[:title, :message, :action_link]
Instance Attribute Summary collapse
-
#action_link ⇒ String
The action link included in the notification.
-
#creation_timestamp ⇒ Time
The timestamp of when a notification was created.
-
#domain_identifier ⇒ String
The identifier of a Amazon DataZone domain in which the notification exists.
-
#identifier ⇒ String
The identifier of the notification.
-
#last_updated_timestamp ⇒ Time
The timestamp of when the notification was last updated.
-
#message ⇒ String
The message included in the notification.
-
#metadata ⇒ Hash<String,String>
The metadata included in the notification.
-
#status ⇒ String
The status included in the notification.
-
#title ⇒ String
The title of the notification.
-
#topic ⇒ Types::Topic
The topic of the notification.
-
#type ⇒ String
The type of the notification.
Instance Attribute Details
#action_link ⇒ String
The action link included in the notification.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#creation_timestamp ⇒ Time
The timestamp of when a notification was created.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of a Amazon DataZone domain in which the notification exists.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#identifier ⇒ String
The identifier of the notification.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#last_updated_timestamp ⇒ Time
The timestamp of when the notification was last updated.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#message ⇒ String
The message included in the notification.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The metadata included in the notification.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#status ⇒ String
The status included in the notification.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#title ⇒ String
The title of the notification.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#topic ⇒ Types::Topic
The topic of the notification.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |
#type ⇒ String
The type of the notification.
16106 16107 16108 16109 16110 16111 16112 16113 16114 16115 16116 16117 16118 16119 16120 |
# File 'lib/aws-sdk-datazone/types.rb', line 16106 class NotificationOutput < Struct.new( :identifier, :domain_identifier, :type, :topic, :title, :message, :status, :action_link, :creation_timestamp, :last_updated_timestamp, :metadata) SENSITIVE = [:title, :message, :action_link] include Aws::Structure end |