Class: Aws::DataZone::Types::NotificationResource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of the resource mentioned in a notification.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The ID of the resource mentioned in a notification.

Returns:

  • (String)


16201
16202
16203
16204
16205
16206
16207
# File 'lib/aws-sdk-datazone/types.rb', line 16201

class NotificationResource < Struct.new(
  :type,
  :id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the resource mentioned in a notification.

Returns:

  • (String)


16201
16202
16203
16204
16205
16206
16207
# File 'lib/aws-sdk-datazone/types.rb', line 16201

class NotificationResource < Struct.new(
  :type,
  :id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the resource mentioned in a notification.

Returns:

  • (String)


16201
16202
16203
16204
16205
16206
16207
# File 'lib/aws-sdk-datazone/types.rb', line 16201

class NotificationResource < Struct.new(
  :type,
  :id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end