Class: Aws::DataZone::Types::OpenLineageRunEventSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::OpenLineageRunEventSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The open lineage run event summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ String
The event type of the open lineage run event summary.
-
#inputs ⇒ Array<Types::NameIdentifier>
The inputs of the open lineage run event summary.
-
#job ⇒ Types::NameIdentifier
The job of the open lineage run event summary.
-
#outputs ⇒ Array<Types::NameIdentifier>
The outputs of the open lineage run event summary.
-
#run_id ⇒ String
The runID of the open lineage run event summary.
Instance Attribute Details
#event_type ⇒ String
The event type of the open lineage run event summary.
14217 14218 14219 14220 14221 14222 14223 14224 14225 |
# File 'lib/aws-sdk-datazone/types.rb', line 14217 class OpenLineageRunEventSummary < Struct.new( :event_type, :inputs, :job, :outputs, :run_id) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<Types::NameIdentifier>
The inputs of the open lineage run event summary.
14217 14218 14219 14220 14221 14222 14223 14224 14225 |
# File 'lib/aws-sdk-datazone/types.rb', line 14217 class OpenLineageRunEventSummary < Struct.new( :event_type, :inputs, :job, :outputs, :run_id) SENSITIVE = [] include Aws::Structure end |
#job ⇒ Types::NameIdentifier
The job of the open lineage run event summary.
14217 14218 14219 14220 14221 14222 14223 14224 14225 |
# File 'lib/aws-sdk-datazone/types.rb', line 14217 class OpenLineageRunEventSummary < Struct.new( :event_type, :inputs, :job, :outputs, :run_id) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::NameIdentifier>
The outputs of the open lineage run event summary.
14217 14218 14219 14220 14221 14222 14223 14224 14225 |
# File 'lib/aws-sdk-datazone/types.rb', line 14217 class OpenLineageRunEventSummary < Struct.new( :event_type, :inputs, :job, :outputs, :run_id) SENSITIVE = [] include Aws::Structure end |
#run_id ⇒ String
The runID of the open lineage run event summary.
14217 14218 14219 14220 14221 14222 14223 14224 14225 |
# File 'lib/aws-sdk-datazone/types.rb', line 14217 class OpenLineageRunEventSummary < Struct.new( :event_type, :inputs, :job, :outputs, :run_id) SENSITIVE = [] include Aws::Structure end |