Class: Aws::DataZone::Types::OutputLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

OutputLocation is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OutputLocation corresponding to the set member.

The output location for a notebook export in Amazon SageMaker Unified Studio.

Defined Under Namespace

Classes: S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3Types::S3Destination

The Amazon Simple Storage Service destination for the notebook export.



17671
17672
17673
17674
17675
17676
17677
17678
17679
17680
# File 'lib/aws-sdk-datazone/types.rb', line 17671

class OutputLocation < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < OutputLocation; end
  class Unknown < OutputLocation; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



17671
17672
17673
# File 'lib/aws-sdk-datazone/types.rb', line 17671

def unknown
  @unknown
end