Class: Aws::DataZone::Types::OwnerPropertiesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::OwnerPropertiesOutput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
OwnerPropertiesOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OwnerPropertiesOutput corresponding to the set member.
The ID of the domain unit owners group.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group ⇒ Types::OwnerGroupPropertiesOutput
Specifies that the domain unit owner is a group.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#user ⇒ Types::OwnerUserPropertiesOutput
Specifies that the domain unit owner is a user.
Instance Attribute Details
#group ⇒ Types::OwnerGroupPropertiesOutput
Specifies that the domain unit owner is a group.
17346 17347 17348 17349 17350 17351 17352 17353 17354 17355 17356 17357 |
# File 'lib/aws-sdk-datazone/types.rb', line 17346 class OwnerPropertiesOutput < Struct.new( :user, :group, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class User < OwnerPropertiesOutput; end class Group < OwnerPropertiesOutput; end class Unknown < OwnerPropertiesOutput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
17346 17347 17348 |
# File 'lib/aws-sdk-datazone/types.rb', line 17346 def unknown @unknown end |
#user ⇒ Types::OwnerUserPropertiesOutput
Specifies that the domain unit owner is a user.
17346 17347 17348 17349 17350 17351 17352 17353 17354 17355 17356 17357 |
# File 'lib/aws-sdk-datazone/types.rb', line 17346 class OwnerPropertiesOutput < Struct.new( :user, :group, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class User < OwnerPropertiesOutput; end class Group < OwnerPropertiesOutput; end class Unknown < OwnerPropertiesOutput; end end |