Class: Aws::DataZone::Types::PackageConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::PackageConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The package configuration for a notebook run environment in Amazon SageMaker Unified Studio.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#package_manager ⇒ String
The package manager for the notebook run environment.
-
#package_specification ⇒ String
The package specification content for the notebook run environment.
Instance Attribute Details
#package_manager ⇒ String
The package manager for the notebook run environment. The default value is ‘UV`.
17442 17443 17444 17445 17446 17447 |
# File 'lib/aws-sdk-datazone/types.rb', line 17442 class PackageConfig < Struct.new( :package_manager, :package_specification) SENSITIVE = [] include Aws::Structure end |
#package_specification ⇒ String
The package specification content for the notebook run environment. The maximum length is 10240 characters.
17442 17443 17444 17445 17446 17447 |
# File 'lib/aws-sdk-datazone/types.rb', line 17442 class PackageConfig < Struct.new( :package_manager, :package_specification) SENSITIVE = [] include Aws::Structure end |