Class: Aws::DataZone::Types::Permissions
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::Permissions
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
Permissions is a union - when making an API calls you must set exactly one of the members.
Note:
Permissions is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Permissions corresponding to the set member.
The asset permissions.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3 ⇒ Array<String>
The S3 details of the asset permissions.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#s3 ⇒ Array<String>
The S3 details of the asset permissions.
17749 17750 17751 17752 17753 17754 17755 17756 17757 17758 |
# File 'lib/aws-sdk-datazone/types.rb', line 17749 class Permissions < Struct.new( :s3, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3 < Permissions; end class Unknown < Permissions; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
17749 17750 17751 |
# File 'lib/aws-sdk-datazone/types.rb', line 17749 def unknown @unknown end |