Class: Aws::DataZone::Types::PhysicalEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The physical endpoints of a connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_locationTypes::AwsLocation

The location of a connection.

Returns:



17586
17587
17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
# File 'lib/aws-sdk-datazone/types.rb', line 17586

class PhysicalEndpoint < Struct.new(
  :aws_location,
  :glue_connection_name,
  :glue_connection_names,
  :glue_connection,
  :enable_trusted_identity_propagation,
  :host,
  :port,
  :protocol,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#enable_trusted_identity_propagationBoolean

Specified whether trusted identity propagation for the connection is enabled.

Returns:

  • (Boolean)


17586
17587
17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
# File 'lib/aws-sdk-datazone/types.rb', line 17586

class PhysicalEndpoint < Struct.new(
  :aws_location,
  :glue_connection_name,
  :glue_connection_names,
  :glue_connection,
  :enable_trusted_identity_propagation,
  :host,
  :port,
  :protocol,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#glue_connectionTypes::GlueConnection

The Amazon Web Services Glue connection.



17586
17587
17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
# File 'lib/aws-sdk-datazone/types.rb', line 17586

class PhysicalEndpoint < Struct.new(
  :aws_location,
  :glue_connection_name,
  :glue_connection_names,
  :glue_connection,
  :enable_trusted_identity_propagation,
  :host,
  :port,
  :protocol,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#glue_connection_nameString

The Amazon Web Services Glue connection name.

Returns:

  • (String)


17586
17587
17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
# File 'lib/aws-sdk-datazone/types.rb', line 17586

class PhysicalEndpoint < Struct.new(
  :aws_location,
  :glue_connection_name,
  :glue_connection_names,
  :glue_connection,
  :enable_trusted_identity_propagation,
  :host,
  :port,
  :protocol,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#glue_connection_namesArray<String>

The Amazon Web Services Glue connection names in the physical endpoint.

Returns:

  • (Array<String>)


17586
17587
17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
# File 'lib/aws-sdk-datazone/types.rb', line 17586

class PhysicalEndpoint < Struct.new(
  :aws_location,
  :glue_connection_name,
  :glue_connection_names,
  :glue_connection,
  :enable_trusted_identity_propagation,
  :host,
  :port,
  :protocol,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#hostString

The host in the physical endpoints of a connection.

Returns:

  • (String)


17586
17587
17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
# File 'lib/aws-sdk-datazone/types.rb', line 17586

class PhysicalEndpoint < Struct.new(
  :aws_location,
  :glue_connection_name,
  :glue_connection_names,
  :glue_connection,
  :enable_trusted_identity_propagation,
  :host,
  :port,
  :protocol,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port in the physical endpoints of a connection.

Returns:

  • (Integer)


17586
17587
17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
# File 'lib/aws-sdk-datazone/types.rb', line 17586

class PhysicalEndpoint < Struct.new(
  :aws_location,
  :glue_connection_name,
  :glue_connection_names,
  :glue_connection,
  :enable_trusted_identity_propagation,
  :host,
  :port,
  :protocol,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#protocolString

The protocol in the physical endpoints of a connection.

Returns:

  • (String)


17586
17587
17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
# File 'lib/aws-sdk-datazone/types.rb', line 17586

class PhysicalEndpoint < Struct.new(
  :aws_location,
  :glue_connection_name,
  :glue_connection_names,
  :glue_connection,
  :enable_trusted_identity_propagation,
  :host,
  :port,
  :protocol,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end

#stageString

The stage in the physical endpoints of a connection.

Returns:

  • (String)


17586
17587
17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
# File 'lib/aws-sdk-datazone/types.rb', line 17586

class PhysicalEndpoint < Struct.new(
  :aws_location,
  :glue_connection_name,
  :glue_connection_names,
  :glue_connection,
  :enable_trusted_identity_propagation,
  :host,
  :port,
  :protocol,
  :stage)
  SENSITIVE = []
  include Aws::Structure
end