Class: Aws::DataZone::Types::PolicyGrantMember
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::PolicyGrantMember
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
A member of the policy grant list.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Specifies the timestamp at which policy grant member was created.
-
#created_by ⇒ String
Specifies the user who created the policy grant member.
-
#detail ⇒ Types::PolicyGrantDetail
The details of the policy grant member.
-
#principal ⇒ Types::PolicyGrantPrincipal
The principal of the policy grant member.
Instance Attribute Details
#created_at ⇒ Time
Specifies the timestamp at which policy grant member was created.
11580 11581 11582 11583 11584 11585 11586 11587 |
# File 'lib/aws-sdk-datazone/types.rb', line 11580 class PolicyGrantMember < Struct.new( :created_at, :created_by, :detail, :principal) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
Specifies the user who created the policy grant member.
11580 11581 11582 11583 11584 11585 11586 11587 |
# File 'lib/aws-sdk-datazone/types.rb', line 11580 class PolicyGrantMember < Struct.new( :created_at, :created_by, :detail, :principal) SENSITIVE = [] include Aws::Structure end |
#detail ⇒ Types::PolicyGrantDetail
The details of the policy grant member.
11580 11581 11582 11583 11584 11585 11586 11587 |
# File 'lib/aws-sdk-datazone/types.rb', line 11580 class PolicyGrantMember < Struct.new( :created_at, :created_by, :detail, :principal) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ Types::PolicyGrantPrincipal
The principal of the policy grant member.
11580 11581 11582 11583 11584 11585 11586 11587 |
# File 'lib/aws-sdk-datazone/types.rb', line 11580 class PolicyGrantMember < Struct.new( :created_at, :created_by, :detail, :principal) SENSITIVE = [] include Aws::Structure end |