Class: Aws::DataZone::Types::PostLineageEventInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:event]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


16688
16689
16690
16691
16692
16693
16694
# File 'lib/aws-sdk-datazone/types.rb', line 16688

class PostLineageEventInput < Struct.new(
  :domain_identifier,
  :event,
  :client_token)
  SENSITIVE = [:event]
  include Aws::Structure
end

#domain_identifierString

The ID of the domain where you want to post a data lineage event.

Returns:

  • (String)


16688
16689
16690
16691
16692
16693
16694
# File 'lib/aws-sdk-datazone/types.rb', line 16688

class PostLineageEventInput < Struct.new(
  :domain_identifier,
  :event,
  :client_token)
  SENSITIVE = [:event]
  include Aws::Structure
end

#eventString

The data lineage event that you want to post. Only open-lineage run event are supported as events.

Returns:

  • (String)


16688
16689
16690
16691
16692
16693
16694
# File 'lib/aws-sdk-datazone/types.rb', line 16688

class PostLineageEventInput < Struct.new(
  :domain_identifier,
  :event,
  :client_token)
  SENSITIVE = [:event]
  include Aws::Structure
end