Class: Aws::DataZone::Types::PostTimeSeriesDataPointsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_idString

The ID of the Amazon DataZone domain in which you want to post time series data points.

Returns:

  • (String)


17235
17236
17237
17238
17239
17240
17241
17242
# File 'lib/aws-sdk-datazone/types.rb', line 17235

class PostTimeSeriesDataPointsOutput < Struct.new(
  :domain_id,
  :entity_id,
  :entity_type,
  :forms)
  SENSITIVE = []
  include Aws::Structure
end

#entity_idString

The ID of the asset for which you want to post time series data points.

Returns:

  • (String)


17235
17236
17237
17238
17239
17240
17241
17242
# File 'lib/aws-sdk-datazone/types.rb', line 17235

class PostTimeSeriesDataPointsOutput < Struct.new(
  :domain_id,
  :entity_id,
  :entity_type,
  :forms)
  SENSITIVE = []
  include Aws::Structure
end

#entity_typeString

The type of the asset for which you want to post data points.

Returns:

  • (String)


17235
17236
17237
17238
17239
17240
17241
17242
# File 'lib/aws-sdk-datazone/types.rb', line 17235

class PostTimeSeriesDataPointsOutput < Struct.new(
  :domain_id,
  :entity_id,
  :entity_type,
  :forms)
  SENSITIVE = []
  include Aws::Structure
end

#formsArray<Types::TimeSeriesDataPointFormOutput>

The forms that contain the data points that you have posted.



17235
17236
17237
17238
17239
17240
17241
17242
# File 'lib/aws-sdk-datazone/types.rb', line 17235

class PostTimeSeriesDataPointsOutput < Struct.new(
  :domain_id,
  :entity_id,
  :entity_type,
  :forms)
  SENSITIVE = []
  include Aws::Structure
end