Class: Aws::DataZone::Types::ProjectMembershipAssignment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

A map of user or group profiles to designations that need to be assigned in the project.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#designationString

The designation of the project membership.

Returns:

  • (String)


16932
16933
16934
16935
16936
16937
# File 'lib/aws-sdk-datazone/types.rb', line 16932

class ProjectMembershipAssignment < Struct.new(
  :member,
  :designation)
  SENSITIVE = []
  include Aws::Structure
end

#memberTypes::Member

The details about a project member.

Returns:



16932
16933
16934
16935
16936
16937
# File 'lib/aws-sdk-datazone/types.rb', line 16932

class ProjectMembershipAssignment < Struct.new(
  :member,
  :designation)
  SENSITIVE = []
  include Aws::Structure
end