Class: Aws::DataZone::Types::ProjectPolicyGrantPrincipal
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ProjectPolicyGrantPrincipal
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The project policy grant principal.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#project_designation ⇒ String
The project designation of the project policy grant principal.
-
#project_grant_filter ⇒ Types::ProjectGrantFilter
The project grant filter of the project policy grant principal.
-
#project_identifier ⇒ String
The project ID of the project policy grant principal.
Instance Attribute Details
#project_designation ⇒ String
The project designation of the project policy grant principal.
16892 16893 16894 16895 16896 16897 16898 |
# File 'lib/aws-sdk-datazone/types.rb', line 16892 class ProjectPolicyGrantPrincipal < Struct.new( :project_designation, :project_identifier, :project_grant_filter) SENSITIVE = [] include Aws::Structure end |
#project_grant_filter ⇒ Types::ProjectGrantFilter
The project grant filter of the project policy grant principal.
16892 16893 16894 16895 16896 16897 16898 |
# File 'lib/aws-sdk-datazone/types.rb', line 16892 class ProjectPolicyGrantPrincipal < Struct.new( :project_designation, :project_identifier, :project_grant_filter) SENSITIVE = [] include Aws::Structure end |
#project_identifier ⇒ String
The project ID of the project policy grant principal.
16892 16893 16894 16895 16896 16897 16898 |
# File 'lib/aws-sdk-datazone/types.rb', line 16892 class ProjectPolicyGrantPrincipal < Struct.new( :project_designation, :project_identifier, :project_grant_filter) SENSITIVE = [] include Aws::Structure end |