Class: Aws::DataZone::Types::ProjectSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ProjectSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of a Amazon DataZone project.
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when a project was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the project.
-
#description ⇒ String
The description of a project.
-
#domain_id ⇒ String
The identifier of a Amazon DataZone domain where the project exists.
-
#domain_unit_id ⇒ String
The ID of the domain unit.
-
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of a project.
-
#name ⇒ String
The name of a project.
-
#project_category ⇒ String
The category of the project.
-
#project_status ⇒ String
The status of the project.
-
#updated_at ⇒ Time
The timestamp of when the project was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when a project was created.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the project.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of a project.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of a Amazon DataZone domain where the project exists.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_unit_id ⇒ String
The ID of the domain unit.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The identifier of a project.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of a project.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_category ⇒ String
The category of the project.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_status ⇒ String
The status of the project.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the project was updated.
17003 17004 17005 17006 17007 17008 17009 17010 17011 17012 17013 17014 17015 17016 17017 |
# File 'lib/aws-sdk-datazone/types.rb', line 17003 class ProjectSummary < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :updated_at, :domain_unit_id, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |