Class: Aws::DataZone::Types::ProvisioningProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ProvisioningProperties
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
ProvisioningProperties is a union - when making an API calls you must set exactly one of the members.
Note:
ProvisioningProperties is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProvisioningProperties corresponding to the set member.
The provisioning properties of an environment blueprint.
Direct Known Subclasses
Defined Under Namespace
Classes: CloudFormation, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_formation ⇒ Types::CloudFormationProperties
The cloud formation properties included as part of the provisioning properties of an environment blueprint.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#cloud_formation ⇒ Types::CloudFormationProperties
The cloud formation properties included as part of the provisioning properties of an environment blueprint.
17074 17075 17076 17077 17078 17079 17080 17081 17082 17083 |
# File 'lib/aws-sdk-datazone/types.rb', line 17074 class ProvisioningProperties < Struct.new( :cloud_formation, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CloudFormation < ProvisioningProperties; end class Unknown < ProvisioningProperties; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
17074 17075 17076 |
# File 'lib/aws-sdk-datazone/types.rb', line 17074 def unknown @unknown end |