Class: Aws::DataZone::Types::PutDataExportConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


16996
16997
16998
16999
17000
17001
17002
17003
# File 'lib/aws-sdk-datazone/types.rb', line 16996

class PutDataExportConfigurationInput < Struct.new(
  :domain_identifier,
  :enable_export,
  :encryption_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The domain ID for which you want to create data export configuration details.

Returns:

  • (String)


16996
16997
16998
16999
17000
17001
17002
17003
# File 'lib/aws-sdk-datazone/types.rb', line 16996

class PutDataExportConfigurationInput < Struct.new(
  :domain_identifier,
  :enable_export,
  :encryption_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#enable_exportBoolean

Specifies that the export is to be enabled as part of creating data export configuration details.

Returns:

  • (Boolean)


16996
16997
16998
16999
17000
17001
17002
17003
# File 'lib/aws-sdk-datazone/types.rb', line 16996

class PutDataExportConfigurationInput < Struct.new(
  :domain_identifier,
  :enable_export,
  :encryption_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The encryption configuration as part of creating data export configuration details.

The KMS key provided here as part of encryptionConfiguration must have the required permissions as described in [KMS permissions for exporting asset metadata in Amazon SageMaker Unified Studio][1].

[1]: docs.aws.amazon.com/sagemaker-unified-studio/latest/adminguide/sagemaker-unified-studio-export-asset-metadata-kms-permissions.html



16996
16997
16998
16999
17000
17001
17002
17003
# File 'lib/aws-sdk-datazone/types.rb', line 16996

class PutDataExportConfigurationInput < Struct.new(
  :domain_identifier,
  :enable_export,
  :encryption_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end