Class: Aws::DataZone::Types::PutResourceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The resource configuration that is used to configure the environment blueprint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the resource configuration.

Returns:

  • (String)


18642
18643
18644
18645
18646
18647
18648
18649
# File 'lib/aws-sdk-datazone/types.rb', line 18642

class PutResourceConfiguration < Struct.new(
  :name,
  :description,
  :region,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the resource configuration.

Returns:

  • (String)


18642
18643
18644
18645
18646
18647
18648
18649
# File 'lib/aws-sdk-datazone/types.rb', line 18642

class PutResourceConfiguration < Struct.new(
  :name,
  :description,
  :region,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,String>

The parameters of the resource configuration.

Returns:

  • (Hash<String,String>)


18642
18643
18644
18645
18646
18647
18648
18649
# File 'lib/aws-sdk-datazone/types.rb', line 18642

class PutResourceConfiguration < Struct.new(
  :name,
  :description,
  :region,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region of the resource configuration.

Returns:

  • (String)


18642
18643
18644
18645
18646
18647
18648
18649
# File 'lib/aws-sdk-datazone/types.rb', line 18642

class PutResourceConfiguration < Struct.new(
  :name,
  :description,
  :region,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end