Class: Aws::DataZone::Types::QueryGraphInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::QueryGraphInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Types::AdditionalAttributes
Additional details on the queried entity that can be requested in the response.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain.
-
#match ⇒ Array<Types::MatchClause>
List of query match clauses.
-
#max_results ⇒ Integer
The maximum number of entities to return in a single call to ‘QueryGraph`.
-
#next_token ⇒ String
When the number of entities is greater than the default value for the ‘MaxResults` parameter, or if you explicitly specify a value for `MaxResults` that is less than the number of entities, the response includes a pagination token named `NextToken`.
Instance Attribute Details
#additional_attributes ⇒ Types::AdditionalAttributes
Additional details on the queried entity that can be requested in the response.
17335 17336 17337 17338 17339 17340 17341 17342 17343 |
# File 'lib/aws-sdk-datazone/types.rb', line 17335 class QueryGraphInput < Struct.new( :domain_identifier, :match, :max_results, :next_token, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain.
17335 17336 17337 17338 17339 17340 17341 17342 17343 |
# File 'lib/aws-sdk-datazone/types.rb', line 17335 class QueryGraphInput < Struct.new( :domain_identifier, :match, :max_results, :next_token, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#match ⇒ Array<Types::MatchClause>
List of query match clauses.
17335 17336 17337 17338 17339 17340 17341 17342 17343 |
# File 'lib/aws-sdk-datazone/types.rb', line 17335 class QueryGraphInput < Struct.new( :domain_identifier, :match, :max_results, :next_token, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of entities to return in a single call to ‘QueryGraph`. When the number of entities to be listed is greater than the value of `MaxResults`, the response contains a `NextToken` value that you can use in a subsequent call to `QueryGraph` to list the next set of entities.
17335 17336 17337 17338 17339 17340 17341 17342 17343 |
# File 'lib/aws-sdk-datazone/types.rb', line 17335 class QueryGraphInput < Struct.new( :domain_identifier, :match, :max_results, :next_token, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When the number of entities is greater than the default value for the ‘MaxResults` parameter, or if you explicitly specify a value for `MaxResults` that is less than the number of entities, the response includes a pagination token named `NextToken`. You can specify this `NextToken` value in a subsequent call to `QueryGraph` to list the next set of entities.
17335 17336 17337 17338 17339 17340 17341 17342 17343 |
# File 'lib/aws-sdk-datazone/types.rb', line 17335 class QueryGraphInput < Struct.new( :domain_identifier, :match, :max_results, :next_token, :additional_attributes) SENSITIVE = [] include Aws::Structure end |