Class: Aws::DataZone::Types::RedshiftLineageSyncConfigurationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The Amaon Redshift lineage sync configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

Specifies whether the Amaon Redshift lineage sync configuration is enabled.

Returns:

  • (Boolean)


18932
18933
18934
18935
18936
18937
18938
# File 'lib/aws-sdk-datazone/types.rb', line 18932

class RedshiftLineageSyncConfigurationOutput < Struct.new(
  :lineage_job_id,
  :enabled,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_job_idString

The lineage job ID of the Amaon Redshift lineage sync configuration.

Returns:

  • (String)


18932
18933
18934
18935
18936
18937
18938
# File 'lib/aws-sdk-datazone/types.rb', line 18932

class RedshiftLineageSyncConfigurationOutput < Struct.new(
  :lineage_job_id,
  :enabled,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleTypes::LineageSyncSchedule

The schedule of teh Amaon Redshift lineage sync configuration.



18932
18933
18934
18935
18936
18937
18938
# File 'lib/aws-sdk-datazone/types.rb', line 18932

class RedshiftLineageSyncConfigurationOutput < Struct.new(
  :lineage_job_id,
  :enabled,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end