Class: Aws::DataZone::Types::RedshiftPropertiesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::RedshiftPropertiesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The Amazon Redshift properties.
Constant Summary collapse
- SENSITIVE =
[:credentials]
Instance Attribute Summary collapse
-
#credentials ⇒ Types::RedshiftCredentials
The Amazon Redshift credentials.
-
#database_name ⇒ String
The Amazon Redshift database name.
-
#is_provisioned_secret ⇒ Boolean
Specifies whether Amaon Redshift properties has a provisioned secret.
-
#jdbc_iam_url ⇒ String
The jdbcIam URL of the Amazon Redshift properties.
-
#jdbc_url ⇒ String
The jdbcURL of the Amazon Redshift properties.
-
#lineage_sync ⇒ Types::RedshiftLineageSyncConfigurationOutput
The lineage syn of the Amazon Redshift properties.
-
#redshift_temp_dir ⇒ String
The redshiftTempDir of the Amazon Redshift properties.
-
#status ⇒ String
The status in the Amazon Redshift properties.
-
#storage ⇒ Types::RedshiftStorageProperties
The storage in the Amazon Redshift properties.
Instance Attribute Details
#credentials ⇒ Types::RedshiftCredentials
The Amazon Redshift credentials.
17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 17516 |
# File 'lib/aws-sdk-datazone/types.rb', line 17504 class RedshiftPropertiesOutput < Struct.new( :storage, :credentials, :is_provisioned_secret, :jdbc_iam_url, :jdbc_url, :redshift_temp_dir, :lineage_sync, :status, :database_name) SENSITIVE = [:credentials] include Aws::Structure end |
#database_name ⇒ String
The Amazon Redshift database name.
17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 17516 |
# File 'lib/aws-sdk-datazone/types.rb', line 17504 class RedshiftPropertiesOutput < Struct.new( :storage, :credentials, :is_provisioned_secret, :jdbc_iam_url, :jdbc_url, :redshift_temp_dir, :lineage_sync, :status, :database_name) SENSITIVE = [:credentials] include Aws::Structure end |
#is_provisioned_secret ⇒ Boolean
Specifies whether Amaon Redshift properties has a provisioned secret.
17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 17516 |
# File 'lib/aws-sdk-datazone/types.rb', line 17504 class RedshiftPropertiesOutput < Struct.new( :storage, :credentials, :is_provisioned_secret, :jdbc_iam_url, :jdbc_url, :redshift_temp_dir, :lineage_sync, :status, :database_name) SENSITIVE = [:credentials] include Aws::Structure end |
#jdbc_iam_url ⇒ String
The jdbcIam URL of the Amazon Redshift properties.
17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 17516 |
# File 'lib/aws-sdk-datazone/types.rb', line 17504 class RedshiftPropertiesOutput < Struct.new( :storage, :credentials, :is_provisioned_secret, :jdbc_iam_url, :jdbc_url, :redshift_temp_dir, :lineage_sync, :status, :database_name) SENSITIVE = [:credentials] include Aws::Structure end |
#jdbc_url ⇒ String
The jdbcURL of the Amazon Redshift properties.
17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 17516 |
# File 'lib/aws-sdk-datazone/types.rb', line 17504 class RedshiftPropertiesOutput < Struct.new( :storage, :credentials, :is_provisioned_secret, :jdbc_iam_url, :jdbc_url, :redshift_temp_dir, :lineage_sync, :status, :database_name) SENSITIVE = [:credentials] include Aws::Structure end |
#lineage_sync ⇒ Types::RedshiftLineageSyncConfigurationOutput
The lineage syn of the Amazon Redshift properties.
17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 17516 |
# File 'lib/aws-sdk-datazone/types.rb', line 17504 class RedshiftPropertiesOutput < Struct.new( :storage, :credentials, :is_provisioned_secret, :jdbc_iam_url, :jdbc_url, :redshift_temp_dir, :lineage_sync, :status, :database_name) SENSITIVE = [:credentials] include Aws::Structure end |
#redshift_temp_dir ⇒ String
The redshiftTempDir of the Amazon Redshift properties.
17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 17516 |
# File 'lib/aws-sdk-datazone/types.rb', line 17504 class RedshiftPropertiesOutput < Struct.new( :storage, :credentials, :is_provisioned_secret, :jdbc_iam_url, :jdbc_url, :redshift_temp_dir, :lineage_sync, :status, :database_name) SENSITIVE = [:credentials] include Aws::Structure end |
#status ⇒ String
The status in the Amazon Redshift properties.
17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 17516 |
# File 'lib/aws-sdk-datazone/types.rb', line 17504 class RedshiftPropertiesOutput < Struct.new( :storage, :credentials, :is_provisioned_secret, :jdbc_iam_url, :jdbc_url, :redshift_temp_dir, :lineage_sync, :status, :database_name) SENSITIVE = [:credentials] include Aws::Structure end |
#storage ⇒ Types::RedshiftStorageProperties
The storage in the Amazon Redshift properties.
17504 17505 17506 17507 17508 17509 17510 17511 17512 17513 17514 17515 17516 |
# File 'lib/aws-sdk-datazone/types.rb', line 17504 class RedshiftPropertiesOutput < Struct.new( :storage, :credentials, :is_provisioned_secret, :jdbc_iam_url, :jdbc_url, :redshift_temp_dir, :lineage_sync, :status, :database_name) SENSITIVE = [:credentials] include Aws::Structure end |