Class: Aws::DataZone::Types::RejectPredictionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


17808
17809
17810
17811
17812
17813
17814
17815
17816
17817
# File 'lib/aws-sdk-datazone/types.rb', line 17808

class RejectPredictionsInput < Struct.new(
  :domain_identifier,
  :identifier,
  :revision,
  :reject_rule,
  :reject_choices,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain.

Returns:

  • (String)


17808
17809
17810
17811
17812
17813
17814
17815
17816
17817
# File 'lib/aws-sdk-datazone/types.rb', line 17808

class RejectPredictionsInput < Struct.new(
  :domain_identifier,
  :identifier,
  :revision,
  :reject_rule,
  :reject_choices,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the prediction.

Returns:

  • (String)


17808
17809
17810
17811
17812
17813
17814
17815
17816
17817
# File 'lib/aws-sdk-datazone/types.rb', line 17808

class RejectPredictionsInput < Struct.new(
  :domain_identifier,
  :identifier,
  :revision,
  :reject_rule,
  :reject_choices,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#reject_choicesArray<Types::RejectChoice>

Specifies the prediction (aka, the automatically generated piece of metadata) and the target (for example, a column name) that can be rejected.

Returns:



17808
17809
17810
17811
17812
17813
17814
17815
17816
17817
# File 'lib/aws-sdk-datazone/types.rb', line 17808

class RejectPredictionsInput < Struct.new(
  :domain_identifier,
  :identifier,
  :revision,
  :reject_rule,
  :reject_choices,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#reject_ruleTypes::RejectRule

Specifies the rule (or the conditions) under which a prediction can be rejected.

Returns:



17808
17809
17810
17811
17812
17813
17814
17815
17816
17817
# File 'lib/aws-sdk-datazone/types.rb', line 17808

class RejectPredictionsInput < Struct.new(
  :domain_identifier,
  :identifier,
  :revision,
  :reject_rule,
  :reject_choices,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#revisionString

The revision that is to be made to the asset.

Returns:

  • (String)


17808
17809
17810
17811
17812
17813
17814
17815
17816
17817
# File 'lib/aws-sdk-datazone/types.rb', line 17808

class RejectPredictionsInput < Struct.new(
  :domain_identifier,
  :identifier,
  :revision,
  :reject_rule,
  :reject_choices,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end