Class: Aws::DataZone::Types::Resource
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::Resource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of a provisioned resource of this Amazon DataZone environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of a provisioned resource of this Amazon DataZone environment.
-
#provider ⇒ String
The provider of a provisioned resource of this Amazon DataZone environment.
-
#type ⇒ String
The type of a provisioned resource of this Amazon DataZone environment.
-
#value ⇒ String
The value of a provisioned resource of this Amazon DataZone environment.
Instance Attribute Details
#name ⇒ String
The name of a provisioned resource of this Amazon DataZone environment.
18132 18133 18134 18135 18136 18137 18138 18139 |
# File 'lib/aws-sdk-datazone/types.rb', line 18132 class Resource < Struct.new( :provider, :name, :value, :type) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The provider of a provisioned resource of this Amazon DataZone environment.
18132 18133 18134 18135 18136 18137 18138 18139 |
# File 'lib/aws-sdk-datazone/types.rb', line 18132 class Resource < Struct.new( :provider, :name, :value, :type) SENSITIVE = [] include Aws::Structure end |