Class: Aws::DataZone::Types::ResourceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ResourceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the resource configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the resource configuration.
-
#identifier ⇒ String
The identifier of the resource configuration.
-
#name ⇒ String
The name of the resource configuration.
-
#parameters ⇒ Hash<String,String>
The parameters of the resource configuration.
-
#region ⇒ String
The Amazon Web Services Region of the resource configuration.
Instance Attribute Details
#description ⇒ String
The description of the resource configuration.
19576 19577 19578 19579 19580 19581 19582 19583 19584 |
# File 'lib/aws-sdk-datazone/types.rb', line 19576 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the resource configuration.
19576 19577 19578 19579 19580 19581 19582 19583 19584 |
# File 'lib/aws-sdk-datazone/types.rb', line 19576 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource configuration.
19576 19577 19578 19579 19580 19581 19582 19583 19584 |
# File 'lib/aws-sdk-datazone/types.rb', line 19576 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
The parameters of the resource configuration.
19576 19577 19578 19579 19580 19581 19582 19583 19584 |
# File 'lib/aws-sdk-datazone/types.rb', line 19576 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region of the resource configuration.
19576 19577 19578 19579 19580 19581 19582 19583 19584 |
# File 'lib/aws-sdk-datazone/types.rb', line 19576 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |