Class: Aws::DataZone::Types::ResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ResultItem
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
ResultItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ResultItem corresponding to the set member.
Resulting entity from the query.
Direct Known Subclasses
Defined Under Namespace
Classes: LineageNode, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lineage_node ⇒ Types::LineageNodeItem
Resulting data lineage node from the query.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#lineage_node ⇒ Types::LineageNodeItem
Resulting data lineage node from the query.
18276 18277 18278 18279 18280 18281 18282 18283 18284 18285 |
# File 'lib/aws-sdk-datazone/types.rb', line 18276 class ResultItem < Struct.new( :lineage_node, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class LineageNode < ResultItem; end class Unknown < ResultItem; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
18276 18277 18278 |
# File 'lib/aws-sdk-datazone/types.rb', line 18276 def unknown @unknown end |