Class: Aws::DataZone::Types::RuleDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::RuleDetail
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
RuleDetail is a union - when making an API calls you must set exactly one of the members.
RuleDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RuleDetail corresponding to the set member.
The details of a rule.
Direct Known Subclasses
GlossaryTermEnforcementDetail, MetadataFormEnforcementDetail, Unknown
Defined Under Namespace
Classes: GlossaryTermEnforcementDetail, MetadataFormEnforcementDetail, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#glossary_term_enforcement_detail ⇒ Types::GlossaryTermEnforcementDetail
The enforcement details of a glossary term that’s part of the metadata rule.
-
#metadata_form_enforcement_detail ⇒ Types::MetadataFormEnforcementDetail
The enforcement detail of the metadata form.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#glossary_term_enforcement_detail ⇒ Types::GlossaryTermEnforcementDetail
The enforcement details of a glossary term that’s part of the metadata rule.
19504 19505 19506 19507 19508 19509 19510 19511 19512 19513 19514 19515 |
# File 'lib/aws-sdk-datazone/types.rb', line 19504 class RuleDetail < Struct.new( :metadata_form_enforcement_detail, :glossary_term_enforcement_detail, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class MetadataFormEnforcementDetail < RuleDetail; end class GlossaryTermEnforcementDetail < RuleDetail; end class Unknown < RuleDetail; end end |
#metadata_form_enforcement_detail ⇒ Types::MetadataFormEnforcementDetail
The enforcement detail of the metadata form.
19504 19505 19506 19507 19508 19509 19510 19511 19512 19513 19514 19515 |
# File 'lib/aws-sdk-datazone/types.rb', line 19504 class RuleDetail < Struct.new( :metadata_form_enforcement_detail, :glossary_term_enforcement_detail, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class MetadataFormEnforcementDetail < RuleDetail; end class GlossaryTermEnforcementDetail < RuleDetail; end class Unknown < RuleDetail; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
19504 19505 19506 |
# File 'lib/aws-sdk-datazone/types.rb', line 19504 def unknown @unknown end |