Class: Aws::DataZone::Types::RuleSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The summary of the rule.

Constant Summary collapse

SENSITIVE =
[:name]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action of the rule.

Returns:

  • (String)


19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#identifierString

The ID of the rule.

Returns:

  • (String)


19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#last_updated_byString

The timestamp at which the rule was last updated.

Returns:

  • (String)


19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#nameString

The name of the rule.

Returns:

  • (String)


19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#revisionString

The revision of the rule.

Returns:

  • (String)


19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#rule_typeString

The type of the rule.

Returns:

  • (String)


19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#scopeTypes::RuleScope

The scope of the rule.

Returns:



19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#targetTypes::RuleTarget

The target of the rule.

Returns:



19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#target_typeString

The target type of the rule.

Returns:

  • (String)


19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#updated_atTime

The timestamp at which the rule was last updated.

Returns:

  • (Time)


19018
19019
19020
19021
19022
19023
19024
19025
19026
19027
19028
19029
19030
19031
# File 'lib/aws-sdk-datazone/types.rb', line 19018

class RuleSummary < Struct.new(
  :identifier,
  :revision,
  :rule_type,
  :name,
  :target_type,
  :target,
  :action,
  :scope,
  :updated_at,
  :last_updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end