Class: Aws::DataZone::Types::SearchInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SearchInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Array<String>
Specifies additional attributes for the ‘Search` action.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain.
-
#filters ⇒ Types::FilterClause
Specifies the search filters.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call to ‘Search`.
-
#next_token ⇒ String
When the number of results is greater than the default value for the ‘MaxResults` parameter, or if you explicitly specify a value for `MaxResults` that is less than the number of results, the response includes a pagination token named `NextToken`.
-
#owning_project_identifier ⇒ String
The identifier of the owning project specified for the search.
-
#search_in ⇒ Array<Types::SearchInItem>
The details of the search.
-
#search_scope ⇒ String
The scope of the search.
-
#search_text ⇒ String
Specifies the text for which to search.
-
#sort ⇒ Types::SearchSort
Specifies the way in which the search results are to be sorted.
Instance Attribute Details
#additional_attributes ⇒ Array<String>
Specifies additional attributes for the ‘Search` action.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Types::FilterClause
Specifies the search filters.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call to ‘Search`. When the number of results to be listed is greater than the value of `MaxResults`, the response contains a `NextToken` value that you can use in a subsequent call to `Search` to list the next set of results.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When the number of results is greater than the default value for the ‘MaxResults` parameter, or if you explicitly specify a value for `MaxResults` that is less than the number of results, the response includes a pagination token named `NextToken`. You can specify this `NextToken` value in a subsequent call to `Search` to list the next set of results.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#owning_project_identifier ⇒ String
The identifier of the owning project specified for the search.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#search_in ⇒ Array<Types::SearchInItem>
The details of the search.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#search_scope ⇒ String
The scope of the search.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#search_text ⇒ String
Specifies the text for which to search.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |
#sort ⇒ Types::SearchSort
Specifies the way in which the search results are to be sorted.
18900 18901 18902 18903 18904 18905 18906 18907 18908 18909 18910 18911 18912 18913 |
# File 'lib/aws-sdk-datazone/types.rb', line 18900 class SearchInput < Struct.new( :domain_identifier, :owning_project_identifier, :max_results, :next_token, :search_scope, :search_text, :search_in, :filters, :sort, :additional_attributes) SENSITIVE = [] include Aws::Structure end |