Class: Aws::DataZone::Types::SearchInventoryResultItem

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

SearchInventoryResultItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SearchInventoryResultItem corresponding to the set member.

The details of the search results.

Defined Under Namespace

Classes: AssetItem, DataProductItem, GlossaryItem, GlossaryTermItem, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_itemTypes::AssetItem

The asset item included in the search results.

Returns:



11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
11778
11779
11780
11781
11782
11783
# File 'lib/aws-sdk-datazone/types.rb', line 11768

class SearchInventoryResultItem < Struct.new(
  :asset_item,
  :data_product_item,
  :glossary_item,
  :glossary_term_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetItem < SearchInventoryResultItem; end
  class DataProductItem < SearchInventoryResultItem; end
  class GlossaryItem < SearchInventoryResultItem; end
  class GlossaryTermItem < SearchInventoryResultItem; end
  class Unknown < SearchInventoryResultItem; end
end

#data_product_itemTypes::DataProductResultItem

The data product.



11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
11778
11779
11780
11781
11782
11783
# File 'lib/aws-sdk-datazone/types.rb', line 11768

class SearchInventoryResultItem < Struct.new(
  :asset_item,
  :data_product_item,
  :glossary_item,
  :glossary_term_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetItem < SearchInventoryResultItem; end
  class DataProductItem < SearchInventoryResultItem; end
  class GlossaryItem < SearchInventoryResultItem; end
  class GlossaryTermItem < SearchInventoryResultItem; end
  class Unknown < SearchInventoryResultItem; end
end

#glossary_itemTypes::GlossaryItem

The glossary item included in the search results.

Returns:



11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
11778
11779
11780
11781
11782
11783
# File 'lib/aws-sdk-datazone/types.rb', line 11768

class SearchInventoryResultItem < Struct.new(
  :asset_item,
  :data_product_item,
  :glossary_item,
  :glossary_term_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetItem < SearchInventoryResultItem; end
  class DataProductItem < SearchInventoryResultItem; end
  class GlossaryItem < SearchInventoryResultItem; end
  class GlossaryTermItem < SearchInventoryResultItem; end
  class Unknown < SearchInventoryResultItem; end
end

#glossary_term_itemTypes::GlossaryTermItem

The glossary term item included in the search results.



11768
11769
11770
11771
11772
11773
11774
11775
11776
11777
11778
11779
11780
11781
11782
11783
# File 'lib/aws-sdk-datazone/types.rb', line 11768

class SearchInventoryResultItem < Struct.new(
  :asset_item,
  :data_product_item,
  :glossary_item,
  :glossary_term_item,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetItem < SearchInventoryResultItem; end
  class DataProductItem < SearchInventoryResultItem; end
  class GlossaryItem < SearchInventoryResultItem; end
  class GlossaryTermItem < SearchInventoryResultItem; end
  class Unknown < SearchInventoryResultItem; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



11768
11769
11770
# File 'lib/aws-sdk-datazone/types.rb', line 11768

def unknown
  @unknown
end