Class: Aws::DataZone::Types::SearchTypesResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SearchTypesResultItem
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
SearchTypesResultItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SearchTypesResultItem corresponding to the set member.
The details of the results of the ‘SearchTypes` action.
Direct Known Subclasses
Defined Under Namespace
Classes: AssetTypeItem, FormTypeItem, LineageNodeTypeItem, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_type_item ⇒ Types::AssetTypeItem
The asset type included in the results of the ‘SearchTypes` action.
-
#form_type_item ⇒ Types::FormTypeData
The form type included in the results of the ‘SearchTypes` action.
-
#lineage_node_type_item ⇒ Types::LineageNodeTypeItem
The details of a data lineage node type.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#asset_type_item ⇒ Types::AssetTypeItem
The asset type included in the results of the ‘SearchTypes` action.
19694 19695 19696 19697 19698 19699 19700 19701 19702 19703 19704 19705 19706 19707 |
# File 'lib/aws-sdk-datazone/types.rb', line 19694 class SearchTypesResultItem < Struct.new( :asset_type_item, :form_type_item, :lineage_node_type_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetTypeItem < SearchTypesResultItem; end class FormTypeItem < SearchTypesResultItem; end class LineageNodeTypeItem < SearchTypesResultItem; end class Unknown < SearchTypesResultItem; end end |
#form_type_item ⇒ Types::FormTypeData
The form type included in the results of the ‘SearchTypes` action.
19694 19695 19696 19697 19698 19699 19700 19701 19702 19703 19704 19705 19706 19707 |
# File 'lib/aws-sdk-datazone/types.rb', line 19694 class SearchTypesResultItem < Struct.new( :asset_type_item, :form_type_item, :lineage_node_type_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetTypeItem < SearchTypesResultItem; end class FormTypeItem < SearchTypesResultItem; end class LineageNodeTypeItem < SearchTypesResultItem; end class Unknown < SearchTypesResultItem; end end |
#lineage_node_type_item ⇒ Types::LineageNodeTypeItem
The details of a data lineage node type.
19694 19695 19696 19697 19698 19699 19700 19701 19702 19703 19704 19705 19706 19707 |
# File 'lib/aws-sdk-datazone/types.rb', line 19694 class SearchTypesResultItem < Struct.new( :asset_type_item, :form_type_item, :lineage_node_type_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetTypeItem < SearchTypesResultItem; end class FormTypeItem < SearchTypesResultItem; end class LineageNodeTypeItem < SearchTypesResultItem; end class Unknown < SearchTypesResultItem; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
19694 19695 19696 |
# File 'lib/aws-sdk-datazone/types.rb', line 19694 def unknown @unknown end |