Class: Aws::DataZone::Types::SelfGrantStatusOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SelfGrantStatusOutput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
SelfGrantStatusOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SelfGrantStatusOutput corresponding to the set member.
The details for the self granting status for a data source.
Direct Known Subclasses
Defined Under Namespace
Classes: GlueSelfGrantStatus, RedshiftSelfGrantStatus, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#glue_self_grant_status ⇒ Types::GlueSelfGrantStatusOutput
The details for the self granting status for a Glue data source.
-
#redshift_self_grant_status ⇒ Types::RedshiftSelfGrantStatusOutput
The details for the self granting status for an Amazon Redshift data source.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#glue_self_grant_status ⇒ Types::GlueSelfGrantStatusOutput
The details for the self granting status for a Glue data source.
12172 12173 12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 |
# File 'lib/aws-sdk-datazone/types.rb', line 12172 class SelfGrantStatusOutput < Struct.new( :glue_self_grant_status, :redshift_self_grant_status, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueSelfGrantStatus < SelfGrantStatusOutput; end class RedshiftSelfGrantStatus < SelfGrantStatusOutput; end class Unknown < SelfGrantStatusOutput; end end |
#redshift_self_grant_status ⇒ Types::RedshiftSelfGrantStatusOutput
The details for the self granting status for an Amazon Redshift data source.
12172 12173 12174 12175 12176 12177 12178 12179 12180 12181 12182 12183 |
# File 'lib/aws-sdk-datazone/types.rb', line 12172 class SelfGrantStatusOutput < Struct.new( :glue_self_grant_status, :redshift_self_grant_status, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueSelfGrantStatus < SelfGrantStatusOutput; end class RedshiftSelfGrantStatus < SelfGrantStatusOutput; end class Unknown < SelfGrantStatusOutput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
12172 12173 12174 |
# File 'lib/aws-sdk-datazone/types.rb', line 12172 def unknown @unknown end |