Class: Aws::DataZone::Types::SnowflakePropertiesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Contains the Snowflake-specific settings required when creating or updating a connection, including the Snowflake role, identity mapping, and lineage sync configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connectivity_propertiesTypes::ConnectivityProperties

The connectivity properties of the Snowflake connection.



20885
20886
20887
20888
20889
20890
20891
20892
# File 'lib/aws-sdk-datazone/types.rb', line 20885

class SnowflakePropertiesInput < Struct.new(
  :connectivity_properties,
  :snowflake_role,
  :identity_mapping,
  :lineage_sync)
  SENSITIVE = []
  include Aws::Structure
end

#identity_mappingTypes::IdentityMapping

The identity mapping configuration for the Snowflake connection.



20885
20886
20887
20888
20889
20890
20891
20892
# File 'lib/aws-sdk-datazone/types.rb', line 20885

class SnowflakePropertiesInput < Struct.new(
  :connectivity_properties,
  :snowflake_role,
  :identity_mapping,
  :lineage_sync)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_syncTypes::LineageSyncInput

The lineage sync configuration for the Snowflake connection.



20885
20886
20887
20888
20889
20890
20891
20892
# File 'lib/aws-sdk-datazone/types.rb', line 20885

class SnowflakePropertiesInput < Struct.new(
  :connectivity_properties,
  :snowflake_role,
  :identity_mapping,
  :lineage_sync)
  SENSITIVE = []
  include Aws::Structure
end

#snowflake_roleString

The Snowflake role used to access Snowflake resources.

Returns:

  • (String)


20885
20886
20887
20888
20889
20890
20891
20892
# File 'lib/aws-sdk-datazone/types.rb', line 20885

class SnowflakePropertiesInput < Struct.new(
  :connectivity_properties,
  :snowflake_role,
  :identity_mapping,
  :lineage_sync)
  SENSITIVE = []
  include Aws::Structure
end