Class: Aws::DataZone::Types::SparkGluePropertiesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SparkGluePropertiesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The Spark Amazon Web Services Glue properties.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_args ⇒ Types::SparkGlueArgs
The additional args in the Spark Amazon Web Services Glue properties.
-
#glue_connection_name ⇒ String
The Amazon Web Services Glue connection name in the Spark Amazon Web Services Glue properties.
-
#glue_connection_names ⇒ Array<String>
The Amazon Web Services Glue connection names in the Spark Amazon Web Services Glue properties.
-
#glue_version ⇒ String
The Amazon Web Services Glue version in the Spark Amazon Web Services Glue properties.
-
#idle_timeout ⇒ Integer
The idle timeout in the Spark Amazon Web Services Glue properties.
-
#java_virtual_env ⇒ String
The Java virtual env in the Spark Amazon Web Services Glue properties.
-
#number_of_workers ⇒ Integer
The number of workers in the Spark Amazon Web Services Glue properties.
-
#python_virtual_env ⇒ String
The Python virtual env in the Spark Amazon Web Services Glue properties.
-
#worker_type ⇒ String
The worker type in the Spark Amazon Web Services Glue properties.
Instance Attribute Details
#additional_args ⇒ Types::SparkGlueArgs
The additional args in the Spark Amazon Web Services Glue properties.
21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-datazone/types.rb', line 21330 class SparkGluePropertiesInput < Struct.new( :additional_args, :glue_connection_name, :glue_connection_names, :glue_version, :idle_timeout, :java_virtual_env, :number_of_workers, :python_virtual_env, :worker_type) SENSITIVE = [] include Aws::Structure end |
#glue_connection_name ⇒ String
The Amazon Web Services Glue connection name in the Spark Amazon Web
Services Glue properties. Specify either glueConnectionName or
glueConnectionNames, but not both.
21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-datazone/types.rb', line 21330 class SparkGluePropertiesInput < Struct.new( :additional_args, :glue_connection_name, :glue_connection_names, :glue_version, :idle_timeout, :java_virtual_env, :number_of_workers, :python_virtual_env, :worker_type) SENSITIVE = [] include Aws::Structure end |
#glue_connection_names ⇒ Array<String>
The Amazon Web Services Glue connection names in the Spark Amazon
Web Services Glue properties. Specify either glueConnectionName or
glueConnectionNames, but not both.
21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-datazone/types.rb', line 21330 class SparkGluePropertiesInput < Struct.new( :additional_args, :glue_connection_name, :glue_connection_names, :glue_version, :idle_timeout, :java_virtual_env, :number_of_workers, :python_virtual_env, :worker_type) SENSITIVE = [] include Aws::Structure end |
#glue_version ⇒ String
The Amazon Web Services Glue version in the Spark Amazon Web Services Glue properties.
21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-datazone/types.rb', line 21330 class SparkGluePropertiesInput < Struct.new( :additional_args, :glue_connection_name, :glue_connection_names, :glue_version, :idle_timeout, :java_virtual_env, :number_of_workers, :python_virtual_env, :worker_type) SENSITIVE = [] include Aws::Structure end |
#idle_timeout ⇒ Integer
The idle timeout in the Spark Amazon Web Services Glue properties.
21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-datazone/types.rb', line 21330 class SparkGluePropertiesInput < Struct.new( :additional_args, :glue_connection_name, :glue_connection_names, :glue_version, :idle_timeout, :java_virtual_env, :number_of_workers, :python_virtual_env, :worker_type) SENSITIVE = [] include Aws::Structure end |
#java_virtual_env ⇒ String
The Java virtual env in the Spark Amazon Web Services Glue properties.
21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-datazone/types.rb', line 21330 class SparkGluePropertiesInput < Struct.new( :additional_args, :glue_connection_name, :glue_connection_names, :glue_version, :idle_timeout, :java_virtual_env, :number_of_workers, :python_virtual_env, :worker_type) SENSITIVE = [] include Aws::Structure end |
#number_of_workers ⇒ Integer
The number of workers in the Spark Amazon Web Services Glue properties.
21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-datazone/types.rb', line 21330 class SparkGluePropertiesInput < Struct.new( :additional_args, :glue_connection_name, :glue_connection_names, :glue_version, :idle_timeout, :java_virtual_env, :number_of_workers, :python_virtual_env, :worker_type) SENSITIVE = [] include Aws::Structure end |
#python_virtual_env ⇒ String
The Python virtual env in the Spark Amazon Web Services Glue properties.
21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-datazone/types.rb', line 21330 class SparkGluePropertiesInput < Struct.new( :additional_args, :glue_connection_name, :glue_connection_names, :glue_version, :idle_timeout, :java_virtual_env, :number_of_workers, :python_virtual_env, :worker_type) SENSITIVE = [] include Aws::Structure end |
#worker_type ⇒ String
The worker type in the Spark Amazon Web Services Glue properties.
21330 21331 21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 |
# File 'lib/aws-sdk-datazone/types.rb', line 21330 class SparkGluePropertiesInput < Struct.new( :additional_args, :glue_connection_name, :glue_connection_names, :glue_version, :idle_timeout, :java_virtual_env, :number_of_workers, :python_virtual_env, :worker_type) SENSITIVE = [] include Aws::Structure end |