Class: Aws::DataZone::Types::StartNotebookExportInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


21033
21034
21035
21036
21037
21038
21039
21040
21041
# File 'lib/aws-sdk-datazone/types.rb', line 21033

class StartNotebookExportInput < Struct.new(
  :domain_identifier,
  :notebook_identifier,
  :owning_project_identifier,
  :file_format,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon SageMaker Unified Studio domain in which to export the notebook.

Returns:

  • (String)


21033
21034
21035
21036
21037
21038
21039
21040
21041
# File 'lib/aws-sdk-datazone/types.rb', line 21033

class StartNotebookExportInput < Struct.new(
  :domain_identifier,
  :notebook_identifier,
  :owning_project_identifier,
  :file_format,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#file_formatString

The file format for the notebook export. Valid values are ‘PDF` and `IPYNB`.

Returns:

  • (String)


21033
21034
21035
21036
21037
21038
21039
21040
21041
# File 'lib/aws-sdk-datazone/types.rb', line 21033

class StartNotebookExportInput < Struct.new(
  :domain_identifier,
  :notebook_identifier,
  :owning_project_identifier,
  :file_format,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#notebook_identifierString

The identifier of the notebook to export.

Returns:

  • (String)


21033
21034
21035
21036
21037
21038
21039
21040
21041
# File 'lib/aws-sdk-datazone/types.rb', line 21033

class StartNotebookExportInput < Struct.new(
  :domain_identifier,
  :notebook_identifier,
  :owning_project_identifier,
  :file_format,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#owning_project_identifierString

The identifier of the project that owns the notebook.

Returns:

  • (String)


21033
21034
21035
21036
21037
21038
21039
21040
21041
# File 'lib/aws-sdk-datazone/types.rb', line 21033

class StartNotebookExportInput < Struct.new(
  :domain_identifier,
  :notebook_identifier,
  :owning_project_identifier,
  :file_format,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end