Class: Aws::DataZone::Types::StartNotebookExportOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the notebook export was started.

Returns:

  • (Time)


21077
21078
21079
21080
21081
21082
21083
21084
21085
21086
21087
21088
# File 'lib/aws-sdk-datazone/types.rb', line 21077

class StartNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The identifier of the user who started the notebook export.

Returns:

  • (String)


21077
21078
21079
21080
21081
21082
21083
21084
21085
21086
21087
21088
# File 'lib/aws-sdk-datazone/types.rb', line 21077

class StartNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon SageMaker Unified Studio domain.

Returns:

  • (String)


21077
21078
21079
21080
21081
21082
21083
21084
21085
21086
21087
21088
# File 'lib/aws-sdk-datazone/types.rb', line 21077

class StartNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#file_formatString

The file format of the notebook export.

Returns:

  • (String)


21077
21078
21079
21080
21081
21082
21083
21084
21085
21086
21087
21088
# File 'lib/aws-sdk-datazone/types.rb', line 21077

class StartNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the notebook export.

Returns:

  • (String)


21077
21078
21079
21080
21081
21082
21083
21084
21085
21086
21087
21088
# File 'lib/aws-sdk-datazone/types.rb', line 21077

class StartNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#notebook_idString

The identifier of the notebook.

Returns:

  • (String)


21077
21078
21079
21080
21081
21082
21083
21084
21085
21086
21087
21088
# File 'lib/aws-sdk-datazone/types.rb', line 21077

class StartNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the notebook.

Returns:

  • (String)


21077
21078
21079
21080
21081
21082
21083
21084
21085
21086
21087
21088
# File 'lib/aws-sdk-datazone/types.rb', line 21077

class StartNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the notebook export.

Returns:

  • (String)


21077
21078
21079
21080
21081
21082
21083
21084
21085
21086
21087
21088
# File 'lib/aws-sdk-datazone/types.rb', line 21077

class StartNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end