Class: Aws::DataZone::Types::StartNotebookImportOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the notebook import was started.

Returns:

  • (Time)


21337
21338
21339
21340
21341
21342
21343
21344
21345
21346
21347
21348
21349
# File 'lib/aws-sdk-datazone/types.rb', line 21337

class StartNotebookImportOutput < Struct.new(
  :notebook_id,
  :status,
  :domain_id,
  :owning_project_id,
  :name,
  :description,
  :source_location,
  :created_at,
  :created_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_byString

The identifier of the user who started the notebook import.

Returns:

  • (String)


21337
21338
21339
21340
21341
21342
21343
21344
21345
21346
21347
21348
21349
# File 'lib/aws-sdk-datazone/types.rb', line 21337

class StartNotebookImportOutput < Struct.new(
  :notebook_id,
  :status,
  :domain_id,
  :owning_project_id,
  :name,
  :description,
  :source_location,
  :created_at,
  :created_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the imported notebook.

Returns:

  • (String)


21337
21338
21339
21340
21341
21342
21343
21344
21345
21346
21347
21348
21349
# File 'lib/aws-sdk-datazone/types.rb', line 21337

class StartNotebookImportOutput < Struct.new(
  :notebook_id,
  :status,
  :domain_id,
  :owning_project_id,
  :name,
  :description,
  :source_location,
  :created_at,
  :created_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon SageMaker Unified Studio domain.

Returns:

  • (String)


21337
21338
21339
21340
21341
21342
21343
21344
21345
21346
21347
21348
21349
# File 'lib/aws-sdk-datazone/types.rb', line 21337

class StartNotebookImportOutput < Struct.new(
  :notebook_id,
  :status,
  :domain_id,
  :owning_project_id,
  :name,
  :description,
  :source_location,
  :created_at,
  :created_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the imported notebook.

Returns:

  • (String)


21337
21338
21339
21340
21341
21342
21343
21344
21345
21346
21347
21348
21349
# File 'lib/aws-sdk-datazone/types.rb', line 21337

class StartNotebookImportOutput < Struct.new(
  :notebook_id,
  :status,
  :domain_id,
  :owning_project_id,
  :name,
  :description,
  :source_location,
  :created_at,
  :created_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#notebook_idString

The identifier of the imported notebook.

Returns:

  • (String)


21337
21338
21339
21340
21341
21342
21343
21344
21345
21346
21347
21348
21349
# File 'lib/aws-sdk-datazone/types.rb', line 21337

class StartNotebookImportOutput < Struct.new(
  :notebook_id,
  :status,
  :domain_id,
  :owning_project_id,
  :name,
  :description,
  :source_location,
  :created_at,
  :created_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the imported notebook.

Returns:

  • (String)


21337
21338
21339
21340
21341
21342
21343
21344
21345
21346
21347
21348
21349
# File 'lib/aws-sdk-datazone/types.rb', line 21337

class StartNotebookImportOutput < Struct.new(
  :notebook_id,
  :status,
  :domain_id,
  :owning_project_id,
  :name,
  :description,
  :source_location,
  :created_at,
  :created_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#source_locationTypes::SourceLocation

The source location from which the notebook was imported.



21337
21338
21339
21340
21341
21342
21343
21344
21345
21346
21347
21348
21349
# File 'lib/aws-sdk-datazone/types.rb', line 21337

class StartNotebookImportOutput < Struct.new(
  :notebook_id,
  :status,
  :domain_id,
  :owning_project_id,
  :name,
  :description,
  :source_location,
  :created_at,
  :created_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#statusString

The status of the notebook import.

Returns:

  • (String)


21337
21338
21339
21340
21341
21342
21343
21344
21345
21346
21347
21348
21349
# File 'lib/aws-sdk-datazone/types.rb', line 21337

class StartNotebookImportOutput < Struct.new(
  :notebook_id,
  :status,
  :domain_id,
  :owning_project_id,
  :name,
  :description,
  :source_location,
  :created_at,
  :created_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end