Class: Aws::DataZone::Types::StartNotebookRunInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:metadata, :parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#compute_configurationTypes::ComputeConfig

The compute configuration for the notebook run, including instance type and environment version.



21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon SageMaker Unified Studio domain in which the notebook run is started.

Returns:

  • (String)


21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#metadataHash<String,String>

The metadata for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.

Returns:

  • (Hash<String,String>)


21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#network_configurationTypes::NetworkConfig

The network configuration for the notebook run, including network access type and optional VPC settings.



21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#notebook_identifierString

The identifier of the notebook to run.

Returns:

  • (String)


21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#owning_project_identifierString

The identifier of the project that owns the notebook run.

Returns:

  • (String)


21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#parametersHash<String,String>

The sensitive parameters for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.

Returns:

  • (Hash<String,String>)


21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#schedule_identifierString

The identifier of the schedule associated with the notebook run.

Returns:

  • (String)


21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#timeout_configurationTypes::TimeoutConfig

The timeout configuration for the notebook run. The default timeout is 720 minutes (12 hours) and the maximum is 1440 minutes (24 hours).



21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#trigger_sourceTypes::TriggerSource

The source that triggered the notebook run.



21410
21411
21412
21413
21414
21415
21416
21417
21418
21419
21420
21421
21422
21423
21424
# File 'lib/aws-sdk-datazone/types.rb', line 21410

class StartNotebookRunInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :notebook_identifier,
  :schedule_identifier,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :trigger_source,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end