Class: Aws::DataZone::Types::StartNotebookSyncOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartNotebookSyncOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the notebook sync was started.
-
#created_by ⇒ String
The identifier of the user who started the notebook sync.
-
#description ⇒ String
The description of the synced notebook.
-
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
-
#git_metadata ⇒ Types::GitMetadata
The Git metadata associated with the synced notebook.
-
#name ⇒ String
The name of the synced notebook.
-
#notebook_id ⇒ String
The identifier of the synced notebook.
-
#owning_project_id ⇒ String
The identifier of the project that owns the synced notebook.
-
#source_location ⇒ Types::SourceLocation
The source location from which the notebook was synced.
-
#status ⇒ String
The status of the notebook sync.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the notebook sync was started.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who started the notebook sync.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the synced notebook.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#git_metadata ⇒ Types::GitMetadata
The Git metadata associated with the synced notebook.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the synced notebook.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#notebook_id ⇒ String
The identifier of the synced notebook.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the synced notebook.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#source_location ⇒ Types::SourceLocation
The source location from which the notebook was synced.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#status ⇒ String
The status of the notebook sync.
22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 |
# File 'lib/aws-sdk-datazone/types.rb', line 22090 class StartNotebookSyncOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :source_location, :git_metadata, :name, :description, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |