Class: Aws::DataZone::Types::StopNotebookRunInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


20612
20613
20614
20615
20616
20617
20618
# File 'lib/aws-sdk-datazone/types.rb', line 20612

class StopNotebookRunInput < Struct.new(
  :domain_identifier,
  :identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain in which the notebook run is stopped.

Returns:

  • (String)


20612
20613
20614
20615
20616
20617
20618
# File 'lib/aws-sdk-datazone/types.rb', line 20612

class StopNotebookRunInput < Struct.new(
  :domain_identifier,
  :identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the notebook run to stop.

Returns:

  • (String)


20612
20613
20614
20615
20616
20617
20618
# File 'lib/aws-sdk-datazone/types.rb', line 20612

class StopNotebookRunInput < Struct.new(
  :domain_identifier,
  :identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end