Class: Aws::DataZone::Types::StorageConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The storage configuration for a notebook run in Amazon DataZone.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_arnString

The ARN of the KMS key used for encryption.

Returns:

  • (String)


20659
20660
20661
20662
20663
20664
# File 'lib/aws-sdk-datazone/types.rb', line 20659

class StorageConfig < Struct.new(
  :project_s3_path,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#project_s3_pathString

The Amazon Simple Storage Service path for the project storage.

Returns:

  • (String)


20659
20660
20661
20662
20663
20664
# File 'lib/aws-sdk-datazone/types.rb', line 20659

class StorageConfig < Struct.new(
  :project_s3_path,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end