Class: Aws::DataZone::Types::SubscribedAsset
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SubscribedAsset
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the asset for which the subscription grant is created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_id ⇒ String
The identifier of the asset for which the subscription grant is created.
-
#asset_revision ⇒ String
The revision of the asset for which the subscription grant is created.
-
#asset_scope ⇒ Types::AssetScope
The asset scope of the subscribed asset.
-
#failure_cause ⇒ Types::FailureCause
The failure cause included in the details of the asset for which the subscription grant is created.
-
#failure_timestamp ⇒ Time
The failure timestamp included in the details of the asset for which the subscription grant is created.
-
#granted_timestamp ⇒ Time
The timestamp of when the subscription grant to the asset is created.
-
#permissions ⇒ Types::Permissions
The asset permissions.
-
#status ⇒ String
The status of the asset for which the subscription grant is created.
-
#target_name ⇒ String
The target name of the asset for which the subscription grant is created.
Instance Attribute Details
#asset_id ⇒ String
The identifier of the asset for which the subscription grant is created.
21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/aws-sdk-datazone/types.rb', line 21500 class SubscribedAsset < Struct.new( :asset_id, :asset_revision, :status, :target_name, :failure_cause, :granted_timestamp, :failure_timestamp, :asset_scope, :permissions) SENSITIVE = [] include Aws::Structure end |
#asset_revision ⇒ String
The revision of the asset for which the subscription grant is created.
21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/aws-sdk-datazone/types.rb', line 21500 class SubscribedAsset < Struct.new( :asset_id, :asset_revision, :status, :target_name, :failure_cause, :granted_timestamp, :failure_timestamp, :asset_scope, :permissions) SENSITIVE = [] include Aws::Structure end |
#asset_scope ⇒ Types::AssetScope
The asset scope of the subscribed asset.
21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/aws-sdk-datazone/types.rb', line 21500 class SubscribedAsset < Struct.new( :asset_id, :asset_revision, :status, :target_name, :failure_cause, :granted_timestamp, :failure_timestamp, :asset_scope, :permissions) SENSITIVE = [] include Aws::Structure end |
#failure_cause ⇒ Types::FailureCause
The failure cause included in the details of the asset for which the subscription grant is created.
21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/aws-sdk-datazone/types.rb', line 21500 class SubscribedAsset < Struct.new( :asset_id, :asset_revision, :status, :target_name, :failure_cause, :granted_timestamp, :failure_timestamp, :asset_scope, :permissions) SENSITIVE = [] include Aws::Structure end |
#failure_timestamp ⇒ Time
The failure timestamp included in the details of the asset for which the subscription grant is created.
21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/aws-sdk-datazone/types.rb', line 21500 class SubscribedAsset < Struct.new( :asset_id, :asset_revision, :status, :target_name, :failure_cause, :granted_timestamp, :failure_timestamp, :asset_scope, :permissions) SENSITIVE = [] include Aws::Structure end |
#granted_timestamp ⇒ Time
The timestamp of when the subscription grant to the asset is created.
21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/aws-sdk-datazone/types.rb', line 21500 class SubscribedAsset < Struct.new( :asset_id, :asset_revision, :status, :target_name, :failure_cause, :granted_timestamp, :failure_timestamp, :asset_scope, :permissions) SENSITIVE = [] include Aws::Structure end |
#permissions ⇒ Types::Permissions
The asset permissions.
21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/aws-sdk-datazone/types.rb', line 21500 class SubscribedAsset < Struct.new( :asset_id, :asset_revision, :status, :target_name, :failure_cause, :granted_timestamp, :failure_timestamp, :asset_scope, :permissions) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the asset for which the subscription grant is created.
21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/aws-sdk-datazone/types.rb', line 21500 class SubscribedAsset < Struct.new( :asset_id, :asset_revision, :status, :target_name, :failure_cause, :granted_timestamp, :failure_timestamp, :asset_scope, :permissions) SENSITIVE = [] include Aws::Structure end |
#target_name ⇒ String
The target name of the asset for which the subscription grant is created.
21500 21501 21502 21503 21504 21505 21506 21507 21508 21509 21510 21511 21512 |
# File 'lib/aws-sdk-datazone/types.rb', line 21500 class SubscribedAsset < Struct.new( :asset_id, :asset_revision, :status, :target_name, :failure_cause, :granted_timestamp, :failure_timestamp, :asset_scope, :permissions) SENSITIVE = [] include Aws::Structure end |