Class: Aws::DataZone::Types::SubscribedPrincipal
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SubscribedPrincipal
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
SubscribedPrincipal is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SubscribedPrincipal corresponding to the set member.
The principal that has the subscription grant for the asset.
Defined Under Namespace
Classes: Group, Iam, Project, Unknown, User
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group ⇒ Types::SubscribedGroup
The subscribed group.
-
#iam ⇒ Types::SubscribedIamPrincipal
The subscribed IAM principal.
-
#project ⇒ Types::SubscribedProject
The project that has the subscription grant.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#user ⇒ Types::SubscribedUser
The subscribed user.
Instance Attribute Details
#group ⇒ Types::SubscribedGroup
The subscribed group.
22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 |
# File 'lib/aws-sdk-datazone/types.rb', line 22360 class SubscribedPrincipal < Struct.new( :project, :user, :group, :iam, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class User < SubscribedPrincipal; end class Group < SubscribedPrincipal; end class Iam < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |
#iam ⇒ Types::SubscribedIamPrincipal
The subscribed IAM principal.
22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 |
# File 'lib/aws-sdk-datazone/types.rb', line 22360 class SubscribedPrincipal < Struct.new( :project, :user, :group, :iam, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class User < SubscribedPrincipal; end class Group < SubscribedPrincipal; end class Iam < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |
#project ⇒ Types::SubscribedProject
The project that has the subscription grant.
22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 |
# File 'lib/aws-sdk-datazone/types.rb', line 22360 class SubscribedPrincipal < Struct.new( :project, :user, :group, :iam, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class User < SubscribedPrincipal; end class Group < SubscribedPrincipal; end class Iam < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
22360 22361 22362 |
# File 'lib/aws-sdk-datazone/types.rb', line 22360 def unknown @unknown end |
#user ⇒ Types::SubscribedUser
The subscribed user.
22360 22361 22362 22363 22364 22365 22366 22367 22368 22369 22370 22371 22372 22373 22374 22375 |
# File 'lib/aws-sdk-datazone/types.rb', line 22360 class SubscribedPrincipal < Struct.new( :project, :user, :group, :iam, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class User < SubscribedPrincipal; end class Group < SubscribedPrincipal; end class Iam < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |