Class: Aws::DataZone::Types::SubscriptionTargetForm
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SubscriptionTargetForm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the subscription target configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
The content of the subscription target configuration.
-
#form_name ⇒ String
The form name included in the subscription target configuration.
Instance Attribute Details
#content ⇒ String
The content of the subscription target configuration.
20674 20675 20676 20677 20678 20679 |
# File 'lib/aws-sdk-datazone/types.rb', line 20674 class SubscriptionTargetForm < Struct.new( :form_name, :content) SENSITIVE = [] include Aws::Structure end |
#form_name ⇒ String
The form name included in the subscription target configuration.
20674 20675 20676 20677 20678 20679 |
# File 'lib/aws-sdk-datazone/types.rb', line 20674 class SubscriptionTargetForm < Struct.new( :form_name, :content) SENSITIVE = [] include Aws::Structure end |