Class: Aws::DataZone::Types::TextMatchItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::TextMatchItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
A structure indicating matched terms for an attribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The name of the attribute.
-
#match_offsets ⇒ Array<Types::MatchOffset>
List of offsets indicating matching terms in the TextMatchItem text.
-
#text ⇒ String
Snippet of attribute text containing highlighted content.
Instance Attribute Details
#attribute ⇒ String
The name of the attribute.
20766 20767 20768 20769 20770 20771 20772 |
# File 'lib/aws-sdk-datazone/types.rb', line 20766 class TextMatchItem < Struct.new( :attribute, :text, :match_offsets) SENSITIVE = [] include Aws::Structure end |
#match_offsets ⇒ Array<Types::MatchOffset>
List of offsets indicating matching terms in the TextMatchItem text.
20766 20767 20768 20769 20770 20771 20772 |
# File 'lib/aws-sdk-datazone/types.rb', line 20766 class TextMatchItem < Struct.new( :attribute, :text, :match_offsets) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
Snippet of attribute text containing highlighted content.
20766 20767 20768 20769 20770 20771 20772 |
# File 'lib/aws-sdk-datazone/types.rb', line 20766 class TextMatchItem < Struct.new( :attribute, :text, :match_offsets) SENSITIVE = [] include Aws::Structure end |