Class: Aws::DataZone::Types::TimeSeriesDataPointFormOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The time series data points form.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The content of the time series data points form.

Returns:

  • (String)


12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
# File 'lib/aws-sdk-datazone/types.rb', line 12324

class TimeSeriesDataPointFormOutput < Struct.new(
  :content,
  :form_name,
  :id,
  :timestamp,
  :type_identifier,
  :type_revision)
  SENSITIVE = []
  include Aws::Structure
end

#form_nameString

The name of the time series data points form.

Returns:

  • (String)


12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
# File 'lib/aws-sdk-datazone/types.rb', line 12324

class TimeSeriesDataPointFormOutput < Struct.new(
  :content,
  :form_name,
  :id,
  :timestamp,
  :type_identifier,
  :type_revision)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the time series data points form.

Returns:

  • (String)


12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
# File 'lib/aws-sdk-datazone/types.rb', line 12324

class TimeSeriesDataPointFormOutput < Struct.new(
  :content,
  :form_name,
  :id,
  :timestamp,
  :type_identifier,
  :type_revision)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The timestamp of the time series data points form.

Returns:

  • (Time)


12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
# File 'lib/aws-sdk-datazone/types.rb', line 12324

class TimeSeriesDataPointFormOutput < Struct.new(
  :content,
  :form_name,
  :id,
  :timestamp,
  :type_identifier,
  :type_revision)
  SENSITIVE = []
  include Aws::Structure
end

#type_identifierString

The ID of the type of the time series data points form.

Returns:

  • (String)


12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
# File 'lib/aws-sdk-datazone/types.rb', line 12324

class TimeSeriesDataPointFormOutput < Struct.new(
  :content,
  :form_name,
  :id,
  :timestamp,
  :type_identifier,
  :type_revision)
  SENSITIVE = []
  include Aws::Structure
end

#type_revisionString

The revision type of the time series data points form.

Returns:

  • (String)


12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
# File 'lib/aws-sdk-datazone/types.rb', line 12324

class TimeSeriesDataPointFormOutput < Struct.new(
  :content,
  :form_name,
  :id,
  :timestamp,
  :type_identifier,
  :type_revision)
  SENSITIVE = []
  include Aws::Structure
end