Class: Aws::DataZone::Types::TimeSeriesDataPointSummaryFormOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The summary of the time series data points form.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_summaryString

The content of the summary of the time series data points form.

Returns:

  • (String)


20888
20889
20890
20891
20892
20893
20894
20895
20896
20897
# File 'lib/aws-sdk-datazone/types.rb', line 20888

class TimeSeriesDataPointSummaryFormOutput < Struct.new(
  :form_name,
  :type_identifier,
  :type_revision,
  :timestamp,
  :content_summary,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#form_nameString

The name of the time series data points summary form.

Returns:

  • (String)


20888
20889
20890
20891
20892
20893
20894
20895
20896
20897
# File 'lib/aws-sdk-datazone/types.rb', line 20888

class TimeSeriesDataPointSummaryFormOutput < Struct.new(
  :form_name,
  :type_identifier,
  :type_revision,
  :timestamp,
  :content_summary,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the time series data points summary form.

Returns:

  • (String)


20888
20889
20890
20891
20892
20893
20894
20895
20896
20897
# File 'lib/aws-sdk-datazone/types.rb', line 20888

class TimeSeriesDataPointSummaryFormOutput < Struct.new(
  :form_name,
  :type_identifier,
  :type_revision,
  :timestamp,
  :content_summary,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The timestamp of the time series data points summary form.

Returns:

  • (Time)


20888
20889
20890
20891
20892
20893
20894
20895
20896
20897
# File 'lib/aws-sdk-datazone/types.rb', line 20888

class TimeSeriesDataPointSummaryFormOutput < Struct.new(
  :form_name,
  :type_identifier,
  :type_revision,
  :timestamp,
  :content_summary,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#type_identifierString

The type ID of the time series data points summary form.

Returns:

  • (String)


20888
20889
20890
20891
20892
20893
20894
20895
20896
20897
# File 'lib/aws-sdk-datazone/types.rb', line 20888

class TimeSeriesDataPointSummaryFormOutput < Struct.new(
  :form_name,
  :type_identifier,
  :type_revision,
  :timestamp,
  :content_summary,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#type_revisionString

The type revision of the time series data points summary form.

Returns:

  • (String)


20888
20889
20890
20891
20892
20893
20894
20895
20896
20897
# File 'lib/aws-sdk-datazone/types.rb', line 20888

class TimeSeriesDataPointSummaryFormOutput < Struct.new(
  :form_name,
  :type_identifier,
  :type_revision,
  :timestamp,
  :content_summary,
  :id)
  SENSITIVE = []
  include Aws::Structure
end