Class: Aws::DataZone::Types::Topic

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The topic of the notification.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resourceTypes::NotificationResource

The details of the resource mentioned in a notification.



20915
20916
20917
20918
20919
20920
20921
# File 'lib/aws-sdk-datazone/types.rb', line 20915

class Topic < Struct.new(
  :subject,
  :resource,
  :role)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The role of the resource mentioned in a notification.

Returns:

  • (String)


20915
20916
20917
20918
20919
20920
20921
# File 'lib/aws-sdk-datazone/types.rb', line 20915

class Topic < Struct.new(
  :subject,
  :resource,
  :role)
  SENSITIVE = []
  include Aws::Structure
end

#subjectString

The subject of the resource mentioned in a notification.

Returns:

  • (String)


20915
20916
20917
20918
20919
20920
20921
# File 'lib/aws-sdk-datazone/types.rb', line 20915

class Topic < Struct.new(
  :subject,
  :resource,
  :role)
  SENSITIVE = []
  include Aws::Structure
end