Class: Aws::DataZone::Types::UpdateAccountPoolInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateAccountPoolInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#account_source ⇒ Types::AccountSource
The source of accounts for the account pool.
-
#description ⇒ String
The description of the account pool that is to be udpated.
-
#domain_identifier ⇒ String
The domain ID where the account pool that is to be updated lives.
-
#identifier ⇒ String
The ID of the account pool that is to be updated.
-
#name ⇒ String
The name of the account pool that is to be updated.
-
#resolution_strategy ⇒ String
The mechanism used to resolve the account selection from the account pool.
Instance Attribute Details
#account_source ⇒ Types::AccountSource
The source of accounts for the account pool. In the current release, it’s either a static list of accounts provided by the customer or a custom Amazon Web Services Lambda handler.
20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 |
# File 'lib/aws-sdk-datazone/types.rb', line 20872 class UpdateAccountPoolInput < Struct.new( :domain_identifier, :identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the account pool that is to be udpated.
20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 |
# File 'lib/aws-sdk-datazone/types.rb', line 20872 class UpdateAccountPoolInput < Struct.new( :domain_identifier, :identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_identifier ⇒ String
The domain ID where the account pool that is to be updated lives.
20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 |
# File 'lib/aws-sdk-datazone/types.rb', line 20872 class UpdateAccountPoolInput < Struct.new( :domain_identifier, :identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |
#identifier ⇒ String
The ID of the account pool that is to be updated.
20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 |
# File 'lib/aws-sdk-datazone/types.rb', line 20872 class UpdateAccountPoolInput < Struct.new( :domain_identifier, :identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the account pool that is to be updated.
20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 |
# File 'lib/aws-sdk-datazone/types.rb', line 20872 class UpdateAccountPoolInput < Struct.new( :domain_identifier, :identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |
#resolution_strategy ⇒ String
The mechanism used to resolve the account selection from the account pool.
20872 20873 20874 20875 20876 20877 20878 20879 20880 20881 |
# File 'lib/aws-sdk-datazone/types.rb', line 20872 class UpdateAccountPoolInput < Struct.new( :domain_identifier, :identifier, :name, :description, :resolution_strategy, :account_source) SENSITIVE = [:name, :description] include Aws::Structure end |