Class: Aws::DataZone::Types::UpdateConnectionOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationsArray<Types::Configuration>

The configurations of the connection.

Returns:



23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#connection_idString

The ID of the connection.

Returns:

  • (String)


23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The connection description.

Returns:

  • (String)


23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#domain_idString

The ID of the domain where a connection is to be updated.

Returns:

  • (String)


23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#domain_unit_idString

The ID of the domain unit where a connection is to be updated.

Returns:

  • (String)


23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#environment_idString

The ID of the environment where a connection is to be updated.

Returns:

  • (String)


23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name of the connection.

Returns:

  • (String)


23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#physical_endpointsArray<Types::PhysicalEndpoint>

The physical endpoints of the connection.

Returns:



23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#project_idString

The project ID of the connection.

Returns:

  • (String)


23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#propsTypes::ConnectionPropertiesOutput

The connection props.



23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#scopeString

The scope of the connection.

Returns:

  • (String)


23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#typeString

The connection type.

Returns:

  • (String)


23434
23435
23436
23437
23438
23439
23440
23441
23442
23443
23444
23445
23446
23447
23448
23449
# File 'lib/aws-sdk-datazone/types.rb', line 23434

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end