Class: Aws::DataZone::Types::UpdateDataSourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateDataSourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :schedule]
Instance Attribute Summary collapse
-
#asset_forms_output ⇒ Array<Types::FormOutput>
The asset forms to be updated as part of the
UpdateDataSourceaction. -
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration to be updated as part of the
UpdateDataSourceaction. -
#connection_id ⇒ String
The connection ID.
-
#created_at ⇒ Time
The timestamp of when the data source was updated.
-
#description ⇒ String
The description to be updated as part of the
UpdateDataSourceaction. -
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a data source is to be updated.
-
#enable_setting ⇒ String
The enable setting to be updated as part of the
UpdateDataSourceaction. -
#environment_id ⇒ String
The identifier of the environment in which a data source is to be updated.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of the data source to be updated.
-
#last_run_at ⇒ Time
The timestamp of when the data source was last run.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The last run error message of the data source.
-
#last_run_status ⇒ String
The last run status of the data source.
-
#name ⇒ String
The name to be updated as part of the
UpdateDataSourceaction. -
#project_id ⇒ String
The identifier of the project where data source is to be updated.
-
#publish_on_import ⇒ Boolean
The publish on import setting to be updated as part of the
UpdateDataSourceaction. -
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation to be updated as part of the
UpdateDataSourceaction. -
#retain_permissions_on_revoke_failure ⇒ Boolean
Specifies that the granted permissions are retained in case of a self-subscribe functionality failure for a data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The schedule to be updated as part of the
UpdateDataSourceaction. -
#self_grant_status ⇒ Types::SelfGrantStatusOutput
Specifies the status of the self-granting functionality.
-
#status ⇒ String
The status to be updated as part of the
UpdateDataSourceaction. -
#type ⇒ String
The type to be updated as part of the
UpdateDataSourceaction. -
#updated_at ⇒ Time
The timestamp of when the data source was updated.
Instance Attribute Details
#asset_forms_output ⇒ Array<Types::FormOutput>
The asset forms to be updated as part of the UpdateDataSource
action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration to be updated as part of the UpdateDataSource
action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#connection_id ⇒ String
The connection ID.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the data source was updated.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the UpdateDataSource
action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a data source is to be updated.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
The enable setting to be updated as part of the UpdateDataSource
action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#environment_id ⇒ String
The identifier of the environment in which a data source is to be updated.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#id ⇒ String
The identifier of the data source to be updated.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp of when the data source was last run.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The last run error message of the data source.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#last_run_status ⇒ String
The last run status of the data source.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the UpdateDataSource action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project where data source is to be updated.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#publish_on_import ⇒ Boolean
The publish on import setting to be updated as part of the
UpdateDataSource action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation to be updated as part of the UpdateDataSource
action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#retain_permissions_on_revoke_failure ⇒ Boolean
Specifies that the granted permissions are retained in case of a self-subscribe functionality failure for a data source.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The schedule to be updated as part of the UpdateDataSource action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#self_grant_status ⇒ Types::SelfGrantStatusOutput
Specifies the status of the self-granting functionality.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the UpdateDataSource action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#type ⇒ String
The type to be updated as part of the UpdateDataSource action.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source was updated.
23729 23730 23731 23732 23733 23734 23735 23736 23737 23738 23739 23740 23741 23742 23743 23744 23745 23746 23747 23748 23749 23750 23751 23752 23753 23754 23755 |
# File 'lib/aws-sdk-datazone/types.rb', line 23729 class UpdateDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :error_message, :created_at, :updated_at, :self_grant_status, :retain_permissions_on_revoke_failure) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |