Class: Aws::DataZone::Types::UpdateDomainInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateDomainInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateDomain` action.
-
#domain_execution_role ⇒ String
The domain execution role to be updated as part of the ‘UpdateDomain` action.
-
#identifier ⇒ String
The ID of the Amazon Web Services domain that is to be updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateDomain` action.
-
#service_role ⇒ String
The service role of the domain.
-
#single_sign_on ⇒ Types::SingleSignOn
The single sign-on option to be updated as part of the ‘UpdateDomain` action.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 |
# File 'lib/aws-sdk-datazone/types.rb', line 21511 class UpdateDomainInput < Struct.new( :identifier, :description, :single_sign_on, :domain_execution_role, :service_role, :name, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateDomain` action.
21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 |
# File 'lib/aws-sdk-datazone/types.rb', line 21511 class UpdateDomainInput < Struct.new( :identifier, :description, :single_sign_on, :domain_execution_role, :service_role, :name, :client_token) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role ⇒ String
The domain execution role to be updated as part of the ‘UpdateDomain` action.
21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 |
# File 'lib/aws-sdk-datazone/types.rb', line 21511 class UpdateDomainInput < Struct.new( :identifier, :description, :single_sign_on, :domain_execution_role, :service_role, :name, :client_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The ID of the Amazon Web Services domain that is to be updated.
21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 |
# File 'lib/aws-sdk-datazone/types.rb', line 21511 class UpdateDomainInput < Struct.new( :identifier, :description, :single_sign_on, :domain_execution_role, :service_role, :name, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateDomain` action.
21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 |
# File 'lib/aws-sdk-datazone/types.rb', line 21511 class UpdateDomainInput < Struct.new( :identifier, :description, :single_sign_on, :domain_execution_role, :service_role, :name, :client_token) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
The service role of the domain.
21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 |
# File 'lib/aws-sdk-datazone/types.rb', line 21511 class UpdateDomainInput < Struct.new( :identifier, :description, :single_sign_on, :domain_execution_role, :service_role, :name, :client_token) SENSITIVE = [] include Aws::Structure end |
#single_sign_on ⇒ Types::SingleSignOn
The single sign-on option to be updated as part of the ‘UpdateDomain` action.
21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 |
# File 'lib/aws-sdk-datazone/types.rb', line 21511 class UpdateDomainInput < Struct.new( :identifier, :description, :single_sign_on, :domain_execution_role, :service_role, :name, :client_token) SENSITIVE = [] include Aws::Structure end |