Class: Aws::DataZone::Types::UpdateDomainOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateDomainOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description to be updated as part of the ‘UpdateDomain` action.
-
#domain_execution_role ⇒ String
The domain execution role to be updated as part of the ‘UpdateDomain` action.
-
#id ⇒ String
The identifier of the Amazon DataZone domain.
-
#last_updated_at ⇒ Time
Specifies the timestamp of when the domain was last updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateDomain` action.
-
#root_domain_unit_id ⇒ String
The ID of the root domain unit.
-
#single_sign_on ⇒ Types::SingleSignOn
The single sign-on option of the Amazon DataZone domain.
Instance Attribute Details
#description ⇒ String
The description to be updated as part of the ‘UpdateDomain` action.
14832 14833 14834 14835 14836 14837 14838 14839 14840 14841 14842 |
# File 'lib/aws-sdk-datazone/types.rb', line 14832 class UpdateDomainOutput < Struct.new( :description, :domain_execution_role, :id, :last_updated_at, :name, :root_domain_unit_id, :single_sign_on) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role ⇒ String
The domain execution role to be updated as part of the ‘UpdateDomain` action.
14832 14833 14834 14835 14836 14837 14838 14839 14840 14841 14842 |
# File 'lib/aws-sdk-datazone/types.rb', line 14832 class UpdateDomainOutput < Struct.new( :description, :domain_execution_role, :id, :last_updated_at, :name, :root_domain_unit_id, :single_sign_on) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the Amazon DataZone domain.
14832 14833 14834 14835 14836 14837 14838 14839 14840 14841 14842 |
# File 'lib/aws-sdk-datazone/types.rb', line 14832 class UpdateDomainOutput < Struct.new( :description, :domain_execution_role, :id, :last_updated_at, :name, :root_domain_unit_id, :single_sign_on) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
Specifies the timestamp of when the domain was last updated.
14832 14833 14834 14835 14836 14837 14838 14839 14840 14841 14842 |
# File 'lib/aws-sdk-datazone/types.rb', line 14832 class UpdateDomainOutput < Struct.new( :description, :domain_execution_role, :id, :last_updated_at, :name, :root_domain_unit_id, :single_sign_on) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateDomain` action.
14832 14833 14834 14835 14836 14837 14838 14839 14840 14841 14842 |
# File 'lib/aws-sdk-datazone/types.rb', line 14832 class UpdateDomainOutput < Struct.new( :description, :domain_execution_role, :id, :last_updated_at, :name, :root_domain_unit_id, :single_sign_on) SENSITIVE = [] include Aws::Structure end |
#root_domain_unit_id ⇒ String
The ID of the root domain unit.
14832 14833 14834 14835 14836 14837 14838 14839 14840 14841 14842 |
# File 'lib/aws-sdk-datazone/types.rb', line 14832 class UpdateDomainOutput < Struct.new( :description, :domain_execution_role, :id, :last_updated_at, :name, :root_domain_unit_id, :single_sign_on) SENSITIVE = [] include Aws::Structure end |
#single_sign_on ⇒ Types::SingleSignOn
The single sign-on option of the Amazon DataZone domain.
14832 14833 14834 14835 14836 14837 14838 14839 14840 14841 14842 |
# File 'lib/aws-sdk-datazone/types.rb', line 14832 class UpdateDomainOutput < Struct.new( :description, :domain_execution_role, :id, :last_updated_at, :name, :root_domain_unit_id, :single_sign_on) SENSITIVE = [] include Aws::Structure end |