Class: Aws::DataZone::Types::UpdateDomainUnitInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the domain unit that you want to update.

Returns:

  • (String)


21589
21590
21591
21592
21593
21594
21595
21596
# File 'lib/aws-sdk-datazone/types.rb', line 21589

class UpdateDomainUnitInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#domain_identifierString

The ID of the domain where you want to update a domain unit.

Returns:

  • (String)


21589
21590
21591
21592
21593
21594
21595
21596
# File 'lib/aws-sdk-datazone/types.rb', line 21589

class UpdateDomainUnitInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#identifierString

The ID of the domain unit that you want to update.

Returns:

  • (String)


21589
21590
21591
21592
21593
21594
21595
21596
# File 'lib/aws-sdk-datazone/types.rb', line 21589

class UpdateDomainUnitInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#nameString

The name of the domain unit that you want to update.

Returns:

  • (String)


21589
21590
21591
21592
21593
21594
21595
21596
# File 'lib/aws-sdk-datazone/types.rb', line 21589

class UpdateDomainUnitInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end