Class: Aws::DataZone::Types::UpdateDomainUnitOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateDomainUnitOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time stamp at which the domain unit that you want to update was created.
-
#created_by ⇒ String
The user who created the domain unit that you want to update.
-
#description ⇒ String
The description of the domain unit that you want to update.
-
#domain_id ⇒ String
The ID of the domain where you want to update the domain unit.
-
#id ⇒ String
The ID of the domain unit that you want to update.
-
#last_updated_at ⇒ Time
The timestamp at which the domain unit was last updated.
-
#last_updated_by ⇒ String
The user who last updated the domain unit.
-
#name ⇒ String
The name of the domain unit that you want to update.
-
#owners ⇒ Array<Types::DomainUnitOwnerProperties>
The owners of the domain unit that you want to update.
-
#parent_domain_unit_id ⇒ String
The ID of the parent domain unit.
Instance Attribute Details
#created_at ⇒ Time
The time stamp at which the domain unit that you want to update was created.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The user who created the domain unit that you want to update.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description of the domain unit that you want to update.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain where you want to update the domain unit.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The ID of the domain unit that you want to update.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp at which the domain unit was last updated.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |
#last_updated_by ⇒ String
The user who last updated the domain unit.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of the domain unit that you want to update.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |
#owners ⇒ Array<Types::DomainUnitOwnerProperties>
The owners of the domain unit that you want to update.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |
#parent_domain_unit_id ⇒ String
The ID of the parent domain unit.
14914 14915 14916 14917 14918 14919 14920 14921 14922 14923 14924 14925 14926 14927 |
# File 'lib/aws-sdk-datazone/types.rb', line 14914 class UpdateDomainUnitOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :id, :last_updated_at, :last_updated_by, :name, :owners, :parent_domain_unit_id) SENSITIVE = [:description, :name] include Aws::Structure end |