Class: Aws::DataZone::Types::UpdateEnvironmentBlueprintInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description to be updated as part of the UpdateEnvironmentBlueprint action.

Returns:

  • (String)


24038
24039
24040
24041
24042
24043
24044
24045
24046
# File 'lib/aws-sdk-datazone/types.rb', line 24038

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain in which an environment blueprint is to be updated.

Returns:

  • (String)


24038
24039
24040
24041
24042
24043
24044
24045
24046
# File 'lib/aws-sdk-datazone/types.rb', line 24038

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the environment blueprint to be updated.

Returns:

  • (String)


24038
24039
24040
24041
24042
24043
24044
24045
24046
# File 'lib/aws-sdk-datazone/types.rb', line 24038

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#provisioning_propertiesTypes::ProvisioningProperties

The provisioning properties to be updated as part of the UpdateEnvironmentBlueprint action.



24038
24039
24040
24041
24042
24043
24044
24045
24046
# File 'lib/aws-sdk-datazone/types.rb', line 24038

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#user_parametersArray<Types::CustomParameter>

The user parameters to be updated as part of the UpdateEnvironmentBlueprint action.

Returns:



24038
24039
24040
24041
24042
24043
24044
24045
24046
# File 'lib/aws-sdk-datazone/types.rb', line 24038

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end