Class: Aws::DataZone::Types::UpdateEnvironmentBlueprintOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentBlueprintOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the environment blueprint was created.
-
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#id ⇒ String
The identifier of the blueprint to be updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#provider ⇒ String
The provider of the blueprint to be udpated.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#updated_at ⇒ Time
The timestamp of when the blueprint was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the environment blueprint was created.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#id ⇒ String
The identifier of the blueprint to be updated.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#provider ⇒ String
The provider of the blueprint to be udpated.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the blueprint was updated.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
22581 22582 22583 22584 22585 22586 22587 22588 22589 22590 22591 22592 22593 22594 |
# File 'lib/aws-sdk-datazone/types.rb', line 22581 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |