Class: Aws::DataZone::Types::UpdateEnvironmentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:environment_configuration_name]
Instance Attribute Summary collapse
-
#blueprint_version ⇒ String
The blueprint version to which the environment should be updated.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironment` action.
-
#domain_identifier ⇒ String
The identifier of the domain in which the environment is to be updated.
-
#environment_configuration_name ⇒ String
The configuration name of the environment.
-
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironment` action.
-
#identifier ⇒ String
The identifier of the environment that is to be updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironment` action.
-
#user_parameters ⇒ Array<Types::EnvironmentParameter>
The user parameters of the environment.
Instance Attribute Details
#blueprint_version ⇒ String
The blueprint version to which the environment should be updated. You can only specify the following string for this parameter: ‘latest`.
21868 21869 21870 21871 21872 21873 21874 21875 21876 21877 21878 21879 |
# File 'lib/aws-sdk-datazone/types.rb', line 21868 class UpdateEnvironmentInput < Struct.new( :domain_identifier, :identifier, :name, :description, :glossary_terms, :blueprint_version, :user_parameters, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironment` action.
21868 21869 21870 21871 21872 21873 21874 21875 21876 21877 21878 21879 |
# File 'lib/aws-sdk-datazone/types.rb', line 21868 class UpdateEnvironmentInput < Struct.new( :domain_identifier, :identifier, :name, :description, :glossary_terms, :blueprint_version, :user_parameters, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the domain in which the environment is to be updated.
21868 21869 21870 21871 21872 21873 21874 21875 21876 21877 21878 21879 |
# File 'lib/aws-sdk-datazone/types.rb', line 21868 class UpdateEnvironmentInput < Struct.new( :domain_identifier, :identifier, :name, :description, :glossary_terms, :blueprint_version, :user_parameters, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#environment_configuration_name ⇒ String
The configuration name of the environment.
21868 21869 21870 21871 21872 21873 21874 21875 21876 21877 21878 21879 |
# File 'lib/aws-sdk-datazone/types.rb', line 21868 class UpdateEnvironmentInput < Struct.new( :domain_identifier, :identifier, :name, :description, :glossary_terms, :blueprint_version, :user_parameters, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironment` action.
21868 21869 21870 21871 21872 21873 21874 21875 21876 21877 21878 21879 |
# File 'lib/aws-sdk-datazone/types.rb', line 21868 class UpdateEnvironmentInput < Struct.new( :domain_identifier, :identifier, :name, :description, :glossary_terms, :blueprint_version, :user_parameters, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#identifier ⇒ String
The identifier of the environment that is to be updated.
21868 21869 21870 21871 21872 21873 21874 21875 21876 21877 21878 21879 |
# File 'lib/aws-sdk-datazone/types.rb', line 21868 class UpdateEnvironmentInput < Struct.new( :domain_identifier, :identifier, :name, :description, :glossary_terms, :blueprint_version, :user_parameters, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironment` action.
21868 21869 21870 21871 21872 21873 21874 21875 21876 21877 21878 21879 |
# File 'lib/aws-sdk-datazone/types.rb', line 21868 class UpdateEnvironmentInput < Struct.new( :domain_identifier, :identifier, :name, :description, :glossary_terms, :blueprint_version, :user_parameters, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentParameter>
The user parameters of the environment.
21868 21869 21870 21871 21872 21873 21874 21875 21876 21877 21878 21879 |
# File 'lib/aws-sdk-datazone/types.rb', line 21868 class UpdateEnvironmentInput < Struct.new( :domain_identifier, :identifier, :name, :description, :glossary_terms, :blueprint_version, :user_parameters, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |