Class: Aws::DataZone::Types::UpdateEnvironmentOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :environment_configuration_id, :environment_configuration_name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which the environment is to be updated.
-
#aws_account_region ⇒ String
The Amazon Web Services Region in which the environment is updated.
-
#created_at ⇒ Time
The timestamp of when the environment was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the environment.
-
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the
UpdateEnvironmentaction. -
#description ⇒ String
The description to be updated as part of the
UpdateEnvironmentaction. -
#domain_id ⇒ String
The identifier of the domain in which the environment is to be updated.
-
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The environment actions to be updated as part of the
UpdateEnvironmentaction. -
#environment_blueprint_id ⇒ String
The blueprint identifier of the environment.
-
#environment_configuration_id ⇒ String
The configuration ID of the environment.
-
#environment_configuration_name ⇒ String
The configuration name of the environment.
-
#environment_profile_id ⇒ String
The profile identifier of the environment.
-
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the
UpdateEnvironmentaction. -
#id ⇒ String
The identifier of the environment that is to be updated.
-
#last_deployment ⇒ Types::Deployment
The last deployment of the environment.
-
#name ⇒ String
The name to be updated as part of the
UpdateEnvironmentaction. -
#project_id ⇒ String
The project identifier of the environment.
-
#provider ⇒ String
The provider identifier of the environment.
-
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources to be updated as part of the
UpdateEnvironmentaction. -
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the
UpdateEnvironmentaction. -
#status ⇒ String
The status to be updated as part of the
UpdateEnvironmentaction. -
#updated_at ⇒ Time
The timestamp of when the environment was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the
UpdateEnvironmentaction.
Instance Attribute Details
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which the environment is to be updated.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services Region in which the environment is updated.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the environment was created.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the environment.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the
UpdateEnvironment action.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the UpdateEnvironment
action.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the domain in which the environment is to be updated.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The environment actions to be updated as part of the
UpdateEnvironment action.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The blueprint identifier of the environment.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_configuration_id ⇒ String
The configuration ID of the environment.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_configuration_name ⇒ String
The configuration name of the environment.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_profile_id ⇒ String
The profile identifier of the environment.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the UpdateEnvironment
action.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#id ⇒ String
The identifier of the environment that is to be updated.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#last_deployment ⇒ Types::Deployment
The last deployment of the environment.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the UpdateEnvironment action.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#project_id ⇒ String
The project identifier of the environment.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provider ⇒ String
The provider identifier of the environment.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources to be updated as part of the
UpdateEnvironment action.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the
UpdateEnvironment action.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the UpdateEnvironment action.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the environment was updated.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the UpdateEnvironment
action.
24266 24267 24268 24269 24270 24271 24272 24273 24274 24275 24276 24277 24278 24279 24280 24281 24282 24283 24284 24285 24286 24287 24288 24289 24290 24291 24292 |
# File 'lib/aws-sdk-datazone/types.rb', line 24266 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |