Class: Aws::DataZone::Types::UpdateEnvironmentProfileInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account in which a specified environment profile is to be udpated.

Returns:

  • (String)


22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
# File 'lib/aws-sdk-datazone/types.rb', line 22048

class UpdateEnvironmentProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :user_parameters,
  :aws_account_id,
  :aws_account_region)
  SENSITIVE = [:name]
  include Aws::Structure
end

#aws_account_regionString

The Amazon Web Services Region in which a specified environment profile is to be updated.

Returns:

  • (String)


22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
# File 'lib/aws-sdk-datazone/types.rb', line 22048

class UpdateEnvironmentProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :user_parameters,
  :aws_account_id,
  :aws_account_region)
  SENSITIVE = [:name]
  include Aws::Structure
end

#descriptionString

The description to be updated as part of the ‘UpdateEnvironmentProfile` action.

Returns:

  • (String)


22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
# File 'lib/aws-sdk-datazone/types.rb', line 22048

class UpdateEnvironmentProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :user_parameters,
  :aws_account_id,
  :aws_account_region)
  SENSITIVE = [:name]
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain in which an environment profile is to be updated.

Returns:

  • (String)


22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
# File 'lib/aws-sdk-datazone/types.rb', line 22048

class UpdateEnvironmentProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :user_parameters,
  :aws_account_id,
  :aws_account_region)
  SENSITIVE = [:name]
  include Aws::Structure
end

#identifierString

The identifier of the environment profile that is to be updated.

Returns:

  • (String)


22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
# File 'lib/aws-sdk-datazone/types.rb', line 22048

class UpdateEnvironmentProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :user_parameters,
  :aws_account_id,
  :aws_account_region)
  SENSITIVE = [:name]
  include Aws::Structure
end

#nameString

The name to be updated as part of the ‘UpdateEnvironmentProfile` action.

Returns:

  • (String)


22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
# File 'lib/aws-sdk-datazone/types.rb', line 22048

class UpdateEnvironmentProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :user_parameters,
  :aws_account_id,
  :aws_account_region)
  SENSITIVE = [:name]
  include Aws::Structure
end

#user_parametersArray<Types::EnvironmentParameter>

The user parameters to be updated as part of the ‘UpdateEnvironmentProfile` action.

Returns:



22048
22049
22050
22051
22052
22053
22054
22055
22056
22057
22058
# File 'lib/aws-sdk-datazone/types.rb', line 22048

class UpdateEnvironmentProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :user_parameters,
  :aws_account_id,
  :aws_account_region)
  SENSITIVE = [:name]
  include Aws::Structure
end