Class: Aws::DataZone::Types::UpdateGlossaryOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description to be updated as part of the ‘UpdateGlossary` action.

Returns:

  • (String)


23768
23769
23770
23771
23772
23773
23774
23775
23776
23777
23778
# File 'lib/aws-sdk-datazone/types.rb', line 23768

class UpdateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon DataZone domain in which a business glossary is to be updated.

Returns:

  • (String)


23768
23769
23770
23771
23772
23773
23774
23775
23776
23777
23778
# File 'lib/aws-sdk-datazone/types.rb', line 23768

class UpdateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The identifier of the business glossary that is to be updated.

Returns:

  • (String)


23768
23769
23770
23771
23772
23773
23774
23775
23776
23777
23778
# File 'lib/aws-sdk-datazone/types.rb', line 23768

class UpdateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name to be updated as part of the ‘UpdateGlossary` action.

Returns:

  • (String)


23768
23769
23770
23771
23772
23773
23774
23775
23776
23777
23778
# File 'lib/aws-sdk-datazone/types.rb', line 23768

class UpdateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#owning_project_idString

The identifier of the project in which to update a business glossary.

Returns:

  • (String)


23768
23769
23770
23771
23772
23773
23774
23775
23776
23777
23778
# File 'lib/aws-sdk-datazone/types.rb', line 23768

class UpdateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#statusString

The status to be updated as part of the ‘UpdateGlossary` action.

Returns:

  • (String)


23768
23769
23770
23771
23772
23773
23774
23775
23776
23777
23778
# File 'lib/aws-sdk-datazone/types.rb', line 23768

class UpdateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#usage_restrictionsArray<String>

The usage restriction of the restricted glossary.

Returns:

  • (Array<String>)


23768
23769
23770
23771
23772
23773
23774
23775
23776
23777
23778
# File 'lib/aws-sdk-datazone/types.rb', line 23768

class UpdateGlossaryOutput < Struct.new(
  :domain_id,
  :id,
  :name,
  :owning_project_id,
  :description,
  :status,
  :usage_restrictions)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end