Class: Aws::DataZone::Types::UpdateGlossaryTermInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateGlossaryTermInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:long_description, :name, :short_description]
Instance Attribute Summary collapse
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which a business glossary term is to be updated.
-
#glossary_identifier ⇒ String
The identifier of the business glossary in which a term is to be updated.
-
#identifier ⇒ String
The identifier of the business glossary term that is to be updated.
-
#long_description ⇒ String
The long description to be updated as part of the ‘UpdateGlossaryTerm` action.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateGlossaryTerm` action.
-
#short_description ⇒ String
The short description to be updated as part of the ‘UpdateGlossaryTerm` action.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateGlossaryTerm` action.
-
#term_relations ⇒ Types::TermRelations
The term relations to be updated as part of the ‘UpdateGlossaryTerm` action.
Instance Attribute Details
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which a business glossary term is to be updated.
15467 15468 15469 15470 15471 15472 15473 15474 15475 15476 15477 15478 |
# File 'lib/aws-sdk-datazone/types.rb', line 15467 class UpdateGlossaryTermInput < Struct.new( :domain_identifier, :glossary_identifier, :identifier, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#glossary_identifier ⇒ String
The identifier of the business glossary in which a term is to be updated.
15467 15468 15469 15470 15471 15472 15473 15474 15475 15476 15477 15478 |
# File 'lib/aws-sdk-datazone/types.rb', line 15467 class UpdateGlossaryTermInput < Struct.new( :domain_identifier, :glossary_identifier, :identifier, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#identifier ⇒ String
The identifier of the business glossary term that is to be updated.
15467 15468 15469 15470 15471 15472 15473 15474 15475 15476 15477 15478 |
# File 'lib/aws-sdk-datazone/types.rb', line 15467 class UpdateGlossaryTermInput < Struct.new( :domain_identifier, :glossary_identifier, :identifier, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#long_description ⇒ String
The long description to be updated as part of the ‘UpdateGlossaryTerm` action.
15467 15468 15469 15470 15471 15472 15473 15474 15475 15476 15477 15478 |
# File 'lib/aws-sdk-datazone/types.rb', line 15467 class UpdateGlossaryTermInput < Struct.new( :domain_identifier, :glossary_identifier, :identifier, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateGlossaryTerm` action.
15467 15468 15469 15470 15471 15472 15473 15474 15475 15476 15477 15478 |
# File 'lib/aws-sdk-datazone/types.rb', line 15467 class UpdateGlossaryTermInput < Struct.new( :domain_identifier, :glossary_identifier, :identifier, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#short_description ⇒ String
The short description to be updated as part of the ‘UpdateGlossaryTerm` action.
15467 15468 15469 15470 15471 15472 15473 15474 15475 15476 15477 15478 |
# File 'lib/aws-sdk-datazone/types.rb', line 15467 class UpdateGlossaryTermInput < Struct.new( :domain_identifier, :glossary_identifier, :identifier, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateGlossaryTerm` action.
15467 15468 15469 15470 15471 15472 15473 15474 15475 15476 15477 15478 |
# File 'lib/aws-sdk-datazone/types.rb', line 15467 class UpdateGlossaryTermInput < Struct.new( :domain_identifier, :glossary_identifier, :identifier, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#term_relations ⇒ Types::TermRelations
The term relations to be updated as part of the ‘UpdateGlossaryTerm` action.
15467 15468 15469 15470 15471 15472 15473 15474 15475 15476 15477 15478 |
# File 'lib/aws-sdk-datazone/types.rb', line 15467 class UpdateGlossaryTermInput < Struct.new( :domain_identifier, :glossary_identifier, :identifier, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |