Class: Aws::DataZone::Types::UpdateGlossaryTermOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :short_description, :long_description]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_idString

The identifier of the Amazon DataZone domain in which a business glossary term is to be updated.

Returns:

  • (String)


22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
# File 'lib/aws-sdk-datazone/types.rb', line 22318

class UpdateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#glossary_idString

The identifier of the business glossary in which a term is to be updated.

Returns:

  • (String)


22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
# File 'lib/aws-sdk-datazone/types.rb', line 22318

class UpdateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#idString

The identifier of the business glossary term that is to be updated.

Returns:

  • (String)


22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
# File 'lib/aws-sdk-datazone/types.rb', line 22318

class UpdateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#long_descriptionString

The long description to be updated as part of the ‘UpdateGlossaryTerm` action.

Returns:

  • (String)


22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
# File 'lib/aws-sdk-datazone/types.rb', line 22318

class UpdateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#nameString

The name to be updated as part of the ‘UpdateGlossaryTerm` action.

Returns:

  • (String)


22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
# File 'lib/aws-sdk-datazone/types.rb', line 22318

class UpdateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#short_descriptionString

The short description to be updated as part of the ‘UpdateGlossaryTerm` action.

Returns:

  • (String)


22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
# File 'lib/aws-sdk-datazone/types.rb', line 22318

class UpdateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#statusString

The status to be updated as part of the ‘UpdateGlossaryTerm` action.

Returns:

  • (String)


22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
# File 'lib/aws-sdk-datazone/types.rb', line 22318

class UpdateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#term_relationsTypes::TermRelations

The term relations to be updated as part of the ‘UpdateGlossaryTerm` action.



22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
# File 'lib/aws-sdk-datazone/types.rb', line 22318

class UpdateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end

#usage_restrictionsArray<String>

The usage restriction of a term within a restricted glossary.

Returns:

  • (Array<String>)


22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
# File 'lib/aws-sdk-datazone/types.rb', line 22318

class UpdateGlossaryTermOutput < Struct.new(
  :id,
  :domain_id,
  :glossary_id,
  :name,
  :status,
  :short_description,
  :long_description,
  :term_relations,
  :usage_restrictions)
  SENSITIVE = [:name, :short_description, :long_description]
  include Aws::Structure
end