Class: Aws::DataZone::Types::UpdateNotebookInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name, :metadata, :parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#cell_orderArray<Types::CellInformation>

The updated ordered list of cells in the notebook.

Returns:



24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end

#descriptionString

The updated description of the notebook.

Returns:

  • (String)


24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon SageMaker Unified Studio domain in which the notebook exists.

Returns:

  • (String)


24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end

#environment_configurationTypes::EnvironmentConfig

The updated environment configuration for the notebook.



24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end

#identifierString

The identifier of the notebook to update.

Returns:

  • (String)


24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end

#metadataHash<String,String>

The updated metadata for the notebook, specified as key-value pairs.

Returns:

  • (Hash<String,String>)


24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end

#nameString

The updated name of the notebook.

Returns:

  • (String)


24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end

#parametersHash<String,String>

The updated sensitive parameters for the notebook, specified as key-value pairs.

Returns:

  • (Hash<String,String>)


24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end

#statusString

The updated status of the notebook.

Returns:

  • (String)


24000
24001
24002
24003
24004
24005
24006
24007
24008
24009
24010
24011
24012
24013
# File 'lib/aws-sdk-datazone/types.rb', line 24000

class UpdateNotebookInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :status,
  :name,
  :cell_order,
  :metadata,
  :parameters,
  :environment_configuration,
  :client_token)
  SENSITIVE = [:description, :name, :metadata, :parameters]
  include Aws::Structure
end