Class: Aws::DataZone::Types::UpdateProjectInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateProjectInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#description ⇒ String
The description to be updated as part of the ‘UpdateProject` action.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which a project is to be updated.
-
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateProject` action.
-
#identifier ⇒ String
The identifier of the project that is to be updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateProject` action.
Instance Attribute Details
#description ⇒ String
The description to be updated as part of the ‘UpdateProject` action.
12522 12523 12524 12525 12526 12527 12528 12529 12530 |
# File 'lib/aws-sdk-datazone/types.rb', line 12522 class UpdateProjectInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which a project is to be updated.
12522 12523 12524 12525 12526 12527 12528 12529 12530 |
# File 'lib/aws-sdk-datazone/types.rb', line 12522 class UpdateProjectInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [:description, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateProject` action.
12522 12523 12524 12525 12526 12527 12528 12529 12530 |
# File 'lib/aws-sdk-datazone/types.rb', line 12522 class UpdateProjectInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [:description, :name] include Aws::Structure end |
#identifier ⇒ String
The identifier of the project that is to be updated.
12522 12523 12524 12525 12526 12527 12528 12529 12530 |
# File 'lib/aws-sdk-datazone/types.rb', line 12522 class UpdateProjectInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateProject` action.
12522 12523 12524 12525 12526 12527 12528 12529 12530 |
# File 'lib/aws-sdk-datazone/types.rb', line 12522 class UpdateProjectInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [:description, :name] include Aws::Structure end |