Class: Aws::DataZone::Types::UpdateProjectProfileInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateProjectProfileInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :project_resource_tags_description]
Instance Attribute Summary collapse
-
#allow_custom_project_resource_tags ⇒ Boolean
Specifies whether custom project resource tags are supported.
-
#description ⇒ String
The description of a project profile.
-
#domain_identifier ⇒ String
The ID of the domain where a project profile is to be updated.
-
#domain_unit_identifier ⇒ String
The ID of the domain unit where a project profile is to be updated.
-
#environment_configurations ⇒ Array<Types::EnvironmentConfiguration>
The environment configurations of a project profile.
-
#identifier ⇒ String
The ID of a project profile that is to be updated.
-
#name ⇒ String
The name of a project profile.
-
#project_resource_tags ⇒ Array<Types::ResourceTagParameter>
The resource tags of the project profile.
-
#project_resource_tags_description ⇒ String
Field viewable through the UI that provides a project user with the allowed resource tag specifications.
-
#status ⇒ String
The status of a project profile.
Instance Attribute Details
#allow_custom_project_resource_tags ⇒ Boolean
Specifies whether custom project resource tags are supported.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#description ⇒ String
The description of a project profile.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#domain_identifier ⇒ String
The ID of the domain where a project profile is to be updated.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#domain_unit_identifier ⇒ String
The ID of the domain unit where a project profile is to be updated.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#environment_configurations ⇒ Array<Types::EnvironmentConfiguration>
The environment configurations of a project profile.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#identifier ⇒ String
The ID of a project profile that is to be updated.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#name ⇒ String
The name of a project profile.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#project_resource_tags ⇒ Array<Types::ResourceTagParameter>
The resource tags of the project profile.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#project_resource_tags_description ⇒ String
Field viewable through the UI that provides a project user with the allowed resource tag specifications.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |
#status ⇒ String
The status of a project profile.
24310 24311 24312 24313 24314 24315 24316 24317 24318 24319 24320 24321 24322 24323 |
# File 'lib/aws-sdk-datazone/types.rb', line 24310 class UpdateProjectProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :project_resource_tags, :allow_custom_project_resource_tags, :project_resource_tags_description, :environment_configurations, :domain_unit_identifier) SENSITIVE = [:name, :description, :project_resource_tags_description] include Aws::Structure end |