Class: Aws::DataZone::Types::UpdateRootDomainUnitOwnerInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


25046
25047
25048
25049
25050
25051
25052
25053
# File 'lib/aws-sdk-datazone/types.rb', line 25046

class UpdateRootDomainUnitOwnerInput < Struct.new(
  :domain_identifier,
  :current_owner,
  :new_owner,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#current_ownerString

The current owner of the root domain unit.

Returns:

  • (String)


25046
25047
25048
25049
25050
25051
25052
25053
# File 'lib/aws-sdk-datazone/types.rb', line 25046

class UpdateRootDomainUnitOwnerInput < Struct.new(
  :domain_identifier,
  :current_owner,
  :new_owner,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The ID of the domain where the root domain unit owner is to be updated.

Returns:

  • (String)


25046
25047
25048
25049
25050
25051
25052
25053
# File 'lib/aws-sdk-datazone/types.rb', line 25046

class UpdateRootDomainUnitOwnerInput < Struct.new(
  :domain_identifier,
  :current_owner,
  :new_owner,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#new_ownerString

The new owner of the root domain unit.

Returns:

  • (String)


25046
25047
25048
25049
25050
25051
25052
25053
# File 'lib/aws-sdk-datazone/types.rb', line 25046

class UpdateRootDomainUnitOwnerInput < Struct.new(
  :domain_identifier,
  :current_owner,
  :new_owner,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end