Class: Aws::DataZone::Types::UpdateUserProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateUserProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#details ⇒ Types::UserProfileDetails
The results of the UpdateUserProfile action.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a user profile is updated.
-
#id ⇒ String
The identifier of the user profile.
-
#status ⇒ String
The status of the user profile.
-
#type ⇒ String
The type of the user profile.
Instance Attribute Details
#details ⇒ Types::UserProfileDetails
The results of the UpdateUserProfile action.
23269 23270 23271 23272 23273 23274 23275 23276 23277 |
# File 'lib/aws-sdk-datazone/types.rb', line 23269 class UpdateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a user profile is updated.
23269 23270 23271 23272 23273 23274 23275 23276 23277 |
# File 'lib/aws-sdk-datazone/types.rb', line 23269 class UpdateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the user profile.
23269 23270 23271 23272 23273 23274 23275 23276 23277 |
# File 'lib/aws-sdk-datazone/types.rb', line 23269 class UpdateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the user profile.
23269 23270 23271 23272 23273 23274 23275 23276 23277 |
# File 'lib/aws-sdk-datazone/types.rb', line 23269 class UpdateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the user profile.
23269 23270 23271 23272 23273 23274 23275 23276 23277 |
# File 'lib/aws-sdk-datazone/types.rb', line 23269 class UpdateUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |