Class: Aws::DataZone::Types::UserPolicyGrantPrincipal

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

UserPolicyGrantPrincipal is a union - when making an API calls you must set exactly one of the members.

Note:

UserPolicyGrantPrincipal is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UserPolicyGrantPrincipal corresponding to the set member.

The user policy grant principal.

Defined Under Namespace

Classes: AllUsersGrantFilter, Unknown, UserIdentifier

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#all_users_grant_filterTypes::AllUsersGrantFilter

The all users grant filter of the user policy grant principal.



25497
25498
25499
25500
25501
25502
25503
25504
25505
25506
25507
25508
# File 'lib/aws-sdk-datazone/types.rb', line 25497

class UserPolicyGrantPrincipal < Struct.new(
  :user_identifier,
  :all_users_grant_filter,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class UserIdentifier < UserPolicyGrantPrincipal; end
  class AllUsersGrantFilter < UserPolicyGrantPrincipal; end
  class Unknown < UserPolicyGrantPrincipal; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



25497
25498
25499
# File 'lib/aws-sdk-datazone/types.rb', line 25497

def unknown
  @unknown
end

#user_identifierString

The user ID of the user policy grant principal.

Returns:

  • (String)


25497
25498
25499
25500
25501
25502
25503
25504
25505
25506
25507
25508
# File 'lib/aws-sdk-datazone/types.rb', line 25497

class UserPolicyGrantPrincipal < Struct.new(
  :user_identifier,
  :all_users_grant_filter,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class UserIdentifier < UserPolicyGrantPrincipal; end
  class AllUsersGrantFilter < UserPolicyGrantPrincipal; end
  class Unknown < UserPolicyGrantPrincipal; end
end