Class: Aws::DataZone::Types::UserProfileDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UserProfileDetails
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
UserProfileDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UserProfileDetails corresponding to the set member.
The user profile details.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#iam ⇒ Types::IamUserProfileDetails
The IAM details of the user profile.
-
#sso ⇒ Types::SsoUserProfileDetails
The SSO details of the user profile.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#iam ⇒ Types::IamUserProfileDetails
The IAM details of the user profile.
23351 23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 |
# File 'lib/aws-sdk-datazone/types.rb', line 23351 class UserProfileDetails < Struct.new( :iam, :sso, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Iam < UserProfileDetails; end class Sso < UserProfileDetails; end class Unknown < UserProfileDetails; end end |
#sso ⇒ Types::SsoUserProfileDetails
The SSO details of the user profile.
23351 23352 23353 23354 23355 23356 23357 23358 23359 23360 23361 23362 |
# File 'lib/aws-sdk-datazone/types.rb', line 23351 class UserProfileDetails < Struct.new( :iam, :sso, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Iam < UserProfileDetails; end class Sso < UserProfileDetails; end class Unknown < UserProfileDetails; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
23351 23352 23353 |
# File 'lib/aws-sdk-datazone/types.rb', line 23351 def unknown @unknown end |