Class: Aws::DataZone::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DataZone::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-datazone/client.rb
Overview
An API client for DataZone. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DataZone::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_predictions(params = {}) ⇒ Types::AcceptPredictionsOutput
Accepts automatically generated business-friendly metadata for your Amazon DataZone assets.
-
#accept_subscription_request(params = {}) ⇒ Types::AcceptSubscriptionRequestOutput
Accepts a subscription request to a specific asset.
-
#associate_environment_role(params = {}) ⇒ Struct
Associates the environment role in Amazon DataZone.
-
#cancel_metadata_generation_run(params = {}) ⇒ Struct
Cancels the metadata generation run.
-
#cancel_subscription(params = {}) ⇒ Types::CancelSubscriptionOutput
Cancels the subscription to the specified asset.
-
#create_asset(params = {}) ⇒ Types::CreateAssetOutput
Creates an asset in Amazon DataZone catalog.
-
#create_asset_revision(params = {}) ⇒ Types::CreateAssetRevisionOutput
Creates a revision of the asset.
-
#create_asset_type(params = {}) ⇒ Types::CreateAssetTypeOutput
Creates a custom asset type.
-
#create_data_source(params = {}) ⇒ Types::CreateDataSourceOutput
Creates an Amazon DataZone data source.
-
#create_domain(params = {}) ⇒ Types::CreateDomainOutput
Creates an Amazon DataZone domain.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Create an Amazon DataZone environment.
-
#create_environment_action(params = {}) ⇒ Types::CreateEnvironmentActionOutput
Creates an action for the environment, for example, creates a console link for an analytics tool that is available in this environment.
-
#create_environment_profile(params = {}) ⇒ Types::CreateEnvironmentProfileOutput
Creates an Amazon DataZone environment profile.
-
#create_form_type(params = {}) ⇒ Types::CreateFormTypeOutput
Creates a metadata form type.
-
#create_glossary(params = {}) ⇒ Types::CreateGlossaryOutput
Creates an Amazon DataZone business glossary.
-
#create_glossary_term(params = {}) ⇒ Types::CreateGlossaryTermOutput
Creates a business glossary term.
-
#create_group_profile(params = {}) ⇒ Types::CreateGroupProfileOutput
Creates a group profile in Amazon DataZone.
-
#create_listing_change_set(params = {}) ⇒ Types::CreateListingChangeSetOutput
Publishes a listing (a record of an asset at a given time) or removes a listing from the catalog.
-
#create_project(params = {}) ⇒ Types::CreateProjectOutput
Creates an Amazon DataZone project.
-
#create_project_membership(params = {}) ⇒ Struct
Creates a project membership in Amazon DataZone.
-
#create_subscription_grant(params = {}) ⇒ Types::CreateSubscriptionGrantOutput
Creates a subsscription grant in Amazon DataZone.
-
#create_subscription_request(params = {}) ⇒ Types::CreateSubscriptionRequestOutput
Creates a subscription request in Amazon DataZone.
-
#create_subscription_target(params = {}) ⇒ Types::CreateSubscriptionTargetOutput
Creates a subscription target in Amazon DataZone.
-
#create_user_profile(params = {}) ⇒ Types::CreateUserProfileOutput
Creates a user profile in Amazon DataZone.
-
#delete_asset(params = {}) ⇒ Struct
Delets an asset in Amazon DataZone.
-
#delete_asset_type(params = {}) ⇒ Struct
Deletes an asset type in Amazon DataZone.
-
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceOutput
Deletes a data source in Amazon DataZone.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainOutput
Deletes a Amazon DataZone domain.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an environment in Amazon DataZone.
-
#delete_environment_action(params = {}) ⇒ Struct
Deletes an action for the environment, for example, deletes a console link for an analytics tool that is available in this environment.
-
#delete_environment_blueprint_configuration(params = {}) ⇒ Struct
Deletes the blueprint configuration in Amazon DataZone.
-
#delete_environment_profile(params = {}) ⇒ Struct
Deletes an environment profile in Amazon DataZone.
-
#delete_form_type(params = {}) ⇒ Struct
Delets and metadata form type in Amazon DataZone.
-
#delete_glossary(params = {}) ⇒ Struct
Deletes a business glossary in Amazon DataZone.
-
#delete_glossary_term(params = {}) ⇒ Struct
Deletes a business glossary term in Amazon DataZone.
-
#delete_listing(params = {}) ⇒ Struct
Deletes a listing (a record of an asset at a given time).
-
#delete_project(params = {}) ⇒ Struct
Deletes a project in Amazon DataZone.
-
#delete_project_membership(params = {}) ⇒ Struct
Deletes project membership in Amazon DataZone.
-
#delete_subscription_grant(params = {}) ⇒ Types::DeleteSubscriptionGrantOutput
Deletes and subscription grant in Amazon DataZone.
-
#delete_subscription_request(params = {}) ⇒ Struct
Deletes a subscription request in Amazon DataZone.
-
#delete_subscription_target(params = {}) ⇒ Struct
Deletes a subscription target in Amazon DataZone.
-
#delete_time_series_data_points(params = {}) ⇒ Struct
Deletes the specified time series form for the specified asset.
-
#disassociate_environment_role(params = {}) ⇒ Struct
Disassociates the environment role in Amazon DataZone.
-
#get_asset(params = {}) ⇒ Types::GetAssetOutput
Gets an Amazon DataZone asset.
-
#get_asset_type(params = {}) ⇒ Types::GetAssetTypeOutput
Gets an Amazon DataZone asset type.
-
#get_data_source(params = {}) ⇒ Types::GetDataSourceOutput
Gets an Amazon DataZone data source.
-
#get_data_source_run(params = {}) ⇒ Types::GetDataSourceRunOutput
Gets an Amazon DataZone data source run.
-
#get_domain(params = {}) ⇒ Types::GetDomainOutput
Gets an Amazon DataZone domain.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Gets an Amazon DataZone environment.
-
#get_environment_action(params = {}) ⇒ Types::GetEnvironmentActionOutput
Gets the specified environment action.
-
#get_environment_blueprint(params = {}) ⇒ Types::GetEnvironmentBlueprintOutput
Gets an Amazon DataZone blueprint.
-
#get_environment_blueprint_configuration(params = {}) ⇒ Types::GetEnvironmentBlueprintConfigurationOutput
Gets the blueprint configuration in Amazon DataZone.
-
#get_environment_profile(params = {}) ⇒ Types::GetEnvironmentProfileOutput
Gets an evinronment profile in Amazon DataZone.
-
#get_form_type(params = {}) ⇒ Types::GetFormTypeOutput
Gets a metadata form type in Amazon DataZone.
-
#get_glossary(params = {}) ⇒ Types::GetGlossaryOutput
Gets a business glossary in Amazon DataZone.
-
#get_glossary_term(params = {}) ⇒ Types::GetGlossaryTermOutput
Gets a business glossary term in Amazon DataZone.
-
#get_group_profile(params = {}) ⇒ Types::GetGroupProfileOutput
Gets a group profile in Amazon DataZone.
-
#get_iam_portal_login_url(params = {}) ⇒ Types::GetIamPortalLoginUrlOutput
Gets the data portal URL for the specified Amazon DataZone domain.
-
#get_lineage_node(params = {}) ⇒ Types::GetLineageNodeOutput
Gets the data lineage node.
-
#get_listing(params = {}) ⇒ Types::GetListingOutput
Gets a listing (a record of an asset at a given time).
-
#get_metadata_generation_run(params = {}) ⇒ Types::GetMetadataGenerationRunOutput
Gets a metadata generation run in Amazon DataZone.
-
#get_project(params = {}) ⇒ Types::GetProjectOutput
Gets a project in Amazon DataZone.
-
#get_subscription(params = {}) ⇒ Types::GetSubscriptionOutput
Gets a subscription in Amazon DataZone.
-
#get_subscription_grant(params = {}) ⇒ Types::GetSubscriptionGrantOutput
Gets the subscription grant in Amazon DataZone.
-
#get_subscription_request_details(params = {}) ⇒ Types::GetSubscriptionRequestDetailsOutput
Gets the details of the specified subscription request.
-
#get_subscription_target(params = {}) ⇒ Types::GetSubscriptionTargetOutput
Gets the subscription target in Amazon DataZone.
-
#get_time_series_data_point(params = {}) ⇒ Types::GetTimeSeriesDataPointOutput
Gets the existing data point for the asset.
-
#get_user_profile(params = {}) ⇒ Types::GetUserProfileOutput
Gets a user profile in Amazon DataZone.
-
#list_asset_revisions(params = {}) ⇒ Types::ListAssetRevisionsOutput
Lists the revisions for the asset.
-
#list_data_source_run_activities(params = {}) ⇒ Types::ListDataSourceRunActivitiesOutput
Lists data source run activities.
-
#list_data_source_runs(params = {}) ⇒ Types::ListDataSourceRunsOutput
Lists data source runs in Amazon DataZone.
-
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesOutput
Lists data sources in Amazon DataZone.
-
#list_domains(params = {}) ⇒ Types::ListDomainsOutput
Lists Amazon DataZone domains.
-
#list_environment_actions(params = {}) ⇒ Types::ListEnvironmentActionsOutput
Lists existing environment actions.
-
#list_environment_blueprint_configurations(params = {}) ⇒ Types::ListEnvironmentBlueprintConfigurationsOutput
Lists blueprint configurations for a Amazon DataZone environment.
-
#list_environment_blueprints(params = {}) ⇒ Types::ListEnvironmentBlueprintsOutput
Lists blueprints in an Amazon DataZone environment.
-
#list_environment_profiles(params = {}) ⇒ Types::ListEnvironmentProfilesOutput
Lists Amazon DataZone environment profiles.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists Amazon DataZone environments.
-
#list_lineage_node_history(params = {}) ⇒ Types::ListLineageNodeHistoryOutput
Lists the history of the specified data lineage node.
-
#list_metadata_generation_runs(params = {}) ⇒ Types::ListMetadataGenerationRunsOutput
Lists all metadata generation runs.
-
#list_notifications(params = {}) ⇒ Types::ListNotificationsOutput
Lists all Amazon DataZone notifications.
-
#list_project_memberships(params = {}) ⇒ Types::ListProjectMembershipsOutput
Lists all members of the specified project.
-
#list_projects(params = {}) ⇒ Types::ListProjectsOutput
Lists Amazon DataZone projects.
-
#list_subscription_grants(params = {}) ⇒ Types::ListSubscriptionGrantsOutput
Lists subscription grants.
-
#list_subscription_requests(params = {}) ⇒ Types::ListSubscriptionRequestsOutput
Lists Amazon DataZone subscription requests.
-
#list_subscription_targets(params = {}) ⇒ Types::ListSubscriptionTargetsOutput
Lists subscription targets in Amazon DataZone.
-
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsOutput
Lists subscriptions in Amazon DataZone.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified resource in Amazon DataZone.
-
#list_time_series_data_points(params = {}) ⇒ Types::ListTimeSeriesDataPointsOutput
Lists time series data points.
-
#post_lineage_event(params = {}) ⇒ Struct
Posts a data lineage event.
-
#post_time_series_data_points(params = {}) ⇒ Types::PostTimeSeriesDataPointsOutput
Posts time series data points to Amazon DataZone for the specified asset.
-
#put_environment_blueprint_configuration(params = {}) ⇒ Types::PutEnvironmentBlueprintConfigurationOutput
Writes the configuration for the specified environment blueprint in Amazon DataZone.
-
#reject_predictions(params = {}) ⇒ Types::RejectPredictionsOutput
Rejects automatically generated business-friendly metadata for your Amazon DataZone assets.
-
#reject_subscription_request(params = {}) ⇒ Types::RejectSubscriptionRequestOutput
Rejects the specified subscription request.
-
#revoke_subscription(params = {}) ⇒ Types::RevokeSubscriptionOutput
Revokes a specified subscription in Amazon DataZone.
-
#search(params = {}) ⇒ Types::SearchOutput
Searches for assets in Amazon DataZone.
-
#search_group_profiles(params = {}) ⇒ Types::SearchGroupProfilesOutput
Searches group profiles in Amazon DataZone.
-
#search_listings(params = {}) ⇒ Types::SearchListingsOutput
Searches listings (records of an asset at a given time) in Amazon DataZone.
-
#search_types(params = {}) ⇒ Types::SearchTypesOutput
Searches for types in Amazon DataZone.
-
#search_user_profiles(params = {}) ⇒ Types::SearchUserProfilesOutput
Searches user profiles in Amazon DataZone.
-
#start_data_source_run(params = {}) ⇒ Types::StartDataSourceRunOutput
Start the run of the specified data source in Amazon DataZone.
-
#start_metadata_generation_run(params = {}) ⇒ Types::StartMetadataGenerationRunOutput
Starts the metadata generation run.
-
#tag_resource(params = {}) ⇒ Struct
Tags a resource in Amazon DataZone.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource in Amazon DataZone.
-
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceOutput
Updates the specified data source in Amazon DataZone.
-
#update_domain(params = {}) ⇒ Types::UpdateDomainOutput
Updates a Amazon DataZone domain.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates the specified environment in Amazon DataZone.
-
#update_environment_action(params = {}) ⇒ Types::UpdateEnvironmentActionOutput
Updates an environment action.
-
#update_environment_profile(params = {}) ⇒ Types::UpdateEnvironmentProfileOutput
Updates the specified environment profile in Amazon DataZone.
-
#update_glossary(params = {}) ⇒ Types::UpdateGlossaryOutput
Updates the business glossary in Amazon DataZone.
-
#update_glossary_term(params = {}) ⇒ Types::UpdateGlossaryTermOutput
Updates a business glossary term in Amazon DataZone.
-
#update_group_profile(params = {}) ⇒ Types::UpdateGroupProfileOutput
Updates the specified group profile in Amazon DataZone.
-
#update_project(params = {}) ⇒ Types::UpdateProjectOutput
Updates the specified project in Amazon DataZone.
-
#update_subscription_grant_status(params = {}) ⇒ Types::UpdateSubscriptionGrantStatusOutput
Updates the status of the specified subscription grant status in Amazon DataZone.
-
#update_subscription_request(params = {}) ⇒ Types::UpdateSubscriptionRequestOutput
Updates a specified subscription request in Amazon DataZone.
-
#update_subscription_target(params = {}) ⇒ Types::UpdateSubscriptionTargetOutput
Updates the specified subscription target in Amazon DataZone.
-
#update_user_profile(params = {}) ⇒ Types::UpdateUserProfileOutput
Updates the specified user profile in Amazon DataZone.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
413 414 415 |
# File 'lib/aws-sdk-datazone/client.rb', line 413 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8468 8469 8470 |
# File 'lib/aws-sdk-datazone/client.rb', line 8468 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8471 8472 8473 |
# File 'lib/aws-sdk-datazone/client.rb', line 8471 def errors_module Errors end |
Instance Method Details
#accept_predictions(params = {}) ⇒ Types::AcceptPredictionsOutput
Accepts automatically generated business-friendly metadata for your Amazon DataZone assets.
483 484 485 486 |
# File 'lib/aws-sdk-datazone/client.rb', line 483 def accept_predictions(params = {}, = {}) req = build_request(:accept_predictions, params) req.send_request() end |
#accept_subscription_request(params = {}) ⇒ Types::AcceptSubscriptionRequestOutput
Accepts a subscription request to a specific asset.
559 560 561 562 |
# File 'lib/aws-sdk-datazone/client.rb', line 559 def accept_subscription_request(params = {}, = {}) req = build_request(:accept_subscription_request, params) req.send_request() end |
#associate_environment_role(params = {}) ⇒ Struct
Associates the environment role in Amazon DataZone.
590 591 592 593 |
# File 'lib/aws-sdk-datazone/client.rb', line 590 def associate_environment_role(params = {}, = {}) req = build_request(:associate_environment_role, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 |
# File 'lib/aws-sdk-datazone/client.rb', line 8446 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-datazone' context[:gem_version] = '1.12.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_metadata_generation_run(params = {}) ⇒ Struct
Cancels the metadata generation run.
617 618 619 620 |
# File 'lib/aws-sdk-datazone/client.rb', line 617 def (params = {}, = {}) req = build_request(:cancel_metadata_generation_run, params) req.send_request() end |
#cancel_subscription(params = {}) ⇒ Types::CancelSubscriptionOutput
Cancels the subscription to the specified asset.
683 684 685 686 |
# File 'lib/aws-sdk-datazone/client.rb', line 683 def cancel_subscription(params = {}, = {}) req = build_request(:cancel_subscription, params) req.send_request() end |
#create_asset(params = {}) ⇒ Types::CreateAssetOutput
Creates an asset in Amazon DataZone catalog.
819 820 821 822 |
# File 'lib/aws-sdk-datazone/client.rb', line 819 def create_asset(params = {}, = {}) req = build_request(:create_asset, params) req.send_request() end |
#create_asset_revision(params = {}) ⇒ Types::CreateAssetRevisionOutput
Creates a revision of the asset.
949 950 951 952 |
# File 'lib/aws-sdk-datazone/client.rb', line 949 def create_asset_revision(params = {}, = {}) req = build_request(:create_asset_revision, params) req.send_request() end |
#create_asset_type(params = {}) ⇒ Types::CreateAssetTypeOutput
Creates a custom asset type.
1026 1027 1028 1029 |
# File 'lib/aws-sdk-datazone/client.rb', line 1026 def create_asset_type(params = {}, = {}) req = build_request(:create_asset_type, params) req.send_request() end |
#create_data_source(params = {}) ⇒ Types::CreateDataSourceOutput
Creates an Amazon DataZone data source.
1233 1234 1235 1236 |
# File 'lib/aws-sdk-datazone/client.rb', line 1233 def create_data_source(params = {}, = {}) req = build_request(:create_data_source, params) req.send_request() end |
#create_domain(params = {}) ⇒ Types::CreateDomainOutput
Creates an Amazon DataZone domain.
1318 1319 1320 1321 |
# File 'lib/aws-sdk-datazone/client.rb', line 1318 def create_domain(params = {}, = {}) req = build_request(:create_domain, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentOutput
Create an Amazon DataZone environment.
1455 1456 1457 1458 |
# File 'lib/aws-sdk-datazone/client.rb', line 1455 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#create_environment_action(params = {}) ⇒ Types::CreateEnvironmentActionOutput
Creates an action for the environment, for example, creates a console link for an analytics tool that is available in this environment.
1516 1517 1518 1519 |
# File 'lib/aws-sdk-datazone/client.rb', line 1516 def create_environment_action(params = {}, = {}) req = build_request(:create_environment_action, params) req.send_request() end |
#create_environment_profile(params = {}) ⇒ Types::CreateEnvironmentProfileOutput
Creates an Amazon DataZone environment profile.
1610 1611 1612 1613 |
# File 'lib/aws-sdk-datazone/client.rb', line 1610 def create_environment_profile(params = {}, = {}) req = build_request(:create_environment_profile, params) req.send_request() end |
#create_form_type(params = {}) ⇒ Types::CreateFormTypeOutput
Creates a metadata form type.
1674 1675 1676 1677 |
# File 'lib/aws-sdk-datazone/client.rb', line 1674 def create_form_type(params = {}, = {}) req = build_request(:create_form_type, params) req.send_request() end |
#create_glossary(params = {}) ⇒ Types::CreateGlossaryOutput
Creates an Amazon DataZone business glossary.
1737 1738 1739 1740 |
# File 'lib/aws-sdk-datazone/client.rb', line 1737 def create_glossary(params = {}, = {}) req = build_request(:create_glossary, params) req.send_request() end |
#create_glossary_term(params = {}) ⇒ Types::CreateGlossaryTermOutput
Creates a business glossary term.
1818 1819 1820 1821 |
# File 'lib/aws-sdk-datazone/client.rb', line 1818 def create_glossary_term(params = {}, = {}) req = build_request(:create_glossary_term, params) req.send_request() end |
#create_group_profile(params = {}) ⇒ Types::CreateGroupProfileOutput
Creates a group profile in Amazon DataZone.
1865 1866 1867 1868 |
# File 'lib/aws-sdk-datazone/client.rb', line 1865 def create_group_profile(params = {}, = {}) req = build_request(:create_group_profile, params) req.send_request() end |
#create_listing_change_set(params = {}) ⇒ Types::CreateListingChangeSetOutput
Publishes a listing (a record of an asset at a given time) or removes a listing from the catalog.
1922 1923 1924 1925 |
# File 'lib/aws-sdk-datazone/client.rb', line 1922 def create_listing_change_set(params = {}, = {}) req = build_request(:create_listing_change_set, params) req.send_request() end |
#create_project(params = {}) ⇒ Types::CreateProjectOutput
Creates an Amazon DataZone project.
1983 1984 1985 1986 |
# File 'lib/aws-sdk-datazone/client.rb', line 1983 def create_project(params = {}, = {}) req = build_request(:create_project, params) req.send_request() end |
#create_project_membership(params = {}) ⇒ Struct
Creates a project membership in Amazon DataZone.
2021 2022 2023 2024 |
# File 'lib/aws-sdk-datazone/client.rb', line 2021 def create_project_membership(params = {}, = {}) req = build_request(:create_project_membership, params) req.send_request() end |
#create_subscription_grant(params = {}) ⇒ Types::CreateSubscriptionGrantOutput
Creates a subsscription grant in Amazon DataZone.
2113 2114 2115 2116 |
# File 'lib/aws-sdk-datazone/client.rb', line 2113 def create_subscription_grant(params = {}, = {}) req = build_request(:create_subscription_grant, params) req.send_request() end |
#create_subscription_request(params = {}) ⇒ Types::CreateSubscriptionRequestOutput
Creates a subscription request in Amazon DataZone.
2210 2211 2212 2213 |
# File 'lib/aws-sdk-datazone/client.rb', line 2210 def create_subscription_request(params = {}, = {}) req = build_request(:create_subscription_request, params) req.send_request() end |
#create_subscription_target(params = {}) ⇒ Types::CreateSubscriptionTargetOutput
Creates a subscription target in Amazon DataZone.
2316 2317 2318 2319 |
# File 'lib/aws-sdk-datazone/client.rb', line 2316 def create_subscription_target(params = {}, = {}) req = build_request(:create_subscription_target, params) req.send_request() end |
#create_user_profile(params = {}) ⇒ Types::CreateUserProfileOutput
Creates a user profile in Amazon DataZone.
2372 2373 2374 2375 |
# File 'lib/aws-sdk-datazone/client.rb', line 2372 def create_user_profile(params = {}, = {}) req = build_request(:create_user_profile, params) req.send_request() end |
#delete_asset(params = {}) ⇒ Struct
Delets an asset in Amazon DataZone.
2398 2399 2400 2401 |
# File 'lib/aws-sdk-datazone/client.rb', line 2398 def delete_asset(params = {}, = {}) req = build_request(:delete_asset, params) req.send_request() end |
#delete_asset_type(params = {}) ⇒ Struct
Deletes an asset type in Amazon DataZone.
2425 2426 2427 2428 |
# File 'lib/aws-sdk-datazone/client.rb', line 2425 def delete_asset_type(params = {}, = {}) req = build_request(:delete_asset_type, params) req.send_request() end |
#delete_data_source(params = {}) ⇒ Types::DeleteDataSourceOutput
Deletes a data source in Amazon DataZone.
2548 2549 2550 2551 |
# File 'lib/aws-sdk-datazone/client.rb', line 2548 def delete_data_source(params = {}, = {}) req = build_request(:delete_data_source, params) req.send_request() end |
#delete_domain(params = {}) ⇒ Types::DeleteDomainOutput
Deletes a Amazon DataZone domain.
2590 2591 2592 2593 |
# File 'lib/aws-sdk-datazone/client.rb', line 2590 def delete_domain(params = {}, = {}) req = build_request(:delete_domain, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Struct
Deletes an environment in Amazon DataZone.
2617 2618 2619 2620 |
# File 'lib/aws-sdk-datazone/client.rb', line 2617 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#delete_environment_action(params = {}) ⇒ Struct
Deletes an action for the environment, for example, deletes a console link for an analytics tool that is available in this environment.
2649 2650 2651 2652 |
# File 'lib/aws-sdk-datazone/client.rb', line 2649 def delete_environment_action(params = {}, = {}) req = build_request(:delete_environment_action, params) req.send_request() end |
#delete_environment_blueprint_configuration(params = {}) ⇒ Struct
Deletes the blueprint configuration in Amazon DataZone.
2676 2677 2678 2679 |
# File 'lib/aws-sdk-datazone/client.rb', line 2676 def delete_environment_blueprint_configuration(params = {}, = {}) req = build_request(:delete_environment_blueprint_configuration, params) req.send_request() end |
#delete_environment_profile(params = {}) ⇒ Struct
Deletes an environment profile in Amazon DataZone.
2703 2704 2705 2706 |
# File 'lib/aws-sdk-datazone/client.rb', line 2703 def delete_environment_profile(params = {}, = {}) req = build_request(:delete_environment_profile, params) req.send_request() end |
#delete_form_type(params = {}) ⇒ Struct
Delets and metadata form type in Amazon DataZone.
2730 2731 2732 2733 |
# File 'lib/aws-sdk-datazone/client.rb', line 2730 def delete_form_type(params = {}, = {}) req = build_request(:delete_form_type, params) req.send_request() end |
#delete_glossary(params = {}) ⇒ Struct
Deletes a business glossary in Amazon DataZone.
2757 2758 2759 2760 |
# File 'lib/aws-sdk-datazone/client.rb', line 2757 def delete_glossary(params = {}, = {}) req = build_request(:delete_glossary, params) req.send_request() end |
#delete_glossary_term(params = {}) ⇒ Struct
Deletes a business glossary term in Amazon DataZone.
2784 2785 2786 2787 |
# File 'lib/aws-sdk-datazone/client.rb', line 2784 def delete_glossary_term(params = {}, = {}) req = build_request(:delete_glossary_term, params) req.send_request() end |
#delete_listing(params = {}) ⇒ Struct
Deletes a listing (a record of an asset at a given time).
2810 2811 2812 2813 |
# File 'lib/aws-sdk-datazone/client.rb', line 2810 def delete_listing(params = {}, = {}) req = build_request(:delete_listing, params) req.send_request() end |
#delete_project(params = {}) ⇒ Struct
Deletes a project in Amazon DataZone.
2841 2842 2843 2844 |
# File 'lib/aws-sdk-datazone/client.rb', line 2841 def delete_project(params = {}, = {}) req = build_request(:delete_project, params) req.send_request() end |
#delete_project_membership(params = {}) ⇒ Struct
Deletes project membership in Amazon DataZone.
2876 2877 2878 2879 |
# File 'lib/aws-sdk-datazone/client.rb', line 2876 def delete_project_membership(params = {}, = {}) req = build_request(:delete_project_membership, params) req.send_request() end |
#delete_subscription_grant(params = {}) ⇒ Types::DeleteSubscriptionGrantOutput
Deletes and subscription grant in Amazon DataZone.
2937 2938 2939 2940 |
# File 'lib/aws-sdk-datazone/client.rb', line 2937 def delete_subscription_grant(params = {}, = {}) req = build_request(:delete_subscription_grant, params) req.send_request() end |
#delete_subscription_request(params = {}) ⇒ Struct
Deletes a subscription request in Amazon DataZone.
2964 2965 2966 2967 |
# File 'lib/aws-sdk-datazone/client.rb', line 2964 def delete_subscription_request(params = {}, = {}) req = build_request(:delete_subscription_request, params) req.send_request() end |
#delete_subscription_target(params = {}) ⇒ Struct
Deletes a subscription target in Amazon DataZone.
2996 2997 2998 2999 |
# File 'lib/aws-sdk-datazone/client.rb', line 2996 def delete_subscription_target(params = {}, = {}) req = build_request(:delete_subscription_target, params) req.send_request() end |
#delete_time_series_data_points(params = {}) ⇒ Struct
Deletes the specified time series form for the specified asset.
3039 3040 3041 3042 |
# File 'lib/aws-sdk-datazone/client.rb', line 3039 def delete_time_series_data_points(params = {}, = {}) req = build_request(:delete_time_series_data_points, params) req.send_request() end |
#disassociate_environment_role(params = {}) ⇒ Struct
Disassociates the environment role in Amazon DataZone.
3070 3071 3072 3073 |
# File 'lib/aws-sdk-datazone/client.rb', line 3070 def disassociate_environment_role(params = {}, = {}) req = build_request(:disassociate_environment_role, params) req.send_request() end |
#get_asset(params = {}) ⇒ Types::GetAssetOutput
Gets an Amazon DataZone asset.
3156 3157 3158 3159 |
# File 'lib/aws-sdk-datazone/client.rb', line 3156 def get_asset(params = {}, = {}) req = build_request(:get_asset, params) req.send_request() end |
#get_asset_type(params = {}) ⇒ Types::GetAssetTypeOutput
Gets an Amazon DataZone asset type.
3217 3218 3219 3220 |
# File 'lib/aws-sdk-datazone/client.rb', line 3217 def get_asset_type(params = {}, = {}) req = build_request(:get_asset_type, params) req.send_request() end |
#get_data_source(params = {}) ⇒ Types::GetDataSourceOutput
Gets an Amazon DataZone data source.
3328 3329 3330 3331 |
# File 'lib/aws-sdk-datazone/client.rb', line 3328 def get_data_source(params = {}, = {}) req = build_request(:get_data_source, params) req.send_request() end |
#get_data_source_run(params = {}) ⇒ Types::GetDataSourceRunOutput
Gets an Amazon DataZone data source run.
3389 3390 3391 3392 |
# File 'lib/aws-sdk-datazone/client.rb', line 3389 def get_data_source_run(params = {}, = {}) req = build_request(:get_data_source_run, params) req.send_request() end |
#get_domain(params = {}) ⇒ Types::GetDomainOutput
Gets an Amazon DataZone domain.
3441 3442 3443 3444 |
# File 'lib/aws-sdk-datazone/client.rb', line 3441 def get_domain(params = {}, = {}) req = build_request(:get_domain, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::GetEnvironmentOutput
Gets an Amazon DataZone environment.
3537 3538 3539 3540 |
# File 'lib/aws-sdk-datazone/client.rb', line 3537 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#get_environment_action(params = {}) ⇒ Types::GetEnvironmentActionOutput
Gets the specified environment action.
3584 3585 3586 3587 |
# File 'lib/aws-sdk-datazone/client.rb', line 3584 def get_environment_action(params = {}, = {}) req = build_request(:get_environment_action, params) req.send_request() end |
#get_environment_blueprint(params = {}) ⇒ Types::GetEnvironmentBlueprintOutput
Gets an Amazon DataZone blueprint.
3642 3643 3644 3645 |
# File 'lib/aws-sdk-datazone/client.rb', line 3642 def get_environment_blueprint(params = {}, = {}) req = build_request(:get_environment_blueprint, params) req.send_request() end |
#get_environment_blueprint_configuration(params = {}) ⇒ Types::GetEnvironmentBlueprintConfigurationOutput
Gets the blueprint configuration in Amazon DataZone.
3691 3692 3693 3694 |
# File 'lib/aws-sdk-datazone/client.rb', line 3691 def get_environment_blueprint_configuration(params = {}, = {}) req = build_request(:get_environment_blueprint_configuration, params) req.send_request() end |
#get_environment_profile(params = {}) ⇒ Types::GetEnvironmentProfileOutput
Gets an evinronment profile in Amazon DataZone.
3752 3753 3754 3755 |
# File 'lib/aws-sdk-datazone/client.rb', line 3752 def get_environment_profile(params = {}, = {}) req = build_request(:get_environment_profile, params) req.send_request() end |
#get_form_type(params = {}) ⇒ Types::GetFormTypeOutput
Gets a metadata form type in Amazon DataZone.
3813 3814 3815 3816 |
# File 'lib/aws-sdk-datazone/client.rb', line 3813 def get_form_type(params = {}, = {}) req = build_request(:get_form_type, params) req.send_request() end |
#get_glossary(params = {}) ⇒ Types::GetGlossaryOutput
Gets a business glossary in Amazon DataZone.
3864 3865 3866 3867 |
# File 'lib/aws-sdk-datazone/client.rb', line 3864 def get_glossary(params = {}, = {}) req = build_request(:get_glossary, params) req.send_request() end |
#get_glossary_term(params = {}) ⇒ Types::GetGlossaryTermOutput
Gets a business glossary term in Amazon DataZone.
3922 3923 3924 3925 |
# File 'lib/aws-sdk-datazone/client.rb', line 3922 def get_glossary_term(params = {}, = {}) req = build_request(:get_glossary_term, params) req.send_request() end |
#get_group_profile(params = {}) ⇒ Types::GetGroupProfileOutput
Gets a group profile in Amazon DataZone.
3961 3962 3963 3964 |
# File 'lib/aws-sdk-datazone/client.rb', line 3961 def get_group_profile(params = {}, = {}) req = build_request(:get_group_profile, params) req.send_request() end |
#get_iam_portal_login_url(params = {}) ⇒ Types::GetIamPortalLoginUrlOutput
Gets the data portal URL for the specified Amazon DataZone domain.
3992 3993 3994 3995 |
# File 'lib/aws-sdk-datazone/client.rb', line 3992 def get_iam_portal_login_url(params = {}, = {}) req = build_request(:get_iam_portal_login_url, params) req.send_request() end |
#get_lineage_node(params = {}) ⇒ Types::GetLineageNodeOutput
Gets the data lineage node.
4070 4071 4072 4073 |
# File 'lib/aws-sdk-datazone/client.rb', line 4070 def get_lineage_node(params = {}, = {}) req = build_request(:get_lineage_node, params) req.send_request() end |
#get_listing(params = {}) ⇒ Types::GetListingOutput
Gets a listing (a record of an asset at a given time).
4141 4142 4143 4144 |
# File 'lib/aws-sdk-datazone/client.rb', line 4141 def get_listing(params = {}, = {}) req = build_request(:get_listing, params) req.send_request() end |
#get_metadata_generation_run(params = {}) ⇒ Types::GetMetadataGenerationRunOutput
Gets a metadata generation run in Amazon DataZone.
4190 4191 4192 4193 |
# File 'lib/aws-sdk-datazone/client.rb', line 4190 def (params = {}, = {}) req = build_request(:get_metadata_generation_run, params) req.send_request() end |
#get_project(params = {}) ⇒ Types::GetProjectOutput
Gets a project in Amazon DataZone.
4243 4244 4245 4246 |
# File 'lib/aws-sdk-datazone/client.rb', line 4243 def get_project(params = {}, = {}) req = build_request(:get_project, params) req.send_request() end |
#get_subscription(params = {}) ⇒ Types::GetSubscriptionOutput
Gets a subscription in Amazon DataZone.
4308 4309 4310 4311 |
# File 'lib/aws-sdk-datazone/client.rb', line 4308 def get_subscription(params = {}, = {}) req = build_request(:get_subscription, params) req.send_request() end |
#get_subscription_grant(params = {}) ⇒ Types::GetSubscriptionGrantOutput
Gets the subscription grant in Amazon DataZone.
4369 4370 4371 4372 |
# File 'lib/aws-sdk-datazone/client.rb', line 4369 def get_subscription_grant(params = {}, = {}) req = build_request(:get_subscription_grant, params) req.send_request() end |
#get_subscription_request_details(params = {}) ⇒ Types::GetSubscriptionRequestDetailsOutput
Gets the details of the specified subscription request.
4440 4441 4442 4443 |
# File 'lib/aws-sdk-datazone/client.rb', line 4440 def get_subscription_request_details(params = {}, = {}) req = build_request(:get_subscription_request_details, params) req.send_request() end |
#get_subscription_target(params = {}) ⇒ Types::GetSubscriptionTargetOutput
Gets the subscription target in Amazon DataZone.
4509 4510 4511 4512 |
# File 'lib/aws-sdk-datazone/client.rb', line 4509 def get_subscription_target(params = {}, = {}) req = build_request(:get_subscription_target, params) req.send_request() end |
#get_time_series_data_point(params = {}) ⇒ Types::GetTimeSeriesDataPointOutput
Gets the existing data point for the asset.
4568 4569 4570 4571 |
# File 'lib/aws-sdk-datazone/client.rb', line 4568 def get_time_series_data_point(params = {}, = {}) req = build_request(:get_time_series_data_point, params) req.send_request() end |
#get_user_profile(params = {}) ⇒ Types::GetUserProfileOutput
Gets a user profile in Amazon DataZone.
4616 4617 4618 4619 |
# File 'lib/aws-sdk-datazone/client.rb', line 4616 def get_user_profile(params = {}, = {}) req = build_request(:get_user_profile, params) req.send_request() end |
#list_asset_revisions(params = {}) ⇒ Types::ListAssetRevisionsOutput
Lists the revisions for the asset.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4674 4675 4676 4677 |
# File 'lib/aws-sdk-datazone/client.rb', line 4674 def list_asset_revisions(params = {}, = {}) req = build_request(:list_asset_revisions, params) req.send_request() end |
#list_data_source_run_activities(params = {}) ⇒ Types::ListDataSourceRunActivitiesOutput
Lists data source run activities.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4743 4744 4745 4746 |
# File 'lib/aws-sdk-datazone/client.rb', line 4743 def list_data_source_run_activities(params = {}, = {}) req = build_request(:list_data_source_run_activities, params) req.send_request() end |
#list_data_source_runs(params = {}) ⇒ Types::ListDataSourceRunsOutput
Lists data source runs in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4817 4818 4819 4820 |
# File 'lib/aws-sdk-datazone/client.rb', line 4817 def list_data_source_runs(params = {}, = {}) req = build_request(:list_data_source_runs, params) req.send_request() end |
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesOutput
Lists data sources in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4903 4904 4905 4906 |
# File 'lib/aws-sdk-datazone/client.rb', line 4903 def list_data_sources(params = {}, = {}) req = build_request(:list_data_sources, params) req.send_request() end |
#list_domains(params = {}) ⇒ Types::ListDomainsOutput
Lists Amazon DataZone domains.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
4961 4962 4963 4964 |
# File 'lib/aws-sdk-datazone/client.rb', line 4961 def list_domains(params = {}, = {}) req = build_request(:list_domains, params) req.send_request() end |
#list_environment_actions(params = {}) ⇒ Types::ListEnvironmentActionsOutput
Lists existing environment actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5021 5022 5023 5024 |
# File 'lib/aws-sdk-datazone/client.rb', line 5021 def list_environment_actions(params = {}, = {}) req = build_request(:list_environment_actions, params) req.send_request() end |
#list_environment_blueprint_configurations(params = {}) ⇒ Types::ListEnvironmentBlueprintConfigurationsOutput
Lists blueprint configurations for a Amazon DataZone environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5083 5084 5085 5086 |
# File 'lib/aws-sdk-datazone/client.rb', line 5083 def list_environment_blueprint_configurations(params = {}, = {}) req = build_request(:list_environment_blueprint_configurations, params) req.send_request() end |
#list_environment_blueprints(params = {}) ⇒ Types::ListEnvironmentBlueprintsOutput
Lists blueprints in an Amazon DataZone environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5149 5150 5151 5152 |
# File 'lib/aws-sdk-datazone/client.rb', line 5149 def list_environment_blueprints(params = {}, = {}) req = build_request(:list_environment_blueprints, params) req.send_request() end |
#list_environment_profiles(params = {}) ⇒ Types::ListEnvironmentProfilesOutput
Lists Amazon DataZone environment profiles.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5233 5234 5235 5236 |
# File 'lib/aws-sdk-datazone/client.rb', line 5233 def list_environment_profiles(params = {}, = {}) req = build_request(:list_environment_profiles, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsOutput
Lists Amazon DataZone environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5328 5329 5330 5331 |
# File 'lib/aws-sdk-datazone/client.rb', line 5328 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_lineage_node_history(params = {}) ⇒ Types::ListLineageNodeHistoryOutput
Lists the history of the specified data lineage node.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5415 5416 5417 5418 |
# File 'lib/aws-sdk-datazone/client.rb', line 5415 def list_lineage_node_history(params = {}, = {}) req = build_request(:list_lineage_node_history, params) req.send_request() end |
#list_metadata_generation_runs(params = {}) ⇒ Types::ListMetadataGenerationRunsOutput
Lists all metadata generation runs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5484 5485 5486 5487 |
# File 'lib/aws-sdk-datazone/client.rb', line 5484 def (params = {}, = {}) req = build_request(:list_metadata_generation_runs, params) req.send_request() end |
#list_notifications(params = {}) ⇒ Types::ListNotificationsOutput
Lists all Amazon DataZone notifications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5569 5570 5571 5572 |
# File 'lib/aws-sdk-datazone/client.rb', line 5569 def list_notifications(params = {}, = {}) req = build_request(:list_notifications, params) req.send_request() end |
#list_project_memberships(params = {}) ⇒ Types::ListProjectMembershipsOutput
Lists all members of the specified project.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5634 5635 5636 5637 |
# File 'lib/aws-sdk-datazone/client.rb', line 5634 def list_project_memberships(params = {}, = {}) req = build_request(:list_project_memberships, params) req.send_request() end |
#list_projects(params = {}) ⇒ Types::ListProjectsOutput
Lists Amazon DataZone projects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5706 5707 5708 5709 |
# File 'lib/aws-sdk-datazone/client.rb', line 5706 def list_projects(params = {}, = {}) req = build_request(:list_projects, params) req.send_request() end |
#list_subscription_grants(params = {}) ⇒ Types::ListSubscriptionGrantsOutput
Lists subscription grants.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5798 5799 5800 5801 |
# File 'lib/aws-sdk-datazone/client.rb', line 5798 def list_subscription_grants(params = {}, = {}) req = build_request(:list_subscription_grants, params) req.send_request() end |
#list_subscription_requests(params = {}) ⇒ Types::ListSubscriptionRequestsOutput
Lists Amazon DataZone subscription requests.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5900 5901 5902 5903 |
# File 'lib/aws-sdk-datazone/client.rb', line 5900 def list_subscription_requests(params = {}, = {}) req = build_request(:list_subscription_requests, params) req.send_request() end |
#list_subscription_targets(params = {}) ⇒ Types::ListSubscriptionTargetsOutput
Lists subscription targets in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
5985 5986 5987 5988 |
# File 'lib/aws-sdk-datazone/client.rb', line 5985 def list_subscription_targets(params = {}, = {}) req = build_request(:list_subscription_targets, params) req.send_request() end |
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsOutput
Lists subscriptions in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6089 6090 6091 6092 |
# File 'lib/aws-sdk-datazone/client.rb', line 6089 def list_subscriptions(params = {}, = {}) req = build_request(:list_subscriptions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for the specified resource in Amazon DataZone.
6118 6119 6120 6121 |
# File 'lib/aws-sdk-datazone/client.rb', line 6118 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_time_series_data_points(params = {}) ⇒ Types::ListTimeSeriesDataPointsOutput
Lists time series data points.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6194 6195 6196 6197 |
# File 'lib/aws-sdk-datazone/client.rb', line 6194 def list_time_series_data_points(params = {}, = {}) req = build_request(:list_time_series_data_points, params) req.send_request() end |
#post_lineage_event(params = {}) ⇒ Struct
Posts a data lineage event.
6229 6230 6231 6232 |
# File 'lib/aws-sdk-datazone/client.rb', line 6229 def post_lineage_event(params = {}, = {}) req = build_request(:post_lineage_event, params) req.send_request() end |
#post_time_series_data_points(params = {}) ⇒ Types::PostTimeSeriesDataPointsOutput
Posts time series data points to Amazon DataZone for the specified asset.
6300 6301 6302 6303 |
# File 'lib/aws-sdk-datazone/client.rb', line 6300 def post_time_series_data_points(params = {}, = {}) req = build_request(:post_time_series_data_points, params) req.send_request() end |
#put_environment_blueprint_configuration(params = {}) ⇒ Types::PutEnvironmentBlueprintConfigurationOutput
Writes the configuration for the specified environment blueprint in Amazon DataZone.
6370 6371 6372 6373 |
# File 'lib/aws-sdk-datazone/client.rb', line 6370 def put_environment_blueprint_configuration(params = {}, = {}) req = build_request(:put_environment_blueprint_configuration, params) req.send_request() end |
#reject_predictions(params = {}) ⇒ Types::RejectPredictionsOutput
Rejects automatically generated business-friendly metadata for your Amazon DataZone assets.
6438 6439 6440 6441 |
# File 'lib/aws-sdk-datazone/client.rb', line 6438 def reject_predictions(params = {}, = {}) req = build_request(:reject_predictions, params) req.send_request() end |
#reject_subscription_request(params = {}) ⇒ Types::RejectSubscriptionRequestOutput
Rejects the specified subscription request.
6512 6513 6514 6515 |
# File 'lib/aws-sdk-datazone/client.rb', line 6512 def reject_subscription_request(params = {}, = {}) req = build_request(:reject_subscription_request, params) req.send_request() end |
#revoke_subscription(params = {}) ⇒ Types::RevokeSubscriptionOutput
Revokes a specified subscription in Amazon DataZone.
6583 6584 6585 6586 |
# File 'lib/aws-sdk-datazone/client.rb', line 6583 def revoke_subscription(params = {}, = {}) req = build_request(:revoke_subscription, params) req.send_request() end |
#search(params = {}) ⇒ Types::SearchOutput
Searches for assets in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6753 6754 6755 6756 |
# File 'lib/aws-sdk-datazone/client.rb', line 6753 def search(params = {}, = {}) req = build_request(:search, params) req.send_request() end |
#search_group_profiles(params = {}) ⇒ Types::SearchGroupProfilesOutput
Searches group profiles in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6815 6816 6817 6818 |
# File 'lib/aws-sdk-datazone/client.rb', line 6815 def search_group_profiles(params = {}, = {}) req = build_request(:search_group_profiles, params) req.send_request() end |
#search_listings(params = {}) ⇒ Types::SearchListingsOutput
Searches listings (records of an asset at a given time) in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
6931 6932 6933 6934 |
# File 'lib/aws-sdk-datazone/client.rb', line 6931 def search_listings(params = {}, = {}) req = build_request(:search_listings, params) req.send_request() end |
#search_types(params = {}) ⇒ Types::SearchTypesOutput
Searches for types in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
7070 7071 7072 7073 |
# File 'lib/aws-sdk-datazone/client.rb', line 7070 def search_types(params = {}, = {}) req = build_request(:search_types, params) req.send_request() end |
#search_user_profiles(params = {}) ⇒ Types::SearchUserProfilesOutput
Searches user profiles in Amazon DataZone.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
7136 7137 7138 7139 |
# File 'lib/aws-sdk-datazone/client.rb', line 7136 def search_user_profiles(params = {}, = {}) req = build_request(:search_user_profiles, params) req.send_request() end |
#start_data_source_run(params = {}) ⇒ Types::StartDataSourceRunOutput
Start the run of the specified data source in Amazon DataZone.
7206 7207 7208 7209 |
# File 'lib/aws-sdk-datazone/client.rb', line 7206 def start_data_source_run(params = {}, = {}) req = build_request(:start_data_source_run, params) req.send_request() end |
#start_metadata_generation_run(params = {}) ⇒ Types::StartMetadataGenerationRunOutput
Starts the metadata generation run.
7272 7273 7274 7275 |
# File 'lib/aws-sdk-datazone/client.rb', line 7272 def (params = {}, = {}) req = build_request(:start_metadata_generation_run, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags a resource in Amazon DataZone.
7300 7301 7302 7303 |
# File 'lib/aws-sdk-datazone/client.rb', line 7300 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untags a resource in Amazon DataZone.
7326 7327 7328 7329 |
# File 'lib/aws-sdk-datazone/client.rb', line 7326 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceOutput
Updates the specified data source in Amazon DataZone.
7535 7536 7537 7538 |
# File 'lib/aws-sdk-datazone/client.rb', line 7535 def update_data_source(params = {}, = {}) req = build_request(:update_data_source, params) req.send_request() end |
#update_domain(params = {}) ⇒ Types::UpdateDomainOutput
Updates a Amazon DataZone domain.
7603 7604 7605 7606 |
# File 'lib/aws-sdk-datazone/client.rb', line 7603 def update_domain(params = {}, = {}) req = build_request(:update_domain, params) req.send_request() end |
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentOutput
Updates the specified environment in Amazon DataZone.
7714 7715 7716 7717 |
# File 'lib/aws-sdk-datazone/client.rb', line 7714 def update_environment(params = {}, = {}) req = build_request(:update_environment, params) req.send_request() end |
#update_environment_action(params = {}) ⇒ Types::UpdateEnvironmentActionOutput
Updates an environment action.
7776 7777 7778 7779 |
# File 'lib/aws-sdk-datazone/client.rb', line 7776 def update_environment_action(params = {}, = {}) req = build_request(:update_environment_action, params) req.send_request() end |
#update_environment_profile(params = {}) ⇒ Types::UpdateEnvironmentProfileOutput
Updates the specified environment profile in Amazon DataZone.
7867 7868 7869 7870 |
# File 'lib/aws-sdk-datazone/client.rb', line 7867 def update_environment_profile(params = {}, = {}) req = build_request(:update_environment_profile, params) req.send_request() end |
#update_glossary(params = {}) ⇒ Types::UpdateGlossaryOutput
Updates the business glossary in Amazon DataZone.
7930 7931 7932 7933 |
# File 'lib/aws-sdk-datazone/client.rb', line 7930 def update_glossary(params = {}, = {}) req = build_request(:update_glossary, params) req.send_request() end |
#update_glossary_term(params = {}) ⇒ Types::UpdateGlossaryTermOutput
Updates a business glossary term in Amazon DataZone.
8011 8012 8013 8014 |
# File 'lib/aws-sdk-datazone/client.rb', line 8011 def update_glossary_term(params = {}, = {}) req = build_request(:update_glossary_term, params) req.send_request() end |
#update_group_profile(params = {}) ⇒ Types::UpdateGroupProfileOutput
Updates the specified group profile in Amazon DataZone.
8054 8055 8056 8057 |
# File 'lib/aws-sdk-datazone/client.rb', line 8054 def update_group_profile(params = {}, = {}) req = build_request(:update_group_profile, params) req.send_request() end |
#update_project(params = {}) ⇒ Types::UpdateProjectOutput
Updates the specified project in Amazon DataZone.
8121 8122 8123 8124 |
# File 'lib/aws-sdk-datazone/client.rb', line 8121 def update_project(params = {}, = {}) req = build_request(:update_project, params) req.send_request() end |
#update_subscription_grant_status(params = {}) ⇒ Types::UpdateSubscriptionGrantStatusOutput
Updates the status of the specified subscription grant status in Amazon DataZone.
8206 8207 8208 8209 |
# File 'lib/aws-sdk-datazone/client.rb', line 8206 def update_subscription_grant_status(params = {}, = {}) req = build_request(:update_subscription_grant_status, params) req.send_request() end |
#update_subscription_request(params = {}) ⇒ Types::UpdateSubscriptionRequestOutput
Updates a specified subscription request in Amazon DataZone.
8280 8281 8282 8283 |
# File 'lib/aws-sdk-datazone/client.rb', line 8280 def update_subscription_request(params = {}, = {}) req = build_request(:update_subscription_request, params) req.send_request() end |
#update_subscription_target(params = {}) ⇒ Types::UpdateSubscriptionTargetOutput
Updates the specified subscription target in Amazon DataZone.
8385 8386 8387 8388 |
# File 'lib/aws-sdk-datazone/client.rb', line 8385 def update_subscription_target(params = {}, = {}) req = build_request(:update_subscription_target, params) req.send_request() end |
#update_user_profile(params = {}) ⇒ Types::UpdateUserProfileOutput
Updates the specified user profile in Amazon DataZone.
8437 8438 8439 8440 |
# File 'lib/aws-sdk-datazone/client.rb', line 8437 def update_user_profile(params = {}, = {}) req = build_request(:update_user_profile, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8461 8462 8463 |
# File 'lib/aws-sdk-datazone/client.rb', line 8461 def waiter_names [] end |