Module: Aws::DataZone::Types
- Defined in:
- lib/aws-sdk-datazone/types.rb
Defined Under Namespace
Classes: AcceptChoice, AcceptPredictionsInput, AcceptPredictionsOutput, AcceptRule, AcceptSubscriptionRequestInput, AcceptSubscriptionRequestOutput, AccessDeniedException, AssetItem, AssetItemAdditionalAttributes, AssetListing, AssetListingDetails, AssetListingItem, AssetListingItemAdditionalAttributes, AssetRevision, AssetTargetNameMap, AssetTypeItem, BusinessNameGenerationConfiguration, CancelSubscriptionInput, CancelSubscriptionOutput, CloudFormationProperties, ConfigurableActionParameter, ConfigurableEnvironmentAction, ConflictException, CreateAssetInput, CreateAssetOutput, CreateAssetRevisionInput, CreateAssetRevisionOutput, CreateAssetTypeInput, CreateAssetTypeOutput, CreateDataSourceInput, CreateDataSourceOutput, CreateDomainInput, CreateDomainOutput, CreateEnvironmentInput, CreateEnvironmentOutput, CreateEnvironmentProfileInput, CreateEnvironmentProfileOutput, CreateFormTypeInput, CreateFormTypeOutput, CreateGlossaryInput, CreateGlossaryOutput, CreateGlossaryTermInput, CreateGlossaryTermOutput, CreateGroupProfileInput, CreateGroupProfileOutput, CreateListingChangeSetInput, CreateListingChangeSetOutput, CreateProjectInput, CreateProjectMembershipInput, CreateProjectMembershipOutput, CreateProjectOutput, CreateSubscriptionGrantInput, CreateSubscriptionGrantOutput, CreateSubscriptionRequestInput, CreateSubscriptionRequestOutput, CreateSubscriptionTargetInput, CreateSubscriptionTargetOutput, CreateUserProfileInput, CreateUserProfileOutput, CustomParameter, DataProductItem, DataProductSummary, DataSourceConfigurationInput, DataSourceConfigurationOutput, DataSourceErrorMessage, DataSourceRunActivity, DataSourceRunSummary, DataSourceSummary, DeleteAssetInput, DeleteAssetOutput, DeleteAssetTypeInput, DeleteAssetTypeOutput, DeleteDataSourceInput, DeleteDataSourceOutput, DeleteDomainInput, DeleteDomainOutput, DeleteEnvironmentBlueprintConfigurationInput, DeleteEnvironmentBlueprintConfigurationOutput, DeleteEnvironmentInput, DeleteEnvironmentProfileInput, DeleteFormTypeInput, DeleteFormTypeOutput, DeleteGlossaryInput, DeleteGlossaryOutput, DeleteGlossaryTermInput, DeleteGlossaryTermOutput, DeleteListingInput, DeleteListingOutput, DeleteProjectInput, DeleteProjectMembershipInput, DeleteProjectMembershipOutput, DeleteProjectOutput, DeleteSubscriptionGrantInput, DeleteSubscriptionGrantOutput, DeleteSubscriptionRequestInput, DeleteSubscriptionTargetInput, Deployment, DeploymentProperties, DetailedGlossaryTerm, DomainSummary, EnvironmentBlueprintConfigurationItem, EnvironmentBlueprintSummary, EnvironmentError, EnvironmentParameter, EnvironmentProfileSummary, EnvironmentSummary, FailureCause, Filter, FilterClause, FilterExpression, FormEntryInput, FormEntryOutput, FormInput, FormOutput, FormTypeData, GetAssetInput, GetAssetOutput, GetAssetTypeInput, GetAssetTypeOutput, GetDataSourceInput, GetDataSourceOutput, GetDataSourceRunInput, GetDataSourceRunOutput, GetDomainInput, GetDomainOutput, GetEnvironmentBlueprintConfigurationInput, GetEnvironmentBlueprintConfigurationOutput, GetEnvironmentBlueprintInput, GetEnvironmentBlueprintOutput, GetEnvironmentInput, GetEnvironmentOutput, GetEnvironmentProfileInput, GetEnvironmentProfileOutput, GetFormTypeInput, GetFormTypeOutput, GetGlossaryInput, GetGlossaryOutput, GetGlossaryTermInput, GetGlossaryTermOutput, GetGroupProfileInput, GetGroupProfileOutput, GetIamPortalLoginUrlInput, GetIamPortalLoginUrlOutput, GetListingInput, GetListingOutput, GetProjectInput, GetProjectOutput, GetSubscriptionGrantInput, GetSubscriptionGrantOutput, GetSubscriptionInput, GetSubscriptionOutput, GetSubscriptionRequestDetailsInput, GetSubscriptionRequestDetailsOutput, GetSubscriptionTargetInput, GetSubscriptionTargetOutput, GetUserProfileInput, GetUserProfileOutput, GlossaryItem, GlossaryTermItem, GlueRunConfigurationInput, GlueRunConfigurationOutput, GrantedEntity, GrantedEntityInput, GroupDetails, GroupProfileSummary, IamUserProfileDetails, Import, InternalServerException, ListAssetRevisionsInput, ListAssetRevisionsOutput, ListDataSourceRunActivitiesInput, ListDataSourceRunActivitiesOutput, ListDataSourceRunsInput, ListDataSourceRunsOutput, ListDataSourcesInput, ListDataSourcesOutput, ListDomainsInput, ListDomainsOutput, ListEnvironmentBlueprintConfigurationsInput, ListEnvironmentBlueprintConfigurationsOutput, ListEnvironmentBlueprintsInput, ListEnvironmentBlueprintsOutput, ListEnvironmentProfilesInput, ListEnvironmentProfilesOutput, ListEnvironmentsInput, ListEnvironmentsOutput, ListNotificationsInput, ListNotificationsOutput, ListProjectMembershipsInput, ListProjectMembershipsOutput, ListProjectsInput, ListProjectsOutput, ListSubscriptionGrantsInput, ListSubscriptionGrantsOutput, ListSubscriptionRequestsInput, ListSubscriptionRequestsOutput, ListSubscriptionTargetsInput, ListSubscriptionTargetsOutput, ListSubscriptionsInput, ListSubscriptionsOutput, ListTagsForResourceRequest, ListTagsForResourceResponse, ListingItem, ListingRevision, ListingRevisionInput, Member, MemberDetails, Model, NotificationOutput, NotificationResource, PredictionConfiguration, ProjectDeletionError, ProjectMember, ProjectSummary, ProvisioningProperties, PutEnvironmentBlueprintConfigurationInput, PutEnvironmentBlueprintConfigurationOutput, RecommendationConfiguration, RedshiftClusterStorage, RedshiftCredentialConfiguration, RedshiftRunConfigurationInput, RedshiftRunConfigurationOutput, RedshiftServerlessStorage, RedshiftStorage, RejectChoice, RejectPredictionsInput, RejectPredictionsOutput, RejectRule, RejectSubscriptionRequestInput, RejectSubscriptionRequestOutput, RelationalFilterConfiguration, Resource, ResourceNotFoundException, RevokeSubscriptionInput, RevokeSubscriptionOutput, RunStatisticsForAssets, ScheduleConfiguration, SearchGroupProfilesInput, SearchGroupProfilesOutput, SearchInItem, SearchInput, SearchInventoryResultItem, SearchListingsInput, SearchListingsOutput, SearchOutput, SearchResultItem, SearchSort, SearchTypesInput, SearchTypesOutput, SearchTypesResultItem, SearchUserProfilesInput, SearchUserProfilesOutput, ServiceQuotaExceededException, SingleSignOn, SsoUserProfileDetails, StartDataSourceRunInput, StartDataSourceRunOutput, SubscribedAsset, SubscribedAssetListing, SubscribedListing, SubscribedListingInput, SubscribedListingItem, SubscribedPrincipal, SubscribedPrincipalInput, SubscribedProject, SubscribedProjectInput, SubscriptionGrantSummary, SubscriptionRequestSummary, SubscriptionSummary, SubscriptionTargetForm, SubscriptionTargetSummary, TagResourceRequest, TagResourceResponse, TermRelations, ThrottlingException, Topic, UnauthorizedException, UntagResourceRequest, UntagResourceResponse, UpdateDataSourceInput, UpdateDataSourceOutput, UpdateDomainInput, UpdateDomainOutput, UpdateEnvironmentInput, UpdateEnvironmentOutput, UpdateEnvironmentProfileInput, UpdateEnvironmentProfileOutput, UpdateGlossaryInput, UpdateGlossaryOutput, UpdateGlossaryTermInput, UpdateGlossaryTermOutput, UpdateGroupProfileInput, UpdateGroupProfileOutput, UpdateProjectInput, UpdateProjectOutput, UpdateSubscriptionGrantStatusInput, UpdateSubscriptionGrantStatusOutput, UpdateSubscriptionRequestInput, UpdateSubscriptionRequestOutput, UpdateSubscriptionTargetInput, UpdateSubscriptionTargetOutput, UpdateUserProfileInput, UpdateUserProfileOutput, UserDetails, UserProfileDetails, UserProfileSummary, ValidationException
Instance Attribute Summary collapse
-
#and ⇒ Array<Types::FilterClause>
The ‘and’ search filter clause in Amazon DataZone.
-
#asset_item ⇒ Types::AssetItem
The asset item included in the search results.
-
#asset_listing ⇒ Types::SubscribedAssetListing
The asset for which the subscription grant is created.
-
#asset_type_item ⇒ Types::AssetTypeItem
The asset type included in the results of the ‘SearchTypes` action.
-
#cloud_formation ⇒ Types::CloudFormationProperties
The cloud formation properties included as part of the provisioning properties of an environment blueprint.
-
#data_product_item ⇒ Types::DataProductSummary
The data product item included in the search results.
-
#filter ⇒ Types::Filter
A search filter in Amazon DataZone.
-
#form_type_item ⇒ Types::FormTypeData
The form type included in the results of the ‘SearchTypes` action.
-
#glossary_item ⇒ Types::GlossaryItem
The glossary item included in the search results.
-
#glossary_term_item ⇒ Types::GlossaryTermItem
The glossary term item included in the search results.
-
#glue_run_configuration ⇒ Types::GlueRunConfigurationOutput
The configuration of the Amazon Web Services Glue data source.
-
#group ⇒ Types::GroupDetails
The group details of a project member.
-
#group_identifier ⇒ String
The ID of the group of a project member.
-
#iam ⇒ Types::IamUserProfileDetails
The IAM details included in the user profile details.
-
#listing ⇒ Types::ListingRevisionInput
The listing for which a subscription is to be granted.
-
#or ⇒ Array<Types::FilterClause>
The ‘or’ search filter clause in Amazon DataZone.
-
#project ⇒ Types::SubscribedProjectInput
The project that is to be given a subscription grant.
-
#redshift_cluster_source ⇒ Types::RedshiftClusterStorage
The details of the Amazon Redshift cluster source.
-
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationOutput
The configuration of the Amazon Redshift data source.
-
#redshift_serverless_source ⇒ Types::RedshiftServerlessStorage
The details of the Amazon Redshift Serverless workgroup source.
- #smithy ⇒ String
-
#sso ⇒ Types::SsoUserProfileDetails
The single sign-on details included in the user profile details.
-
#user ⇒ Types::UserDetails
The user details of a project member.
-
#user_identifier ⇒ String
The user ID of a project member.
Instance Attribute Details
#and ⇒ Array<Types::FilterClause>
The ‘and’ search filter clause in Amazon DataZone.
4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-datazone/types.rb', line 4134 class FilterClause < Struct.new( :and, :filter, :or, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class And < FilterClause; end class Filter < FilterClause; end class Or < FilterClause; end class Unknown < FilterClause; end end |
#asset_item ⇒ Types::AssetItem
The asset item included in the search results.
8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 |
# File 'lib/aws-sdk-datazone/types.rb', line 8798 class SearchInventoryResultItem < Struct.new( :asset_item, :data_product_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class DataProductItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#asset_listing ⇒ Types::SubscribedAssetListing
The asset for which the subscription grant is created.
7629 7630 7631 7632 7633 7634 7635 7636 7637 7638 |
# File 'lib/aws-sdk-datazone/types.rb', line 7629 class ListingItem < Struct.new( :asset_listing, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetListing < ListingItem; end class Unknown < ListingItem; end end |
#asset_type_item ⇒ Types::AssetTypeItem
The asset type included in the results of the ‘SearchTypes` action.
9066 9067 9068 9069 9070 9071 9072 9073 9074 9075 9076 9077 |
# File 'lib/aws-sdk-datazone/types.rb', line 9066 class SearchTypesResultItem < Struct.new( :asset_type_item, :form_type_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetTypeItem < SearchTypesResultItem; end class FormTypeItem < SearchTypesResultItem; end class Unknown < SearchTypesResultItem; end end |
#cloud_formation ⇒ Types::CloudFormationProperties
The cloud formation properties included as part of the provisioning properties of an environment blueprint.
7963 7964 7965 7966 7967 7968 7969 7970 7971 7972 |
# File 'lib/aws-sdk-datazone/types.rb', line 7963 class ProvisioningProperties < Struct.new( :cloud_formation, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CloudFormation < ProvisioningProperties; end class Unknown < ProvisioningProperties; end end |
#data_product_item ⇒ Types::DataProductSummary
The data product item included in the search results.
8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 |
# File 'lib/aws-sdk-datazone/types.rb', line 8798 class SearchInventoryResultItem < Struct.new( :asset_item, :data_product_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class DataProductItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#filter ⇒ Types::Filter
A search filter in Amazon DataZone.
4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-datazone/types.rb', line 4134 class FilterClause < Struct.new( :and, :filter, :or, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class And < FilterClause; end class Filter < FilterClause; end class Or < FilterClause; end class Unknown < FilterClause; end end |
#form_type_item ⇒ Types::FormTypeData
The form type included in the results of the ‘SearchTypes` action.
9066 9067 9068 9069 9070 9071 9072 9073 9074 9075 9076 9077 |
# File 'lib/aws-sdk-datazone/types.rb', line 9066 class SearchTypesResultItem < Struct.new( :asset_type_item, :form_type_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetTypeItem < SearchTypesResultItem; end class FormTypeItem < SearchTypesResultItem; end class Unknown < SearchTypesResultItem; end end |
#glossary_item ⇒ Types::GlossaryItem
The glossary item included in the search results.
8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 |
# File 'lib/aws-sdk-datazone/types.rb', line 8798 class SearchInventoryResultItem < Struct.new( :asset_item, :data_product_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class DataProductItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#glossary_term_item ⇒ Types::GlossaryTermItem
The glossary term item included in the search results.
8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 8808 8809 8810 8811 8812 8813 |
# File 'lib/aws-sdk-datazone/types.rb', line 8798 class SearchInventoryResultItem < Struct.new( :asset_item, :data_product_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class DataProductItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#glue_run_configuration ⇒ Types::GlueRunConfigurationOutput
The configuration of the Amazon Web Services Glue data source.
2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 |
# File 'lib/aws-sdk-datazone/types.rb', line 2851 class DataSourceConfigurationInput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationInput; end class RedshiftRunConfiguration < DataSourceConfigurationInput; end class Unknown < DataSourceConfigurationInput; end end |
#group ⇒ Types::GroupDetails
The group details of a project member.
7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 |
# File 'lib/aws-sdk-datazone/types.rb', line 7724 class MemberDetails < Struct.new( :group, :user, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Group < MemberDetails; end class User < MemberDetails; end class Unknown < MemberDetails; end end |
#group_identifier ⇒ String
The ID of the group of a project member.
7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 |
# File 'lib/aws-sdk-datazone/types.rb', line 7697 class Member < Struct.new( :group_identifier, :user_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GroupIdentifier < Member; end class UserIdentifier < Member; end class Unknown < Member; end end |
#iam ⇒ Types::IamUserProfileDetails
The IAM details included in the user profile details.
11284 11285 11286 11287 11288 11289 11290 11291 11292 11293 11294 11295 |
# File 'lib/aws-sdk-datazone/types.rb', line 11284 class UserProfileDetails < Struct.new( :iam, :sso, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Iam < UserProfileDetails; end class Sso < UserProfileDetails; end class Unknown < UserProfileDetails; end end |
#listing ⇒ Types::ListingRevisionInput
The listing for which a subscription is to be granted.
6305 6306 6307 6308 6309 6310 6311 6312 6313 6314 |
# File 'lib/aws-sdk-datazone/types.rb', line 6305 class GrantedEntity < Struct.new( :listing, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Listing < GrantedEntity; end class Unknown < GrantedEntity; end end |
#or ⇒ Array<Types::FilterClause>
The ‘or’ search filter clause in Amazon DataZone.
4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-datazone/types.rb', line 4134 class FilterClause < Struct.new( :and, :filter, :or, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class And < FilterClause; end class Filter < FilterClause; end class Or < FilterClause; end class Unknown < FilterClause; end end |
#project ⇒ Types::SubscribedProjectInput
The project that is to be given a subscription grant.
9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 |
# File 'lib/aws-sdk-datazone/types.rb', line 9490 class SubscribedPrincipal < Struct.new( :project, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |
#redshift_cluster_source ⇒ Types::RedshiftClusterStorage
The details of the Amazon Redshift cluster source.
8212 8213 8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 |
# File 'lib/aws-sdk-datazone/types.rb', line 8212 class RedshiftStorage < Struct.new( :redshift_cluster_source, :redshift_serverless_source, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RedshiftClusterSource < RedshiftStorage; end class RedshiftServerlessSource < RedshiftStorage; end class Unknown < RedshiftStorage; end end |
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationOutput
The configuration of the Amazon Redshift data source.
2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 |
# File 'lib/aws-sdk-datazone/types.rb', line 2851 class DataSourceConfigurationInput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationInput; end class RedshiftRunConfiguration < DataSourceConfigurationInput; end class Unknown < DataSourceConfigurationInput; end end |
#redshift_serverless_source ⇒ Types::RedshiftServerlessStorage
The details of the Amazon Redshift Serverless workgroup source.
8212 8213 8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 |
# File 'lib/aws-sdk-datazone/types.rb', line 8212 class RedshiftStorage < Struct.new( :redshift_cluster_source, :redshift_serverless_source, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RedshiftClusterSource < RedshiftStorage; end class RedshiftServerlessSource < RedshiftStorage; end class Unknown < RedshiftStorage; end end |
#smithy ⇒ String
7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 |
# File 'lib/aws-sdk-datazone/types.rb', line 7746 class Model < Struct.new( :smithy, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Smithy < Model; end class Unknown < Model; end end |
#sso ⇒ Types::SsoUserProfileDetails
The single sign-on details included in the user profile details.
11284 11285 11286 11287 11288 11289 11290 11291 11292 11293 11294 11295 |
# File 'lib/aws-sdk-datazone/types.rb', line 11284 class UserProfileDetails < Struct.new( :iam, :sso, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Iam < UserProfileDetails; end class Sso < UserProfileDetails; end class Unknown < UserProfileDetails; end end |
#user ⇒ Types::UserDetails
The user details of a project member.
7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 |
# File 'lib/aws-sdk-datazone/types.rb', line 7724 class MemberDetails < Struct.new( :group, :user, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Group < MemberDetails; end class User < MemberDetails; end class Unknown < MemberDetails; end end |
#user_identifier ⇒ String
The user ID of a project member.
7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 |
# File 'lib/aws-sdk-datazone/types.rb', line 7697 class Member < Struct.new( :group_identifier, :user_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GroupIdentifier < Member; end class UserIdentifier < Member; end class Unknown < Member; end end |