Module: Aws::DataZone::Types
- Defined in:
- lib/aws-sdk-datazone/types.rb
Defined Under Namespace
Classes: AcceptChoice, AcceptPredictionsInput, AcceptPredictionsOutput, AcceptRule, AcceptSubscriptionRequestInput, AcceptSubscriptionRequestOutput, AccessDeniedException, AssetItem, AssetItemAdditionalAttributes, AssetListing, AssetListingDetails, AssetListingItem, AssetListingItemAdditionalAttributes, AssetRevision, AssetTargetNameMap, AssetTypeItem, BusinessNameGenerationConfiguration, CancelSubscriptionInput, CancelSubscriptionOutput, CloudFormationProperties, ConfigurableActionParameter, ConfigurableEnvironmentAction, ConflictException, CreateAssetInput, CreateAssetOutput, CreateAssetRevisionInput, CreateAssetRevisionOutput, CreateAssetTypeInput, CreateAssetTypeOutput, CreateDataSourceInput, CreateDataSourceOutput, CreateDomainInput, CreateDomainOutput, CreateEnvironmentInput, CreateEnvironmentOutput, CreateEnvironmentProfileInput, CreateEnvironmentProfileOutput, CreateFormTypeInput, CreateFormTypeOutput, CreateGlossaryInput, CreateGlossaryOutput, CreateGlossaryTermInput, CreateGlossaryTermOutput, CreateGroupProfileInput, CreateGroupProfileOutput, CreateListingChangeSetInput, CreateListingChangeSetOutput, CreateProjectInput, CreateProjectMembershipInput, CreateProjectMembershipOutput, CreateProjectOutput, CreateSubscriptionGrantInput, CreateSubscriptionGrantOutput, CreateSubscriptionRequestInput, CreateSubscriptionRequestOutput, CreateSubscriptionTargetInput, CreateSubscriptionTargetOutput, CreateUserProfileInput, CreateUserProfileOutput, CustomParameter, DataProductItem, DataProductSummary, DataSourceConfigurationInput, DataSourceConfigurationOutput, DataSourceErrorMessage, DataSourceRunActivity, DataSourceRunSummary, DataSourceSummary, DeleteAssetInput, DeleteAssetOutput, DeleteAssetTypeInput, DeleteAssetTypeOutput, DeleteDataSourceInput, DeleteDataSourceOutput, DeleteDomainInput, DeleteDomainOutput, DeleteEnvironmentBlueprintConfigurationInput, DeleteEnvironmentBlueprintConfigurationOutput, DeleteEnvironmentInput, DeleteEnvironmentProfileInput, DeleteFormTypeInput, DeleteFormTypeOutput, DeleteGlossaryInput, DeleteGlossaryOutput, DeleteGlossaryTermInput, DeleteGlossaryTermOutput, DeleteListingInput, DeleteListingOutput, DeleteProjectInput, DeleteProjectMembershipInput, DeleteProjectMembershipOutput, DeleteProjectOutput, DeleteSubscriptionGrantInput, DeleteSubscriptionGrantOutput, DeleteSubscriptionRequestInput, DeleteSubscriptionTargetInput, Deployment, DeploymentProperties, DetailedGlossaryTerm, DomainSummary, EnvironmentBlueprintConfigurationItem, EnvironmentBlueprintSummary, EnvironmentError, EnvironmentParameter, EnvironmentProfileSummary, EnvironmentSummary, FailureCause, Filter, FilterClause, FilterExpression, FormEntryInput, FormEntryOutput, FormInput, FormOutput, FormTypeData, GetAssetInput, GetAssetOutput, GetAssetTypeInput, GetAssetTypeOutput, GetDataSourceInput, GetDataSourceOutput, GetDataSourceRunInput, GetDataSourceRunOutput, GetDomainInput, GetDomainOutput, GetEnvironmentBlueprintConfigurationInput, GetEnvironmentBlueprintConfigurationOutput, GetEnvironmentBlueprintInput, GetEnvironmentBlueprintOutput, GetEnvironmentInput, GetEnvironmentOutput, GetEnvironmentProfileInput, GetEnvironmentProfileOutput, GetFormTypeInput, GetFormTypeOutput, GetGlossaryInput, GetGlossaryOutput, GetGlossaryTermInput, GetGlossaryTermOutput, GetGroupProfileInput, GetGroupProfileOutput, GetIamPortalLoginUrlInput, GetIamPortalLoginUrlOutput, GetListingInput, GetListingOutput, GetProjectInput, GetProjectOutput, GetSubscriptionGrantInput, GetSubscriptionGrantOutput, GetSubscriptionInput, GetSubscriptionOutput, GetSubscriptionRequestDetailsInput, GetSubscriptionRequestDetailsOutput, GetSubscriptionTargetInput, GetSubscriptionTargetOutput, GetUserProfileInput, GetUserProfileOutput, GlossaryItem, GlossaryTermItem, GlueRunConfigurationInput, GlueRunConfigurationOutput, GrantedEntity, GrantedEntityInput, GroupDetails, GroupProfileSummary, IamUserProfileDetails, Import, InternalServerException, ListAssetRevisionsInput, ListAssetRevisionsOutput, ListDataSourceRunActivitiesInput, ListDataSourceRunActivitiesOutput, ListDataSourceRunsInput, ListDataSourceRunsOutput, ListDataSourcesInput, ListDataSourcesOutput, ListDomainsInput, ListDomainsOutput, ListEnvironmentBlueprintConfigurationsInput, ListEnvironmentBlueprintConfigurationsOutput, ListEnvironmentBlueprintsInput, ListEnvironmentBlueprintsOutput, ListEnvironmentProfilesInput, ListEnvironmentProfilesOutput, ListEnvironmentsInput, ListEnvironmentsOutput, ListNotificationsInput, ListNotificationsOutput, ListProjectMembershipsInput, ListProjectMembershipsOutput, ListProjectsInput, ListProjectsOutput, ListSubscriptionGrantsInput, ListSubscriptionGrantsOutput, ListSubscriptionRequestsInput, ListSubscriptionRequestsOutput, ListSubscriptionTargetsInput, ListSubscriptionTargetsOutput, ListSubscriptionsInput, ListSubscriptionsOutput, ListTagsForResourceRequest, ListTagsForResourceResponse, ListingItem, ListingRevision, ListingRevisionInput, Member, MemberDetails, Model, NotificationOutput, NotificationResource, PredictionConfiguration, ProjectMember, ProjectSummary, ProvisioningProperties, PutEnvironmentBlueprintConfigurationInput, PutEnvironmentBlueprintConfigurationOutput, RecommendationConfiguration, RedshiftClusterStorage, RedshiftCredentialConfiguration, RedshiftRunConfigurationInput, RedshiftRunConfigurationOutput, RedshiftServerlessStorage, RedshiftStorage, RejectChoice, RejectPredictionsInput, RejectPredictionsOutput, RejectRule, RejectSubscriptionRequestInput, RejectSubscriptionRequestOutput, RelationalFilterConfiguration, Resource, ResourceNotFoundException, RevokeSubscriptionInput, RevokeSubscriptionOutput, RunStatisticsForAssets, ScheduleConfiguration, SearchGroupProfilesInput, SearchGroupProfilesOutput, SearchInItem, SearchInput, SearchInventoryResultItem, SearchListingsInput, SearchListingsOutput, SearchOutput, SearchResultItem, SearchSort, SearchTypesInput, SearchTypesOutput, SearchTypesResultItem, SearchUserProfilesInput, SearchUserProfilesOutput, ServiceQuotaExceededException, SingleSignOn, SsoUserProfileDetails, StartDataSourceRunInput, StartDataSourceRunOutput, SubscribedAsset, SubscribedAssetListing, SubscribedListing, SubscribedListingInput, SubscribedListingItem, SubscribedPrincipal, SubscribedPrincipalInput, SubscribedProject, SubscribedProjectInput, SubscriptionGrantSummary, SubscriptionRequestSummary, SubscriptionSummary, SubscriptionTargetForm, SubscriptionTargetSummary, TagResourceRequest, TagResourceResponse, TermRelations, ThrottlingException, Topic, UnauthorizedException, UntagResourceRequest, UntagResourceResponse, UpdateDataSourceInput, UpdateDataSourceOutput, UpdateDomainInput, UpdateDomainOutput, UpdateEnvironmentInput, UpdateEnvironmentOutput, UpdateEnvironmentProfileInput, UpdateEnvironmentProfileOutput, UpdateGlossaryInput, UpdateGlossaryOutput, UpdateGlossaryTermInput, UpdateGlossaryTermOutput, UpdateGroupProfileInput, UpdateGroupProfileOutput, UpdateProjectInput, UpdateProjectOutput, UpdateSubscriptionGrantStatusInput, UpdateSubscriptionGrantStatusOutput, UpdateSubscriptionRequestInput, UpdateSubscriptionRequestOutput, UpdateSubscriptionTargetInput, UpdateSubscriptionTargetOutput, UpdateUserProfileInput, UpdateUserProfileOutput, UserDetails, UserProfileDetails, UserProfileSummary, ValidationException
Instance Attribute Summary collapse
-
#and ⇒ Array<Types::FilterClause>
The ‘and’ search filter clause in Amazon DataZone.
-
#asset_item ⇒ Types::AssetItem
The asset item included in the search results.
-
#asset_listing ⇒ Types::SubscribedAssetListing
The asset for which the subscription grant is created.
-
#asset_type_item ⇒ Types::AssetTypeItem
The asset type included in the results of the ‘SearchTypes` action.
-
#cloud_formation ⇒ Types::CloudFormationProperties
The cloud formation properties included as part of the provisioning properties of an environment blueprint.
-
#data_product_item ⇒ Types::DataProductSummary
The data product item included in the search results.
-
#filter ⇒ Types::Filter
A search filter in Amazon DataZone.
-
#form_type_item ⇒ Types::FormTypeData
The form type included in the results of the ‘SearchTypes` action.
-
#glossary_item ⇒ Types::GlossaryItem
The glossary item included in the search results.
-
#glossary_term_item ⇒ Types::GlossaryTermItem
The glossary term item included in the search results.
-
#glue_run_configuration ⇒ Types::GlueRunConfigurationOutput
The configuration of the Amazon Web Services Glue data source.
-
#group ⇒ Types::GroupDetails
The group details of a project member.
-
#group_identifier ⇒ String
The ID of the group of a project member.
-
#iam ⇒ Types::IamUserProfileDetails
The IAM details included in the user profile details.
-
#listing ⇒ Types::ListingRevisionInput
The listing for which a subscription is to be granted.
-
#or ⇒ Array<Types::FilterClause>
The ‘or’ search filter clause in Amazon DataZone.
-
#project ⇒ Types::SubscribedProjectInput
The project that is to be given a subscription grant.
-
#redshift_cluster_source ⇒ Types::RedshiftClusterStorage
The details of the Amazon Redshift cluster source.
-
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationOutput
The configuration of the Amazon Redshift data source.
-
#redshift_serverless_source ⇒ Types::RedshiftServerlessStorage
The details of the Amazon Redshift Serverless workgroup source.
- #smithy ⇒ String
-
#sso ⇒ Types::SsoUserProfileDetails
The single sign-on details included in the user profile details.
-
#user ⇒ Types::UserDetails
The user details of a project member.
-
#user_identifier ⇒ String
The user ID of a project member.
Instance Attribute Details
#and ⇒ Array<Types::FilterClause>
The ‘and’ search filter clause in Amazon DataZone.
4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 |
# File 'lib/aws-sdk-datazone/types.rb', line 4113 class FilterClause < Struct.new( :and, :filter, :or, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class And < FilterClause; end class Filter < FilterClause; end class Or < FilterClause; end class Unknown < FilterClause; end end |
#asset_item ⇒ Types::AssetItem
The asset item included in the search results.
8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-datazone/types.rb', line 8738 class SearchInventoryResultItem < Struct.new( :asset_item, :data_product_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class DataProductItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#asset_listing ⇒ Types::SubscribedAssetListing
The asset for which the subscription grant is created.
7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 |
# File 'lib/aws-sdk-datazone/types.rb', line 7598 class ListingItem < Struct.new( :asset_listing, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetListing < ListingItem; end class Unknown < ListingItem; end end |
#asset_type_item ⇒ Types::AssetTypeItem
The asset type included in the results of the ‘SearchTypes` action.
9006 9007 9008 9009 9010 9011 9012 9013 9014 9015 9016 9017 |
# File 'lib/aws-sdk-datazone/types.rb', line 9006 class SearchTypesResultItem < Struct.new( :asset_type_item, :form_type_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetTypeItem < SearchTypesResultItem; end class FormTypeItem < SearchTypesResultItem; end class Unknown < SearchTypesResultItem; end end |
#cloud_formation ⇒ Types::CloudFormationProperties
The cloud formation properties included as part of the provisioning properties of an environment blueprint.
7903 7904 7905 7906 7907 7908 7909 7910 7911 7912 |
# File 'lib/aws-sdk-datazone/types.rb', line 7903 class ProvisioningProperties < Struct.new( :cloud_formation, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CloudFormation < ProvisioningProperties; end class Unknown < ProvisioningProperties; end end |
#data_product_item ⇒ Types::DataProductSummary
The data product item included in the search results.
8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-datazone/types.rb', line 8738 class SearchInventoryResultItem < Struct.new( :asset_item, :data_product_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class DataProductItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#filter ⇒ Types::Filter
A search filter in Amazon DataZone.
4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 |
# File 'lib/aws-sdk-datazone/types.rb', line 4113 class FilterClause < Struct.new( :and, :filter, :or, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class And < FilterClause; end class Filter < FilterClause; end class Or < FilterClause; end class Unknown < FilterClause; end end |
#form_type_item ⇒ Types::FormTypeData
The form type included in the results of the ‘SearchTypes` action.
9006 9007 9008 9009 9010 9011 9012 9013 9014 9015 9016 9017 |
# File 'lib/aws-sdk-datazone/types.rb', line 9006 class SearchTypesResultItem < Struct.new( :asset_type_item, :form_type_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetTypeItem < SearchTypesResultItem; end class FormTypeItem < SearchTypesResultItem; end class Unknown < SearchTypesResultItem; end end |
#glossary_item ⇒ Types::GlossaryItem
The glossary item included in the search results.
8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-datazone/types.rb', line 8738 class SearchInventoryResultItem < Struct.new( :asset_item, :data_product_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class DataProductItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#glossary_term_item ⇒ Types::GlossaryTermItem
The glossary term item included in the search results.
8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-datazone/types.rb', line 8738 class SearchInventoryResultItem < Struct.new( :asset_item, :data_product_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class DataProductItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#glue_run_configuration ⇒ Types::GlueRunConfigurationOutput
The configuration of the Amazon Web Services Glue data source.
2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 |
# File 'lib/aws-sdk-datazone/types.rb', line 2841 class DataSourceConfigurationInput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationInput; end class RedshiftRunConfiguration < DataSourceConfigurationInput; end class Unknown < DataSourceConfigurationInput; end end |
#group ⇒ Types::GroupDetails
The group details of a project member.
7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-datazone/types.rb', line 7693 class MemberDetails < Struct.new( :group, :user, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Group < MemberDetails; end class User < MemberDetails; end class Unknown < MemberDetails; end end |
#group_identifier ⇒ String
The ID of the group of a project member.
7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 7676 7677 |
# File 'lib/aws-sdk-datazone/types.rb', line 7666 class Member < Struct.new( :group_identifier, :user_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GroupIdentifier < Member; end class UserIdentifier < Member; end class Unknown < Member; end end |
#iam ⇒ Types::IamUserProfileDetails
The IAM details included in the user profile details.
11214 11215 11216 11217 11218 11219 11220 11221 11222 11223 11224 11225 |
# File 'lib/aws-sdk-datazone/types.rb', line 11214 class UserProfileDetails < Struct.new( :iam, :sso, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Iam < UserProfileDetails; end class Sso < UserProfileDetails; end class Unknown < UserProfileDetails; end end |
#listing ⇒ Types::ListingRevisionInput
The listing for which a subscription is to be granted.
6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 |
# File 'lib/aws-sdk-datazone/types.rb', line 6274 class GrantedEntity < Struct.new( :listing, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Listing < GrantedEntity; end class Unknown < GrantedEntity; end end |
#or ⇒ Array<Types::FilterClause>
The ‘or’ search filter clause in Amazon DataZone.
4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 |
# File 'lib/aws-sdk-datazone/types.rb', line 4113 class FilterClause < Struct.new( :and, :filter, :or, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class And < FilterClause; end class Filter < FilterClause; end class Or < FilterClause; end class Unknown < FilterClause; end end |
#project ⇒ Types::SubscribedProjectInput
The project that is to be given a subscription grant.
9430 9431 9432 9433 9434 9435 9436 9437 9438 9439 |
# File 'lib/aws-sdk-datazone/types.rb', line 9430 class SubscribedPrincipal < Struct.new( :project, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |
#redshift_cluster_source ⇒ Types::RedshiftClusterStorage
The details of the Amazon Redshift cluster source.
8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 8162 8163 |
# File 'lib/aws-sdk-datazone/types.rb', line 8152 class RedshiftStorage < Struct.new( :redshift_cluster_source, :redshift_serverless_source, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RedshiftClusterSource < RedshiftStorage; end class RedshiftServerlessSource < RedshiftStorage; end class Unknown < RedshiftStorage; end end |
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationOutput
The configuration of the Amazon Redshift data source.
2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 |
# File 'lib/aws-sdk-datazone/types.rb', line 2841 class DataSourceConfigurationInput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationInput; end class RedshiftRunConfiguration < DataSourceConfigurationInput; end class Unknown < DataSourceConfigurationInput; end end |
#redshift_serverless_source ⇒ Types::RedshiftServerlessStorage
The details of the Amazon Redshift Serverless workgroup source.
8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 8162 8163 |
# File 'lib/aws-sdk-datazone/types.rb', line 8152 class RedshiftStorage < Struct.new( :redshift_cluster_source, :redshift_serverless_source, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RedshiftClusterSource < RedshiftStorage; end class RedshiftServerlessSource < RedshiftStorage; end class Unknown < RedshiftStorage; end end |
#smithy ⇒ String
7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 |
# File 'lib/aws-sdk-datazone/types.rb', line 7715 class Model < Struct.new( :smithy, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Smithy < Model; end class Unknown < Model; end end |
#sso ⇒ Types::SsoUserProfileDetails
The single sign-on details included in the user profile details.
11214 11215 11216 11217 11218 11219 11220 11221 11222 11223 11224 11225 |
# File 'lib/aws-sdk-datazone/types.rb', line 11214 class UserProfileDetails < Struct.new( :iam, :sso, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Iam < UserProfileDetails; end class Sso < UserProfileDetails; end class Unknown < UserProfileDetails; end end |
#user ⇒ Types::UserDetails
The user details of a project member.
7693 7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 |
# File 'lib/aws-sdk-datazone/types.rb', line 7693 class MemberDetails < Struct.new( :group, :user, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Group < MemberDetails; end class User < MemberDetails; end class Unknown < MemberDetails; end end |
#user_identifier ⇒ String
The user ID of a project member.
7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 7676 7677 |
# File 'lib/aws-sdk-datazone/types.rb', line 7666 class Member < Struct.new( :group_identifier, :user_identifier, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GroupIdentifier < Member; end class UserIdentifier < Member; end class Unknown < Member; end end |