Class: Aws::DataZone::Types::AssetItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::AssetItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
A Amazon DataZone inventory asset.
Constant Summary collapse
- SENSITIVE =
[:description, :external_identifier, :name]
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Types::AssetItemAdditionalAttributes
The additional attributes of a Amazon DataZone inventory asset.
-
#created_at ⇒ Time
The timestamp of when the Amazon DataZone inventory asset was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the inventory asset.
-
#description ⇒ String
The description of an Amazon DataZone inventory asset.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the inventory asset exists.
-
#external_identifier ⇒ String
The external identifier of the Amazon DataZone inventory asset.
-
#first_revision_created_at ⇒ Time
The timestamp of when the first revision of the inventory asset was created.
-
#first_revision_created_by ⇒ String
The Amazon DataZone user who created the first revision of the inventory asset.
-
#glossary_terms ⇒ Array<String>
The glossary terms attached to the Amazon DataZone inventory asset.
-
#identifier ⇒ String
the identifier of the Amazon DataZone inventory asset.
-
#name ⇒ String
The name of the Amazon DataZone inventory asset.
-
#owning_project_id ⇒ String
The identifier of the Amazon DataZone project that owns the inventory asset.
-
#type_identifier ⇒ String
The identifier of the asset type of the specified Amazon DataZone inventory asset.
-
#type_revision ⇒ String
The revision of the inventory asset type.
Instance Attribute Details
#additional_attributes ⇒ Types::AssetItemAdditionalAttributes
The additional attributes of a Amazon DataZone inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the Amazon DataZone inventory asset was created.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#description ⇒ String
The description of an Amazon DataZone inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the inventory asset exists.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#external_identifier ⇒ String
The external identifier of the Amazon DataZone inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#first_revision_created_at ⇒ Time
The timestamp of when the first revision of the inventory asset was created.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#first_revision_created_by ⇒ String
The Amazon DataZone user who created the first revision of the inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms attached to the Amazon DataZone inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#identifier ⇒ String
the identifier of the Amazon DataZone inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the Amazon DataZone project that owns the inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#type_identifier ⇒ String
The identifier of the asset type of the specified Amazon DataZone inventory asset.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#type_revision ⇒ String
The revision of the inventory asset type.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/aws-sdk-datazone/types.rb', line 417 class AssetItem < Struct.new( :additional_attributes, :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :identifier, :name, :owning_project_id, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |