Class: Aws::DataZone::Types::AttributeError
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::AttributeError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The attribute error.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_identifier ⇒ String
The attribute ID as part of the attribute error.
-
#code ⇒ String
The code generated as part of the attribute error.
-
#message ⇒ String
The message generated as part of the attribute error.
Instance Attribute Details
#attribute_identifier ⇒ String
The attribute ID as part of the attribute error.
1423 1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-datazone/types.rb', line 1423 class AttributeError < Struct.new( :attribute_identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |
#code ⇒ String
The code generated as part of the attribute error.
1423 1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-datazone/types.rb', line 1423 class AttributeError < Struct.new( :attribute_identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The message generated as part of the attribute error.
1423 1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-datazone/types.rb', line 1423 class AttributeError < Struct.new( :attribute_identifier, :code, :message) SENSITIVE = [] include Aws::Structure end |