Class: Aws::DataZone::Types::ConnectionPropertiesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

ConnectionPropertiesInput is a union - when making an API calls you must set exactly one of the members.

The properties of a connection.

Defined Under Namespace

Classes: AmazonQProperties, AthenaProperties, GlueProperties, HyperPodProperties, IamProperties, MlflowProperties, RedshiftProperties, S3Properties, SparkEmrProperties, SparkGlueProperties, Unknown, WorkflowsMwaaProperties, WorkflowsServerlessProperties

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_q_propertiesTypes::AmazonQPropertiesInput

The Amazon Q properties of the connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#athena_propertiesTypes::AthenaPropertiesInput

The Amazon Athena properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#glue_propertiesTypes::GluePropertiesInput

The Amazon Web Services Glue properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#hyper_pod_propertiesTypes::HyperPodPropertiesInput

The hyper pod properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#iam_propertiesTypes::IamPropertiesInput

The IAM properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#mlflow_propertiesTypes::MlflowPropertiesInput

The MLflow properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#redshift_propertiesTypes::RedshiftPropertiesInput

The Amazon Redshift properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#s3_propertiesTypes::S3PropertiesInput

The Amazon S3 properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#spark_emr_propertiesTypes::SparkEmrPropertiesInput

The Spark EMR properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#spark_glue_propertiesTypes::SparkGluePropertiesInput

The Spark Amazon Web Services Glue properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2093
2094
2095
# File 'lib/aws-sdk-datazone/types.rb', line 2093

def unknown
  @unknown
end

#workflows_mwaa_propertiesTypes::WorkflowsMwaaPropertiesInput

The Amazon MWAA properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end

#workflows_serverless_propertiesTypes::WorkflowsServerlessPropertiesInput

The MWAA serverless properties of a connection.



2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
# File 'lib/aws-sdk-datazone/types.rb', line 2093

class ConnectionPropertiesInput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesInput; end
  class GlueProperties < ConnectionPropertiesInput; end
  class HyperPodProperties < ConnectionPropertiesInput; end
  class IamProperties < ConnectionPropertiesInput; end
  class RedshiftProperties < ConnectionPropertiesInput; end
  class SparkEmrProperties < ConnectionPropertiesInput; end
  class SparkGlueProperties < ConnectionPropertiesInput; end
  class S3Properties < ConnectionPropertiesInput; end
  class AmazonQProperties < ConnectionPropertiesInput; end
  class MlflowProperties < ConnectionPropertiesInput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesInput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesInput; end
  class Unknown < ConnectionPropertiesInput; end
end