Class: Aws::DataZone::Types::ConnectionPropertiesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ConnectionPropertiesOutput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
ConnectionPropertiesOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConnectionPropertiesOutput corresponding to the set member.
The properties of a connection.
Defined Under Namespace
Classes: AmazonQProperties, AthenaProperties, GlueProperties, HyperPodProperties, IamProperties, LakehouseProperties, MlflowProperties, RedshiftProperties, S3Properties, SnowflakeProperties, SparkEmrProperties, SparkGlueProperties, Unknown, VpcProperties, WorkflowsMwaaProperties, WorkflowsServerlessProperties
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_q_properties ⇒ Types::AmazonQPropertiesOutput
The Amazon Q properties of the connection.
-
#athena_properties ⇒ Types::AthenaPropertiesOutput
The Amazon Athena properties of a connection.
-
#glue_properties ⇒ Types::GluePropertiesOutput
The Amazon Web Services Glue properties of a connection.
-
#hyper_pod_properties ⇒ Types::HyperPodPropertiesOutput
The hyper pod properties of a connection.
-
#iam_properties ⇒ Types::IamPropertiesOutput
The IAM properties of a connection.
-
#lakehouse_properties ⇒ Types::LakehousePropertiesOutput
The lakehouse properties of a connection.
-
#mlflow_properties ⇒ Types::MlflowPropertiesOutput
The MLflow properties of a connection.
-
#redshift_properties ⇒ Types::RedshiftPropertiesOutput
The Amazon Redshift properties of a connection.
-
#s3_properties ⇒ Types::S3PropertiesOutput
The Amazon S3 properties of a connection.
-
#snowflake_properties ⇒ Types::SnowflakePropertiesOutput
The Snowflake-specific connection properties for an existing connection.
-
#spark_emr_properties ⇒ Types::SparkEmrPropertiesOutput
The Spark EMR properties of a connection.
-
#spark_glue_properties ⇒ Types::SparkGluePropertiesOutput
The Spark Amazon Web Services Glue properties of a connection.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#vpc_properties ⇒ Types::VpcPropertiesOutput
The VPC properties of a connection.
-
#workflows_mwaa_properties ⇒ Types::WorkflowsMwaaPropertiesOutput
The Amazon MWAA properties of a connection.
-
#workflows_serverless_properties ⇒ Types::WorkflowsServerlessPropertiesOutput
The MWAA serverless properties of a connection.
Instance Attribute Details
#amazon_q_properties ⇒ Types::AmazonQPropertiesOutput
The Amazon Q properties of the connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#athena_properties ⇒ Types::AthenaPropertiesOutput
The Amazon Athena properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#glue_properties ⇒ Types::GluePropertiesOutput
The Amazon Web Services Glue properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#hyper_pod_properties ⇒ Types::HyperPodPropertiesOutput
The hyper pod properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#iam_properties ⇒ Types::IamPropertiesOutput
The IAM properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#lakehouse_properties ⇒ Types::LakehousePropertiesOutput
The lakehouse properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#mlflow_properties ⇒ Types::MlflowPropertiesOutput
The MLflow properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#redshift_properties ⇒ Types::RedshiftPropertiesOutput
The Amazon Redshift properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#s3_properties ⇒ Types::S3PropertiesOutput
The Amazon S3 properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#snowflake_properties ⇒ Types::SnowflakePropertiesOutput
The Snowflake-specific connection properties for an existing connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#spark_emr_properties ⇒ Types::SparkEmrPropertiesOutput
The Spark EMR properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#spark_glue_properties ⇒ Types::SparkGluePropertiesOutput
The Spark Amazon Web Services Glue properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2241 2242 2243 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 def unknown @unknown end |
#vpc_properties ⇒ Types::VpcPropertiesOutput
The VPC properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#workflows_mwaa_properties ⇒ Types::WorkflowsMwaaPropertiesOutput
The Amazon MWAA properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |
#workflows_serverless_properties ⇒ Types::WorkflowsServerlessPropertiesOutput
The MWAA serverless properties of a connection.
2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/aws-sdk-datazone/types.rb', line 2241 class ConnectionPropertiesOutput < Struct.new( :athena_properties, :glue_properties, :hyper_pod_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :spark_glue_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :workflows_mwaa_properties, :workflows_serverless_properties, :lakehouse_properties, :vpc_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesOutput; end class GlueProperties < ConnectionPropertiesOutput; end class HyperPodProperties < ConnectionPropertiesOutput; end class IamProperties < ConnectionPropertiesOutput; end class RedshiftProperties < ConnectionPropertiesOutput; end class SparkEmrProperties < ConnectionPropertiesOutput; end class SparkGlueProperties < ConnectionPropertiesOutput; end class S3Properties < ConnectionPropertiesOutput; end class SnowflakeProperties < ConnectionPropertiesOutput; end class AmazonQProperties < ConnectionPropertiesOutput; end class MlflowProperties < ConnectionPropertiesOutput; end class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end class LakehouseProperties < ConnectionPropertiesOutput; end class VpcProperties < ConnectionPropertiesOutput; end class Unknown < ConnectionPropertiesOutput; end end |