Class: Aws::DataZone::Types::ConnectionPropertiesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

ConnectionPropertiesOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConnectionPropertiesOutput corresponding to the set member.

The properties of a connection.

Defined Under Namespace

Classes: AmazonQProperties, AthenaProperties, GlueProperties, HyperPodProperties, IamProperties, LakehouseProperties, MlflowProperties, RedshiftProperties, S3Properties, SparkEmrProperties, SparkGlueProperties, Unknown, WorkflowsMwaaProperties, WorkflowsServerlessProperties

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_q_propertiesTypes::AmazonQPropertiesOutput

The Amazon Q properties of the connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#athena_propertiesTypes::AthenaPropertiesOutput

The Amazon Athena properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#glue_propertiesTypes::GluePropertiesOutput

The Amazon Web Services Glue properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#hyper_pod_propertiesTypes::HyperPodPropertiesOutput

The hyper pod properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#iam_propertiesTypes::IamPropertiesOutput

The IAM properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#lakehouse_propertiesTypes::LakehousePropertiesOutput

The lakehouse properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#mlflow_propertiesTypes::MlflowPropertiesOutput

The MLflow properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#redshift_propertiesTypes::RedshiftPropertiesOutput

The Amazon Redshift properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#s3_propertiesTypes::S3PropertiesOutput

The Amazon S3 properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#spark_emr_propertiesTypes::SparkEmrPropertiesOutput

The Spark EMR properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#spark_glue_propertiesTypes::SparkGluePropertiesOutput

The Spark Amazon Web Services Glue properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2190
2191
2192
# File 'lib/aws-sdk-datazone/types.rb', line 2190

def unknown
  @unknown
end

#workflows_mwaa_propertiesTypes::WorkflowsMwaaPropertiesOutput

The Amazon MWAA properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#workflows_serverless_propertiesTypes::WorkflowsServerlessPropertiesOutput

The MWAA serverless properties of a connection.



2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/aws-sdk-datazone/types.rb', line 2190

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :s3_properties,
  :amazon_q_properties,
  :mlflow_properties,
  :workflows_mwaa_properties,
  :workflows_serverless_properties,
  :lakehouse_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class AmazonQProperties < ConnectionPropertiesOutput; end
  class MlflowProperties < ConnectionPropertiesOutput; end
  class WorkflowsMwaaProperties < ConnectionPropertiesOutput; end
  class WorkflowsServerlessProperties < ConnectionPropertiesOutput; end
  class LakehouseProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end