Class: Aws::DataZone::Types::ConnectionPropertiesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

ConnectionPropertiesOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ConnectionPropertiesOutput corresponding to the set member.

The properties of a connection.

Defined Under Namespace

Classes: AthenaProperties, GlueProperties, HyperPodProperties, IamProperties, RedshiftProperties, S3Properties, SparkEmrProperties, SparkGlueProperties, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#athena_propertiesTypes::AthenaPropertiesOutput

The Amazon Athena properties of a connection.



1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
# File 'lib/aws-sdk-datazone/types.rb', line 1590

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :s3_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#glue_propertiesTypes::GluePropertiesOutput

The Amazon Web Services Glue properties of a connection.



1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
# File 'lib/aws-sdk-datazone/types.rb', line 1590

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :s3_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#hyper_pod_propertiesTypes::HyperPodPropertiesOutput

The hyper pod properties of a connection.



1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
# File 'lib/aws-sdk-datazone/types.rb', line 1590

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :s3_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#iam_propertiesTypes::IamPropertiesOutput

The IAM properties of a connection.



1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
# File 'lib/aws-sdk-datazone/types.rb', line 1590

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :s3_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#redshift_propertiesTypes::RedshiftPropertiesOutput

The Amazon Redshift properties of a connection.



1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
# File 'lib/aws-sdk-datazone/types.rb', line 1590

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :s3_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#s3_propertiesTypes::S3PropertiesOutput

The Amazon S3 properties of a connection.



1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
# File 'lib/aws-sdk-datazone/types.rb', line 1590

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :s3_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#spark_emr_propertiesTypes::SparkEmrPropertiesOutput

The Spark EMR properties of a connection.



1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
# File 'lib/aws-sdk-datazone/types.rb', line 1590

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :s3_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#spark_glue_propertiesTypes::SparkGluePropertiesOutput

The Spark Amazon Web Services Glue properties of a connection.



1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
# File 'lib/aws-sdk-datazone/types.rb', line 1590

class ConnectionPropertiesOutput < Struct.new(
  :athena_properties,
  :glue_properties,
  :hyper_pod_properties,
  :iam_properties,
  :redshift_properties,
  :s3_properties,
  :spark_emr_properties,
  :spark_glue_properties,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AthenaProperties < ConnectionPropertiesOutput; end
  class GlueProperties < ConnectionPropertiesOutput; end
  class HyperPodProperties < ConnectionPropertiesOutput; end
  class IamProperties < ConnectionPropertiesOutput; end
  class RedshiftProperties < ConnectionPropertiesOutput; end
  class S3Properties < ConnectionPropertiesOutput; end
  class SparkEmrProperties < ConnectionPropertiesOutput; end
  class SparkGlueProperties < ConnectionPropertiesOutput; end
  class Unknown < ConnectionPropertiesOutput; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1590
1591
1592
# File 'lib/aws-sdk-datazone/types.rb', line 1590

def unknown
  @unknown
end