Class: Aws::DataZone::Types::ConnectionPropertiesPatch
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ConnectionPropertiesPatch
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
ConnectionPropertiesPatch is a union - when making an API calls you must set exactly one of the members.
The connection properties patch.
Defined Under Namespace
Classes: AmazonQProperties, AthenaProperties, GitProperties, GlueProperties, IamProperties, LakehouseProperties, MlflowProperties, RedshiftProperties, S3Properties, SnowflakeProperties, SparkEmrProperties, Unknown, VpcProperties
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_q_properties ⇒ Types::AmazonQPropertiesPatch
The Amazon Q properties of the connection.
-
#athena_properties ⇒ Types::AthenaPropertiesPatch
The Amazon Athena properties of a connection properties patch.
-
#git_properties ⇒ Types::GitPropertiesPatch
The Git properties of a connection properties patch.
-
#glue_properties ⇒ Types::GluePropertiesPatch
The Amazon Web Services Glue properties of a connection properties patch.
-
#iam_properties ⇒ Types::IamPropertiesPatch
The IAM properties of a connection properties patch.
-
#lakehouse_properties ⇒ Types::LakehousePropertiesPatch
The lakehouse properties of a connection properties patch.
-
#mlflow_properties ⇒ Types::MlflowPropertiesPatch
The MLflow properties of a connection.
-
#redshift_properties ⇒ Types::RedshiftPropertiesPatch
The Amazon Redshift properties of a connection properties patch.
-
#s3_properties ⇒ Types::S3PropertiesPatch
The Amazon S3 properties of a connection properties patch.
-
#snowflake_properties ⇒ Types::SnowflakePropertiesPatch
The Snowflake-specific connection properties to update.
-
#spark_emr_properties ⇒ Types::SparkEmrPropertiesPatch
The Spark EMR properties of a connection properties patch.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#vpc_properties ⇒ Types::VpcPropertiesPatch
The VPC properties of a connection properties patch.
Instance Attribute Details
#amazon_q_properties ⇒ Types::AmazonQPropertiesPatch
The Amazon Q properties of the connection.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#athena_properties ⇒ Types::AthenaPropertiesPatch
The Amazon Athena properties of a connection properties patch.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#git_properties ⇒ Types::GitPropertiesPatch
The Git properties of a connection properties patch.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#glue_properties ⇒ Types::GluePropertiesPatch
The Amazon Web Services Glue properties of a connection properties patch.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#iam_properties ⇒ Types::IamPropertiesPatch
The IAM properties of a connection properties patch.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#lakehouse_properties ⇒ Types::LakehousePropertiesPatch
The lakehouse properties of a connection properties patch.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#mlflow_properties ⇒ Types::MlflowPropertiesPatch
The MLflow properties of a connection.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#redshift_properties ⇒ Types::RedshiftPropertiesPatch
The Amazon Redshift properties of a connection properties patch.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#s3_properties ⇒ Types::S3PropertiesPatch
The Amazon S3 properties of a connection properties patch.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#snowflake_properties ⇒ Types::SnowflakePropertiesPatch
The Snowflake-specific connection properties to update.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#spark_emr_properties ⇒ Types::SparkEmrPropertiesPatch
The Spark EMR properties of a connection properties patch.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2347 2348 2349 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 def unknown @unknown end |
#vpc_properties ⇒ Types::VpcPropertiesPatch
The VPC properties of a connection properties patch.
2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/aws-sdk-datazone/types.rb', line 2347 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :snowflake_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :vpc_properties, :git_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SnowflakeProperties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class VpcProperties < ConnectionPropertiesPatch; end class GitProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |