Class: Aws::DataZone::Types::ConnectionPropertiesPatch
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ConnectionPropertiesPatch
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
ConnectionPropertiesPatch is a union - when making an API calls you must set exactly one of the members.
The connection properties patch.
Direct Known Subclasses
AmazonQProperties, AthenaProperties, GlueProperties, IamProperties, LakehouseProperties, MlflowProperties, RedshiftProperties, S3Properties, SparkEmrProperties, Unknown
Defined Under Namespace
Classes: AmazonQProperties, AthenaProperties, GlueProperties, IamProperties, LakehouseProperties, MlflowProperties, RedshiftProperties, S3Properties, SparkEmrProperties, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_q_properties ⇒ Types::AmazonQPropertiesPatch
The Amazon Q properties of the connection.
-
#athena_properties ⇒ Types::AthenaPropertiesPatch
The Amazon Athena properties of a connection properties patch.
-
#glue_properties ⇒ Types::GluePropertiesPatch
The Amazon Web Services Glue properties of a connection properties patch.
-
#iam_properties ⇒ Types::IamPropertiesPatch
The IAM properties of a connection properties patch.
-
#lakehouse_properties ⇒ Types::LakehousePropertiesPatch
The lakehouse properties of a connection properties patch.
-
#mlflow_properties ⇒ Types::MlflowPropertiesPatch
The MLflow properties of a connection.
-
#redshift_properties ⇒ Types::RedshiftPropertiesPatch
The Amazon Redshift properties of a connection properties patch.
-
#s3_properties ⇒ Types::S3PropertiesPatch
The Amazon S3 properties of a connection properties patch.
-
#spark_emr_properties ⇒ Types::SparkEmrPropertiesPatch
The Spark EMR properties of a connection properties patch.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#amazon_q_properties ⇒ Types::AmazonQPropertiesPatch
The Amazon Q properties of the connection.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#athena_properties ⇒ Types::AthenaPropertiesPatch
The Amazon Athena properties of a connection properties patch.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#glue_properties ⇒ Types::GluePropertiesPatch
The Amazon Web Services Glue properties of a connection properties patch.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#iam_properties ⇒ Types::IamPropertiesPatch
The IAM properties of a connection properties patch.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#lakehouse_properties ⇒ Types::LakehousePropertiesPatch
The lakehouse properties of a connection properties patch.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#mlflow_properties ⇒ Types::MlflowPropertiesPatch
The MLflow properties of a connection.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#redshift_properties ⇒ Types::RedshiftPropertiesPatch
The Amazon Redshift properties of a connection properties patch.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#s3_properties ⇒ Types::S3PropertiesPatch
The Amazon S3 properties of a connection properties patch.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#spark_emr_properties ⇒ Types::SparkEmrPropertiesPatch
The Spark EMR properties of a connection properties patch.
2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :spark_emr_properties, :s3_properties, :amazon_q_properties, :mlflow_properties, :lakehouse_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class AmazonQProperties < ConnectionPropertiesPatch; end class MlflowProperties < ConnectionPropertiesPatch; end class LakehouseProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2293 2294 2295 |
# File 'lib/aws-sdk-datazone/types.rb', line 2293 def unknown @unknown end |