Class: Aws::DataZone::Types::ConnectionPropertiesPatch
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ConnectionPropertiesPatch
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
ConnectionPropertiesPatch is a union - when making an API calls you must set exactly one of the members.
The connection properties patch.
Direct Known Subclasses
AthenaProperties, GlueProperties, IamProperties, RedshiftProperties, S3Properties, SparkEmrProperties, Unknown
Defined Under Namespace
Classes: AthenaProperties, GlueProperties, IamProperties, RedshiftProperties, S3Properties, SparkEmrProperties, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#athena_properties ⇒ Types::AthenaPropertiesPatch
The Amazon Athena properties of a connection properties patch.
-
#glue_properties ⇒ Types::GluePropertiesPatch
The Amazon Web Services Glue properties of a connection properties patch.
-
#iam_properties ⇒ Types::IamPropertiesPatch
The IAM properties of a connection properties patch.
-
#redshift_properties ⇒ Types::RedshiftPropertiesPatch
The Amazon Redshift properties of a connection properties patch.
-
#s3_properties ⇒ Types::S3PropertiesPatch
The Amazon S3 properties of a connection properties patch.
-
#spark_emr_properties ⇒ Types::SparkEmrPropertiesPatch
The Spark EMR properties of a connection properties patch.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#athena_properties ⇒ Types::AthenaPropertiesPatch
The Amazon Athena properties of a connection properties patch.
1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-datazone/types.rb', line 1646 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :s3_properties, :spark_emr_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#glue_properties ⇒ Types::GluePropertiesPatch
The Amazon Web Services Glue properties of a connection properties patch.
1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-datazone/types.rb', line 1646 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :s3_properties, :spark_emr_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#iam_properties ⇒ Types::IamPropertiesPatch
The IAM properties of a connection properties patch.
1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-datazone/types.rb', line 1646 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :s3_properties, :spark_emr_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#redshift_properties ⇒ Types::RedshiftPropertiesPatch
The Amazon Redshift properties of a connection properties patch.
1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-datazone/types.rb', line 1646 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :s3_properties, :spark_emr_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#s3_properties ⇒ Types::S3PropertiesPatch
The Amazon S3 properties of a connection properties patch.
1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-datazone/types.rb', line 1646 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :s3_properties, :spark_emr_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#spark_emr_properties ⇒ Types::SparkEmrPropertiesPatch
The Spark EMR properties of a connection properties patch.
1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'lib/aws-sdk-datazone/types.rb', line 1646 class ConnectionPropertiesPatch < Struct.new( :athena_properties, :glue_properties, :iam_properties, :redshift_properties, :s3_properties, :spark_emr_properties, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AthenaProperties < ConnectionPropertiesPatch; end class GlueProperties < ConnectionPropertiesPatch; end class IamProperties < ConnectionPropertiesPatch; end class RedshiftProperties < ConnectionPropertiesPatch; end class S3Properties < ConnectionPropertiesPatch; end class SparkEmrProperties < ConnectionPropertiesPatch; end class Unknown < ConnectionPropertiesPatch; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1646 1647 1648 |
# File 'lib/aws-sdk-datazone/types.rb', line 1646 def unknown @unknown end |