Class: Aws::DataZone::Types::CreateAssetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateAssetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :external_identifier, :name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the asset was created.
-
#created_by ⇒ String
The Amazon DataZone user that created this asset in the catalog.
-
#description ⇒ String
The description of the created asset.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset was created.
-
#external_identifier ⇒ String
The external identifier of the asset.
-
#first_revision_created_at ⇒ Time
The timestamp of when the first revision of the asset took place.
-
#first_revision_created_by ⇒ String
The Amazon DataZone user that made the first revision of the asset.
-
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms that are attached to the created asset.
-
#glossary_terms ⇒ Array<String>
The glossary terms that are attached to the created asset.
-
#id ⇒ String
The unique identifier of the created asset.
-
#latest_time_series_data_point_forms_output ⇒ Array<Types::TimeSeriesDataPointSummaryFormOutput>
The latest data point that was imported into the time series form for the asset.
-
#listing ⇒ Types::AssetListingDetails
The details of an asset published in an Amazon DataZone catalog.
-
#name ⇒ String
The name of the created asset.
-
#owning_project_id ⇒ String
The ID of the Amazon DataZone project that owns the created asset.
-
#prediction_configuration ⇒ Types::PredictionConfiguration
The configuration of the automatically generated business-friendly metadata for the asset.
-
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms that are attached to the created asset.
-
#revision ⇒ String
The revision of the asset.
-
#type_identifier ⇒ String
The identifier of the created asset type.
-
#type_revision ⇒ String
The revision type of the asset.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the asset was created.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user that created this asset in the catalog.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#description ⇒ String
The description of the created asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset was created.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#external_identifier ⇒ String
The external identifier of the asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#first_revision_created_at ⇒ Time
The timestamp of when the first revision of the asset took place.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#first_revision_created_by ⇒ String
The Amazon DataZone user that made the first revision of the asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms that are attached to the created asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms that are attached to the created asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#id ⇒ String
The unique identifier of the created asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#latest_time_series_data_point_forms_output ⇒ Array<Types::TimeSeriesDataPointSummaryFormOutput>
The latest data point that was imported into the time series form for the asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#listing ⇒ Types::AssetListingDetails
The details of an asset published in an Amazon DataZone catalog.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#name ⇒ String
The name of the created asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the Amazon DataZone project that owns the created asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#prediction_configuration ⇒ Types::PredictionConfiguration
The configuration of the automatically generated business-friendly metadata for the asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms that are attached to the created asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#revision ⇒ String
The revision of the asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#type_identifier ⇒ String
The identifier of the created asset type.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#type_revision ⇒ String
The revision type of the asset.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-datazone/types.rb', line 1491 class CreateAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |