Class: Aws::DataZone::Types::CreateAssetOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :external_identifier, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the asset was created.

Returns:

  • (Time)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user that created this asset in the catalog.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#descriptionString

The description of the created asset.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which the asset was created.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#external_identifierString

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#first_revision_created_atTime

The timestamp of when the first revision of the asset took place.

Returns:

  • (Time)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#first_revision_created_byString

The Amazon DataZone user that made the first revision of the asset.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#forms_outputArray<Types::FormOutput>

The metadata forms that are attached to the created asset.

Returns:



929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms that are attached to the created asset.

Returns:

  • (Array<String>)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#idString

The unique identifier of the created asset.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#listingTypes::AssetListingDetails



929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#nameString

The name of the created asset.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#owning_project_idString

The ID of the Amazon DataZone project that owns the created asset.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#prediction_configurationTypes::PredictionConfiguration

The configuration of the automatically generated business-friendly metadata for the asset.



929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#read_only_forms_outputArray<Types::FormOutput>

The read-only metadata forms that are attached to the created asset.

Returns:



929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#revisionString

The revision of the asset.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#type_identifierString

The identifier of the created asset type.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#type_revisionString

The revision type of the asset.

Returns:

  • (String)


929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
# File 'lib/aws-sdk-datazone/types.rb', line 929

class CreateAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :prediction_configuration,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end