Class: Aws::DataZone::Types::CreateAssetRevisionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateAssetRevisionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the asset revision occured.
-
#created_by ⇒ String
The Amazon DataZone user who performed the asset revision.
-
#description ⇒ String
The revised asset description.
-
#domain_id ⇒ String
The unique identifier of the Amazon DataZone domain where the asset was revised.
-
#external_identifier ⇒ String
The external identifier of the asset.
-
#first_revision_created_at ⇒ Time
The timestamp of when the first asset revision occured.
-
#first_revision_created_by ⇒ String
The Amazon DataZone user who performed the first asset revision.
-
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms that were attached to the asset as part of the asset revision.
-
#glossary_terms ⇒ Array<String>
The glossary terms that were attached to the asset as part of asset revision.
-
#governed_glossary_terms ⇒ Array<String>
The glossary terms in a restricted glossary.
-
#id ⇒ String
The unique identifier of the asset revision.
-
#latest_time_series_data_point_forms_output ⇒ Array<Types::TimeSeriesDataPointSummaryFormOutput>
The latest data point that was imported into the time series form for the asset.
-
#listing ⇒ Types::AssetListingDetails
The details of an asset published in an Amazon DataZone catalog.
-
#name ⇒ String
The revised name of the asset.
-
#owning_project_id ⇒ String
The unique identifier of the revised project that owns the asset.
-
#prediction_configuration ⇒ Types::PredictionConfiguration
The configuration of the automatically generated business-friendly metadata for the asset.
-
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms that were attached to the asset as part of the asset revision.
-
#revision ⇒ String
The revision of the asset.
-
#type_identifier ⇒ String
The identifier of the revision type.
-
#type_revision ⇒ String
The revision type of the asset.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the asset revision occured.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who performed the asset revision.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The revised asset description.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The unique identifier of the Amazon DataZone domain where the asset was revised.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#external_identifier ⇒ String
The external identifier of the asset.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#first_revision_created_at ⇒ Time
The timestamp of when the first asset revision occured.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#first_revision_created_by ⇒ String
The Amazon DataZone user who performed the first asset revision.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms that were attached to the asset as part of the asset revision.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms that were attached to the asset as part of asset revision.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#governed_glossary_terms ⇒ Array<String>
The glossary terms in a restricted glossary.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The unique identifier of the asset revision.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#latest_time_series_data_point_forms_output ⇒ Array<Types::TimeSeriesDataPointSummaryFormOutput>
The latest data point that was imported into the time series form for the asset.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#listing ⇒ Types::AssetListingDetails
The details of an asset published in an Amazon DataZone catalog.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The revised name of the asset.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The unique identifier of the revised project that owns the asset.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#prediction_configuration ⇒ Types::PredictionConfiguration
The configuration of the automatically generated business-friendly metadata for the asset.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms that were attached to the asset as part of the asset revision.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#revision ⇒ String
The revision of the asset.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#type_identifier ⇒ String
The identifier of the revision type.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |
#type_revision ⇒ String
The revision type of the asset.
2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 |
# File 'lib/aws-sdk-datazone/types.rb', line 2937 class CreateAssetRevisionOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output, :prediction_configuration) SENSITIVE = [:name, :description] include Aws::Structure end |