Class: Aws::DataZone::Types::CreateAssetRevisionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateAssetRevisionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :external_identifier, :name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the asset revision occured.
-
#created_by ⇒ String
The Amazon DataZone user who performed the asset revision.
-
#description ⇒ String
The revised asset description.
-
#domain_id ⇒ String
The unique identifier of the Amazon DataZone domain where the asset was revised.
- #external_identifier ⇒ String
-
#first_revision_created_at ⇒ Time
The timestamp of when the first asset revision occured.
-
#first_revision_created_by ⇒ String
The Amazon DataZone user who performed the first asset revision.
-
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms that were attached to the asset as part of the asset revision.
-
#glossary_terms ⇒ Array<String>
The glossary terms that were attached to the asset as part of asset revision.
-
#id ⇒ String
The unique identifier of the asset revision.
- #listing ⇒ Types::AssetListingDetails
-
#name ⇒ String
The revised name of the asset.
-
#owning_project_id ⇒ String
The unique identifier of the revised project that owns the asset.
-
#prediction_configuration ⇒ Types::PredictionConfiguration
The configuration of the automatically generated business-friendly metadata for the asset.
-
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms that were attached to the asset as part of the asset revision.
-
#revision ⇒ String
The revision of the asset.
-
#type_identifier ⇒ String
The identifier of the revision type.
-
#type_revision ⇒ String
The revision type of the asset.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the asset revision occured.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who performed the asset revision.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#description ⇒ String
The revised asset description.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#domain_id ⇒ String
The unique identifier of the Amazon DataZone domain where the asset was revised.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#external_identifier ⇒ String
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#first_revision_created_at ⇒ Time
The timestamp of when the first asset revision occured.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#first_revision_created_by ⇒ String
The Amazon DataZone user who performed the first asset revision.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms that were attached to the asset as part of the asset revision.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms that were attached to the asset as part of asset revision.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#id ⇒ String
The unique identifier of the asset revision.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#listing ⇒ Types::AssetListingDetails
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#name ⇒ String
The revised name of the asset.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#owning_project_id ⇒ String
The unique identifier of the revised project that owns the asset.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#prediction_configuration ⇒ Types::PredictionConfiguration
The configuration of the automatically generated business-friendly metadata for the asset.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms that were attached to the asset as part of the asset revision.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#revision ⇒ String
The revision of the asset.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#type_identifier ⇒ String
The identifier of the revision type.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |
#type_revision ⇒ String
The revision type of the asset.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 |
# File 'lib/aws-sdk-datazone/types.rb', line 1089 class CreateAssetRevisionOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :listing, :name, :owning_project_id, :prediction_configuration, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :external_identifier, :name] include Aws::Structure end |