Class: Aws::DataZone::Types::CreateDataSourceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateDataSourceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:asset_forms_input, :description, :name, :schedule]
Instance Attribute Summary collapse
-
#asset_forms_input ⇒ Array<Types::FormInput>
The metadata forms that are to be attached to the assets that this data source works with.
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#configuration ⇒ Types::DataSourceConfigurationInput
Specifies the configuration of the data source.
-
#description ⇒ String
The description of the data source.
-
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain where the data source is created.
-
#enable_setting ⇒ String
Specifies whether the data source is enabled.
-
#environment_identifier ⇒ String
The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
-
#name ⇒ String
The name of the data source.
-
#project_identifier ⇒ String
The identifier of the Amazon DataZone project in which you want to add this data source.
-
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
-
#recommendation ⇒ Types::RecommendationConfiguration
Specifies whether the business name generation is to be enabled for this data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
-
#type ⇒ String
The type of the data source.
Instance Attribute Details
#asset_forms_input ⇒ Array<Types::FormInput>
The metadata forms that are to be attached to the assets that this data source works with.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#configuration ⇒ Types::DataSourceConfigurationInput
Specifies the configuration of the data source. It can be set to either ‘glueRunConfiguration` or `redshiftRunConfiguration`.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#description ⇒ String
The description of the data source.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain where the data source is created.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
Specifies whether the data source is enabled.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#environment_identifier ⇒ String
The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#name ⇒ String
The name of the data source.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#project_identifier ⇒ String
The identifier of the Amazon DataZone project in which you want to add this data source.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#recommendation ⇒ Types::RecommendationConfiguration
Specifies whether the business name generation is to be enabled for this data source.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |
#type ⇒ String
The type of the data source.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/aws-sdk-datazone/types.rb', line 2043 class CreateDataSourceInput < Struct.new( :asset_forms_input, :client_token, :configuration, :description, :domain_identifier, :enable_setting, :environment_identifier, :name, :project_identifier, :publish_on_import, :recommendation, :schedule, :type) SENSITIVE = [:asset_forms_input, :description, :name, :schedule] include Aws::Structure end |