Class: Aws::DataZone::Types::CreateDataSourceInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:asset_forms_input, :description, :name, :schedule]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_forms_inputArray<Types::FormInput>

The metadata forms that are to be attached to the assets that this data source works with.

Returns:



1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#configurationTypes::DataSourceConfigurationInput

Specifies the configuration of the data source. It can be set to either ‘glueRunConfiguration` or `redshiftRunConfiguration`.



1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#descriptionString

The description of the data source.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#domain_identifierString

The ID of the Amazon DataZone domain where the data source is created.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#enable_settingString

Specifies whether the data source is enabled.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#environment_identifierString

The unique identifier of the Amazon DataZone environment to which the data source publishes assets.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#nameString

The name of the data source.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#project_identifierString

The identifier of the Amazon DataZone project in which you want to add this data source.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#publish_on_importBoolean

Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.

Returns:

  • (Boolean)


1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#recommendationTypes::RecommendationConfiguration

Specifies whether the business name generation is to be enabled for this data source.



1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#scheduleTypes::ScheduleConfiguration

The schedule of the data source runs.



1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end

#typeString

The type of the data source.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
# File 'lib/aws-sdk-datazone/types.rb', line 1420

class CreateDataSourceInput < Struct.new(
  :asset_forms_input,
  :client_token,
  :configuration,
  :description,
  :domain_identifier,
  :enable_setting,
  :environment_identifier,
  :name,
  :project_identifier,
  :publish_on_import,
  :recommendation,
  :schedule,
  :type)
  SENSITIVE = [:asset_forms_input, :description, :name, :schedule]
  include Aws::Structure
end