Class: Aws::DataZone::Types::CreateDataSourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateDataSourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name, :schedule]
Instance Attribute Summary collapse
-
#asset_forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the assets that this data source creates.
-
#configuration ⇒ Types::DataSourceConfigurationOutput
Specifies the configuration of the data source.
-
#created_at ⇒ Time
The timestamp of when the data source was created.
-
#description ⇒ String
The description of the data source.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source is created.
-
#enable_setting ⇒ String
Specifies whether the data source is enabled.
-
#environment_id ⇒ String
The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The unique identifier of the data source.
-
#last_run_at ⇒ Time
The timestamp that specifies when the data source was last run.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#last_run_status ⇒ String
The status of the last run of this data source.
-
#name ⇒ String
The name of the data source.
-
#project_id ⇒ String
The ID of the Amazon DataZone project to which the data source is added.
-
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
-
#recommendation ⇒ Types::RecommendationConfiguration
Specifies whether the business name generation is to be enabled for this data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
-
#status ⇒ String
The status of the data source.
-
#type ⇒ String
The type of the data source.
-
#updated_at ⇒ Time
The timestamp of when the data source was updated.
Instance Attribute Details
#asset_forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the assets that this data source creates.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#configuration ⇒ Types::DataSourceConfigurationOutput
Specifies the configuration of the data source. It can be set to either ‘glueRunConfiguration` or `redshiftRunConfiguration`.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the data source was created.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#description ⇒ String
The description of the data source.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source is created.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
Specifies whether the data source is enabled.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#environment_id ⇒ String
The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#id ⇒ String
The unique identifier of the data source.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp that specifies when the data source was last run.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_status ⇒ String
The status of the last run of this data source.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#name ⇒ String
The name of the data source.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#project_id ⇒ String
The ID of the Amazon DataZone project to which the data source is added.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#recommendation ⇒ Types::RecommendationConfiguration
Specifies whether the business name generation is to be enabled for this data source.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#status ⇒ String
The status of the data source.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#type ⇒ String
The type of the data source.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source was updated.
1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 |
# File 'lib/aws-sdk-datazone/types.rb', line 1735 class CreateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |