Class: Aws::DataZone::Types::CreateDomainInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
# File 'lib/aws-sdk-datazone/types.rb', line 3704

class CreateDomainInput < Struct.new(
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :kms_key_identifier,
  :tags,
  :domain_version,
  :service_role,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Amazon DataZone domain.

Returns:

  • (String)


3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
# File 'lib/aws-sdk-datazone/types.rb', line 3704

class CreateDomainInput < Struct.new(
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :kms_key_identifier,
  :tags,
  :domain_version,
  :service_role,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#domain_execution_roleString

The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the Amazon Web Services account that houses the Amazon DataZone domain.

Returns:

  • (String)


3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
# File 'lib/aws-sdk-datazone/types.rb', line 3704

class CreateDomainInput < Struct.new(
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :kms_key_identifier,
  :tags,
  :domain_version,
  :service_role,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#domain_versionString

The version of the domain that is created.

Returns:

  • (String)


3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
# File 'lib/aws-sdk-datazone/types.rb', line 3704

class CreateDomainInput < Struct.new(
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :kms_key_identifier,
  :tags,
  :domain_version,
  :service_role,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_identifierString

The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.

Returns:

  • (String)


3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
# File 'lib/aws-sdk-datazone/types.rb', line 3704

class CreateDomainInput < Struct.new(
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :kms_key_identifier,
  :tags,
  :domain_version,
  :service_role,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon DataZone domain.

Returns:

  • (String)


3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
# File 'lib/aws-sdk-datazone/types.rb', line 3704

class CreateDomainInput < Struct.new(
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :kms_key_identifier,
  :tags,
  :domain_version,
  :service_role,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The service role of the domain that is created.

Returns:

  • (String)


3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
# File 'lib/aws-sdk-datazone/types.rb', line 3704

class CreateDomainInput < Struct.new(
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :kms_key_identifier,
  :tags,
  :domain_version,
  :service_role,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#single_sign_onTypes::SingleSignOn

The single-sign on configuration of the Amazon DataZone domain.

Returns:



3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
# File 'lib/aws-sdk-datazone/types.rb', line 3704

class CreateDomainInput < Struct.new(
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :kms_key_identifier,
  :tags,
  :domain_version,
  :service_role,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags specified for the Amazon DataZone domain.

Returns:

  • (Hash<String,String>)


3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
# File 'lib/aws-sdk-datazone/types.rb', line 3704

class CreateDomainInput < Struct.new(
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :kms_key_identifier,
  :tags,
  :domain_version,
  :service_role,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end