Class: Aws::DataZone::Types::CreateDomainInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
# File 'lib/aws-sdk-datazone/types.rb', line 2215

class CreateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :kms_key_identifier,
  :name,
  :single_sign_on,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Amazon DataZone domain.

Returns:

  • (String)


2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
# File 'lib/aws-sdk-datazone/types.rb', line 2215

class CreateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :kms_key_identifier,
  :name,
  :single_sign_on,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#domain_execution_roleString

The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the Amazon Web Services account that houses the Amazon DataZone domain.

Returns:

  • (String)


2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
# File 'lib/aws-sdk-datazone/types.rb', line 2215

class CreateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :kms_key_identifier,
  :name,
  :single_sign_on,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_identifierString

The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.

Returns:

  • (String)


2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
# File 'lib/aws-sdk-datazone/types.rb', line 2215

class CreateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :kms_key_identifier,
  :name,
  :single_sign_on,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon DataZone domain.

Returns:

  • (String)


2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
# File 'lib/aws-sdk-datazone/types.rb', line 2215

class CreateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :kms_key_identifier,
  :name,
  :single_sign_on,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#single_sign_onTypes::SingleSignOn

The single-sign on configuration of the Amazon DataZone domain.

Returns:



2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
# File 'lib/aws-sdk-datazone/types.rb', line 2215

class CreateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :kms_key_identifier,
  :name,
  :single_sign_on,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags specified for the Amazon DataZone domain.

Returns:

  • (Hash<String,String>)


2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
# File 'lib/aws-sdk-datazone/types.rb', line 2215

class CreateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :kms_key_identifier,
  :name,
  :single_sign_on,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end