Class: Aws::DataZone::Types::CreateDomainInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateDomainInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#description ⇒ String
The description of the Amazon DataZone domain.
-
#domain_execution_role ⇒ String
The domain execution role that is created when an Amazon DataZone domain is created.
-
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
-
#name ⇒ String
The name of the Amazon DataZone domain.
-
#single_sign_on ⇒ Types::SingleSignOn
The single-sign on configuration of the Amazon DataZone domain.
-
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 |
# File 'lib/aws-sdk-datazone/types.rb', line 1798 class CreateDomainInput < Struct.new( :client_token, :description, :domain_execution_role, :kms_key_identifier, :name, :single_sign_on, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone domain.
1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 |
# File 'lib/aws-sdk-datazone/types.rb', line 1798 class CreateDomainInput < Struct.new( :client_token, :description, :domain_execution_role, :kms_key_identifier, :name, :single_sign_on, :tags) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role ⇒ String
The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the Amazon Web Services account that houses the Amazon DataZone domain.
1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 |
# File 'lib/aws-sdk-datazone/types.rb', line 1798 class CreateDomainInput < Struct.new( :client_token, :description, :domain_execution_role, :kms_key_identifier, :name, :single_sign_on, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 |
# File 'lib/aws-sdk-datazone/types.rb', line 1798 class CreateDomainInput < Struct.new( :client_token, :description, :domain_execution_role, :kms_key_identifier, :name, :single_sign_on, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone domain.
1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 |
# File 'lib/aws-sdk-datazone/types.rb', line 1798 class CreateDomainInput < Struct.new( :client_token, :description, :domain_execution_role, :kms_key_identifier, :name, :single_sign_on, :tags) SENSITIVE = [] include Aws::Structure end |
#single_sign_on ⇒ Types::SingleSignOn
The single-sign on configuration of the Amazon DataZone domain.
1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 |
# File 'lib/aws-sdk-datazone/types.rb', line 1798 class CreateDomainInput < Struct.new( :client_token, :description, :domain_execution_role, :kms_key_identifier, :name, :single_sign_on, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 |
# File 'lib/aws-sdk-datazone/types.rb', line 1798 class CreateDomainInput < Struct.new( :client_token, :description, :domain_execution_role, :kms_key_identifier, :name, :single_sign_on, :tags) SENSITIVE = [] include Aws::Structure end |