Class: Aws::DataZone::Types::CreateDomainOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateDomainOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Amazon DataZone domain.
-
#description ⇒ String
The description of the Amazon DataZone domain.
-
#domain_execution_role ⇒ String
The domain execution role that is created when an Amazon DataZone domain is created.
-
#domain_version ⇒ String
The version of the domain that is created.
-
#id ⇒ String
The identifier of the Amazon DataZone domain.
-
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
-
#name ⇒ String
The name of the Amazon DataZone domain.
-
#portal_url ⇒ String
The URL of the data portal for this Amazon DataZone domain.
-
#root_domain_unit_id ⇒ String
The ID of the root domain unit.
-
#service_role ⇒ String
Te service role of the domain that is created.
-
#single_sign_on ⇒ Types::SingleSignOn
The single-sign on configuration of the Amazon DataZone domain.
-
#status ⇒ String
The status of the Amazon DataZone domain.
-
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
Instance Attribute Details
#arn ⇒ String
The ARN of the Amazon DataZone domain.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone domain.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role ⇒ String
The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the Amazon Web Services account that houses the Amazon DataZone domain.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#domain_version ⇒ String
The version of the domain that is created.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the Amazon DataZone domain.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone domain.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#portal_url ⇒ String
The URL of the data portal for this Amazon DataZone domain.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#root_domain_unit_id ⇒ String
The ID of the root domain unit.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#service_role ⇒ String
Te service role of the domain that is created.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#single_sign_on ⇒ Types::SingleSignOn
The single-sign on configuration of the Amazon DataZone domain.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Amazon DataZone domain.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 |
# File 'lib/aws-sdk-datazone/types.rb', line 3780 class CreateDomainOutput < Struct.new( :id, :root_domain_unit_id, :name, :description, :single_sign_on, :domain_execution_role, :arn, :kms_key_identifier, :status, :portal_url, :tags, :domain_version, :service_role) SENSITIVE = [] include Aws::Structure end |