Class: Aws::DataZone::Types::CreateDomainOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the Amazon DataZone domain.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Amazon DataZone domain.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#domain_execution_roleString

The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the Amazon Web Services account that houses the Amazon DataZone domain.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#domain_versionString

The version of the domain that is created.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the Amazon DataZone domain.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_identifierString

The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon DataZone domain.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#portal_urlString

The URL of the data portal for this Amazon DataZone domain.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#root_domain_unit_idString

The ID of the root domain unit.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

Te service role of the domain that is created.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#single_sign_onTypes::SingleSignOn

The single-sign on configuration of the Amazon DataZone domain.

Returns:



3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Amazon DataZone domain.

Returns:

  • (String)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags specified for the Amazon DataZone domain.

Returns:

  • (Hash<String,String>)


3751
3752
3753
3754
3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/aws-sdk-datazone/types.rb', line 3751

class CreateDomainOutput < Struct.new(
  :id,
  :root_domain_unit_id,
  :name,
  :description,
  :single_sign_on,
  :domain_execution_role,
  :arn,
  :kms_key_identifier,
  :status,
  :portal_url,
  :tags,
  :domain_version,
  :service_role)
  SENSITIVE = []
  include Aws::Structure
end