Class: Aws::DataZone::Types::CreateDomainOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the Amazon DataZone domain.

Returns:

  • (String)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Amazon DataZone domain.

Returns:

  • (String)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#domain_execution_roleString

The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the Amazon Web Services account that houses the Amazon DataZone domain.

Returns:

  • (String)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the Amazon DataZone domain.

Returns:

  • (String)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_identifierString

The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.

Returns:

  • (String)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon DataZone domain.

Returns:

  • (String)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#portal_urlString

The URL of the data portal for this Amazon DataZone domain.

Returns:

  • (String)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#root_domain_unit_idString

The ID of the root domain unit.

Returns:

  • (String)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#single_sign_onTypes::SingleSignOn

The single-sign on configuration of the Amazon DataZone domain.

Returns:



2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Amazon DataZone domain.

Returns:

  • (String)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags specified for the Amazon DataZone domain.

Returns:

  • (Hash<String,String>)


2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
# File 'lib/aws-sdk-datazone/types.rb', line 2330

class CreateDomainOutput < Struct.new(
  :arn,
  :description,
  :domain_execution_role,
  :id,
  :kms_key_identifier,
  :name,
  :portal_url,
  :root_domain_unit_id,
  :single_sign_on,
  :status,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end