Class: Aws::DataZone::Types::CreateDomainOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateDomainOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the Amazon DataZone domain.
-
#description ⇒ String
The description of the Amazon DataZone domain.
-
#domain_execution_role ⇒ String
The domain execution role that is created when an Amazon DataZone domain is created.
-
#id ⇒ String
The identifier of the Amazon DataZone domain.
-
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
-
#name ⇒ String
The name of the Amazon DataZone domain.
-
#portal_url ⇒ String
The URL of the data portal for this Amazon DataZone domain.
-
#single_sign_on ⇒ Types::SingleSignOn
The single-sign on configuration of the Amazon DataZone domain.
-
#status ⇒ String
The status of the Amazon DataZone domain.
-
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
Instance Attribute Details
#arn ⇒ String
The ARN of the Amazon DataZone domain.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone domain.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role ⇒ String
The domain execution role that is created when an Amazon DataZone domain is created. The domain execution role is created in the Amazon Web Services account that houses the Amazon DataZone domain.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the Amazon DataZone domain.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone domain.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_url ⇒ String
The URL of the data portal for this Amazon DataZone domain.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#single_sign_on ⇒ Types::SingleSignOn
The single-sign on configuration of the Amazon DataZone domain.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Amazon DataZone domain.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 |
# File 'lib/aws-sdk-datazone/types.rb', line 1650 class CreateDomainOutput < Struct.new( :arn, :description, :domain_execution_role, :id, :kms_key_identifier, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |