Class: Aws::DataZone::Types::CreateEnvironmentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateEnvironmentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:environment_configuration_name]
Instance Attribute Summary collapse
-
#deployment_order ⇒ Integer
The deployment order of the environment.
-
#description ⇒ String
The description of the Amazon DataZone environment.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which the environment is created.
-
#environment_account_identifier ⇒ String
The ID of the account in which the environment is being created.
-
#environment_account_region ⇒ String
The region of the account in which the environment is being created.
-
#environment_blueprint_identifier ⇒ String
The ID of the blueprint with which the environment is being created.
-
#environment_configuration_id ⇒ String
The configuration ID of the environment.
-
#environment_configuration_name ⇒ String
The configuration name of the environment.
-
#environment_profile_identifier ⇒ String
The identifier of the environment profile that is used to create this Amazon DataZone environment.
-
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in this Amazon DataZone environment.
-
#name ⇒ String
The name of the Amazon DataZone environment.
-
#project_identifier ⇒ String
The identifier of the Amazon DataZone project in which this environment is created.
-
#user_parameters ⇒ Array<Types::EnvironmentParameter>
The user parameters of this Amazon DataZone environment.
Instance Attribute Details
#deployment_order ⇒ Integer
The deployment order of the environment.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone environment.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which the environment is created.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#environment_account_identifier ⇒ String
The ID of the account in which the environment is being created.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#environment_account_region ⇒ String
The region of the account in which the environment is being created.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#environment_blueprint_identifier ⇒ String
The ID of the blueprint with which the environment is being created.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#environment_configuration_id ⇒ String
The configuration ID of the environment.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#environment_configuration_name ⇒ String
The configuration name of the environment.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#environment_profile_identifier ⇒ String
The identifier of the environment profile that is used to create this Amazon DataZone environment.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in this Amazon DataZone environment.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone environment.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#project_identifier ⇒ String
The identifier of the Amazon DataZone project in which this environment is created.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentParameter>
The user parameters of this Amazon DataZone environment.
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 |
# File 'lib/aws-sdk-datazone/types.rb', line 4115 class CreateEnvironmentInput < Struct.new( :project_identifier, :domain_identifier, :description, :name, :environment_profile_identifier, :user_parameters, :glossary_terms, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :deployment_order, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:environment_configuration_name] include Aws::Structure end |