Class: Aws::DataZone::Types::CreateEnvironmentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateEnvironmentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_order ⇒ Integer
The deployment order of the environment.
-
#description ⇒ String
The description of the Amazon DataZone environment.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which the environment is created.
-
#environment_account_identifier ⇒ String
The ID of the account in which the environment is being created.
-
#environment_account_region ⇒ String
The region of the account in which the environment is being created.
-
#environment_blueprint_identifier ⇒ String
The ID of the blueprint with which the environment is being created.
-
#environment_configuration_id ⇒ String
The configuration ID of the environment.
-
#environment_profile_identifier ⇒ String
The identifier of the environment profile that is used to create this Amazon DataZone environment.
-
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in this Amazon DataZone environment.
-
#name ⇒ String
The name of the Amazon DataZone environment.
-
#project_identifier ⇒ String
The identifier of the Amazon DataZone project in which this environment is created.
-
#user_parameters ⇒ Array<Types::EnvironmentParameter>
The user parameters of this Amazon DataZone environment.
Instance Attribute Details
#deployment_order ⇒ Integer
The deployment order of the environment.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone environment.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which the environment is created.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#environment_account_identifier ⇒ String
The ID of the account in which the environment is being created.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#environment_account_region ⇒ String
The region of the account in which the environment is being created.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#environment_blueprint_identifier ⇒ String
The ID of the blueprint with which the environment is being created.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#environment_configuration_id ⇒ String
The configuration ID of the environment.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#environment_profile_identifier ⇒ String
The identifier of the environment profile that is used to create this Amazon DataZone environment.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in this Amazon DataZone environment.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone environment.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#project_identifier ⇒ String
The identifier of the Amazon DataZone project in which this environment is created.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentParameter>
The user parameters of this Amazon DataZone environment.
3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 |
# File 'lib/aws-sdk-datazone/types.rb', line 3304 class CreateEnvironmentInput < Struct.new( :deployment_order, :description, :domain_identifier, :environment_account_identifier, :environment_account_region, :environment_blueprint_identifier, :environment_configuration_id, :environment_profile_identifier, :glossary_terms, :name, :project_identifier, :user_parameters) SENSITIVE = [] include Aws::Structure end |