Class: Aws::DataZone::Types::CreateEnvironmentInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the Amazon DataZone environment.

Returns:

  • (String)


2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain in which the environment is created.

Returns:

  • (String)


2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#environment_account_identifierString

The ID of the account in which the environment is being created.

Returns:

  • (String)


2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#environment_account_regionString

The region of the account in which the environment is being created.

Returns:

  • (String)


2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#environment_blueprint_identifierString

The ID of the blueprint with which the environment is being created.

Returns:

  • (String)


2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#environment_profile_identifierString

The identifier of the environment profile that is used to create this Amazon DataZone environment.

Returns:

  • (String)


2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms that can be used in this Amazon DataZone environment.

Returns:

  • (Array<String>)


2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon DataZone environment.

Returns:

  • (String)


2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#project_identifierString

The identifier of the Amazon DataZone project in which this environment is created.

Returns:

  • (String)


2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#user_parametersArray<Types::EnvironmentParameter>

The user parameters of this Amazon DataZone environment.

Returns:



2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/aws-sdk-datazone/types.rb', line 2513

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_account_identifier,
  :environment_account_region,
  :environment_blueprint_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end