Class: Aws::DataZone::Types::CreateEnvironmentInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the Amazon DataZone environment.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
# File 'lib/aws-sdk-datazone/types.rb', line 1561

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain in which the environment is created.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
# File 'lib/aws-sdk-datazone/types.rb', line 1561

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#environment_profile_identifierString

The identifier of the environment profile that is used to create this Amazon DataZone environment.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
# File 'lib/aws-sdk-datazone/types.rb', line 1561

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms that can be used in this Amazon DataZone environment.

Returns:

  • (Array<String>)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
# File 'lib/aws-sdk-datazone/types.rb', line 1561

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon DataZone environment.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
# File 'lib/aws-sdk-datazone/types.rb', line 1561

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#project_identifierString

The identifier of the Amazon DataZone project in which this environment is created.

Returns:

  • (String)


1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
# File 'lib/aws-sdk-datazone/types.rb', line 1561

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#user_parametersArray<Types::EnvironmentParameter>

The user parameters of this Amazon DataZone environment.

Returns:



1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
# File 'lib/aws-sdk-datazone/types.rb', line 1561

class CreateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :environment_profile_identifier,
  :glossary_terms,
  :name,
  :project_identifier,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end