Class: Aws::DataZone::Types::CreateEnvironmentOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The Amazon Web Services account in which the Amazon DataZone environment is created.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#aws_account_regionString

The Amazon Web Services region in which the Amazon DataZone environment is created.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#created_atTime

The timestamp of when the environment was created.

Returns:

  • (Time)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created this environment.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#deployment_propertiesTypes::DeploymentProperties

The deployment properties of this Amazon DataZone environment.



1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#descriptionString

The description of this Amazon DataZone environment.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon DataZone domain in which the environment is created.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_actionsArray<Types::ConfigurableEnvironmentAction>

The configurable actions of this Amazon DataZone environment.



1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_blueprint_idString

The ID of the blueprint with which this Amazon DataZone environment was created.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_profile_idString

The ID of the environment profile with which this Amazon DataZone environment was created.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms that can be used in this Amazon DataZone environment.

Returns:

  • (Array<String>)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#idString

The ID of this Amazon DataZone environment.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#last_deploymentTypes::Deployment

The details of the last deployment of this Amazon DataZone environment.

Returns:



1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#nameString

The name of this environment.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#project_idString

The ID of the Amazon DataZone project in which this environment is created.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#providerString

The provider of this Amazon DataZone environment.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#provisioned_resourcesArray<Types::Resource>

The provisioned resources of this Amazon DataZone environment.

Returns:



1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#provisioning_propertiesTypes::ProvisioningProperties

The provisioning properties of this Amazon DataZone environment.



1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#statusString

The status of this Amazon DataZone environment.

Returns:

  • (String)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#updated_atTime

The timestamp of when this environment was updated.

Returns:

  • (Time)


1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#user_parametersArray<Types::CustomParameter>

The user parameters of this Amazon DataZone environment.

Returns:



1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
# File 'lib/aws-sdk-datazone/types.rb', line 1892

class CreateEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end