Class: Aws::DataZone::Types::CreateEnvironmentProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateEnvironmentProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID in which this Amazon DataZone environment profile is created.
-
#aws_account_region ⇒ String
The Amazon Web Services region in which this Amazon DataZone environment profile is created.
-
#created_at ⇒ Time
The timestamp of when this environment profile was created.
-
#created_by ⇒ String
The Amazon DataZone user who created this environment profile.
-
#description ⇒ String
The description of this Amazon DataZone environment profile.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this environment profile is created.
-
#environment_blueprint_id ⇒ String
The ID of the blueprint with which this environment profile is created.
-
#id ⇒ String
The ID of this Amazon DataZone environment profile.
-
#name ⇒ String
The name of this Amazon DataZone environment profile.
-
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment profile is created.
-
#updated_at ⇒ Time
The timestamp of when this environment profile was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone environment profile.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID in which this Amazon DataZone environment profile is created.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services region in which this Amazon DataZone environment profile is created.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when this environment profile was created.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created this environment profile.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of this Amazon DataZone environment profile.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this environment profile is created.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The ID of the blueprint with which this environment profile is created.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The ID of this Amazon DataZone environment profile.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of this Amazon DataZone environment profile.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment profile is created.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this environment profile was updated.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone environment profile.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 |
# File 'lib/aws-sdk-datazone/types.rb', line 4374 class CreateEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |