Class: Aws::DataZone::Types::CreateEnvironmentProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateEnvironmentProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID in which this Amazon DataZone environment profile is created.
-
#aws_account_region ⇒ String
The Amazon Web Services region in which this Amazon DataZone environment profile is created.
-
#created_at ⇒ Time
The timestamp of when this environment profile was created.
-
#created_by ⇒ String
The Amazon DataZone user who created this environment profile.
-
#description ⇒ String
The description of this Amazon DataZone environment profile.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this environment profile is created.
-
#environment_blueprint_id ⇒ String
The ID of the blueprint with which this environment profile is created.
-
#id ⇒ String
The ID of this Amazon DataZone environment profile.
-
#name ⇒ String
The name of this Amazon DataZone environment profile.
-
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment profile is created.
-
#updated_at ⇒ Time
The timestamp of when this environment profile was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone environment profile.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID in which this Amazon DataZone environment profile is created.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services region in which this Amazon DataZone environment profile is created.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when this environment profile was created.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created this environment profile.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description of this Amazon DataZone environment profile.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this environment profile is created.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The ID of the blueprint with which this environment profile is created.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The ID of this Amazon DataZone environment profile.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of this Amazon DataZone environment profile.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment profile is created.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this environment profile was updated.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone environment profile.
2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 |
# File 'lib/aws-sdk-datazone/types.rb', line 2231 class CreateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |