Class: Aws::DataZone::Types::CreateGlossaryOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateGlossaryOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of this business glossary.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this business glossary is created.
-
#id ⇒ String
The ID of this business glossary.
-
#name ⇒ String
The name of this business glossary.
-
#owning_project_id ⇒ String
The ID of the project that currently owns this business glossary.
-
#status ⇒ String
The status of this business glossary.
-
#usage_restrictions ⇒ Array<String>
The usage restriction of the restricted glossary.
Instance Attribute Details
#description ⇒ String
The description of this business glossary.
4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/aws-sdk-datazone/types.rb', line 4535 class CreateGlossaryOutput < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this business glossary is created.
4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/aws-sdk-datazone/types.rb', line 4535 class CreateGlossaryOutput < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The ID of this business glossary.
4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/aws-sdk-datazone/types.rb', line 4535 class CreateGlossaryOutput < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of this business glossary.
4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/aws-sdk-datazone/types.rb', line 4535 class CreateGlossaryOutput < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions) SENSITIVE = [:name, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the project that currently owns this business glossary.
4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/aws-sdk-datazone/types.rb', line 4535 class CreateGlossaryOutput < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions) SENSITIVE = [:name, :description] include Aws::Structure end |
#status ⇒ String
The status of this business glossary.
4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/aws-sdk-datazone/types.rb', line 4535 class CreateGlossaryOutput < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions) SENSITIVE = [:name, :description] include Aws::Structure end |
#usage_restrictions ⇒ Array<String>
The usage restriction of the restricted glossary.
4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 |
# File 'lib/aws-sdk-datazone/types.rb', line 4535 class CreateGlossaryOutput < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions) SENSITIVE = [:name, :description] include Aws::Structure end |