Class: Aws::DataZone::Types::CreateGlossaryOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateGlossaryOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of this business glossary.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this business glossary is created.
-
#id ⇒ String
The ID of this business glossary.
-
#name ⇒ String
The name of this business glossary.
-
#owning_project_id ⇒ String
The ID of the project that currently owns this business glossary.
-
#status ⇒ String
The status of this business glossary.
Instance Attribute Details
#description ⇒ String
The description of this business glossary.
2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 |
# File 'lib/aws-sdk-datazone/types.rb', line 2684 class CreateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this business glossary is created.
2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 |
# File 'lib/aws-sdk-datazone/types.rb', line 2684 class CreateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The ID of this business glossary.
2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 |
# File 'lib/aws-sdk-datazone/types.rb', line 2684 class CreateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of this business glossary.
2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 |
# File 'lib/aws-sdk-datazone/types.rb', line 2684 class CreateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the project that currently owns this business glossary.
2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 |
# File 'lib/aws-sdk-datazone/types.rb', line 2684 class CreateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#status ⇒ String
The status of this business glossary.
2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 |
# File 'lib/aws-sdk-datazone/types.rb', line 2684 class CreateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |