Class: Aws::DataZone::Types::CreateGlossaryTermInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:long_description, :name, :short_description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-datazone/types.rb', line 2452

class CreateGlossaryTermInput < Struct.new(
  :client_token,
  :domain_identifier,
  :glossary_identifier,
  :long_description,
  :name,
  :short_description,
  :status,
  :term_relations)
  SENSITIVE = [:long_description, :name, :short_description]
  include Aws::Structure
end

#domain_identifierString

The ID of the Amazon DataZone domain in which this business glossary term is created.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-datazone/types.rb', line 2452

class CreateGlossaryTermInput < Struct.new(
  :client_token,
  :domain_identifier,
  :glossary_identifier,
  :long_description,
  :name,
  :short_description,
  :status,
  :term_relations)
  SENSITIVE = [:long_description, :name, :short_description]
  include Aws::Structure
end

#glossary_identifierString

The ID of the business glossary in which this term is created.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-datazone/types.rb', line 2452

class CreateGlossaryTermInput < Struct.new(
  :client_token,
  :domain_identifier,
  :glossary_identifier,
  :long_description,
  :name,
  :short_description,
  :status,
  :term_relations)
  SENSITIVE = [:long_description, :name, :short_description]
  include Aws::Structure
end

#long_descriptionString

The long description of this business glossary term.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-datazone/types.rb', line 2452

class CreateGlossaryTermInput < Struct.new(
  :client_token,
  :domain_identifier,
  :glossary_identifier,
  :long_description,
  :name,
  :short_description,
  :status,
  :term_relations)
  SENSITIVE = [:long_description, :name, :short_description]
  include Aws::Structure
end

#nameString

The name of this business glossary term.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-datazone/types.rb', line 2452

class CreateGlossaryTermInput < Struct.new(
  :client_token,
  :domain_identifier,
  :glossary_identifier,
  :long_description,
  :name,
  :short_description,
  :status,
  :term_relations)
  SENSITIVE = [:long_description, :name, :short_description]
  include Aws::Structure
end

#short_descriptionString

The short description of this business glossary term.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-datazone/types.rb', line 2452

class CreateGlossaryTermInput < Struct.new(
  :client_token,
  :domain_identifier,
  :glossary_identifier,
  :long_description,
  :name,
  :short_description,
  :status,
  :term_relations)
  SENSITIVE = [:long_description, :name, :short_description]
  include Aws::Structure
end

#statusString

The status of this business glossary term.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-datazone/types.rb', line 2452

class CreateGlossaryTermInput < Struct.new(
  :client_token,
  :domain_identifier,
  :glossary_identifier,
  :long_description,
  :name,
  :short_description,
  :status,
  :term_relations)
  SENSITIVE = [:long_description, :name, :short_description]
  include Aws::Structure
end

#term_relationsTypes::TermRelations

The term relations of this business glossary term.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
# File 'lib/aws-sdk-datazone/types.rb', line 2452

class CreateGlossaryTermInput < Struct.new(
  :client_token,
  :domain_identifier,
  :glossary_identifier,
  :long_description,
  :name,
  :short_description,
  :status,
  :term_relations)
  SENSITIVE = [:long_description, :name, :short_description]
  include Aws::Structure
end