Class: Aws::DataZone::Types::CreateGroupProfileInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateGroupProfileInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which the group profile is created.
-
#group_identifier ⇒ String
The identifier of the group for which the group profile is created.
-
#role_principal_arn ⇒ String
The ARN of the IAM role that will be associated with the group profile.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
4709 4710 4711 4712 4713 4714 4715 4716 |
# File 'lib/aws-sdk-datazone/types.rb', line 4709 class CreateGroupProfileInput < Struct.new( :domain_identifier, :group_identifier, :role_principal_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which the group profile is created.
4709 4710 4711 4712 4713 4714 4715 4716 |
# File 'lib/aws-sdk-datazone/types.rb', line 4709 class CreateGroupProfileInput < Struct.new( :domain_identifier, :group_identifier, :role_principal_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#group_identifier ⇒ String
The identifier of the group for which the group profile is created.
4709 4710 4711 4712 4713 4714 4715 4716 |
# File 'lib/aws-sdk-datazone/types.rb', line 4709 class CreateGroupProfileInput < Struct.new( :domain_identifier, :group_identifier, :role_principal_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#role_principal_arn ⇒ String
The ARN of the IAM role that will be associated with the group profile. This role defines the permissions that group members will assume when accessing Amazon DataZone resources.
4709 4710 4711 4712 4713 4714 4715 4716 |
# File 'lib/aws-sdk-datazone/types.rb', line 4709 class CreateGroupProfileInput < Struct.new( :domain_identifier, :group_identifier, :role_principal_arn, :client_token) SENSITIVE = [] include Aws::Structure end |