Class: Aws::DataZone::Types::CreateGroupProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateGroupProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:group_name]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the group profile is created.
-
#group_name ⇒ String
The name of the group for which group profile is created.
-
#id ⇒ String
The identifier of the group profile.
-
#role_principal_arn ⇒ String
The ARN of the IAM role principal.
-
#role_principal_id ⇒ String
The unique identifier of the IAM role principal.
-
#status ⇒ String
The status of the group profile.
Instance Attribute Details
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the group profile is created.
4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4729 class CreateGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#group_name ⇒ String
The name of the group for which group profile is created.
4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4729 class CreateGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#id ⇒ String
The identifier of the group profile.
4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4729 class CreateGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#role_principal_arn ⇒ String
The ARN of the IAM role principal. This role is associated with the group profile.
4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4729 class CreateGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#role_principal_id ⇒ String
The unique identifier of the IAM role principal. This principal is associated with the group profile.
4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4729 class CreateGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |
#status ⇒ String
The status of the group profile.
4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4729 class CreateGroupProfileOutput < Struct.new( :domain_id, :id, :status, :group_name, :role_principal_arn, :role_principal_id) SENSITIVE = [:group_name] include Aws::Structure end |