Class: Aws::DataZone::Types::CreateNotebookInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description, :metadata, :parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
# File 'lib/aws-sdk-datazone/types.rb', line 4890

class CreateNotebookInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :name,
  :description,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#descriptionString

The description of the notebook.

Returns:

  • (String)


4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
# File 'lib/aws-sdk-datazone/types.rb', line 4890

class CreateNotebookInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :name,
  :description,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon SageMaker Unified Studio domain in which to create the notebook.

Returns:

  • (String)


4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
# File 'lib/aws-sdk-datazone/types.rb', line 4890

class CreateNotebookInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :name,
  :description,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#metadataHash<String,String>

The metadata for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.

Returns:

  • (Hash<String,String>)


4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
# File 'lib/aws-sdk-datazone/types.rb', line 4890

class CreateNotebookInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :name,
  :description,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#nameString

The name of the notebook. The name must be between 1 and 256 characters.

Returns:

  • (String)


4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
# File 'lib/aws-sdk-datazone/types.rb', line 4890

class CreateNotebookInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :name,
  :description,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#owning_project_identifierString

The identifier of the project that owns the notebook.

Returns:

  • (String)


4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
# File 'lib/aws-sdk-datazone/types.rb', line 4890

class CreateNotebookInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :name,
  :description,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#parametersHash<String,String>

The sensitive parameters for the notebook, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.

Returns:

  • (Hash<String,String>)


4890
4891
4892
4893
4894
4895
4896
4897
4898
4899
4900
# File 'lib/aws-sdk-datazone/types.rb', line 4890

class CreateNotebookInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :name,
  :description,
  :metadata,
  :parameters,
  :client_token)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end