Class: Aws::DataZone::Types::CreateNotebookOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateNotebookOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :metadata, :parameters]
Instance Attribute Summary collapse
-
#cell_order ⇒ Array<Types::CellInformation>
The ordered list of cells in the notebook.
-
#compute_id ⇒ String
The identifier of the compute associated with the notebook.
-
#created_at ⇒ Time
The timestamp of when the notebook was created.
-
#created_by ⇒ String
The identifier of the user who created the notebook.
-
#description ⇒ String
The description of the notebook.
-
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
-
#environment_configuration ⇒ Types::EnvironmentConfig
The environment configuration of the notebook.
-
#error ⇒ Types::NotebookError
The error details if the notebook creation failed.
-
#id ⇒ String
The identifier of the notebook.
-
#lock_expires_at ⇒ Time
The timestamp of when the notebook lock expires.
-
#locked_at ⇒ Time
The timestamp of when the notebook was locked.
-
#locked_by ⇒ String
The identifier of the user who locked the notebook.
-
#metadata ⇒ Hash<String,String>
The metadata of the notebook.
-
#name ⇒ String
The name of the notebook.
-
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
-
#parameters ⇒ Hash<String,String>
The sensitive parameters of the notebook.
-
#status ⇒ String
The status of the notebook.
-
#updated_at ⇒ Time
The timestamp of when the notebook was last updated.
-
#updated_by ⇒ String
The identifier of the user who last updated the notebook.
Instance Attribute Details
#cell_order ⇒ Array<Types::CellInformation>
The ordered list of cells in the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#compute_id ⇒ String
The identifier of the compute associated with the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the notebook was created.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who created the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#description ⇒ String
The description of the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#environment_configuration ⇒ Types::EnvironmentConfig
The environment configuration of the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#error ⇒ Types::NotebookError
The error details if the notebook creation failed.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#id ⇒ String
The identifier of the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#lock_expires_at ⇒ Time
The timestamp of when the notebook lock expires.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#locked_at ⇒ Time
The timestamp of when the notebook was locked.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#locked_by ⇒ String
The identifier of the user who locked the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The metadata of the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#name ⇒ String
The name of the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
The sensitive parameters of the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#status ⇒ String
The status of the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the notebook was last updated.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#updated_by ⇒ String
The identifier of the user who last updated the notebook.
4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-datazone/types.rb', line 4980 class CreateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |