Class: Aws::DataZone::Types::CreateProjectInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateProjectInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the Amazon DataZone project.
-
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain in which this project is created.
-
#domain_unit_id ⇒ String
The ID of the domain unit.
-
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in this Amazon DataZone project.
-
#name ⇒ String
The name of the Amazon DataZone project.
Instance Attribute Details
#description ⇒ String
The description of the Amazon DataZone project.
3275 3276 3277 3278 3279 3280 3281 3282 3283 |
# File 'lib/aws-sdk-datazone/types.rb', line 3275 class CreateProjectInput < Struct.new( :description, :domain_identifier, :domain_unit_id, :glossary_terms, :name) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_identifier ⇒ String
The ID of the Amazon DataZone domain in which this project is created.
3275 3276 3277 3278 3279 3280 3281 3282 3283 |
# File 'lib/aws-sdk-datazone/types.rb', line 3275 class CreateProjectInput < Struct.new( :description, :domain_identifier, :domain_unit_id, :glossary_terms, :name) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_unit_id ⇒ String
The ID of the domain unit. This parameter is not required and if it is not specified, then the project is created at the root domain unit level.
3275 3276 3277 3278 3279 3280 3281 3282 3283 |
# File 'lib/aws-sdk-datazone/types.rb', line 3275 class CreateProjectInput < Struct.new( :description, :domain_identifier, :domain_unit_id, :glossary_terms, :name) SENSITIVE = [:description, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in this Amazon DataZone project.
3275 3276 3277 3278 3279 3280 3281 3282 3283 |
# File 'lib/aws-sdk-datazone/types.rb', line 3275 class CreateProjectInput < Struct.new( :description, :domain_identifier, :domain_unit_id, :glossary_terms, :name) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone project.
3275 3276 3277 3278 3279 3280 3281 3282 3283 |
# File 'lib/aws-sdk-datazone/types.rb', line 3275 class CreateProjectInput < Struct.new( :description, :domain_identifier, :domain_unit_id, :glossary_terms, :name) SENSITIVE = [:description, :name] include Aws::Structure end |