Class: Aws::DataZone::Types::CreateProjectOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateProjectOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the project was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the project.
-
#description ⇒ String
The description of the project.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the project was created.
-
#domain_unit_id ⇒ String
The ID of the domain unit.
-
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment details.
-
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in the project.
-
#id ⇒ String
The ID of the Amazon DataZone project.
-
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
-
#name ⇒ String
The name of the project.
-
#project_category ⇒ String
The category of the project.
-
#project_profile_id ⇒ String
The project profile ID.
-
#project_status ⇒ String
The status of the Amazon DataZone project that was created.
-
#resource_tags ⇒ Array<Types::ResourceTag>
The resource tags of the project.
-
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of the project.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the project was created.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the project.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the project.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the project was created.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_unit_id ⇒ String
The ID of the domain unit.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment details.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in the project.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The ID of the Amazon DataZone project.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the project.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_category ⇒ String
The category of the project.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_profile_id ⇒ String
The project profile ID.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_status ⇒ String
The status of the Amazon DataZone project that was created.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#resource_tags ⇒ Array<Types::ResourceTag>
The resource tags of the project.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of the project.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 |
# File 'lib/aws-sdk-datazone/types.rb', line 5010 class CreateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |