Class: Aws::DataZone::Types::CreateProjectOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateProjectOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the project was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the project.
-
#description ⇒ String
The description of the project.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the project was created.
-
#domain_unit_id ⇒ String
The ID of the domain unit.
-
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment details.
-
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in the project.
-
#id ⇒ String
The ID of the Amazon DataZone project.
-
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
-
#name ⇒ String
The name of the project.
-
#project_profile_id ⇒ String
The project profile ID.
-
#project_status ⇒ String
The status of the Amazon DataZone project that was created.
-
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of the project.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the project was created.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the project.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description of the project.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the project was created.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_unit_id ⇒ String
The ID of the domain unit.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment details.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms that can be used in the project.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The ID of the Amazon DataZone project.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of the project.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_profile_id ⇒ String
The project profile ID.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_status ⇒ String
The status of the Amazon DataZone project that was created.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of the project.
4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 |
# File 'lib/aws-sdk-datazone/types.rb', line 4071 class CreateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |