Class: Aws::DataZone::Types::CreateProjectOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the project was created.

Returns:

  • (Time)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
# File 'lib/aws-sdk-datazone/types.rb', line 2284

class CreateProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created the project.

Returns:

  • (String)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
# File 'lib/aws-sdk-datazone/types.rb', line 2284

class CreateProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#descriptionString

The description of the project.

Returns:

  • (String)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
# File 'lib/aws-sdk-datazone/types.rb', line 2284

class CreateProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon DataZone domain in which the project was created.

Returns:

  • (String)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
# File 'lib/aws-sdk-datazone/types.rb', line 2284

class CreateProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms that can be used in the project.

Returns:

  • (Array<String>)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
# File 'lib/aws-sdk-datazone/types.rb', line 2284

class CreateProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#idString

The ID of the Amazon DataZone project.

Returns:

  • (String)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
# File 'lib/aws-sdk-datazone/types.rb', line 2284

class CreateProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the project was last updated.

Returns:

  • (Time)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
# File 'lib/aws-sdk-datazone/types.rb', line 2284

class CreateProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#nameString

The name of the project.

Returns:

  • (String)


2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
# File 'lib/aws-sdk-datazone/types.rb', line 2284

class CreateProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end