Class: Aws::DataZone::Types::CreateSubscriptionGrantOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateSubscriptionGrantOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assets ⇒ Array<Types::SubscribedAsset>
The assets for which the subscription grant is created.
-
#created_at ⇒ Time
A timestamp of when the subscription grant is created.
-
#created_by ⇒ String
The Amazon DataZone user who created the subscription grant.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription grant is created.
-
#environment_id ⇒ String
The environment ID for which subscription grant is created.
-
#granted_entity ⇒ Types::GrantedEntity
The entity to which the subscription is granted.
-
#id ⇒ String
The ID of the subscription grant.
-
#status ⇒ String
The status of the subscription grant.
-
#subscription_id ⇒ String
The identifier of the subscription grant.
-
#subscription_target_id ⇒ String
The ID of the subscription target for which the subscription grant is created.
-
#updated_at ⇒ Time
A timestamp of when the subscription grant was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant.
Instance Attribute Details
#assets ⇒ Array<Types::SubscribedAsset>
The assets for which the subscription grant is created.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
A timestamp of when the subscription grant is created.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the subscription grant.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription grant is created.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The environment ID for which subscription grant is created.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#granted_entity ⇒ Types::GrantedEntity
The entity to which the subscription is granted.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the subscription grant.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the subscription grant.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#subscription_id ⇒ String
The identifier of the subscription grant.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#subscription_target_id ⇒ String
The ID of the subscription target for which the subscription grant is created.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
A timestamp of when the subscription grant was updated.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant.
5362 5363 5364 5365 5366 5367 5368 5369 5370 5371 5372 5373 5374 5375 5376 5377 |
# File 'lib/aws-sdk-datazone/types.rb', line 5362 class CreateSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |