Class: Aws::DataZone::Types::CreateSubscriptionTargetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CreateSubscriptionTargetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#applicable_asset_types ⇒ Array<String>
The asset types that can be included in the subscription target.
-
#authorized_principals ⇒ Array<String>
The authorised principals of the subscription target.
-
#created_at ⇒ Time
The timestamp of when the subscription target was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the subscription target.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription target was created.
-
#environment_id ⇒ String
The ID of the environment in which the subscription target was created.
-
#id ⇒ String
The ID of the subscription target.
-
#manage_access_role ⇒ String
The manage access role with which the subscription target was created.
-
#name ⇒ String
The name of the subscription target.
-
#project_id ⇒ String
???.
-
#provider ⇒ String
The provider of the subscription target.
-
#subscription_target_config ⇒ Array<Types::SubscriptionTargetForm>
The configuration of the subscription target.
-
#type ⇒ String
The type of the subscription target.
-
#updated_at ⇒ Time
The timestamp of when the subscription target was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription target.
Instance Attribute Details
#applicable_asset_types ⇒ Array<String>
The asset types that can be included in the subscription target.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#authorized_principals ⇒ Array<String>
The authorised principals of the subscription target.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the subscription target was created.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the subscription target.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription target was created.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment in which the subscription target was created.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#id ⇒ String
The ID of the subscription target.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#manage_access_role ⇒ String
The manage access role with which the subscription target was created.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
The name of the subscription target.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#project_id ⇒ String
???
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#provider ⇒ String
The provider of the subscription target.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#subscription_target_config ⇒ Array<Types::SubscriptionTargetForm>
The configuration of the subscription target.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#type ⇒ String
The type of the subscription target.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription target was updated.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription target.
2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-datazone/types.rb', line 2637 class CreateSubscriptionTargetOutput < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |