Method: Aws::DataZone::Types::CreateUserProfileInput#client_token
- Defined in:
- lib/aws-sdk-datazone/types.rb
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
5656 5657 5658 5659 5660 5661 5662 5663 |
# File 'lib/aws-sdk-datazone/types.rb', line 5656 class CreateUserProfileInput < Struct.new( :domain_identifier, :user_identifier, :user_type, :client_token) SENSITIVE = [] include Aws::Structure end |