Class: Aws::DataZone::Types::CustomAccountPoolHandler

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The custom Amazon Web Services Lambda handler within an account pool.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lambda_execution_role_arnString

The ARN of the IAM role that enables Amazon SageMaker Unified Studio to invoke the Amazon Web Services Lambda funtion if the account source is the custom account pool handler.

Returns:

  • (String)


5960
5961
5962
5963
5964
5965
# File 'lib/aws-sdk-datazone/types.rb', line 5960

class CustomAccountPoolHandler < Struct.new(
  :lambda_function_arn,
  :lambda_execution_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#lambda_function_arnString

The ARN of the Amazon Web Services Lambda function for the custom Amazon Web Services Lambda handler.

Returns:

  • (String)


5960
5961
5962
5963
5964
5965
# File 'lib/aws-sdk-datazone/types.rb', line 5960

class CustomAccountPoolHandler < Struct.new(
  :lambda_function_arn,
  :lambda_execution_role_arn)
  SENSITIVE = []
  include Aws::Structure
end