Class: Aws::DataZone::Types::CustomAccountPoolHandler
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::CustomAccountPoolHandler
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The custom Amazon Web Services Lambda handler within an account pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lambda_execution_role_arn ⇒ String
The ARN of the IAM role that enables Amazon SageMaker Unified Studio to invoke the Amazon Web Services Lambda funtion if the account source is the custom account pool handler.
-
#lambda_function_arn ⇒ String
The ARN of the Amazon Web Services Lambda function for the custom Amazon Web Services Lambda handler.
Instance Attribute Details
#lambda_execution_role_arn ⇒ String
The ARN of the IAM role that enables Amazon SageMaker Unified Studio to invoke the Amazon Web Services Lambda funtion if the account source is the custom account pool handler.
5777 5778 5779 5780 5781 5782 |
# File 'lib/aws-sdk-datazone/types.rb', line 5777 class CustomAccountPoolHandler < Struct.new( :lambda_function_arn, :lambda_execution_role_arn) SENSITIVE = [] include Aws::Structure end |
#lambda_function_arn ⇒ String
The ARN of the Amazon Web Services Lambda function for the custom Amazon Web Services Lambda handler.
5777 5778 5779 5780 5781 5782 |
# File 'lib/aws-sdk-datazone/types.rb', line 5777 class CustomAccountPoolHandler < Struct.new( :lambda_function_arn, :lambda_execution_role_arn) SENSITIVE = [] include Aws::Structure end |