Class: Aws::DataZone::Types::DataSourceConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceConfigurationInput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
DataSourceConfigurationInput is a union - when making an API calls you must set exactly one of the members.
The configuration of the data source.
Direct Known Subclasses
Defined Under Namespace
Classes: GlueRunConfiguration, RedshiftRunConfiguration, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#glue_run_configuration ⇒ Types::GlueRunConfigurationInput
The configuration of the Amazon Web Services Glue data source.
-
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationInput
The configuration of the Amazon Redshift data source.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#glue_run_configuration ⇒ Types::GlueRunConfigurationInput
The configuration of the Amazon Web Services Glue data source.
2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 |
# File 'lib/aws-sdk-datazone/types.rb', line 2851 class DataSourceConfigurationInput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationInput; end class RedshiftRunConfiguration < DataSourceConfigurationInput; end class Unknown < DataSourceConfigurationInput; end end |
#redshift_run_configuration ⇒ Types::RedshiftRunConfigurationInput
The configuration of the Amazon Redshift data source.
2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 |
# File 'lib/aws-sdk-datazone/types.rb', line 2851 class DataSourceConfigurationInput < Struct.new( :glue_run_configuration, :redshift_run_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GlueRunConfiguration < DataSourceConfigurationInput; end class RedshiftRunConfiguration < DataSourceConfigurationInput; end class Unknown < DataSourceConfigurationInput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2851 2852 2853 |
# File 'lib/aws-sdk-datazone/types.rb', line 2851 def unknown @unknown end |