Class: Aws::DataZone::Types::DataSourceRunActivity
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceRunActivity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The activity details of the data source run.
Constant Summary collapse
- SENSITIVE =
[:database, :technical_name, :technical_description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when data source run activity was created.
-
#data_asset_id ⇒ String
The identifier of the asset included in the data source run activity.
-
#data_asset_status ⇒ String
The status of the asset included in the data source run activity.
-
#data_source_run_id ⇒ String
The identifier of the data source for the data source run activity.
-
#database ⇒ String
The database included in the data source run activity.
-
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
-
#lineage_summary ⇒ Types::LineageInfo
The data lineage summary.
-
#project_id ⇒ String
The project ID included in the data source run activity.
-
#technical_description ⇒ String
The technical description included in the data source run activity.
-
#technical_name ⇒ String
The technical name included in the data source run activity.
-
#updated_at ⇒ Time
The timestamp of when data source run activity was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when data source run activity was created.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#data_asset_id ⇒ String
The identifier of the asset included in the data source run activity.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#data_asset_status ⇒ String
The status of the asset included in the data source run activity.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#data_source_run_id ⇒ String
The identifier of the data source for the data source run activity.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#database ⇒ String
The database included in the data source run activity.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#lineage_summary ⇒ Types::LineageInfo
The data lineage summary.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#project_id ⇒ String
The project ID included in the data source run activity.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#technical_description ⇒ String
The technical description included in the data source run activity.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#technical_name ⇒ String
The technical name included in the data source run activity.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when data source run activity was updated.
6271 6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 |
# File 'lib/aws-sdk-datazone/types.rb', line 6271 class DataSourceRunActivity < Struct.new( :database, :data_source_run_id, :technical_name, :data_asset_status, :project_id, :data_asset_id, :technical_description, :error_message, :lineage_summary, :created_at, :updated_at) SENSITIVE = [:database, :technical_name, :technical_description] include Aws::Structure end |