Class: Aws::DataZone::Types::DataSourceRunActivity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The activity details of the data source run.

Constant Summary collapse

SENSITIVE =
[:database, :technical_name, :technical_description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when data source run activity was created.

Returns:

  • (Time)


6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#data_asset_idString

The identifier of the asset included in the data source run activity.

Returns:

  • (String)


6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#data_asset_statusString

The status of the asset included in the data source run activity.

Returns:

  • (String)


6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#data_source_run_idString

The identifier of the data source for the data source run activity.

Returns:

  • (String)


6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#databaseString

The database included in the data source run activity.

Returns:

  • (String)


6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

The details of the error message that is returned if the operation cannot be successfully completed.



6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#lineage_summaryTypes::LineageInfo

The data lineage summary.

Returns:



6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#project_idString

The project ID included in the data source run activity.

Returns:

  • (String)


6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#technical_descriptionString

The technical description included in the data source run activity.

Returns:

  • (String)


6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#technical_nameString

The technical name included in the data source run activity.

Returns:

  • (String)


6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end

#updated_atTime

The timestamp of when data source run activity was updated.

Returns:

  • (Time)


6246
6247
6248
6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
# File 'lib/aws-sdk-datazone/types.rb', line 6246

class DataSourceRunActivity < Struct.new(
  :database,
  :data_source_run_id,
  :technical_name,
  :data_asset_status,
  :project_id,
  :data_asset_id,
  :technical_description,
  :error_message,
  :lineage_summary,
  :created_at,
  :updated_at)
  SENSITIVE = [:database, :technical_name, :technical_description]
  include Aws::Structure
end