Class: Aws::DataZone::Types::DataSourceRunActivity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The activity details of the data source run.

Constant Summary collapse

SENSITIVE =
[:database, :technical_description, :technical_name]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when data source run activity was created.

Returns:

  • (Time)


3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end

#data_asset_idString

The identifier of the asset included in the data source run activity.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end

#data_asset_statusString

The status of the asset included in the data source run activity.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end

#data_source_run_idString

The identifier of the data source for the data source run activity.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end

#databaseString

The database included in the data source run activity.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

The details of the error message that is returned if the operation cannot be successfully completed.



3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end

#project_idString

The project ID included in the data source run activity.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end

#technical_descriptionString

The technical description included in the data source run activity.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end

#technical_nameString

The technical name included in the data source run activity.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end

#updated_atTime

The timestamp of when data source run activity was updated.

Returns:

  • (Time)


3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
# File 'lib/aws-sdk-datazone/types.rb', line 3340

class DataSourceRunActivity < Struct.new(
  :created_at,
  :data_asset_id,
  :data_asset_status,
  :data_source_run_id,
  :database,
  :error_message,
  :project_id,
  :technical_description,
  :technical_name,
  :updated_at)
  SENSITIVE = [:database, :technical_description, :technical_name]
  include Aws::Structure
end