Class: Aws::DataZone::Types::DataSourceRunActivity
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceRunActivity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The activity details of the data source run.
Constant Summary collapse
- SENSITIVE =
[:database, :technical_description, :technical_name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when data source run activity was created.
-
#data_asset_id ⇒ String
The identifier of the asset included in the data source run activity.
-
#data_asset_status ⇒ String
The status of the asset included in the data source run activity.
-
#data_source_run_id ⇒ String
The identifier of the data source for the data source run activity.
-
#database ⇒ String
The database included in the data source run activity.
-
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
-
#project_id ⇒ String
The project ID included in the data source run activity.
-
#technical_description ⇒ String
The technical description included in the data source run activity.
-
#technical_name ⇒ String
The technical name included in the data source run activity.
-
#updated_at ⇒ Time
The timestamp of when data source run activity was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when data source run activity was created.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#data_asset_id ⇒ String
The identifier of the asset included in the data source run activity.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#data_asset_status ⇒ String
The status of the asset included in the data source run activity.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#data_source_run_id ⇒ String
The identifier of the data source for the data source run activity.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#database ⇒ String
The database included in the data source run activity.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#project_id ⇒ String
The project ID included in the data source run activity.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#technical_description ⇒ String
The technical description included in the data source run activity.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#technical_name ⇒ String
The technical name included in the data source run activity.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when data source run activity was updated.
3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 |
# File 'lib/aws-sdk-datazone/types.rb', line 3406 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |