Class: Aws::DataZone::Types::DataSourceRunActivity
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceRunActivity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The activity details of the data source run.
Constant Summary collapse
- SENSITIVE =
[:database, :technical_description, :technical_name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when data source run activity was created.
-
#data_asset_id ⇒ String
The identifier of the asset included in the data source run activity.
-
#data_asset_status ⇒ String
The status of the asset included in the data source run activity.
-
#data_source_run_id ⇒ String
The identifier of the data source for the data source run activity.
-
#database ⇒ String
The database included in the data source run activity.
-
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
-
#project_id ⇒ String
The project ID included in the data source run activity.
-
#technical_description ⇒ String
The technical description included in the data source run activity.
-
#technical_name ⇒ String
The technical name included in the data source run activity.
-
#updated_at ⇒ Time
The timestamp of when data source run activity was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when data source run activity was created.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#data_asset_id ⇒ String
The identifier of the asset included in the data source run activity.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#data_asset_status ⇒ String
The status of the asset included in the data source run activity.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#data_source_run_id ⇒ String
The identifier of the data source for the data source run activity.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#database ⇒ String
The database included in the data source run activity.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#project_id ⇒ String
The project ID included in the data source run activity.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#technical_description ⇒ String
The technical description included in the data source run activity.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#technical_name ⇒ String
The technical name included in the data source run activity.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when data source run activity was updated.
2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 |
# File 'lib/aws-sdk-datazone/types.rb', line 2949 class DataSourceRunActivity < Struct.new( :created_at, :data_asset_id, :data_asset_status, :data_source_run_id, :database, :error_message, :project_id, :technical_description, :technical_name, :updated_at) SENSITIVE = [:database, :technical_description, :technical_name] include Aws::Structure end |