Class: Aws::DataZone::Types::DataSourceRunSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of a data source run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when a data source run was created.

Returns:

  • (Time)


6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_idString

The identifier of the data source of the data source run.

Returns:

  • (String)


6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

The details of the error message that is returned if the operation cannot be successfully completed.



6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the data source run.

Returns:

  • (String)


6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_summaryTypes::DataSourceRunLineageSummary

The run lineage summary of a data source.



6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#project_idString

The project ID of the data source run.

Returns:

  • (String)


6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#run_statistics_for_assetsTypes::RunStatisticsForAssets

The asset statistics from the data source run.



6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp of when a data source run was started.

Returns:

  • (Time)


6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the data source run.

Returns:

  • (String)


6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atTime

The timestamp of when a data source run was stopped.

Returns:

  • (Time)


6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the data source run.

Returns:

  • (String)


6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when a data source run was updated.

Returns:

  • (Time)


6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
# File 'lib/aws-sdk-datazone/types.rb', line 6652

class DataSourceRunSummary < Struct.new(
  :id,
  :data_source_id,
  :type,
  :status,
  :project_id,
  :run_statistics_for_assets,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at,
  :lineage_summary)
  SENSITIVE = []
  include Aws::Structure
end