Class: Aws::DataZone::Types::DataSourceRunSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceRunSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of a data source run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when a data source run was created.
-
#data_source_id ⇒ String
The identifier of the data source of the data source run.
-
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of the data source run.
-
#lineage_summary ⇒ Types::DataSourceRunLineageSummary
The run lineage summary of a data source.
-
#project_id ⇒ String
The project ID of the data source run.
-
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from the data source run.
-
#started_at ⇒ Time
The timestamp of when a data source run was started.
-
#status ⇒ String
The status of the data source run.
-
#stopped_at ⇒ Time
The timestamp of when a data source run was stopped.
-
#type ⇒ String
The type of the data source run.
-
#updated_at ⇒ Time
The timestamp of when a data source run was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when a data source run was created.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The identifier of the data source of the data source run.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the data source run.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#lineage_summary ⇒ Types::DataSourceRunLineageSummary
The run lineage summary of a data source.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The project ID of the data source run.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from the data source run.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when a data source run was started.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data source run.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The timestamp of when a data source run was stopped.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the data source run.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when a data source run was updated.
6513 6514 6515 6516 6517 6518 6519 6520 6521 6522 6523 6524 6525 6526 6527 6528 |
# File 'lib/aws-sdk-datazone/types.rb', line 6513 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |