Class: Aws::DataZone::Types::DataSourceRunSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceRunSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of a data source run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when a data source run was created.
-
#data_source_id ⇒ String
The identifier of the data source of the data source run.
-
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of the data source run.
-
#lineage_summary ⇒ Types::DataSourceRunLineageSummary
The run lineage summary of a data source.
-
#project_id ⇒ String
The project ID of the data source run.
-
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from the data source run.
-
#started_at ⇒ Time
The timestamp of when a data source run was started.
-
#status ⇒ String
The status of the data source run.
-
#stopped_at ⇒ Time
The timestamp of when a data source run was stopped.
-
#type ⇒ String
The type of the data source run.
-
#updated_at ⇒ Time
The timestamp of when a data source run was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when a data source run was created.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The identifier of the data source of the data source run.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the data source run.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#lineage_summary ⇒ Types::DataSourceRunLineageSummary
The run lineage summary of a data source.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The project ID of the data source run.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from the data source run.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when a data source run was started.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data source run.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The timestamp of when a data source run was stopped.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the data source run.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when a data source run was updated.
6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 6370 |
# File 'lib/aws-sdk-datazone/types.rb', line 6355 class DataSourceRunSummary < Struct.new( :id, :data_source_id, :type, :status, :project_id, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at, :lineage_summary) SENSITIVE = [] include Aws::Structure end |