Class: Aws::DataZone::Types::DataSourceRunSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceRunSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of a data source run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when a data source run was created.
-
#data_source_id ⇒ String
The identifier of the data source of the data source run.
-
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of the data source run.
-
#project_id ⇒ String
The project ID of the data source run.
-
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from the data source run.
-
#started_at ⇒ Time
The timestamp of when a data source run was started.
-
#status ⇒ String
The status of the data source run.
-
#stopped_at ⇒ Time
The timestamp of when a data source run was stopped.
-
#type ⇒ String
The type of the data source run.
-
#updated_at ⇒ Time
The timestamp of when a data source run was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when a data source run was created.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The identifier of the data source of the data source run.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the data source run.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The project ID of the data source run.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from the data source run.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when a data source run was started.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data source run.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The timestamp of when a data source run was stopped.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the data source run.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when a data source run was updated.
4305 4306 4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 |
# File 'lib/aws-sdk-datazone/types.rb', line 4305 class DataSourceRunSummary < Struct.new( :created_at, :data_source_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |