Class: Aws::DataZone::Types::DataSourceRunSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of a data source run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when a data source run was created.

Returns:

  • (Time)


3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_idString

The identifier of the data source of the data source run.

Returns:

  • (String)


3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

The details of the error message that is returned if the operation cannot be successfully completed.



3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the data source run.

Returns:

  • (String)


3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#project_idString

The project ID of the data source run.

Returns:

  • (String)


3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#run_statistics_for_assetsTypes::RunStatisticsForAssets

The asset statistics from the data source run.



3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp of when a data source run was started.

Returns:

  • (Time)


3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the data source run.

Returns:

  • (String)


3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atTime

The timestamp of when a data source run was stopped.

Returns:

  • (Time)


3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the data source run.

Returns:

  • (String)


3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when a data source run was updated.

Returns:

  • (Time)


3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
# File 'lib/aws-sdk-datazone/types.rb', line 3942

class DataSourceRunSummary < Struct.new(
  :created_at,
  :data_source_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end