Class: Aws::DataZone::Types::DataSourceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of the data source.

Constant Summary collapse

SENSITIVE =
[:name, :schedule, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_idString

The connection ID that’s part of the data source summary.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#created_atTime

The timestamp of when the data source was created.

Returns:

  • (Time)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#data_source_idString

The ID of the data source.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#descriptionString

The data source description.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which the data source exists.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#enable_settingString

Specifies whether the data source is enabled.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#environment_idString

The ID of the environment in which the data source exists.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#last_run_asset_countInteger

The count of the assets created during the last data source run.

Returns:

  • (Integer)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#last_run_atTime

The timestamp of when the data source run was last performed.

Returns:

  • (Time)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#last_run_error_messageTypes::DataSourceErrorMessage

The details of the error message that is returned if the operation cannot be successfully completed.



6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#last_run_statusString

The status of the last data source run.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#nameString

The name of the data source.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#scheduleTypes::ScheduleConfiguration

The details of the schedule of the data source runs.



6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#statusString

The status of the data source.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#typeString

The type of the data source.

Returns:

  • (String)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the data source was updated.

Returns:

  • (Time)


6618
6619
6620
6621
6622
6623
6624
6625
6626
6627
6628
6629
6630
6631
6632
6633
6634
6635
6636
6637
# File 'lib/aws-sdk-datazone/types.rb', line 6618

class DataSourceSummary < Struct.new(
  :domain_id,
  :environment_id,
  :connection_id,
  :data_source_id,
  :name,
  :type,
  :status,
  :enable_setting,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :created_at,
  :updated_at,
  :description)
  SENSITIVE = [:name, :schedule, :description]
  include Aws::Structure
end