Class: Aws::DataZone::Types::DataSourceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the data source.
Constant Summary collapse
- SENSITIVE =
[:name, :schedule, :description]
Instance Attribute Summary collapse
-
#connection_id ⇒ String
The connection ID that’s part of the data source summary.
-
#created_at ⇒ Time
The timestamp of when the data source was created.
-
#data_source_id ⇒ String
The ID of the data source.
-
#description ⇒ String
The data source description.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
-
#enable_setting ⇒ String
Specifies whether the data source is enabled.
-
#environment_id ⇒ String
The ID of the environment in which the data source exists.
-
#last_run_asset_count ⇒ Integer
The count of the assets created during the last data source run.
-
#last_run_at ⇒ Time
The timestamp of when the data source run was last performed.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
-
#last_run_status ⇒ String
The status of the last data source run.
-
#name ⇒ String
The name of the data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The details of the schedule of the data source runs.
-
#status ⇒ String
The status of the data source.
-
#type ⇒ String
The type of the data source.
-
#updated_at ⇒ Time
The timestamp of when the data source was updated.
Instance Attribute Details
#connection_id ⇒ String
The connection ID that’s part of the data source summary.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the data source was created.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#data_source_id ⇒ String
The ID of the data source.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#description ⇒ String
The data source description.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#enable_setting ⇒ String
Specifies whether the data source is enabled.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment in which the data source exists.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#last_run_asset_count ⇒ Integer
The count of the assets created during the last data source run.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp of when the data source run was last performed.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#last_run_status ⇒ String
The status of the last data source run.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#name ⇒ String
The name of the data source.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The details of the schedule of the data source runs.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#status ⇒ String
The status of the data source.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#type ⇒ String
The type of the data source.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source was updated.
6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-datazone/types.rb', line 6417 class DataSourceSummary < Struct.new( :domain_id, :environment_id, :connection_id, :data_source_id, :name, :type, :status, :enable_setting, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :created_at, :updated_at, :description) SENSITIVE = [:name, :schedule, :description] include Aws::Structure end |