Class: Aws::DataZone::Types::DataSourceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the data source.
Constant Summary collapse
- SENSITIVE =
[:description, :name, :schedule]
Instance Attribute Summary collapse
-
#connection_id ⇒ String
The connection ID that’s part of the data source summary.
-
#created_at ⇒ Time
The timestamp of when the data source was created.
-
#data_source_id ⇒ String
The ID of the data source.
-
#description ⇒ String
The data source description.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
-
#enable_setting ⇒ String
Specifies whether the data source is enabled.
-
#environment_id ⇒ String
The ID of the environment in which the data source exists.
-
#last_run_asset_count ⇒ Integer
The count of the assets created during the last data source run.
-
#last_run_at ⇒ Time
The timestamp of when the data source run was last performed.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
-
#last_run_status ⇒ String
The status of the last data source run.
-
#name ⇒ String
The name of the data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The details of the schedule of the data source runs.
-
#status ⇒ String
The status of the data source.
-
#type ⇒ String
The type of the data source.
-
#updated_at ⇒ Time
The timestamp of when the data source was updated.
Instance Attribute Details
#connection_id ⇒ String
The connection ID that’s part of the data source summary.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the data source was created.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#data_source_id ⇒ String
The ID of the data source.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#description ⇒ String
The data source description.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
Specifies whether the data source is enabled.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment in which the data source exists.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_asset_count ⇒ Integer
The count of the assets created during the last data source run.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp of when the data source run was last performed.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_status ⇒ String
The status of the last data source run.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#name ⇒ String
The name of the data source.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The details of the schedule of the data source runs.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#status ⇒ String
The status of the data source.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#type ⇒ String
The type of the data source.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source was updated.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 |
# File 'lib/aws-sdk-datazone/types.rb', line 5466 class DataSourceSummary < Struct.new( :connection_id, :created_at, :data_source_id, :description, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |