Class: Aws::DataZone::Types::DataSourceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of the data source.

Constant Summary collapse

SENSITIVE =
[:name, :schedule]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the data source was created.

Returns:

  • (Time)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#data_source_idString

The ID of the data source.

Returns:

  • (String)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which the data source exists.

Returns:

  • (String)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#enable_settingString

Specifies whether the data source is enabled.

Returns:

  • (String)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#environment_idString

The ID of the environment in which the data source exists.

Returns:

  • (String)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#last_run_asset_countInteger

The count of the assets created during the last data source run.

Returns:

  • (Integer)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#last_run_atTime

The timestamp of when the data source run was last performed.

Returns:

  • (Time)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#last_run_error_messageTypes::DataSourceErrorMessage

The details of the error message that is returned if the operation cannot be successfully completed.



3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#last_run_statusString

The status of the last data source run.

Returns:

  • (String)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#nameString

The name of the data source.

Returns:

  • (String)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#scheduleTypes::ScheduleConfiguration

The details of the schedule of the data source runs.



3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#statusString

The status of the data source.

Returns:

  • (String)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#typeString

The type of the data source.

Returns:

  • (String)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the data source was updated.

Returns:

  • (Time)


3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/aws-sdk-datazone/types.rb', line 3548

class DataSourceSummary < Struct.new(
  :created_at,
  :data_source_id,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:name, :schedule]
  include Aws::Structure
end