Class: Aws::DataZone::Types::DataSourceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DataSourceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the data source.
Constant Summary collapse
- SENSITIVE =
[:name, :schedule]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the data source was created.
-
#data_source_id ⇒ String
The ID of the data source.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
-
#enable_setting ⇒ String
Specifies whether the data source is enabled.
-
#environment_id ⇒ String
The ID of the environment in which the data source exists.
-
#last_run_asset_count ⇒ Integer
The count of the assets created during the last data source run.
-
#last_run_at ⇒ Time
The timestamp of when the data source run was last performed.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
-
#last_run_status ⇒ String
The status of the last data source run.
-
#name ⇒ String
The name of the data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The details of the schedule of the data source runs.
-
#status ⇒ String
The status of the data source.
-
#type ⇒ String
The type of the data source.
-
#updated_at ⇒ Time
The timestamp of when the data source was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the data source was created.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#data_source_id ⇒ String
The ID of the data source.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
Specifies whether the data source is enabled.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment in which the data source exists.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#last_run_asset_count ⇒ Integer
The count of the assets created during the last data source run.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp of when the data source run was last performed.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The details of the error message that is returned if the operation cannot be successfully completed.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#last_run_status ⇒ String
The status of the last data source run.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#name ⇒ String
The name of the data source.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The details of the schedule of the data source runs.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#status ⇒ String
The status of the data source.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#type ⇒ String
The type of the data source.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source was updated.
3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 |
# File 'lib/aws-sdk-datazone/types.rb', line 3548 class DataSourceSummary < Struct.new( :created_at, :data_source_id, :domain_id, :enable_setting, :environment_id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :schedule, :status, :type, :updated_at) SENSITIVE = [:name, :schedule] include Aws::Structure end |