Class: Aws::DataZone::Types::DataSourceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of the data source.

Constant Summary collapse

SENSITIVE =
[:description, :name, :schedule]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_idString

The connection ID that’s part of the data source summary.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#created_atTime

The timestamp of when the data source was created.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#data_source_idString

The ID of the data source.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#descriptionString

The data source description.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which the data source exists.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#enable_settingString

Specifies whether the data source is enabled.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#environment_idString

The ID of the environment in which the data source exists.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#last_run_asset_countInteger

The count of the assets created during the last data source run.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#last_run_atTime

The timestamp of when the data source run was last performed.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#last_run_error_messageTypes::DataSourceErrorMessage

The details of the error message that is returned if the operation cannot be successfully completed.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#last_run_statusString

The status of the last data source run.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#nameString

The name of the data source.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#scheduleTypes::ScheduleConfiguration

The details of the schedule of the data source runs.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#statusString

The status of the data source.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#typeString

The type of the data source.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the data source was updated.

Returns:



5341
5342
5343
5344
5345
5346
5347
5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
# File 'lib/aws-sdk-datazone/types.rb', line 5341

class DataSourceSummary < Struct.new(
  :connection_id,
  :created_at,
  :data_source_id,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :last_run_asset_count,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :schedule,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end