Class: Aws::DataZone::Types::DeleteDataExportConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DeleteDataExportConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_identifier ⇒ String
The domain ID for which you want to delete the data export configuration.
Instance Attribute Details
#domain_identifier ⇒ String
The domain ID for which you want to delete the data export configuration.
6542 6543 6544 6545 6546 |
# File 'lib/aws-sdk-datazone/types.rb', line 6542 class DeleteDataExportConfigurationInput < Struct.new( :domain_identifier) SENSITIVE = [] include Aws::Structure end |