Class: Aws::DataZone::Types::DeleteDataSourceOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name, :schedule]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_forms_outputArray<Types::FormOutput>

The asset data forms associated with this data source.

Returns:



3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#configurationTypes::DataSourceConfigurationOutput

The configuration of the data source that is deleted.



3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#created_atTime

The timestamp of when this data source was created.

Returns:

  • (Time)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#descriptionString

The description of the data source that is deleted.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which the data source is deleted.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#enable_settingString

The enable setting of the data source that specifies whether the data source is enabled or disabled.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#environment_idString

The ID of the environemnt associated with this data source.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

Specifies the error message that is returned if the operation cannot be successfully completed.



3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#idString

The ID of the data source that is deleted.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#last_run_atTime

The timestamp of when the data source was last run.

Returns:

  • (Time)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#last_run_error_messageTypes::DataSourceErrorMessage

Specifies the error message that is returned if the operation cannot be successfully completed.



3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#last_run_statusString

The status of the last run of this data source.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#nameString

The name of the data source that is deleted.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#project_idString

The ID of the project in which this data source exists and from which it’s deleted.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#publish_on_importBoolean

Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.

Returns:

  • (Boolean)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#retain_permissions_on_revoke_failureBoolean

Specifies that the granted permissions are retained in case of a self-subscribe functionality failure for a data source.

Returns:

  • (Boolean)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#scheduleTypes::ScheduleConfiguration

The schedule of runs for this data source.



3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#self_grant_statusTypes::SelfGrantStatusOutput

Specifies the status of the self-granting functionality.



3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#statusString

The status of this data source.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#typeString

The type of this data source.

Returns:

  • (String)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end

#updated_atTime

The timestamp of when this data source was updated.

Returns:

  • (Time)


3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
3778
3779
3780
3781
3782
# File 'lib/aws-sdk-datazone/types.rb', line 3758

class DeleteDataSourceOutput < Struct.new(
  :asset_forms_output,
  :configuration,
  :created_at,
  :description,
  :domain_id,
  :enable_setting,
  :environment_id,
  :error_message,
  :id,
  :last_run_at,
  :last_run_error_message,
  :last_run_status,
  :name,
  :project_id,
  :publish_on_import,
  :retain_permissions_on_revoke_failure,
  :schedule,
  :self_grant_status,
  :status,
  :type,
  :updated_at)
  SENSITIVE = [:description, :name, :schedule]
  include Aws::Structure
end