Class: Aws::DataZone::Types::DeleteDataSourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DeleteDataSourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name, :schedule]
Instance Attribute Summary collapse
-
#asset_forms_output ⇒ Array<Types::FormOutput>
The asset data forms associated with this data source.
-
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration of the data source that is deleted.
-
#created_at ⇒ Time
The timestamp of when this data source was created.
-
#description ⇒ String
The description of the data source that is deleted.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source is deleted.
-
#enable_setting ⇒ String
The enable setting of the data source that specifies whether the data source is enabled or disabled.
-
#environment_id ⇒ String
The ID of the environemnt associated with this data source.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The ID of the data source that is deleted.
-
#last_run_at ⇒ Time
The timestamp of when the data source was last run.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#last_run_status ⇒ String
The status of the last run of this data source.
-
#name ⇒ String
The name of the data source that is deleted.
-
#project_id ⇒ String
The ID of the project in which this data source exists and from which it’s deleted.
-
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
-
#schedule ⇒ Types::ScheduleConfiguration
The schedule of runs for this data source.
-
#status ⇒ String
The status of this data source.
-
#type ⇒ String
The type of this data source.
-
#updated_at ⇒ Time
The timestamp of when this data source was updated.
Instance Attribute Details
#asset_forms_output ⇒ Array<Types::FormOutput>
The asset data forms associated with this data source.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration of the data source that is deleted.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when this data source was created.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#description ⇒ String
The description of the data source that is deleted.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source is deleted.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
The enable setting of the data source that specifies whether the data source is enabled or disabled.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environemnt associated with this data source.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#id ⇒ String
The ID of the data source that is deleted.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp of when the data source was last run.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_status ⇒ String
The status of the last run of this data source.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#name ⇒ String
The name of the data source that is deleted.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#project_id ⇒ String
The ID of the project in which this data source exists and from which it’s deleted.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The schedule of runs for this data source.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#status ⇒ String
The status of this data source.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#type ⇒ String
The type of this data source.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this data source was updated.
3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 |
# File 'lib/aws-sdk-datazone/types.rb', line 3264 class DeleteDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |