Class: Aws::DataZone::Types::DeleteDomainInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3303
3304
3305
3306
3307
3308
# File 'lib/aws-sdk-datazone/types.rb', line 3303

class DeleteDomainInput < Struct.new(
  :client_token,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the Amazon Web Services domain that is to be deleted.

Returns:

  • (String)


3303
3304
3305
3306
3307
3308
# File 'lib/aws-sdk-datazone/types.rb', line 3303

class DeleteDomainInput < Struct.new(
  :client_token,
  :identifier)
  SENSITIVE = []
  include Aws::Structure
end