Class: Aws::DataZone::Types::DeleteSubscriptionGrantOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::DeleteSubscriptionGrantOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assets ⇒ Array<Types::SubscribedAsset>
The assets for which the subsctiption grant that is deleted gave access.
-
#created_at ⇒ Time
The timestamp of when the subscription grant that is deleted was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the subscription grant that is deleted.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription grant is deleted.
-
#environment_id ⇒ String
The ID of the environment in which the subscription grant is deleted.
-
#granted_entity ⇒ Types::GrantedEntity
The entity to which the subscription is deleted.
-
#id ⇒ String
The ID of the subscription grant that is deleted.
-
#status ⇒ String
The status of the subscription grant that is deleted.
-
#subscription_id ⇒ String
The identifier of the subsctiption whose subscription grant is to be deleted.
-
#subscription_target_id ⇒ String
The ID of the subscription target associated with the subscription grant that is deleted.
-
#updated_at ⇒ Time
The timestamp of when the subscription grant that is deleted was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant that is deleted.
Instance Attribute Details
#assets ⇒ Array<Types::SubscribedAsset>
The assets for which the subsctiption grant that is deleted gave access.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the subscription grant that is deleted was created.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the subscription grant that is deleted.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the subscription grant is deleted.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment in which the subscription grant is deleted.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#granted_entity ⇒ Types::GrantedEntity
The entity to which the subscription is deleted.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the subscription grant that is deleted.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the subscription grant that is deleted.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#subscription_id ⇒ String
The identifier of the subsctiption whose subscription grant is to be deleted.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#subscription_target_id ⇒ String
The ID of the subscription target associated with the subscription grant that is deleted.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription grant that is deleted was updated.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant that is deleted.
7153 7154 7155 7156 7157 7158 7159 7160 7161 7162 7163 7164 7165 7166 7167 7168 |
# File 'lib/aws-sdk-datazone/types.rb', line 7153 class DeleteSubscriptionGrantOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |