Class: Aws::DataZone::Types::EnvironmentActionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::EnvironmentActionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details about the specified action configured for an environment. For example, the details of the specified console links for an analytics tool that is available in this environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The environment action description.
-
#domain_id ⇒ String
The Amazon DataZone domain ID of the environment action.
-
#environment_id ⇒ String
The environment ID of the environment action.
-
#id ⇒ String
The ID of the environment action.
-
#name ⇒ String
The name of the environment action.
-
#parameters ⇒ Types::ActionParameters
The parameters of the environment action.
Instance Attribute Details
#description ⇒ String
The environment action description.
5378 5379 5380 5381 5382 5383 5384 5385 5386 5387 |
# File 'lib/aws-sdk-datazone/types.rb', line 5378 class EnvironmentActionSummary < Struct.new( :description, :domain_id, :environment_id, :id, :name, :parameters) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The Amazon DataZone domain ID of the environment action.
5378 5379 5380 5381 5382 5383 5384 5385 5386 5387 |
# File 'lib/aws-sdk-datazone/types.rb', line 5378 class EnvironmentActionSummary < Struct.new( :description, :domain_id, :environment_id, :id, :name, :parameters) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The environment ID of the environment action.
5378 5379 5380 5381 5382 5383 5384 5385 5386 5387 |
# File 'lib/aws-sdk-datazone/types.rb', line 5378 class EnvironmentActionSummary < Struct.new( :description, :domain_id, :environment_id, :id, :name, :parameters) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the environment action.
5378 5379 5380 5381 5382 5383 5384 5385 5386 5387 |
# File 'lib/aws-sdk-datazone/types.rb', line 5378 class EnvironmentActionSummary < Struct.new( :description, :domain_id, :environment_id, :id, :name, :parameters) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the environment action.
5378 5379 5380 5381 5382 5383 5384 5385 5386 5387 |
# File 'lib/aws-sdk-datazone/types.rb', line 5378 class EnvironmentActionSummary < Struct.new( :description, :domain_id, :environment_id, :id, :name, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Types::ActionParameters
The parameters of the environment action.
5378 5379 5380 5381 5382 5383 5384 5385 5386 5387 |
# File 'lib/aws-sdk-datazone/types.rb', line 5378 class EnvironmentActionSummary < Struct.new( :description, :domain_id, :environment_id, :id, :name, :parameters) SENSITIVE = [] include Aws::Structure end |