Class: Aws::DataZone::Types::EnvironmentSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::EnvironmentSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of an environment.
Constant Summary collapse
- SENSITIVE =
[:name, :description, :environment_configuration_id, :environment_configuration_name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which an environment exists.
-
#aws_account_region ⇒ String
The Amazon Web Services Region in which an environment exists.
-
#created_at ⇒ Time
The timestamp of when the environment was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the environment.
-
#description ⇒ String
The description of the environment.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the environment exists.
-
#environment_configuration_id ⇒ String
The configuration ID with which the environment is created.
-
#environment_configuration_name ⇒ String
The configuration name with which the environment is created.
-
#environment_profile_id ⇒ String
The identifier of the environment profile with which the environment was created.
-
#id ⇒ String
The identifier of the environment.
-
#name ⇒ String
The name of the environment.
-
#project_id ⇒ String
The identifier of the project in which the environment exists.
-
#provider ⇒ String
The provider of the environment.
-
#status ⇒ String
The status of the environment.
-
#updated_at ⇒ Time
The timestamp of when the environment was updated.
Instance Attribute Details
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which an environment exists.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services Region in which an environment exists.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the environment was created.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the environment.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#description ⇒ String
The description of the environment.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the environment exists.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_configuration_id ⇒ String
The configuration ID with which the environment is created.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_configuration_name ⇒ String
The configuration name with which the environment is created.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_profile_id ⇒ String
The identifier of the environment profile with which the environment was created.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#id ⇒ String
The identifier of the environment.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#name ⇒ String
The name of the environment.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project in which the environment exists.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provider ⇒ String
The provider of the environment.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#status ⇒ String
The status of the environment.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the environment was updated.
8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'lib/aws-sdk-datazone/types.rb', line 8193 class EnvironmentSummary < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :status, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |