Class: Aws::DataZone::Types::EnvironmentSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::EnvironmentSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of an environment.
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which an environment exists.
-
#aws_account_region ⇒ String
The Amazon Web Services Region in which an environment exists.
-
#created_at ⇒ Time
The timestamp of when the environment was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the environment.
-
#description ⇒ String
The description of the environment.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the environment exists.
-
#environment_profile_id ⇒ String
The identifier of the environment profile with which the environment was created.
-
#id ⇒ String
The identifier of the environment.
-
#name ⇒ String
The name of the environment.
-
#project_id ⇒ String
The identifier of the project in which the environment exists.
-
#provider ⇒ String
The provider of the environment.
-
#status ⇒ String
The status of the environment.
-
#updated_at ⇒ Time
The timestamp of when the environment was updated.
Instance Attribute Details
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which an environment exists.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services Region in which an environment exists.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the environment was created.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the environment.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description of the environment.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the environment exists.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_profile_id ⇒ String
The identifier of the environment profile with which the environment was created.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The identifier of the environment.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of the environment.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project in which the environment exists.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#provider ⇒ String
The provider of the environment.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#status ⇒ String
The status of the environment.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the environment was updated.
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 |
# File 'lib/aws-sdk-datazone/types.rb', line 4064 class EnvironmentSummary < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_profile_id, :id, :name, :project_id, :provider, :status, :updated_at) SENSITIVE = [:description, :name] include Aws::Structure end |