Class: Aws::DataZone::Types::FormTypeData
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::FormTypeData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the metadata form type.
Constant Summary collapse
- SENSITIVE =
[:name, :model, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the metadata form type was created.
-
#created_by ⇒ String
The Amazon DataZone user who created teh metadata form type.
-
#description ⇒ String
The description of the metadata form type.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type exists.
-
#imports ⇒ Array<Types::Import>
The imports specified in the form type.
-
#model ⇒ Types::Model
The model of the form type.
-
#name ⇒ String
The name of the form type.
-
#origin_domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type was originally created.
-
#origin_project_id ⇒ String
The identifier of the project in which the form type was originally created.
-
#owning_project_id ⇒ String
The identifier of the project that owns the form type.
-
#revision ⇒ String
The revision of the form type.
-
#status ⇒ String
The status of the form type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the metadata form type was created.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created teh metadata form type.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#description ⇒ String
The description of the metadata form type.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type exists.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#imports ⇒ Array<Types::Import>
The imports specified in the form type.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#model ⇒ Types::Model
The model of the form type.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#name ⇒ String
The name of the form type.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#origin_domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type was originally created.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#origin_project_id ⇒ String
The identifier of the project in which the form type was originally created.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the form type.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#revision ⇒ String
The revision of the form type.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#status ⇒ String
The status of the form type.
8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-datazone/types.rb', line 8764 class FormTypeData < Struct.new( :domain_id, :name, :revision, :model, :status, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |