Class: Aws::DataZone::Types::FormTypeData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of the metadata form type.

Constant Summary collapse

SENSITIVE =
[:name, :model, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the metadata form type was created.

Returns:

  • (Time)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created teh metadata form type.

Returns:

  • (String)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#descriptionString

The description of the metadata form type.

Returns:

  • (String)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon DataZone domain in which the form type exists.

Returns:

  • (String)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#importsArray<Types::Import>

The imports specified in the form type.

Returns:



8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#modelTypes::Model

The model of the form type.

Returns:



8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#nameString

The name of the form type.

Returns:

  • (String)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#origin_domain_idString

The identifier of the Amazon DataZone domain in which the form type was originally created.

Returns:

  • (String)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#origin_project_idString

The identifier of the project in which the form type was originally created.

Returns:

  • (String)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the form type.

Returns:

  • (String)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#revisionString

The revision of the form type.

Returns:

  • (String)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#statusString

The status of the form type.

Returns:

  • (String)


8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
# File 'lib/aws-sdk-datazone/types.rb', line 8554

class FormTypeData < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :status,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end