Class: Aws::DataZone::Types::FormTypeData
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::FormTypeData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the metadata form type.
Constant Summary collapse
- SENSITIVE =
[:description, :model, :name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the metadata form type was created.
-
#created_by ⇒ String
The Amazon DataZone user who created teh metadata form type.
-
#description ⇒ String
The description of the metadata form type.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type exists.
-
#imports ⇒ Array<Types::Import>
The imports specified in the form type.
-
#model ⇒ Types::Model
The model of the form type.
-
#name ⇒ String
The name of the form type.
-
#origin_domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type was originally created.
-
#origin_project_id ⇒ String
The identifier of the project in which the form type was originally created.
-
#owning_project_id ⇒ String
The identifier of the project that owns the form type.
-
#revision ⇒ String
The revision of the form type.
-
#status ⇒ String
The status of the form type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the metadata form type was created.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created teh metadata form type.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#description ⇒ String
The description of the metadata form type.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type exists.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#imports ⇒ Array<Types::Import>
The imports specified in the form type.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#model ⇒ Types::Model
The model of the form type.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#name ⇒ String
The name of the form type.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#origin_domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the form type was originally created.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#origin_project_id ⇒ String
The identifier of the project in which the form type was originally created.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the form type.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#revision ⇒ String
The revision of the form type.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#status ⇒ String
The status of the form type.
4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 4734 4735 4736 4737 4738 |
# File 'lib/aws-sdk-datazone/types.rb', line 4723 class FormTypeData < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |