Class: Aws::DataZone::Types::GetAccountPoolOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#account_sourceTypes::AccountSource

The source of accounts for the account pool. In the current release, it’s either a static list of accounts provided by the customer or a custom Amazon Web Services Lambda handler.



8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_atTime

The timestamp at which the account pool was created.

Returns:

  • (Time)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_byString

The user who created the account pool.

Returns:

  • (String)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the account pool.

Returns:

  • (String)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The ID of the domain in which the account pool lives whose details are to be displayed.

Returns:

  • (String)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_unit_idString

The domain unit ID of the account pool.

Returns:

  • (String)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The ID of the account pool.

Returns:

  • (String)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#last_updated_atTime

The timestamp at which the account pool was last updated.

Returns:

  • (Time)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the account pool.

Returns:

  • (String)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#resolution_strategyString

The mechanism used to resolve the account selection from the account pool.

Returns:

  • (String)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_byString

The user who last updated the account pool.

Returns:

  • (String)


8577
8578
8579
8580
8581
8582
8583
8584
8585
8586
8587
8588
8589
8590
8591
# File 'lib/aws-sdk-datazone/types.rb', line 8577

class GetAccountPoolOutput < Struct.new(
  :domain_id,
  :name,
  :id,
  :description,
  :resolution_strategy,
  :account_source,
  :created_by,
  :created_at,
  :last_updated_at,
  :updated_by,
  :domain_unit_id)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end