Class: Aws::DataZone::Types::GetAssetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetAssetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the asset was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the asset.
-
#description ⇒ String
The description of the Amazon DataZone asset.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain to which the asset belongs.
-
#external_identifier ⇒ String
The external ID of the asset.
-
#first_revision_created_at ⇒ Time
The timestamp of when the first revision of the asset was created.
-
#first_revision_created_by ⇒ String
The Amazon DataZone user who created the first revision of the asset.
-
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the asset.
-
#glossary_terms ⇒ Array<String>
The business glossary terms attached to the asset.
-
#governed_glossary_terms ⇒ Array<String>
The restricted glossary terms attached to an asset.
-
#id ⇒ String
The ID of the asset.
-
#latest_time_series_data_point_forms_output ⇒ Array<Types::TimeSeriesDataPointSummaryFormOutput>
The latest data point that was imported into the time series form for the asset.
-
#listing ⇒ Types::AssetListingDetails
The listing of the asset.
-
#name ⇒ String
The name of the asset.
-
#owning_project_id ⇒ String
The ID of the project that owns the asset.
-
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms attached to the asset.
-
#revision ⇒ String
The revision of the asset.
-
#type_identifier ⇒ String
The ID of the asset type.
-
#type_revision ⇒ String
The revision of the asset type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the asset was created.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain to which the asset belongs.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#external_identifier ⇒ String
The external ID of the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#first_revision_created_at ⇒ Time
The timestamp of when the first revision of the asset was created.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#first_revision_created_by ⇒ String
The Amazon DataZone user who created the first revision of the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The business glossary terms attached to the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#governed_glossary_terms ⇒ Array<String>
The restricted glossary terms attached to an asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The ID of the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#latest_time_series_data_point_forms_output ⇒ Array<Types::TimeSeriesDataPointSummaryFormOutput>
The latest data point that was imported into the time series form for the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#listing ⇒ Types::AssetListingDetails
The listing of the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the project that owns the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms attached to the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#revision ⇒ String
The revision of the asset.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#type_identifier ⇒ String
The ID of the asset type.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |
#type_revision ⇒ String
The revision of the asset type.
9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 9049 9050 |
# File 'lib/aws-sdk-datazone/types.rb', line 9028 class GetAssetOutput < Struct.new( :id, :name, :type_identifier, :type_revision, :external_identifier, :revision, :description, :created_at, :created_by, :first_revision_created_at, :first_revision_created_by, :glossary_terms, :governed_glossary_terms, :owning_project_id, :domain_id, :listing, :forms_output, :read_only_forms_output, :latest_time_series_data_point_forms_output) SENSITIVE = [:name, :description] include Aws::Structure end |