Class: Aws::DataZone::Types::GetAssetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetAssetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the asset was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the asset.
-
#description ⇒ String
The description of the Amazon DataZone asset.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain to which the asset belongs.
-
#external_identifier ⇒ String
The external ID of the asset.
-
#first_revision_created_at ⇒ Time
The timestamp of when the first revision of the asset was created.
-
#first_revision_created_by ⇒ String
The Amazon DataZone user who created the first revision of the asset.
-
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the asset.
-
#glossary_terms ⇒ Array<String>
The business glossary terms attached to the asset.
-
#id ⇒ String
The ID of the asset.
-
#latest_time_series_data_point_forms_output ⇒ Array<Types::TimeSeriesDataPointSummaryFormOutput>
The latest data point that was imported into the time series form for the asset.
-
#listing ⇒ Types::AssetListingDetails
The listing of the asset.
-
#name ⇒ String
The name of the asset.
-
#owning_project_id ⇒ String
The ID of the project that owns the asset.
-
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms attached to the asset.
-
#revision ⇒ String
The revision of the asset.
-
#type_identifier ⇒ String
The ID of the asset type.
-
#type_revision ⇒ String
The revision of the asset type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the asset was created.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain to which the asset belongs.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#external_identifier ⇒ String
The external ID of the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#first_revision_created_at ⇒ Time
The timestamp of when the first revision of the asset was created.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#first_revision_created_by ⇒ String
The Amazon DataZone user who created the first revision of the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The business glossary terms attached to the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The ID of the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#latest_time_series_data_point_forms_output ⇒ Array<Types::TimeSeriesDataPointSummaryFormOutput>
The latest data point that was imported into the time series form for the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#listing ⇒ Types::AssetListingDetails
The listing of the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the project that owns the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#read_only_forms_output ⇒ Array<Types::FormOutput>
The read-only metadata forms attached to the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#revision ⇒ String
The revision of the asset.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#type_identifier ⇒ String
The ID of the asset type.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |
#type_revision ⇒ String
The revision of the asset type.
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 7459 7460 7461 7462 7463 7464 7465 7466 7467 7468 7469 7470 |
# File 'lib/aws-sdk-datazone/types.rb', line 7449 class GetAssetOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :external_identifier, :first_revision_created_at, :first_revision_created_by, :forms_output, :glossary_terms, :id, :latest_time_series_data_point_forms_output, :listing, :name, :owning_project_id, :read_only_forms_output, :revision, :type_identifier, :type_revision) SENSITIVE = [:description, :name] include Aws::Structure end |