Class: Aws::DataZone::Types::GetAssetOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :external_identifier, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the asset was created.

Returns:

  • (Time)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created the asset.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#descriptionString

The description of the Amazon DataZone asset.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain to which the asset belongs.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#external_identifierString

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#first_revision_created_atTime

The timestamp of when the first revision of the asset was created.

Returns:

  • (Time)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#first_revision_created_byString

The Amazon DataZone user who created the first revision of the asset.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#forms_outputArray<Types::FormOutput>

The metadata forms attached to the asset.

Returns:



4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#glossary_termsArray<String>

The business glossary terms attached to the asset.

Returns:

  • (Array<String>)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#idString

The ID of the asset.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#listingTypes::AssetListingDetails



4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#nameString

The name of the asset.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#owning_project_idString

The ID of the project that owns the asset.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#read_only_forms_outputArray<Types::FormOutput>

The read-only metadata forms attached to the asset.

Returns:



4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#revisionString

The revision of the asset.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#type_identifierString

The ID of the asset type.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end

#type_revisionString

The revision of the asset type.

Returns:

  • (String)


4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-datazone/types.rb', line 4416

class GetAssetOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :external_identifier,
  :first_revision_created_at,
  :first_revision_created_by,
  :forms_output,
  :glossary_terms,
  :id,
  :listing,
  :name,
  :owning_project_id,
  :read_only_forms_output,
  :revision,
  :type_identifier,
  :type_revision)
  SENSITIVE = [:description, :external_identifier, :name]
  include Aws::Structure
end