Class: Aws::DataZone::Types::GetAssetTypeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetAssetTypeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the asset type was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the asset type.
-
#description ⇒ String
The description of the asset type.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type exists.
-
#forms_output ⇒ Hash<String,Types::FormEntryOutput>
The metadata forms attached to the asset type.
-
#name ⇒ String
The name of the asset type.
-
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type was originally created.
-
#origin_project_id ⇒ String
The ID of the Amazon DataZone project in which the asset type was originally created.
-
#owning_project_id ⇒ String
The ID of the Amazon DataZone project that owns the asset type.
-
#revision ⇒ String
The revision of the asset type.
-
#updated_at ⇒ Time
The timestamp of when the asset type was updated.
-
#updated_by ⇒ String
The Amazon DataZone user that updated the asset type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the asset type was created.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the asset type.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the asset type.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type exists.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#forms_output ⇒ Hash<String,Types::FormEntryOutput>
The metadata forms attached to the asset type.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the asset type.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type was originally created.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#origin_project_id ⇒ String
The ID of the Amazon DataZone project in which the asset type was originally created.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the Amazon DataZone project that owns the asset type.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#revision ⇒ String
The revision of the asset type.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the asset type was updated.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user that updated the asset type.
8883 8884 8885 8886 8887 8888 8889 8890 8891 8892 8893 8894 8895 8896 8897 8898 |
# File 'lib/aws-sdk-datazone/types.rb', line 8883 class GetAssetTypeOutput < Struct.new( :domain_id, :name, :revision, :description, :forms_output, :owning_project_id, :origin_domain_id, :origin_project_id, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |