Class: Aws::DataZone::Types::GetAssetTypeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetAssetTypeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the asset type was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the asset type.
-
#description ⇒ String
The description of the asset type.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type exists.
-
#forms_output ⇒ Hash<String,Types::FormEntryOutput>
The metadata forms attached to the asset type.
-
#name ⇒ String
The name of the asset type.
-
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type was originally created.
-
#origin_project_id ⇒ String
The ID of the Amazon DataZone project in which the asset type was originally created.
-
#owning_project_id ⇒ String
The ID of the Amazon DataZone project that owns the asset type.
-
#revision ⇒ String
The revision of the asset type.
-
#updated_at ⇒ Time
The timestamp of when the asset type was updated.
-
#updated_by ⇒ String
The Amazon DataZone user that updated the asset type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the asset type was created.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the asset type.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the asset type.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type exists.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#forms_output ⇒ Hash<String,Types::FormEntryOutput>
The metadata forms attached to the asset type.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the asset type.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain in which the asset type was originally created.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#origin_project_id ⇒ String
The ID of the Amazon DataZone project in which the asset type was originally created.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the Amazon DataZone project that owns the asset type.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#revision ⇒ String
The revision of the asset type.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the asset type was updated.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user that updated the asset type.
5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 |
# File 'lib/aws-sdk-datazone/types.rb', line 5766 class GetAssetTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :forms_output, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :updated_at, :updated_by) SENSITIVE = [:description] include Aws::Structure end |