Class: Aws::DataZone::Types::GetDataExportConfigurationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp at which the data export configuration report was created.

Returns:

  • (Time)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-datazone/types.rb', line 9042

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The encryption configuration as part of the data export configuration details.



9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-datazone/types.rb', line 9042

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#is_export_enabledBoolean

Specifies whether the export is enabled.

Returns:

  • (Boolean)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-datazone/types.rb', line 9042

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#s3_table_bucket_arnString

The Amazon S3 table bucket ARN as part of the data export configuration details.

Returns:

  • (String)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-datazone/types.rb', line 9042

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the data export configuration.

Returns:

  • (String)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-datazone/types.rb', line 9042

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp at which the data export configuration report was updated.

Returns:

  • (Time)


9042
9043
9044
9045
9046
9047
9048
9049
9050
9051
# File 'lib/aws-sdk-datazone/types.rb', line 9042

class GetDataExportConfigurationOutput < Struct.new(
  :is_export_enabled,
  :status,
  :encryption_configuration,
  :s3_table_bucket_arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end