Class: Aws::DataZone::Types::GetDataExportConfigurationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDataExportConfigurationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp at which the data export configuration report was created.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration as part of the data export configuration details.
-
#is_export_enabled ⇒ Boolean
Specifies whether the export is enabled.
-
#s3_table_bucket_arn ⇒ String
The Amazon S3 table bucket ARN as part of the data export configuration details.
-
#status ⇒ String
The status of the data export configuration.
-
#updated_at ⇒ Time
The timestamp at which the data export configuration report was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp at which the data export configuration report was created.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 |
# File 'lib/aws-sdk-datazone/types.rb', line 9042 class GetDataExportConfigurationOutput < Struct.new( :is_export_enabled, :status, :encryption_configuration, :s3_table_bucket_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration as part of the data export configuration details.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 |
# File 'lib/aws-sdk-datazone/types.rb', line 9042 class GetDataExportConfigurationOutput < Struct.new( :is_export_enabled, :status, :encryption_configuration, :s3_table_bucket_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#is_export_enabled ⇒ Boolean
Specifies whether the export is enabled.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 |
# File 'lib/aws-sdk-datazone/types.rb', line 9042 class GetDataExportConfigurationOutput < Struct.new( :is_export_enabled, :status, :encryption_configuration, :s3_table_bucket_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#s3_table_bucket_arn ⇒ String
The Amazon S3 table bucket ARN as part of the data export configuration details.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 |
# File 'lib/aws-sdk-datazone/types.rb', line 9042 class GetDataExportConfigurationOutput < Struct.new( :is_export_enabled, :status, :encryption_configuration, :s3_table_bucket_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data export configuration.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 |
# File 'lib/aws-sdk-datazone/types.rb', line 9042 class GetDataExportConfigurationOutput < Struct.new( :is_export_enabled, :status, :encryption_configuration, :s3_table_bucket_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp at which the data export configuration report was updated.
9042 9043 9044 9045 9046 9047 9048 9049 9050 9051 |
# File 'lib/aws-sdk-datazone/types.rb', line 9042 class GetDataExportConfigurationOutput < Struct.new( :is_export_enabled, :status, :encryption_configuration, :s3_table_bucket_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |