Class: Aws::DataZone::Types::GetDataSourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDataSourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :schedule]
Instance Attribute Summary collapse
-
#asset_forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the assets created by this data source.
-
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration of the data source.
-
#connection_id ⇒ String
The ID of the connection.
-
#created_at ⇒ Time
The timestamp of when the data source was created.
-
#description ⇒ String
The description of the data source.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
-
#enable_setting ⇒ String
Specifies whether this data source is enabled or not.
-
#environment_id ⇒ String
The ID of the environment where this data source creates and publishes assets,.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The ID of the data source.
-
#last_run_asset_count ⇒ Integer
The number of assets created by the data source during its last run.
-
#last_run_at ⇒ Time
The timestamp of the last run of the data source.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#last_run_status ⇒ String
The status of the last run of the data source.
-
#name ⇒ String
The name of the data source.
-
#project_id ⇒ String
The ID of the project where the data source creates and publishes assets.
-
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
-
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation configuration of the data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
-
#self_grant_status ⇒ Types::SelfGrantStatusOutput
Specifies the status of the self-granting functionality.
-
#status ⇒ String
The status of the data source.
-
#type ⇒ String
The type of the data source.
-
#updated_at ⇒ Time
The timestamp of when the data source was updated.
Instance Attribute Details
#asset_forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the assets created by this data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration of the data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#connection_id ⇒ String
The ID of the connection.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the data source was created.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#description ⇒ String
The description of the data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
Specifies whether this data source is enabled or not.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment where this data source creates and publishes assets,
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#id ⇒ String
The ID of the data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#last_run_asset_count ⇒ Integer
The number of assets created by the data source during its last run.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp of the last run of the data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#last_run_status ⇒ String
The status of the last run of the data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#name ⇒ String
The name of the data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#project_id ⇒ String
The ID of the project where the data source creates and publishes assets.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation configuration of the data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#self_grant_status ⇒ Types::SelfGrantStatusOutput
Specifies the status of the self-granting functionality.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#status ⇒ String
The status of the data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#type ⇒ String
The type of the data source.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source was updated.
9583 9584 9585 9586 9587 9588 9589 9590 9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 9609 |
# File 'lib/aws-sdk-datazone/types.rb', line 9583 class GetDataSourceOutput < Struct.new( :id, :status, :type, :name, :description, :domain_id, :project_id, :environment_id, :connection_id, :configuration, :recommendation, :enable_setting, :publish_on_import, :asset_forms_output, :schedule, :last_run_status, :last_run_at, :last_run_error_message, :last_run_asset_count, :error_message, :created_at, :updated_at, :self_grant_status) SENSITIVE = [:name, :description, :schedule] include Aws::Structure end |