Class: Aws::DataZone::Types::GetDataSourceOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description, :schedule]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_forms_outputArray<Types::FormOutput>

The metadata forms attached to the assets created by this data source.

Returns:



9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#configurationTypes::DataSourceConfigurationOutput

The configuration of the data source.



9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#connection_idString

The ID of the connection.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#created_atTime

The timestamp of when the data source was created.

Returns:

  • (Time)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#descriptionString

The description of the data source.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which the data source exists.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#enable_settingString

Specifies whether this data source is enabled or not.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#environment_idString

The ID of the environment where this data source creates and publishes assets,

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

Specifies the error message that is returned if the operation cannot be successfully completed.



9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#idString

The ID of the data source.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#last_run_asset_countInteger

The number of assets created by the data source during its last run.

Returns:

  • (Integer)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#last_run_atTime

The timestamp of the last run of the data source.

Returns:

  • (Time)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#last_run_error_messageTypes::DataSourceErrorMessage

Specifies the error message that is returned if the operation cannot be successfully completed.



9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#last_run_statusString

The status of the last run of the data source.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#nameString

The name of the data source.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#project_idString

The ID of the project where the data source creates and publishes assets.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#publish_on_importBoolean

Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.

Returns:

  • (Boolean)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#recommendationTypes::RecommendationConfiguration

The recommendation configuration of the data source.



9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#scheduleTypes::ScheduleConfiguration

The schedule of the data source runs.



9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#self_grant_statusTypes::SelfGrantStatusOutput

Specifies the status of the self-granting functionality.



9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#statusString

The status of the data source.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#typeString

The type of the data source.

Returns:

  • (String)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the data source was updated.

Returns:

  • (Time)


9290
9291
9292
9293
9294
9295
9296
9297
9298
9299
9300
9301
9302
9303
9304
9305
9306
9307
9308
9309
9310
9311
9312
9313
9314
9315
9316
# File 'lib/aws-sdk-datazone/types.rb', line 9290

class GetDataSourceOutput < Struct.new(
  :id,
  :status,
  :type,
  :name,
  :description,
  :domain_id,
  :project_id,
  :environment_id,
  :connection_id,
  :configuration,
  :recommendation,
  :enable_setting,
  :publish_on_import,
  :asset_forms_output,
  :schedule,
  :last_run_status,
  :last_run_at,
  :last_run_error_message,
  :last_run_asset_count,
  :error_message,
  :created_at,
  :updated_at,
  :self_grant_status)
  SENSITIVE = [:name, :description, :schedule]
  include Aws::Structure
end