Class: Aws::DataZone::Types::GetDataSourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDataSourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name, :schedule]
Instance Attribute Summary collapse
-
#asset_forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the assets created by this data source.
-
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration of the data source.
-
#connection_id ⇒ String
The ID of the connection.
-
#created_at ⇒ Time
The timestamp of when the data source was created.
-
#description ⇒ String
The description of the data source.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
-
#enable_setting ⇒ String
Specifies whether this data source is enabled or not.
-
#environment_id ⇒ String
The ID of the environment where this data source creates and publishes assets,.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The ID of the data source.
-
#last_run_asset_count ⇒ Integer
The number of assets created by the data source during its last run.
-
#last_run_at ⇒ Time
The timestamp of the last run of the data source.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#last_run_status ⇒ String
The status of the last run of the data source.
-
#name ⇒ String
The name of the data source.
-
#project_id ⇒ String
The ID of the project where the data source creates and publishes assets.
-
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
-
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation configuration of the data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
-
#self_grant_status ⇒ Types::SelfGrantStatusOutput
Specifies the status of the self-granting functionality.
-
#status ⇒ String
The status of the data source.
-
#type ⇒ String
The type of the data source.
-
#updated_at ⇒ Time
The timestamp of when the data source was updated.
Instance Attribute Details
#asset_forms_output ⇒ Array<Types::FormOutput>
The metadata forms attached to the assets created by this data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration of the data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#connection_id ⇒ String
The ID of the connection.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the data source was created.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#description ⇒ String
The description of the data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the data source exists.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
Specifies whether this data source is enabled or not.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment where this data source creates and publishes assets,
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#id ⇒ String
The ID of the data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_asset_count ⇒ Integer
The number of assets created by the data source during its last run.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp of the last run of the data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_status ⇒ String
The status of the last run of the data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#name ⇒ String
The name of the data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#project_id ⇒ String
The ID of the project where the data source creates and publishes assets.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#publish_on_import ⇒ Boolean
Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation configuration of the data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The schedule of the data source runs.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#self_grant_status ⇒ Types::SelfGrantStatusOutput
Specifies the status of the self-granting functionality.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#status ⇒ String
The status of the data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#type ⇒ String
The type of the data source.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source was updated.
7871 7872 7873 7874 7875 7876 7877 7878 7879 7880 7881 7882 7883 7884 7885 7886 7887 7888 7889 7890 7891 7892 7893 7894 7895 7896 7897 |
# File 'lib/aws-sdk-datazone/types.rb', line 7871 class GetDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :connection_id, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_asset_count, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |