Class: Aws::DataZone::Types::GetDataSourceRunOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDataSourceRunOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the data source run was created.
-
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source run.
-
#data_source_id ⇒ String
The ID of the data source for this data source run.
-
#domain_id ⇒ String
The ID of the domain in which this data source run was performed.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The ID of the data source run.
-
#lineage_summary ⇒ Types::DataSourceRunLineageSummary
The summary of the data lineage.
-
#project_id ⇒ String
The ID of the project in which this data source run occured.
-
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from this data source run.
-
#started_at ⇒ Time
The timestamp of when this data source run started.
-
#status ⇒ String
The status of this data source run.
-
#stopped_at ⇒ Time
The timestamp of when this data source run stopped.
-
#type ⇒ String
The type of this data source run.
-
#updated_at ⇒ Time
The timestamp of when this data source run was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the data source run was created.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source run.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The ID of the data source for this data source run.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain in which this data source run was performed.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the data source run.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#lineage_summary ⇒ Types::DataSourceRunLineageSummary
The summary of the data lineage.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The ID of the project in which this data source run occured.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from this data source run.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when this data source run started.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of this data source run.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The timestamp of when this data source run stopped.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of this data source run.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this data source run was updated.
9687 9688 9689 9690 9691 9692 9693 9694 9695 9696 9697 9698 9699 9700 9701 9702 9703 9704 |
# File 'lib/aws-sdk-datazone/types.rb', line 9687 class GetDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :lineage_summary, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |