Class: Aws::DataZone::Types::GetDataSourceRunOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the data source run was created.

Returns:

  • (Time)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_configuration_snapshotString

The configuration snapshot of the data source run.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_idString

The ID of the data source for this data source run.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain in which this data source run was performed.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

Specifies the error message that is returned if the operation cannot be successfully completed.



9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the data source run.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_summaryTypes::DataSourceRunLineageSummary

The summary of the data lineage.



9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#project_idString

The ID of the project in which this data source run occured.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#run_statistics_for_assetsTypes::RunStatisticsForAssets

The asset statistics from this data source run.



9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp of when this data source run started.

Returns:

  • (Time)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of this data source run.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atTime

The timestamp of when this data source run stopped.

Returns:

  • (Time)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of this data source run.

Returns:

  • (String)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when this data source run was updated.

Returns:

  • (Time)


9394
9395
9396
9397
9398
9399
9400
9401
9402
9403
9404
9405
9406
9407
9408
9409
9410
9411
# File 'lib/aws-sdk-datazone/types.rb', line 9394

class GetDataSourceRunOutput < Struct.new(
  :domain_id,
  :data_source_id,
  :id,
  :project_id,
  :status,
  :type,
  :data_source_configuration_snapshot,
  :run_statistics_for_assets,
  :lineage_summary,
  :error_message,
  :created_at,
  :updated_at,
  :started_at,
  :stopped_at)
  SENSITIVE = []
  include Aws::Structure
end