Class: Aws::DataZone::Types::GetDataSourceRunOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the data source run was created.

Returns:

  • (Time)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_configuration_snapshotString

The configuration snapshot of the data source run.

Returns:

  • (String)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_idString

The ID of the data source for this data source run.

Returns:

  • (String)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain in which this data source run was performed.

Returns:

  • (String)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

Specifies the error message that is returned if the operation cannot be successfully completed.



7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the data source run.

Returns:

  • (String)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#lineage_summaryTypes::DataSourceRunLineageSummary

The summary of the data lineage.



7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#project_idString

The ID of the project in which this data source run occured.

Returns:

  • (String)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#run_statistics_for_assetsTypes::RunStatisticsForAssets

The asset statistics from this data source run.



7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp of when this data source run started.

Returns:

  • (Time)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of this data source run.

Returns:

  • (String)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atTime

The timestamp of when this data source run stopped.

Returns:

  • (Time)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of this data source run.

Returns:

  • (String)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when this data source run was updated.

Returns:

  • (Time)


7975
7976
7977
7978
7979
7980
7981
7982
7983
7984
7985
7986
7987
7988
7989
7990
7991
7992
# File 'lib/aws-sdk-datazone/types.rb', line 7975

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :lineage_summary,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end