Class: Aws::DataZone::Types::GetDataSourceRunOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDataSourceRunOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the data source run was created.
-
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source run.
-
#data_source_id ⇒ String
The ID of the data source for this data source run.
-
#domain_id ⇒ String
The ID of the domain in which this data source run was performed.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The ID of the data source run.
-
#lineage_summary ⇒ Types::DataSourceRunLineageSummary
The summary of the data lineage.
-
#project_id ⇒ String
The ID of the project in which this data source run occured.
-
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from this data source run.
-
#started_at ⇒ Time
The timestamp of when this data source run started.
-
#status ⇒ String
The status of this data source run.
-
#stopped_at ⇒ Time
The timestamp of when this data source run stopped.
-
#type ⇒ String
The type of this data source run.
-
#updated_at ⇒ Time
The timestamp of when this data source run was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the data source run was created.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source run.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The ID of the data source for this data source run.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain in which this data source run was performed.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the data source run.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#lineage_summary ⇒ Types::DataSourceRunLineageSummary
The summary of the data lineage.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The ID of the project in which this data source run occured.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from this data source run.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when this data source run started.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of this data source run.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The timestamp of when this data source run stopped.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of this data source run.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this data source run was updated.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 |
# File 'lib/aws-sdk-datazone/types.rb', line 7975 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :lineage_summary, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |