Class: Aws::DataZone::Types::GetDataSourceRunOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the data source run was created.

Returns:

  • (Time)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_configuration_snapshotString

The configuration snapshot of the data source run.

Returns:

  • (String)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_idString

The ID of the data source for this data source run.

Returns:

  • (String)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain in which this data source run was performed.

Returns:

  • (String)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

Specifies the error message that is returned if the operation cannot be successfully completed.



5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the data source run.

Returns:

  • (String)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#project_idString

The ID of the project in which this data source run occured.

Returns:

  • (String)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#run_statistics_for_assetsTypes::RunStatisticsForAssets

The asset statistics from this data source run.



5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp of when this data source run started.

Returns:

  • (Time)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of this data source run.

Returns:

  • (String)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atTime

The timestamp of when this data source run stopped.

Returns:

  • (Time)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of this data source run.

Returns:

  • (String)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when this data source run was updated.

Returns:

  • (Time)


5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
# File 'lib/aws-sdk-datazone/types.rb', line 5166

class GetDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end