Class: Aws::DataZone::Types::GetDataSourceRunOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDataSourceRunOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the data source run was created.
-
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source run.
-
#data_source_id ⇒ String
The ID of the data source for this data source run.
-
#domain_id ⇒ String
The ID of the domain in which this data source run was performed.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The ID of the data source run.
-
#project_id ⇒ String
The ID of the project in which this data source run occured.
-
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from this data source run.
-
#started_at ⇒ Time
The timestamp of when this data source run started.
-
#status ⇒ String
The status of this data source run.
-
#stopped_at ⇒ Time
The timestamp of when this data source run stopped.
-
#type ⇒ String
The type of this data source run.
-
#updated_at ⇒ Time
The timestamp of when this data source run was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the data source run was created.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source run.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The ID of the data source for this data source run.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain in which this data source run was performed.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the data source run.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The ID of the project in which this data source run occured.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
The asset statistics from this data source run.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when this data source run started.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of this data source run.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The timestamp of when this data source run stopped.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of this data source run.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this data source run was updated.
4737 4738 4739 4740 4741 4742 4743 4744 4745 4746 4747 4748 4749 4750 4751 4752 4753 |
# File 'lib/aws-sdk-datazone/types.rb', line 4737 class GetDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |