Class: Aws::DataZone::Types::GetDomainOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetDomainOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the specified Amazon DataZone domain.
-
#created_at ⇒ Time
The timestamp of when the Amazon DataZone domain was created.
-
#description ⇒ String
The description of the Amazon DataZone domain.
-
#domain_execution_role ⇒ String
The domain execution role with which the Amazon DataZone domain is created.
-
#id ⇒ String
The identifier of the specified Amazon DataZone domain.
-
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
-
#last_updated_at ⇒ Time
The timestamp of when the Amazon DataZone domain was last updated.
-
#name ⇒ String
The name of the Amazon DataZone domain.
-
#portal_url ⇒ String
The URL of the data portal for this Amazon DataZone domain.
-
#single_sign_on ⇒ Types::SingleSignOn
The single sing-on option of the specified Amazon DataZone domain.
-
#status ⇒ String
The status of the specified Amazon DataZone domain.
-
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
Instance Attribute Details
#arn ⇒ String
The ARN of the specified Amazon DataZone domain.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the Amazon DataZone domain was created.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Amazon DataZone domain.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#domain_execution_role ⇒ String
The domain execution role with which the Amazon DataZone domain is created.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the specified Amazon DataZone domain.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_identifier ⇒ String
The identifier of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the Amazon DataZone domain was last updated.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon DataZone domain.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#portal_url ⇒ String
The URL of the data portal for this Amazon DataZone domain.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#single_sign_on ⇒ Types::SingleSignOn
The single sing-on option of the specified Amazon DataZone domain.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the specified Amazon DataZone domain.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags specified for the Amazon DataZone domain.
5586 5587 5588 5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-datazone/types.rb', line 5586 class GetDomainOutput < Struct.new( :arn, :created_at, :description, :domain_execution_role, :id, :kms_key_identifier, :last_updated_at, :name, :portal_url, :single_sign_on, :status, :tags) SENSITIVE = [] include Aws::Structure end |