Class: Aws::DataZone::Types::GetEnvironmentOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description, :environment_configuration_id, :environment_configuration_name]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account where the environment exists.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#aws_account_regionString

The Amazon Web Services region where the environment exists.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#created_atTime

The timestamp of when the environment was created.

Returns:

  • (Time)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created the environment.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#deployment_propertiesTypes::DeploymentProperties

The deployment properties of the environment.



9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#descriptionString

The description of the environment.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain where the environment exists.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#environment_actionsArray<Types::ConfigurableEnvironmentAction>

The actions of the environment.



9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#environment_blueprint_idString

The blueprint with which the environment is created.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#environment_configuration_idString

The configuration ID that is used to create the environment.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#environment_configuration_nameString

The configuration name that is used to create the environment.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#environment_profile_idString

The ID of the environment profile with which the environment is created.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#glossary_termsArray<String>

The business glossary terms that can be used in this environment.

Returns:

  • (Array<String>)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#idString

The ID of the environment.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#last_deploymentTypes::Deployment

The details of the last deployment of the environment.

Returns:



9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#nameString

The name of the environment.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#project_idString

The ID of the Amazon DataZone project in which this environment is created.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#providerString

The provider of this Amazon DataZone environment.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#provisioned_resourcesArray<Types::Resource>

The provisioned resources of this Amazon DataZone environment.

Returns:



9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#provisioning_propertiesTypes::ProvisioningProperties

The provisioning properties of this Amazon DataZone environment.



9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#statusString

The status of this Amazon DataZone environment.

Returns:

  • (String)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#updated_atTime

The timestamp of when this environment was updated.

Returns:

  • (Time)


9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end

#user_parametersArray<Types::CustomParameter>

The user parameters of this Amazon DataZone environment.

Returns:



9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
# File 'lib/aws-sdk-datazone/types.rb', line 9954

class GetEnvironmentOutput < Struct.new(
  :project_id,
  :id,
  :domain_id,
  :created_by,
  :created_at,
  :updated_at,
  :name,
  :description,
  :environment_profile_id,
  :aws_account_id,
  :aws_account_region,
  :provider,
  :provisioned_resources,
  :status,
  :environment_actions,
  :glossary_terms,
  :user_parameters,
  :last_deployment,
  :provisioning_properties,
  :deployment_properties,
  :environment_blueprint_id,
  :environment_configuration_id,
  :environment_configuration_name)
  SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name]
  include Aws::Structure
end