Class: Aws::DataZone::Types::GetEnvironmentOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetEnvironmentOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :environment_configuration_id, :environment_configuration_name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where the environment exists.
-
#aws_account_region ⇒ String
The Amazon Web Services region where the environment exists.
-
#created_at ⇒ Time
The timestamp of when the environment was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the environment.
-
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties of the environment.
-
#description ⇒ String
The description of the environment.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain where the environment exists.
-
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The actions of the environment.
-
#environment_blueprint_id ⇒ String
The blueprint with which the environment is created.
-
#environment_configuration_id ⇒ String
The configuration ID that is used to create the environment.
-
#environment_configuration_name ⇒ String
The configuration name that is used to create the environment.
-
#environment_profile_id ⇒ String
The ID of the environment profile with which the environment is created.
-
#glossary_terms ⇒ Array<String>
The business glossary terms that can be used in this environment.
-
#id ⇒ String
The ID of the environment.
-
#last_deployment ⇒ Types::Deployment
The details of the last deployment of the environment.
-
#name ⇒ String
The name of the environment.
-
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment is created.
-
#provider ⇒ String
The provider of this Amazon DataZone environment.
-
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources of this Amazon DataZone environment.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties of this Amazon DataZone environment.
-
#status ⇒ String
The status of this Amazon DataZone environment.
-
#updated_at ⇒ Time
The timestamp of when this environment was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone environment.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where the environment exists.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services region where the environment exists.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the environment was created.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties of the environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#description ⇒ String
The description of the environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain where the environment exists.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The actions of the environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The blueprint with which the environment is created.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_configuration_id ⇒ String
The configuration ID that is used to create the environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_configuration_name ⇒ String
The configuration name that is used to create the environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_profile_id ⇒ String
The ID of the environment profile with which the environment is created.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The business glossary terms that can be used in this environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#id ⇒ String
The ID of the environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#last_deployment ⇒ Types::Deployment
The details of the last deployment of the environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#name ⇒ String
The name of the environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment is created.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provider ⇒ String
The provider of this Amazon DataZone environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources of this Amazon DataZone environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties of this Amazon DataZone environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#status ⇒ String
The status of this Amazon DataZone environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this environment was updated.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone environment.
9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 |
# File 'lib/aws-sdk-datazone/types.rb', line 9936 class GetEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |