Class: Aws::DataZone::Types::GetEnvironmentOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account where the environment exists.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#aws_account_regionString

The Amazon Web Services region where the environment exists.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#created_atTime

The timestamp of when the environment was created.

Returns:

  • (Time)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created the environment.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#deployment_propertiesTypes::DeploymentProperties

The deployment properties of the environment.



7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#descriptionString

The description of the environment.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain where the environment exists.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_actionsArray<Types::ConfigurableEnvironmentAction>

The actions of the environment.



7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_blueprint_idString

The blueprint with which the environment is created.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_profile_idString

The ID of the environment profile with which the environment is created.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#glossary_termsArray<String>

The business glossary terms that can be used in this environment.

Returns:

  • (Array<String>)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#idString

The ID of the environment.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#last_deploymentTypes::Deployment

The details of the last deployment of the environment.

Returns:



7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#nameString

The name of the environment.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#project_idString

The ID of the Amazon DataZone project in which this environment is created.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#providerString

The provider of this Amazon DataZone environment.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#provisioned_resourcesArray<Types::Resource>

The provisioned resources of this Amazon DataZone environment.

Returns:



7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#provisioning_propertiesTypes::ProvisioningProperties

The provisioning properties of this Amazon DataZone environment.



7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#statusString

The status of this Amazon DataZone environment.

Returns:

  • (String)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#updated_atTime

The timestamp of when this environment was updated.

Returns:

  • (Time)


7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#user_parametersArray<Types::CustomParameter>

The user parameters of this Amazon DataZone environment.

Returns:



7106
7107
7108
7109
7110
7111
7112
7113
7114
7115
7116
7117
7118
7119
7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-datazone/types.rb', line 7106

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end