Class: Aws::DataZone::Types::GetEnvironmentOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_account_idString

The ID of the Amazon Web Services account where the environment exists.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#aws_account_regionString

The Amazon Web Services region where the environment exists.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#created_atTime

The timestamp of when the environment was created.

Returns:

  • (Time)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created the environment.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#deployment_propertiesTypes::DeploymentProperties

The deployment properties of the environment.



5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#descriptionString

The description of the environment.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain where the environment exists.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_actionsArray<Types::ConfigurableEnvironmentAction>

The actions of the environment.



5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_blueprint_idString

The blueprint with which the environment is created.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#environment_profile_idString

The ID of the environment profile with which the environment is created.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#glossary_termsArray<String>

The business glossary terms that can be used in this environment.

Returns:

  • (Array<String>)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#idString

The ID of the environment.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#last_deploymentTypes::Deployment

The details of the last deployment of the environment.

Returns:



5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#nameString

The name of the environment.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#project_idString

The ID of the Amazon DataZone project in which this environment is created.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#providerString

The provider of this Amazon DataZone environment.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#provisioned_resourcesArray<Types::Resource>

The provisioned resources of this Amazon DataZone environment.

Returns:



5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#provisioning_propertiesTypes::ProvisioningProperties

The provisioning properties of this Amazon DataZone environment.



5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#statusString

The status of this Amazon DataZone environment.

Returns:

  • (String)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#updated_atTime

The timestamp of when this environment was updated.

Returns:

  • (Time)


5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#user_parametersArray<Types::CustomParameter>

The user parameters of this Amazon DataZone environment.

Returns:



5894
5895
5896
5897
5898
5899
5900
5901
5902
5903
5904
5905
5906
5907
5908
5909
5910
5911
5912
5913
5914
5915
5916
5917
5918
# File 'lib/aws-sdk-datazone/types.rb', line 5894

class GetEnvironmentOutput < Struct.new(
  :aws_account_id,
  :aws_account_region,
  :created_at,
  :created_by,
  :deployment_properties,
  :description,
  :domain_id,
  :environment_actions,
  :environment_blueprint_id,
  :environment_profile_id,
  :glossary_terms,
  :id,
  :last_deployment,
  :name,
  :project_id,
  :provider,
  :provisioned_resources,
  :provisioning_properties,
  :status,
  :updated_at,
  :user_parameters)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end