Class: Aws::DataZone::Types::GetEnvironmentOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetEnvironmentOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where the environment exists.
-
#aws_account_region ⇒ String
The Amazon Web Services region where the environment exists.
-
#created_at ⇒ Time
The timestamp of when the environment was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the environment.
-
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties of the environment.
-
#description ⇒ String
The description of the environment.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain where the environment exists.
-
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The actions of the environment.
-
#environment_blueprint_id ⇒ String
The blueprint with which the environment is created.
-
#environment_profile_id ⇒ String
The ID of the environment profile with which the environment is created.
-
#glossary_terms ⇒ Array<String>
The business glossary terms that can be used in this environment.
-
#id ⇒ String
The ID of the environment.
-
#last_deployment ⇒ Types::Deployment
The details of the last deployment of the environment.
-
#name ⇒ String
The name of the environment.
-
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment is created.
-
#provider ⇒ String
The provider of this Amazon DataZone environment.
-
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources of this Amazon DataZone environment.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties of this Amazon DataZone environment.
-
#status ⇒ String
The status of this Amazon DataZone environment.
-
#updated_at ⇒ Time
The timestamp of when this environment was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone environment.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where the environment exists.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services region where the environment exists.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the environment was created.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties of the environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description of the environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain where the environment exists.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The actions of the environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The blueprint with which the environment is created.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_profile_id ⇒ String
The ID of the environment profile with which the environment is created.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The business glossary terms that can be used in this environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The ID of the environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#last_deployment ⇒ Types::Deployment
The details of the last deployment of the environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of the environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment is created.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#provider ⇒ String
The provider of this Amazon DataZone environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources of this Amazon DataZone environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties of this Amazon DataZone environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#status ⇒ String
The status of this Amazon DataZone environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this environment was updated.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of this Amazon DataZone environment.
5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 |
# File 'lib/aws-sdk-datazone/types.rb', line 5104 class GetEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |