Class: Aws::DataZone::Types::GetEnvironmentProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetEnvironmentProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where this environment profile exists.
-
#aws_account_region ⇒ String
The Amazon Web Services region where this environment profile exists.
-
#created_at ⇒ Time
The timestamp of when this environment profile was created.
-
#created_by ⇒ String
The Amazon DataZone user who created this environment profile.
-
#description ⇒ String
The description of the environment profile.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this environment profile exists.
-
#environment_blueprint_id ⇒ String
The ID of the blueprint with which this environment profile is created.
-
#id ⇒ String
The ID of the environment profile.
-
#name ⇒ String
The name of the environment profile.
-
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment profile is created.
-
#updated_at ⇒ Time
The timestamp of when this environment profile was upated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of the environment profile.
Instance Attribute Details
#aws_account_id ⇒ String
The ID of the Amazon Web Services account where this environment profile exists.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services region where this environment profile exists.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when this environment profile was created.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created this environment profile.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the environment profile.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this environment profile exists.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The ID of the blueprint with which this environment profile is created.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The ID of the environment profile.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the environment profile.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_id ⇒ String
The ID of the Amazon DataZone project in which this environment profile is created.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when this environment profile was upated.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters of the environment profile.
10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 |
# File 'lib/aws-sdk-datazone/types.rb', line 10055 class GetEnvironmentProfileOutput < Struct.new( :id, :domain_id, :aws_account_id, :aws_account_region, :created_by, :created_at, :updated_at, :name, :description, :environment_blueprint_id, :project_id, :user_parameters) SENSITIVE = [:name, :description] include Aws::Structure end |