Class: Aws::DataZone::Types::GetFormTypeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetFormTypeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :model, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when this metadata form type was created.
-
#created_by ⇒ String
The Amazon DataZone user who created this metadata form type.
-
#description ⇒ String
The description of the metadata form type.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this metadata form type exists.
-
#imports ⇒ Array<Types::Import>
The imports of the metadata form type.
-
#model ⇒ Types::Model
The model of the metadata form type.
-
#name ⇒ String
The name of the metadata form type.
-
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain in which the metadata form type was originally created.
-
#origin_project_id ⇒ String
The ID of the project in which this metadata form type was originally created.
-
#owning_project_id ⇒ String
The ID of the project that owns this metadata form type.
-
#revision ⇒ String
The revision of the metadata form type.
-
#status ⇒ String
The status of the metadata form type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when this metadata form type was created.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created this metadata form type.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#description ⇒ String
The description of the metadata form type.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this metadata form type exists.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#imports ⇒ Array<Types::Import>
The imports of the metadata form type.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#model ⇒ Types::Model
The model of the metadata form type.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#name ⇒ String
The name of the metadata form type.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain in which the metadata form type was originally created.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#origin_project_id ⇒ String
The ID of the project in which this metadata form type was originally created.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the project that owns this metadata form type.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#revision ⇒ String
The revision of the metadata form type.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |
#status ⇒ String
The status of the metadata form type.
10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 10202 10203 10204 10205 10206 10207 |
# File 'lib/aws-sdk-datazone/types.rb', line 10192 class GetFormTypeOutput < Struct.new( :domain_id, :name, :revision, :model, :owning_project_id, :origin_domain_id, :origin_project_id, :status, :created_at, :created_by, :description, :imports) SENSITIVE = [:name, :model, :description] include Aws::Structure end |