Class: Aws::DataZone::Types::GetFormTypeOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :model, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when this metadata form type was created.

Returns:

  • (Time)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created this metadata form type.

Returns:

  • (String)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#descriptionString

The description of the metadata form type.

Returns:

  • (String)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which this metadata form type exists.

Returns:

  • (String)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#importsArray<Types::Import>

The imports of the metadata form type.

Returns:



9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#modelTypes::Model

The model of the metadata form type.

Returns:



9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#nameString

The name of the metadata form type.

Returns:

  • (String)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#origin_domain_idString

The ID of the Amazon DataZone domain in which the metadata form type was originally created.

Returns:

  • (String)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#origin_project_idString

The ID of the project in which this metadata form type was originally created.

Returns:

  • (String)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#owning_project_idString

The ID of the project that owns this metadata form type.

Returns:

  • (String)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#revisionString

The revision of the metadata form type.

Returns:

  • (String)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end

#statusString

The status of the metadata form type.

Returns:

  • (String)


9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
# File 'lib/aws-sdk-datazone/types.rb', line 9959

class GetFormTypeOutput < Struct.new(
  :domain_id,
  :name,
  :revision,
  :model,
  :owning_project_id,
  :origin_domain_id,
  :origin_project_id,
  :status,
  :created_at,
  :created_by,
  :description,
  :imports)
  SENSITIVE = [:name, :model, :description]
  include Aws::Structure
end