Class: Aws::DataZone::Types::GetFormTypeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetFormTypeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :model, :name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when this metadata form type was created.
-
#created_by ⇒ String
The Amazon DataZone user who created this metadata form type.
-
#description ⇒ String
The description of the metadata form type.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this metadata form type exists.
-
#imports ⇒ Array<Types::Import>
The imports of the metadata form type.
-
#model ⇒ Types::Model
The model of the metadata form type.
-
#name ⇒ String
The name of the metadata form type.
-
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain in which the metadata form type was originally created.
-
#origin_project_id ⇒ String
The ID of the project in which this metadata form type was originally created.
-
#owning_project_id ⇒ String
The ID of the project that owns this metadata form type.
-
#revision ⇒ String
The revision of the metadata form type.
-
#status ⇒ String
The status of the metadata form type.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when this metadata form type was created.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created this metadata form type.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#description ⇒ String
The description of the metadata form type.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this metadata form type exists.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#imports ⇒ Array<Types::Import>
The imports of the metadata form type.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#model ⇒ Types::Model
The model of the metadata form type.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#name ⇒ String
The name of the metadata form type.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#origin_domain_id ⇒ String
The ID of the Amazon DataZone domain in which the metadata form type was originally created.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#origin_project_id ⇒ String
The ID of the project in which this metadata form type was originally created.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#owning_project_id ⇒ String
The ID of the project that owns this metadata form type.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#revision ⇒ String
The revision of the metadata form type.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |
#status ⇒ String
The status of the metadata form type.
8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 |
# File 'lib/aws-sdk-datazone/types.rb', line 8836 class GetFormTypeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :imports, :model, :name, :origin_domain_id, :origin_project_id, :owning_project_id, :revision, :status) SENSITIVE = [:description, :model, :name] include Aws::Structure end |