Class: Aws::DataZone::Types::GetFormTypeOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :model, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when this metadata form type was created.

Returns:

  • (Time)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created this metadata form type.

Returns:

  • (String)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#descriptionString

The description of the metadata form type.

Returns:

  • (String)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which this metadata form type exists.

Returns:

  • (String)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#importsArray<Types::Import>

The imports of the metadata form type.

Returns:



7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#modelTypes::Model

The model of the metadata form type.

Returns:



7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#nameString

The name of the metadata form type.

Returns:

  • (String)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#origin_domain_idString

The ID of the Amazon DataZone domain in which the metadata form type was originally created.

Returns:

  • (String)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#origin_project_idString

The ID of the project in which this metadata form type was originally created.

Returns:

  • (String)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#owning_project_idString

The ID of the project that owns this metadata form type.

Returns:

  • (String)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#revisionString

The revision of the metadata form type.

Returns:

  • (String)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end

#statusString

The status of the metadata form type.

Returns:

  • (String)


7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
# File 'lib/aws-sdk-datazone/types.rb', line 7298

class GetFormTypeOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :imports,
  :model,
  :name,
  :origin_domain_id,
  :origin_project_id,
  :owning_project_id,
  :revision,
  :status)
  SENSITIVE = [:description, :model, :name]
  include Aws::Structure
end