Class: Aws::DataZone::Types::GetGlossaryTermOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetGlossaryTermOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :short_description, :long_description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the business glossary term was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the business glossary.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this business glossary term exists.
-
#glossary_id ⇒ String
The ID of the business glossary to which this term belongs.
-
#id ⇒ String
The ID of the business glossary term.
-
#long_description ⇒ String
The long description of the business glossary term.
-
#name ⇒ String
The name of the business glossary term.
-
#short_description ⇒ String
The short decription of the business glossary term.
-
#status ⇒ String
The status of the business glossary term.
-
#term_relations ⇒ Types::TermRelations
The relations of the business glossary term.
-
#updated_at ⇒ Time
The timestamp of when the business glossary term was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the business glossary term.
-
#usage_restrictions ⇒ Array<String>
The usage restriction of a term within a restricted glossary.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the business glossary term was created.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the business glossary.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this business glossary term exists.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#glossary_id ⇒ String
The ID of the business glossary to which this term belongs.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#id ⇒ String
The ID of the business glossary term.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#long_description ⇒ String
The long description of the business glossary term.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#name ⇒ String
The name of the business glossary term.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#short_description ⇒ String
The short decription of the business glossary term.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#status ⇒ String
The status of the business glossary term.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#term_relations ⇒ Types::TermRelations
The relations of the business glossary term.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the business glossary term was updated.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the business glossary term.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#usage_restrictions ⇒ Array<String>
The usage restriction of a term within a restricted glossary.
10301 10302 10303 10304 10305 10306 10307 10308 10309 10310 10311 10312 10313 10314 10315 10316 10317 |
# File 'lib/aws-sdk-datazone/types.rb', line 10301 class GetGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :usage_restrictions) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |