Class: Aws::DataZone::Types::GetGlossaryTermOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetGlossaryTermOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:long_description, :name, :short_description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the business glossary term was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the business glossary.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this business glossary term exists.
-
#glossary_id ⇒ String
The ID of the business glossary to which this term belongs.
-
#id ⇒ String
The ID of the business glossary term.
-
#long_description ⇒ String
The long description of the business glossary term.
-
#name ⇒ String
The name of the business glossary term.
-
#short_description ⇒ String
The short decription of the business glossary term.
-
#status ⇒ String
The status of the business glossary term.
-
#term_relations ⇒ Types::TermRelations
The relations of the business glossary term.
-
#updated_at ⇒ Time
The timestamp of when the business glossary term was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the business glossary term.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the business glossary term was created.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the business glossary.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which this business glossary term exists.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#glossary_id ⇒ String
The ID of the business glossary to which this term belongs.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#id ⇒ String
The ID of the business glossary term.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#long_description ⇒ String
The long description of the business glossary term.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#name ⇒ String
The name of the business glossary term.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#short_description ⇒ String
The short decription of the business glossary term.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#status ⇒ String
The status of the business glossary term.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#term_relations ⇒ Types::TermRelations
The relations of the business glossary term.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the business glossary term was updated.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the business glossary term.
6248 6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-datazone/types.rb', line 6248 class GetGlossaryTermOutput < Struct.new( :created_at, :created_by, :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations, :updated_at, :updated_by) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |