Class: Aws::DataZone::Types::GetJobRunOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the job run was created.

Returns:

  • (Time)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The user who created the job run.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#detailsTypes::JobRunDetails

The details of the job run.



10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The timestamp of when the job run ended.

Returns:

  • (Time)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#errorTypes::JobRunError

The error generated if the action is not completed successfully.

Returns:



10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the job run.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The ID of the job run.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_typeString

The type of the job run.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#run_modeString

The mode of the job run.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The timestamp of when the job run started.

Returns:

  • (Time)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the job run.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class GetJobRunOutput < Struct.new(
  :domain_id,
  :id,
  :job_id,
  :job_type,
  :run_mode,
  :details,
  :status,
  :error,
  :created_by,
  :created_at,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end