Class: Aws::DataZone::Types::GetLineageNodeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetLineageNodeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp at which the data lineage node was created.
-
#created_by ⇒ String
The user who created the data lineage node.
-
#description ⇒ String
The description of the data lineage node.
-
#domain_id ⇒ String
The ID of the domain where you’re getting the data lineage node.
-
#downstream_nodes ⇒ Array<Types::LineageNodeReference>
The downsteam nodes of the specified data lineage node.
-
#event_timestamp ⇒ Time
The timestamp of the event described in the data lineage node.
-
#forms_output ⇒ Array<Types::FormOutput>
The metadata of the specified data lineage node.
-
#id ⇒ String
The ID of the data lineage node.
-
#name ⇒ String
The name of the data lineage node.
-
#source_identifier ⇒ String
The source identifier of the data lineage node.
-
#type_name ⇒ String
The name of the type of the specified data lineage node.
-
#type_revision ⇒ String
The revision type of the specified data lineage node.
-
#updated_at ⇒ Time
The timestamp at which the data lineage node was updated.
-
#updated_by ⇒ String
The user who updated the data lineage node.
-
#upstream_nodes ⇒ Array<Types::LineageNodeReference>
The upstream nodes of the specified data lineage node.
Instance Attribute Details
#created_at ⇒ Time
The timestamp at which the data lineage node was created.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user who created the data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The ID of the domain where you’re getting the data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#downstream_nodes ⇒ Array<Types::LineageNodeReference>
The downsteam nodes of the specified data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#event_timestamp ⇒ Time
The timestamp of the event described in the data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#forms_output ⇒ Array<Types::FormOutput>
The metadata of the specified data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#source_identifier ⇒ String
The source identifier of the data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the type of the specified data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#type_revision ⇒ String
The revision type of the specified data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp at which the data lineage node was updated.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user who updated the data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |
#upstream_nodes ⇒ Array<Types::LineageNodeReference>
The upstream nodes of the specified data lineage node.
6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/aws-sdk-datazone/types.rb', line 6387 class GetLineageNodeOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :downstream_nodes, :event_timestamp, :forms_output, :id, :name, :source_identifier, :type_name, :type_revision, :updated_at, :updated_by, :upstream_nodes) SENSITIVE = [] include Aws::Structure end |