Class: Aws::DataZone::Types::GetNotebookExportOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completed_atTime

The timestamp of when the notebook export completed.

Returns:

  • (Time)


11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp of when the notebook export was started.

Returns:

  • (Time)


11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The identifier of the user who started the notebook export.

Returns:

  • (String)


11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon SageMaker Unified Studio domain.

Returns:

  • (String)


11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#errorTypes::NotebookExportError

The error details if the notebook export failed.



11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#file_formatString

The file format of the notebook export.

Returns:

  • (String)


11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the notebook export.

Returns:

  • (String)


11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#notebook_idString

The identifier of the notebook.

Returns:

  • (String)


11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#output_locationTypes::OutputLocation

The output location of the exported notebook in Amazon Simple Storage Service.



11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the notebook.

Returns:

  • (String)


11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the notebook export.

Returns:

  • (String)


11136
11137
11138
11139
11140
11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
# File 'lib/aws-sdk-datazone/types.rb', line 11136

class GetNotebookExportOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :file_format,
  :status,
  :output_location,
  :error,
  :completed_at,
  :created_at,
  :created_by)
  SENSITIVE = []
  include Aws::Structure
end