Class: Aws::DataZone::Types::GetNotebookExportOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetNotebookExportOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp of when the notebook export completed.
-
#created_at ⇒ Time
The timestamp of when the notebook export was started.
-
#created_by ⇒ String
The identifier of the user who started the notebook export.
-
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
-
#error ⇒ Types::NotebookExportError
The error details if the notebook export failed.
-
#file_format ⇒ String
The file format of the notebook export.
-
#id ⇒ String
The identifier of the notebook export.
-
#notebook_id ⇒ String
The identifier of the notebook.
-
#output_location ⇒ Types::OutputLocation
The output location of the exported notebook in Amazon Simple Storage Service.
-
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
-
#status ⇒ String
The status of the notebook export.
Instance Attribute Details
#completed_at ⇒ Time
The timestamp of when the notebook export completed.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the notebook export was started.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who started the notebook export.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#error ⇒ Types::NotebookExportError
The error details if the notebook export failed.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#file_format ⇒ String
The file format of the notebook export.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the notebook export.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#notebook_id ⇒ String
The identifier of the notebook.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#output_location ⇒ Types::OutputLocation
The output location of the exported notebook in Amazon Simple Storage Service.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the notebook export.
11136 11137 11138 11139 11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 |
# File 'lib/aws-sdk-datazone/types.rb', line 11136 class GetNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :output_location, :error, :completed_at, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |