Class: Aws::DataZone::Types::GetNotebookOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description, :metadata, :parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#cell_orderArray<Types::CellInformation>

The ordered list of cells in the notebook.

Returns:



11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#compute_idString

The identifier of the compute associated with the notebook.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#created_atTime

The timestamp of when the notebook was created.

Returns:

  • (Time)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#created_byString

The identifier of the user who created the notebook.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#descriptionString

The description of the notebook.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon SageMaker Unified Studio domain.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#environment_configurationTypes::EnvironmentConfig

The environment configuration of the notebook.



11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#errorTypes::NotebookError

The error details if the notebook is in a failed state.



11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#git_metadataTypes::GitMetadata

The Git metadata associated with the notebook.

Returns:



11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#idString

The identifier of the notebook.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#lock_expires_atTime

The timestamp of when the notebook lock expires.

Returns:

  • (Time)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#locked_atTime

The timestamp of when the notebook was locked.

Returns:

  • (Time)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#locked_byString

The identifier of the user who locked the notebook.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#metadataHash<String,String>

The metadata of the notebook.

Returns:

  • (Hash<String,String>)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#nameString

The name of the notebook.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the notebook.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#parametersHash<String,String>

The sensitive parameters of the notebook.

Returns:

  • (Hash<String,String>)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#statusString

The status of the notebook.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the notebook was last updated.

Returns:

  • (Time)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end

#updated_byString

The identifier of the user who last updated the notebook.

Returns:

  • (String)


11470
11471
11472
11473
11474
11475
11476
11477
11478
11479
11480
11481
11482
11483
11484
11485
11486
11487
11488
11489
11490
11491
11492
11493
# File 'lib/aws-sdk-datazone/types.rb', line 11470

class GetNotebookOutput < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :cell_order,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :locked_by,
  :locked_at,
  :lock_expires_at,
  :compute_id,
  :metadata,
  :parameters,
  :environment_configuration,
  :error,
  :git_metadata)
  SENSITIVE = [:name, :description, :metadata, :parameters]
  include Aws::Structure
end