Class: Aws::DataZone::Types::GetProjectOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetProjectOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the project was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the project.
-
#description ⇒ String
The description of the project.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the project exists.
-
#domain_unit_id ⇒ String
The ID of the domain unit.
-
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment status of a project.
-
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#glossary_terms ⇒ Array<String>
The business glossary terms that can be used in the project.
-
#id ⇒ String
>The ID of the project.
-
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
-
#name ⇒ String
The name of the project.
-
#project_category ⇒ String
The category of the project.
-
#project_profile_id ⇒ String
The ID of the project profile of a project.
-
#project_status ⇒ String
The status of the project.
-
#resource_tags ⇒ Array<Types::ResourceTag>
The resource tags of the project.
-
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of a project.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the project was created.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the project exists.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_unit_id ⇒ String
The ID of the domain unit.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment status of a project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The business glossary terms that can be used in the project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
>The ID of the project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_category ⇒ String
The category of the project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_profile_id ⇒ String
The ID of the project profile of a project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_status ⇒ String
The status of the project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#resource_tags ⇒ Array<Types::ResourceTag>
The resource tags of the project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of a project.
10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 |
# File 'lib/aws-sdk-datazone/types.rb', line 10912 class GetProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |