Class: Aws::DataZone::Types::GetProjectOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetProjectOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the project was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the project.
-
#description ⇒ String
The description of the project.
-
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the project exists.
-
#domain_unit_id ⇒ String
The ID of the domain unit.
-
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment status of a project.
-
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#glossary_terms ⇒ Array<String>
The business glossary terms that can be used in the project.
-
#id ⇒ String
>The ID of the project.
-
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
-
#name ⇒ String
The name of the project.
-
#project_profile_id ⇒ String
The ID of the project profile of a project.
-
#project_status ⇒ String
The status of the project.
-
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of a project.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the project was created.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the project.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description of the project.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The ID of the Amazon DataZone domain in which the project exists.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_unit_id ⇒ String
The ID of the domain unit.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment status of a project.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The business glossary terms that can be used in the project.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
>The ID of the project.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of the project.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_profile_id ⇒ String
The ID of the project profile of a project.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_status ⇒ String
The status of the project.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of a project.
9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/aws-sdk-datazone/types.rb', line 9460 class GetProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :domain_unit_id, :environment_deployment_details, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_profile_id, :project_status, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |