Class: Aws::DataZone::Types::GetProjectOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the project was created.

Returns:

  • (Time)


5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
# File 'lib/aws-sdk-datazone/types.rb', line 5654

class GetProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created the project.

Returns:

  • (String)


5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
# File 'lib/aws-sdk-datazone/types.rb', line 5654

class GetProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#descriptionString

The description of the project.

Returns:

  • (String)


5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
# File 'lib/aws-sdk-datazone/types.rb', line 5654

class GetProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which the project exists.

Returns:

  • (String)


5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
# File 'lib/aws-sdk-datazone/types.rb', line 5654

class GetProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#glossary_termsArray<String>

The business glossary terms that can be used in the project.

Returns:

  • (Array<String>)


5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
# File 'lib/aws-sdk-datazone/types.rb', line 5654

class GetProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#idString

&gt;The ID of the project.

Returns:

  • (String)


5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
# File 'lib/aws-sdk-datazone/types.rb', line 5654

class GetProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#last_updated_atTime

The timestamp of when the project was last updated.

Returns:

  • (Time)


5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
# File 'lib/aws-sdk-datazone/types.rb', line 5654

class GetProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#nameString

The name of the project.

Returns:

  • (String)


5654
5655
5656
5657
5658
5659
5660
5661
5662
5663
5664
5665
# File 'lib/aws-sdk-datazone/types.rb', line 5654

class GetProjectOutput < Struct.new(
  :created_at,
  :created_by,
  :description,
  :domain_id,
  :glossary_terms,
  :id,
  :last_updated_at,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end