Class: Aws::DataZone::Types::GetSubscriptionGrantOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#assetsArray<Types::SubscribedAsset>

The assets for which the subscription grant is created.

Returns:



7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp of when the subscription grant is created.

Returns:

  • (Time)


7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created the subscription grant.

Returns:

  • (String)


7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the Amazon DataZone domain in which the subscription grant exists.

Returns:

  • (String)


7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#granted_entityTypes::GrantedEntity

The entity to which the subscription is granted.



7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the subscription grant.

Returns:

  • (String)


7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the subscription grant.

Returns:

  • (String)


7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_idString

The identifier of the subscription.

Returns:

  • (String)


7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_target_idString

The subscription target ID associated with the subscription grant.

Returns:

  • (String)


7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when the subscription grant was upated.

Returns:

  • (Time)


7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The Amazon DataZone user who updated the subscription grant.

Returns:

  • (String)


7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
# File 'lib/aws-sdk-datazone/types.rb', line 7403

class GetSubscriptionGrantOutput < Struct.new(
  :assets,
  :created_at,
  :created_by,
  :domain_id,
  :granted_entity,
  :id,
  :status,
  :subscription_id,
  :subscription_target_id,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end