Class: Aws::DataZone::Types::GetUserProfileInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetUserProfileInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_identifier ⇒ String
the ID of the Amazon DataZone domain the data portal of which you want to get.
-
#session_name ⇒ String
The session name for IAM role sessions.
-
#type ⇒ String
The type of the user profile.
-
#user_identifier ⇒ String
The identifier of the user for which you want to get the user profile.
Instance Attribute Details
#domain_identifier ⇒ String
the ID of the Amazon DataZone domain the data portal of which you want to get.
11609 11610 11611 11612 11613 11614 11615 11616 |
# File 'lib/aws-sdk-datazone/types.rb', line 11609 class GetUserProfileInput < Struct.new( :domain_identifier, :user_identifier, :type, :session_name) SENSITIVE = [] include Aws::Structure end |
#session_name ⇒ String
The session name for IAM role sessions.
11609 11610 11611 11612 11613 11614 11615 11616 |
# File 'lib/aws-sdk-datazone/types.rb', line 11609 class GetUserProfileInput < Struct.new( :domain_identifier, :user_identifier, :type, :session_name) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the user profile.
11609 11610 11611 11612 11613 11614 11615 11616 |
# File 'lib/aws-sdk-datazone/types.rb', line 11609 class GetUserProfileInput < Struct.new( :domain_identifier, :user_identifier, :type, :session_name) SENSITIVE = [] include Aws::Structure end |
#user_identifier ⇒ String
The identifier of the user for which you want to get the user profile.
11609 11610 11611 11612 11613 11614 11615 11616 |
# File 'lib/aws-sdk-datazone/types.rb', line 11609 class GetUserProfileInput < Struct.new( :domain_identifier, :user_identifier, :type, :session_name) SENSITIVE = [] include Aws::Structure end |