Class: Aws::DataZone::Types::GetUserProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetUserProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#details ⇒ Types::UserProfileDetails
The user profile details.
-
#domain_id ⇒ String
the identifier of the Amazon DataZone domain of which you want to get the user profile.
-
#id ⇒ String
The identifier of the user profile.
-
#status ⇒ String
The status of the user profile.
-
#type ⇒ String
The type of the user profile.
Instance Attribute Details
#details ⇒ Types::UserProfileDetails
The user profile details.
11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-datazone/types.rb', line 11623 class GetUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
the identifier of the Amazon DataZone domain of which you want to get the user profile.
11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-datazone/types.rb', line 11623 class GetUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the user profile.
11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-datazone/types.rb', line 11623 class GetUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the user profile.
11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-datazone/types.rb', line 11623 class GetUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the user profile.
11623 11624 11625 11626 11627 11628 11629 11630 11631 |
# File 'lib/aws-sdk-datazone/types.rb', line 11623 class GetUserProfileOutput < Struct.new( :domain_id, :id, :type, :status, :details) SENSITIVE = [] include Aws::Structure end |