Class: Aws::DataZone::Types::GetUserProfileOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detailsTypes::UserProfileDetails

The details of the user profile in Amazon DataZone.



10136
10137
10138
10139
10140
10141
10142
10143
10144
# File 'lib/aws-sdk-datazone/types.rb', line 10136

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

the identifier of the Amazon DataZone domain of which you want to get the user profile.

Returns:

  • (String)


10136
10137
10138
10139
10140
10141
10142
10143
10144
# File 'lib/aws-sdk-datazone/types.rb', line 10136

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the user profile.

Returns:

  • (String)


10136
10137
10138
10139
10140
10141
10142
10143
10144
# File 'lib/aws-sdk-datazone/types.rb', line 10136

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the user profile.

Returns:

  • (String)


10136
10137
10138
10139
10140
10141
10142
10143
10144
# File 'lib/aws-sdk-datazone/types.rb', line 10136

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the user profile.

Returns:

  • (String)


10136
10137
10138
10139
10140
10141
10142
10143
10144
# File 'lib/aws-sdk-datazone/types.rb', line 10136

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end