Class: Aws::DataZone::Types::GetUserProfileOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detailsTypes::UserProfileDetails

The details of the user profile in Amazon DataZone.



8369
8370
8371
8372
8373
8374
8375
8376
8377
# File 'lib/aws-sdk-datazone/types.rb', line 8369

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

the identifier of the Amazon DataZone domain of which you want to get the user profile.

Returns:

  • (String)


8369
8370
8371
8372
8373
8374
8375
8376
8377
# File 'lib/aws-sdk-datazone/types.rb', line 8369

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the user profile.

Returns:

  • (String)


8369
8370
8371
8372
8373
8374
8375
8376
8377
# File 'lib/aws-sdk-datazone/types.rb', line 8369

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the user profile.

Returns:

  • (String)


8369
8370
8371
8372
8373
8374
8375
8376
8377
# File 'lib/aws-sdk-datazone/types.rb', line 8369

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the user profile.

Returns:

  • (String)


8369
8370
8371
8372
8373
8374
8375
8376
8377
# File 'lib/aws-sdk-datazone/types.rb', line 8369

class GetUserProfileOutput < Struct.new(
  :details,
  :domain_id,
  :id,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end