Class: Aws::DataZone::Types::GetUserProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GetUserProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#details ⇒ Types::UserProfileDetails
The details of the user profile in Amazon DataZone.
-
#domain_id ⇒ String
the identifier of the Amazon DataZone domain of which you want to get the user profile.
-
#id ⇒ String
The identifier of the user profile.
-
#status ⇒ String
The status of the user profile.
-
#type ⇒ String
The type of the user profile.
Instance Attribute Details
#details ⇒ Types::UserProfileDetails
The details of the user profile in Amazon DataZone.
7107 7108 7109 7110 7111 7112 7113 7114 7115 |
# File 'lib/aws-sdk-datazone/types.rb', line 7107 class GetUserProfileOutput < Struct.new( :details, :domain_id, :id, :status, :type) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
the identifier of the Amazon DataZone domain of which you want to get the user profile.
7107 7108 7109 7110 7111 7112 7113 7114 7115 |
# File 'lib/aws-sdk-datazone/types.rb', line 7107 class GetUserProfileOutput < Struct.new( :details, :domain_id, :id, :status, :type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the user profile.
7107 7108 7109 7110 7111 7112 7113 7114 7115 |
# File 'lib/aws-sdk-datazone/types.rb', line 7107 class GetUserProfileOutput < Struct.new( :details, :domain_id, :id, :status, :type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the user profile.
7107 7108 7109 7110 7111 7112 7113 7114 7115 |
# File 'lib/aws-sdk-datazone/types.rb', line 7107 class GetUserProfileOutput < Struct.new( :details, :domain_id, :id, :status, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the user profile.
7107 7108 7109 7110 7111 7112 7113 7114 7115 |
# File 'lib/aws-sdk-datazone/types.rb', line 7107 class GetUserProfileOutput < Struct.new( :details, :domain_id, :id, :status, :type) SENSITIVE = [] include Aws::Structure end |