Class: Aws::DataZone::Types::GitPropertiesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GitPropertiesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The properties of a Git connection returned by get and list operations, including connection status and any error details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_connection_arn ⇒ String
The ARN of the CodeConnections connection used to connect to the Git repository.
-
#default_branch ⇒ String
The default branch of the Git repository.
-
#error_message ⇒ String
The error message that describes why the Git connection failed.
-
#repository_id ⇒ String
The ID of the Git repository.
-
#status ⇒ String
The status of the Git connection.
Instance Attribute Details
#code_connection_arn ⇒ String
The ARN of the CodeConnections connection used to connect to the Git repository.
12539 12540 12541 12542 12543 12544 12545 12546 12547 |
# File 'lib/aws-sdk-datazone/types.rb', line 12539 class GitPropertiesOutput < Struct.new( :code_connection_arn, :repository_id, :default_branch, :status, :error_message) SENSITIVE = [] include Aws::Structure end |
#default_branch ⇒ String
The default branch of the Git repository.
12539 12540 12541 12542 12543 12544 12545 12546 12547 |
# File 'lib/aws-sdk-datazone/types.rb', line 12539 class GitPropertiesOutput < Struct.new( :code_connection_arn, :repository_id, :default_branch, :status, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message that describes why the Git connection failed. This member is populated when the connection status is CREATE_FAILED or UPDATE_FAILED.
12539 12540 12541 12542 12543 12544 12545 12546 12547 |
# File 'lib/aws-sdk-datazone/types.rb', line 12539 class GitPropertiesOutput < Struct.new( :code_connection_arn, :repository_id, :default_branch, :status, :error_message) SENSITIVE = [] include Aws::Structure end |
#repository_id ⇒ String
The ID of the Git repository. This is the owner and repository name, for example, owner/repo-name.
12539 12540 12541 12542 12543 12544 12545 12546 12547 |
# File 'lib/aws-sdk-datazone/types.rb', line 12539 class GitPropertiesOutput < Struct.new( :code_connection_arn, :repository_id, :default_branch, :status, :error_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Git connection.
12539 12540 12541 12542 12543 12544 12545 12546 12547 |
# File 'lib/aws-sdk-datazone/types.rb', line 12539 class GitPropertiesOutput < Struct.new( :code_connection_arn, :repository_id, :default_branch, :status, :error_message) SENSITIVE = [] include Aws::Structure end |