Class: Aws::DataZone::Types::GlossaryItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GlossaryItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of a business glossary.
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Types::GlossaryItemAdditionalAttributes
The additional attributes of an Amazon DataZone glossary.
-
#created_at ⇒ Time
The timestamp of when the glossary was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the glossary.
-
#description ⇒ String
The business glossary description.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the business glossary exists.
-
#id ⇒ String
The identifier of the glossary.
-
#name ⇒ String
The name of the glossary.
-
#owning_project_id ⇒ String
The identifier of the project that owns the business glosary.
-
#status ⇒ String
The business glossary status.
-
#updated_at ⇒ Time
The timestamp of when the business glossary was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the business glossary.
-
#usage_restrictions ⇒ Array<String>
The usage restrictions associated with a goverened glossary term.
Instance Attribute Details
#additional_attributes ⇒ Types::GlossaryItemAdditionalAttributes
The additional attributes of an Amazon DataZone glossary.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the glossary was created.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the glossary.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The business glossary description.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the business glossary exists.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The identifier of the glossary.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the glossary.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the business glosary.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#status ⇒ String
The business glossary status.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the business glossary was updated.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the business glossary.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |
#usage_restrictions ⇒ Array<String>
The usage restrictions associated with a goverened glossary term.
11686 11687 11688 11689 11690 11691 11692 11693 11694 11695 11696 11697 11698 11699 11700 11701 |
# File 'lib/aws-sdk-datazone/types.rb', line 11686 class GlossaryItem < Struct.new( :domain_id, :id, :name, :owning_project_id, :description, :status, :usage_restrictions, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :description] include Aws::Structure end |