Class: Aws::DataZone::Types::GlossaryTermItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GlossaryTermItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of a business glossary term.
Constant Summary collapse
- SENSITIVE =
[:name, :short_description, :long_description]
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Types::GlossaryTermItemAdditionalAttributes
The additional attributes of an Amazon DataZone glossary term.
-
#created_at ⇒ Time
The timestamp of when a business glossary term was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the business glossary.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the business glossary exists.
-
#glossary_id ⇒ String
The identifier of the business glossary to which the term belongs.
-
#id ⇒ String
The identifier of the business glossary term.
-
#long_description ⇒ String
The long description of the business glossary term.
-
#name ⇒ String
The name of the business glossary term.
-
#short_description ⇒ String
The short description of the business glossary term.
-
#status ⇒ String
The status of the business glossary term.
-
#term_relations ⇒ Types::TermRelations
The relations of the business glossary term.
-
#updated_at ⇒ Time
The timestamp of when a business glossary term was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the business glossary term.
-
#usage_restrictions ⇒ Array<String>
The usage restrictions associated with a goverened glossary term.
Instance Attribute Details
#additional_attributes ⇒ Types::GlossaryTermItemAdditionalAttributes
The additional attributes of an Amazon DataZone glossary term.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when a business glossary term was created.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the business glossary.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the business glossary exists.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#glossary_id ⇒ String
The identifier of the business glossary to which the term belongs.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#id ⇒ String
The identifier of the business glossary term.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#long_description ⇒ String
The long description of the business glossary term.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#name ⇒ String
The name of the business glossary term.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#short_description ⇒ String
The short description of the business glossary term.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#status ⇒ String
The status of the business glossary term.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#term_relations ⇒ Types::TermRelations
The relations of the business glossary term.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when a business glossary term was updated.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the business glossary term.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |
#usage_restrictions ⇒ Array<String>
The usage restrictions associated with a goverened glossary term.
11991 11992 11993 11994 11995 11996 11997 11998 11999 12000 12001 12002 12003 12004 12005 12006 12007 12008 |
# File 'lib/aws-sdk-datazone/types.rb', line 11991 class GlossaryTermItem < Struct.new( :domain_id, :glossary_id, :id, :name, :short_description, :usage_restrictions, :long_description, :term_relations, :status, :created_at, :created_by, :updated_at, :updated_by, :additional_attributes) SENSITIVE = [:name, :short_description, :long_description] include Aws::Structure end |