Class: Aws::DataZone::Types::GlueConnection
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GlueConnection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The Amazon Web Services Glue connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#athena_properties ⇒ Hash<String,String>
The Amazon Athena properties of the Amazon Web Services Glue connection.
-
#authentication_configuration ⇒ Types::AuthenticationConfiguration
The authentication configuration of the Amazon Web Services Glue connection.
-
#compatible_compute_environments ⇒ Array<String>
The compatible compute environments of the Amazon Web Services Glue connection.
-
#connection_properties ⇒ Hash<String,String>
The properties of the Amazon Web Services Glue connection.
-
#connection_schema_version ⇒ Integer
The connection schema version of the Amazon Web Services Glue connection.
-
#connection_type ⇒ String
The type of the Amazon Web Services Glue connection.
-
#creation_time ⇒ Time
The creation time of the Amazon Web Services Glue connection.
-
#description ⇒ String
The description of the Amazon Web Services Glue connection.
-
#last_connection_validation_time ⇒ Time
The last validation time of the Amazon Web Services Glue connection.
-
#last_updated_by ⇒ String
The user who last updated the Amazon Web Services Glue connection.
-
#last_updated_time ⇒ Time
The timestamp at which the Amazon Web Services Glue connection was last updated.
-
#match_criteria ⇒ Array<String>
The match criteria of the Amazon Web Services Glue connection.
-
#name ⇒ String
The name of the Amazon Web Services Glue connection.
-
#physical_connection_requirements ⇒ Types::PhysicalConnectionRequirements
The physical connection requirements of the Amazon Web Services Glue connection.
-
#python_properties ⇒ Hash<String,String>
The Python properties of the Amazon Web Services Glue connection.
-
#spark_properties ⇒ Hash<String,String>
The Spark properties of the Amazon Web Services Glue connection.
-
#status ⇒ String
The status of the Amazon Web Services Glue connection.
-
#status_reason ⇒ String
The status reason of the Amazon Web Services Glue connection.
Instance Attribute Details
#athena_properties ⇒ Hash<String,String>
The Amazon Athena properties of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#authentication_configuration ⇒ Types::AuthenticationConfiguration
The authentication configuration of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#compatible_compute_environments ⇒ Array<String>
The compatible compute environments of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#connection_properties ⇒ Hash<String,String>
The properties of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#connection_schema_version ⇒ Integer
The connection schema version of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#connection_type ⇒ String
The type of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The creation time of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#last_connection_validation_time ⇒ Time
The last validation time of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#last_updated_by ⇒ String
The user who last updated the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The timestamp at which the Amazon Web Services Glue connection was last updated.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#match_criteria ⇒ Array<String>
The match criteria of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#physical_connection_requirements ⇒ Types::PhysicalConnectionRequirements
The physical connection requirements of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#python_properties ⇒ Hash<String,String>
The Python properties of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#spark_properties ⇒ Hash<String,String>
The Spark properties of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The status reason of the Amazon Web Services Glue connection.
12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 |
# File 'lib/aws-sdk-datazone/types.rb', line 12844 class GlueConnection < Struct.new( :name, :description, :connection_type, :match_criteria, :connection_properties, :spark_properties, :athena_properties, :python_properties, :physical_connection_requirements, :creation_time, :last_updated_time, :last_updated_by, :status, :status_reason, :last_connection_validation_time, :authentication_configuration, :connection_schema_version, :compatible_compute_environments) SENSITIVE = [] include Aws::Structure end |