Class: Aws::DataZone::Types::GlueConnection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The Amazon Web Services Glue connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#athena_propertiesHash<String,String>

The Amazon Athena properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_configurationTypes::AuthenticationConfiguration

The authentication configuration of the Amazon Web Services Glue connection.



12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#compatible_compute_environmentsArray<String>

The compatible compute environments of the Amazon Web Services Glue connection.

Returns:

  • (Array<String>)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#connection_propertiesHash<String,String>

The properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#connection_schema_versionInteger

The connection schema version of the Amazon Web Services Glue connection.

Returns:

  • (Integer)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The type of the Amazon Web Services Glue connection.

Returns:

  • (String)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The creation time of the Amazon Web Services Glue connection.

Returns:

  • (Time)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Amazon Web Services Glue connection.

Returns:

  • (String)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#last_connection_validation_timeTime

The last validation time of the Amazon Web Services Glue connection.

Returns:

  • (Time)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_byString

The user who last updated the Amazon Web Services Glue connection.

Returns:

  • (String)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The timestamp at which the Amazon Web Services Glue connection was last updated.

Returns:

  • (Time)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#match_criteriaArray<String>

The match criteria of the Amazon Web Services Glue connection.

Returns:

  • (Array<String>)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon Web Services Glue connection.

Returns:

  • (String)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#physical_connection_requirementsTypes::PhysicalConnectionRequirements

The physical connection requirements of the Amazon Web Services Glue connection.



12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#python_propertiesHash<String,String>

The Python properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#spark_propertiesHash<String,String>

The Spark properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Amazon Web Services Glue connection.

Returns:

  • (String)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The status reason of the Amazon Web Services Glue connection.

Returns:

  • (String)


12528
12529
12530
12531
12532
12533
12534
12535
12536
12537
12538
12539
12540
12541
12542
12543
12544
12545
12546
12547
12548
12549
# File 'lib/aws-sdk-datazone/types.rb', line 12528

class GlueConnection < Struct.new(
  :name,
  :description,
  :connection_type,
  :match_criteria,
  :connection_properties,
  :spark_properties,
  :athena_properties,
  :python_properties,
  :physical_connection_requirements,
  :creation_time,
  :last_updated_time,
  :last_updated_by,
  :status,
  :status_reason,
  :last_connection_validation_time,
  :authentication_configuration,
  :connection_schema_version,
  :compatible_compute_environments)
  SENSITIVE = []
  include Aws::Structure
end