Class: Aws::DataZone::Types::GlueConnection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The Amazon Web Services Glue connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#athena_propertiesHash<String,String>

The Amazon Athena properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_configurationTypes::AuthenticationConfiguration

The authentication configuration of the Amazon Web Services Glue connection.



10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#compatible_compute_environmentsArray<String>

The compatible compute environments of the Amazon Web Services Glue connection.

Returns:

  • (Array<String>)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#connection_propertiesHash<String,String>

The properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#connection_schema_versionInteger

The connection schema version of the Amazon Web Services Glue connection.

Returns:

  • (Integer)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The type of the Amazon Web Services Glue connection.

Returns:

  • (String)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The creation time of the Amazon Web Services Glue connection.

Returns:

  • (Time)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Amazon Web Services Glue connection.

Returns:

  • (String)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#last_connection_validation_timeTime

The last validation time of the Amazon Web Services Glue connection.

Returns:

  • (Time)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_byString

The user who last updated the Amazon Web Services Glue connection.

Returns:

  • (String)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The timestamp at which the Amazon Web Services Glue connection was last updated.

Returns:

  • (Time)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#match_criteriaArray<String>

The match criteria of the Amazon Web Services Glue connection.

Returns:

  • (Array<String>)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon Web Services Glue connection.

Returns:

  • (String)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#physical_connection_requirementsTypes::PhysicalConnectionRequirements

The physical connection requirements of the Amazon Web Services Glue connection.



10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#python_propertiesHash<String,String>

The Python properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#spark_propertiesHash<String,String>

The Spark properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Amazon Web Services Glue connection.

Returns:

  • (String)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The status reason of the Amazon Web Services Glue connection.

Returns:

  • (String)


10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
10520
10521
10522
10523
10524
10525
10526
10527
10528
10529
# File 'lib/aws-sdk-datazone/types.rb', line 10508

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end