Class: Aws::DataZone::Types::GlueConnection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The Amazon Web Services Glue connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#athena_propertiesHash<String,String>

The Amazon Athena properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_configurationTypes::AuthenticationConfiguration

The authentication configuration of the Amazon Web Services Glue connection.



10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#compatible_compute_environmentsArray<String>

The compatible compute environments of the Amazon Web Services Glue connection.

Returns:

  • (Array<String>)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#connection_propertiesHash<String,String>

The properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#connection_schema_versionInteger

The connection schema version of the Amazon Web Services Glue connection.

Returns:

  • (Integer)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#connection_typeString

The type of the Amazon Web Services Glue connection.

Returns:

  • (String)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The creation time of the Amazon Web Services Glue connection.

Returns:

  • (Time)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Amazon Web Services Glue connection.

Returns:

  • (String)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#last_connection_validation_timeTime

The last validation time of the Amazon Web Services Glue connection.

Returns:

  • (Time)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_byString

The user who last updated the Amazon Web Services Glue connection.

Returns:

  • (String)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The timestamp at which the Amazon Web Services Glue connection was last updated.

Returns:

  • (Time)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#match_criteriaArray<String>

The match criteria of the Amazon Web Services Glue connection.

Returns:

  • (Array<String>)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Amazon Web Services Glue connection.

Returns:

  • (String)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#physical_connection_requirementsTypes::PhysicalConnectionRequirements

The physical connection requirements of the Amazon Web Services Glue connection.



10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#python_propertiesHash<String,String>

The Python properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#spark_propertiesHash<String,String>

The Spark properties of the Amazon Web Services Glue connection.

Returns:

  • (Hash<String,String>)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Amazon Web Services Glue connection.

Returns:

  • (String)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The status reason of the Amazon Web Services Glue connection.

Returns:

  • (String)


10358
10359
10360
10361
10362
10363
10364
10365
10366
10367
10368
10369
10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
# File 'lib/aws-sdk-datazone/types.rb', line 10358

class GlueConnection < Struct.new(
  :athena_properties,
  :authentication_configuration,
  :compatible_compute_environments,
  :connection_properties,
  :connection_schema_version,
  :connection_type,
  :creation_time,
  :description,
  :last_connection_validation_time,
  :last_updated_by,
  :last_updated_time,
  :match_criteria,
  :name,
  :physical_connection_requirements,
  :python_properties,
  :spark_properties,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end