Class: Aws::DataZone::Types::GlueConnectionPatch

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The Amazon Web Services Glue connection patch.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authentication_configurationTypes::AuthenticationConfigurationPatch

The authentication configuration of the Amazon Web Services Glue connection patch.



12022
12023
12024
12025
12026
12027
12028
# File 'lib/aws-sdk-datazone/types.rb', line 12022

class GlueConnectionPatch < Struct.new(
  :description,
  :connection_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#connection_propertiesHash<String,String>

The properties of the Amazon Web Services Glue connection patch.

Returns:

  • (Hash<String,String>)


12022
12023
12024
12025
12026
12027
12028
# File 'lib/aws-sdk-datazone/types.rb', line 12022

class GlueConnectionPatch < Struct.new(
  :description,
  :connection_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Amazon Web Services Glue connection patch.

Returns:

  • (String)


12022
12023
12024
12025
12026
12027
12028
# File 'lib/aws-sdk-datazone/types.rb', line 12022

class GlueConnectionPatch < Struct.new(
  :description,
  :connection_properties,
  :authentication_configuration)
  SENSITIVE = []
  include Aws::Structure
end