Class: Aws::DataZone::Types::GluePropertiesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The properties of the Amazon Web Services Glue connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_messageString

The error message generated if the action is not completed successfully.

Returns:

  • (String)


12086
12087
12088
12089
12090
12091
# File 'lib/aws-sdk-datazone/types.rb', line 12086

class GluePropertiesOutput < Struct.new(
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of a connection.

Returns:

  • (String)


12086
12087
12088
12089
12090
12091
# File 'lib/aws-sdk-datazone/types.rb', line 12086

class GluePropertiesOutput < Struct.new(
  :status,
  :error_message)
  SENSITIVE = []
  include Aws::Structure
end