Class: Aws::DataZone::Types::GluePropertiesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GluePropertiesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The properties of the Amazon Web Services Glue connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_message ⇒ String
The error message generated if the action is not completed successfully.
-
#status ⇒ String
The status of a connection.
Instance Attribute Details
#error_message ⇒ String
The error message generated if the action is not completed successfully.
12086 12087 12088 12089 12090 12091 |
# File 'lib/aws-sdk-datazone/types.rb', line 12086 class GluePropertiesOutput < Struct.new( :status, :error_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of a connection.
12086 12087 12088 12089 12090 12091 |
# File 'lib/aws-sdk-datazone/types.rb', line 12086 class GluePropertiesOutput < Struct.new( :status, :error_message) SENSITIVE = [] include Aws::Structure end |