Class: Aws::DataZone::Types::GrantedEntityInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::GrantedEntityInput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
GrantedEntityInput is a union - when making an API calls you must set exactly one of the members.
The details of a listing for which a subscription is to be granted.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#listing ⇒ Types::ListingRevisionInput
The listing for which a subscription is to be granted.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#listing ⇒ Types::ListingRevisionInput
The listing for which a subscription is to be granted.
12228 12229 12230 12231 12232 12233 12234 12235 12236 12237 |
# File 'lib/aws-sdk-datazone/types.rb', line 12228 class GrantedEntityInput < Struct.new( :listing, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Listing < GrantedEntityInput; end class Unknown < GrantedEntityInput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
12228 12229 12230 |
# File 'lib/aws-sdk-datazone/types.rb', line 12228 def unknown @unknown end |