Class: Aws::DataZone::Types::LineageNodeTypeItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of a data lineage node type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp at which the data lineage node type was created.

Returns:

  • (Time)


13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
# File 'lib/aws-sdk-datazone/types.rb', line 13015

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The user who created the data lineage node type.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
# File 'lib/aws-sdk-datazone/types.rb', line 13015

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the data lineage node type.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
# File 'lib/aws-sdk-datazone/types.rb', line 13015

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The ID of the domain where the data lineage node type lives.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
# File 'lib/aws-sdk-datazone/types.rb', line 13015

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#forms_outputHash<String,Types::FormEntryOutput>

The forms output of the data lineage node type.

Returns:



13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
# File 'lib/aws-sdk-datazone/types.rb', line 13015

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data lineage node type.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
# File 'lib/aws-sdk-datazone/types.rb', line 13015

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#revisionString

The revision of the data lineage node type.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
# File 'lib/aws-sdk-datazone/types.rb', line 13015

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp at which the data lineage node type was updated.

Returns:

  • (Time)


13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
# File 'lib/aws-sdk-datazone/types.rb', line 13015

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The user who updated the data lineage node type.

Returns:

  • (String)


13015
13016
13017
13018
13019
13020
13021
13022
13023
13024
13025
13026
13027
# File 'lib/aws-sdk-datazone/types.rb', line 13015

class LineageNodeTypeItem < Struct.new(
  :domain_id,
  :name,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :revision,
  :forms_output)
  SENSITIVE = []
  include Aws::Structure
end