Class: Aws::DataZone::Types::MetadataGenerationRunTypeStat
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::MetadataGenerationRunTypeStat
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The statistics of the metadata generation run type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_message ⇒ String
The error message displayed if the action fails to run.
-
#status ⇒ String
The status of the metadata generation run type statistics.
-
#type ⇒ String
The type of the metadata generation run type statistics.
Instance Attribute Details
#error_message ⇒ String
The error message displayed if the action fails to run.
15808 15809 15810 15811 15812 15813 15814 |
# File 'lib/aws-sdk-datazone/types.rb', line 15808 class MetadataGenerationRunTypeStat < Struct.new( :type, :status, :error_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the metadata generation run type statistics.
15808 15809 15810 15811 15812 15813 15814 |
# File 'lib/aws-sdk-datazone/types.rb', line 15808 class MetadataGenerationRunTypeStat < Struct.new( :type, :status, :error_message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the metadata generation run type statistics.
15808 15809 15810 15811 15812 15813 15814 |
# File 'lib/aws-sdk-datazone/types.rb', line 15808 class MetadataGenerationRunTypeStat < Struct.new( :type, :status, :error_message) SENSITIVE = [] include Aws::Structure end |