Class: Aws::DataZone::Types::NetworkConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::NetworkConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The network configuration for a notebook run in Amazon SageMaker Unified Studio.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_access_type ⇒ String
The network access type for the notebook run.
-
#security_group_ids ⇒ Array<String>
The identifiers of the security groups for the notebook run.
-
#subnet_ids ⇒ Array<String>
The identifiers of the subnets for the notebook run.
-
#vpc_id ⇒ String
The identifier of the VPC for the notebook run.
Instance Attribute Details
#network_access_type ⇒ String
The network access type for the notebook run. Valid values are ‘PUBLIC_INTERNET_ONLY` and `VPC_ONLY`.
16800 16801 16802 16803 16804 16805 16806 16807 |
# File 'lib/aws-sdk-datazone/types.rb', line 16800 class NetworkConfig < Struct.new( :network_access_type, :vpc_id, :subnet_ids, :security_group_ids) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The identifiers of the security groups for the notebook run. You can specify up to 5 security groups.
16800 16801 16802 16803 16804 16805 16806 16807 |
# File 'lib/aws-sdk-datazone/types.rb', line 16800 class NetworkConfig < Struct.new( :network_access_type, :vpc_id, :subnet_ids, :security_group_ids) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The identifiers of the subnets for the notebook run. You can specify up to 10 subnets.
16800 16801 16802 16803 16804 16805 16806 16807 |
# File 'lib/aws-sdk-datazone/types.rb', line 16800 class NetworkConfig < Struct.new( :network_access_type, :vpc_id, :subnet_ids, :security_group_ids) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The identifier of the VPC for the notebook run. This is required when the network access type is ‘VPC_ONLY`.
16800 16801 16802 16803 16804 16805 16806 16807 |
# File 'lib/aws-sdk-datazone/types.rb', line 16800 class NetworkConfig < Struct.new( :network_access_type, :vpc_id, :subnet_ids, :security_group_ids) SENSITIVE = [] include Aws::Structure end |