Class: Aws::DataZone::Types::NotebookRunSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::NotebookRunSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The summary of a notebook run in Amazon DataZone.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp of when the notebook run completed.
-
#created_at ⇒ Time
The timestamp of when the notebook run was created.
-
#created_by ⇒ String
The identifier of the user who created the notebook run.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain.
-
#id ⇒ String
The identifier of the notebook run.
-
#notebook_id ⇒ String
The identifier of the notebook.
-
#owning_project_id ⇒ String
The identifier of the project that owns the notebook run.
-
#schedule_id ⇒ String
The identifier of the schedule associated with the notebook run.
-
#started_at ⇒ Time
The timestamp of when the notebook run started executing.
-
#status ⇒ String
The status of the notebook run.
-
#trigger_source ⇒ Types::TriggerSource
The source that triggered the notebook run.
-
#updated_at ⇒ Time
The timestamp of when the notebook run was last updated.
-
#updated_by ⇒ String
The identifier of the user who last updated the notebook run.
Instance Attribute Details
#completed_at ⇒ Time
The timestamp of when the notebook run completed.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the notebook run was created.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who created the notebook run.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the notebook run.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#notebook_id ⇒ String
The identifier of the notebook.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the notebook run.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#schedule_id ⇒ String
The identifier of the schedule associated with the notebook run.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when the notebook run started executing.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the notebook run.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#trigger_source ⇒ Types::TriggerSource
The source that triggered the notebook run.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the notebook run was last updated.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The identifier of the user who last updated the notebook run.
16481 16482 16483 16484 16485 16486 16487 16488 16489 16490 16491 16492 16493 16494 16495 16496 16497 |
# File 'lib/aws-sdk-datazone/types.rb', line 16481 class NotebookRunSummary < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :trigger_source, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [] include Aws::Structure end |