Class: Aws::DataZone::Types::NotebookSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::NotebookSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The summary of a notebook in Amazon SageMaker Unified Studio.
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the notebook was created.
-
#created_by ⇒ String
The identifier of the user who created the notebook.
-
#description ⇒ String
The description of the notebook.
-
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
-
#id ⇒ String
The identifier of the notebook.
-
#name ⇒ String
The name of the notebook.
-
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
-
#status ⇒ String
The status of the notebook.
-
#updated_at ⇒ Time
The timestamp of when the notebook was last updated.
-
#updated_by ⇒ String
The identifier of the user who last updated the notebook.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the notebook was created.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who created the notebook.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the notebook.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The identifier of the notebook.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the notebook.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#status ⇒ String
The status of the notebook.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the notebook was last updated.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#updated_by ⇒ String
The identifier of the user who last updated the notebook.
17068 17069 17070 17071 17072 17073 17074 17075 17076 17077 17078 17079 17080 17081 |
# File 'lib/aws-sdk-datazone/types.rb', line 17068 class NotebookSummary < Struct.new( :id, :name, :owning_project_id, :domain_id, :status, :description, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [:name, :description] include Aws::Structure end |