Class: Aws::DataZone::Types::NotebookSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The summary of a notebook in Amazon SageMaker Unified Studio.

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the notebook was created.

Returns:

  • (Time)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#created_byString

The identifier of the user who created the notebook.

Returns:

  • (String)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the notebook.

Returns:

  • (String)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon SageMaker Unified Studio domain.

Returns:

  • (String)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#idString

The identifier of the notebook.

Returns:

  • (String)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the notebook.

Returns:

  • (String)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the notebook.

Returns:

  • (String)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#statusString

The status of the notebook.

Returns:

  • (String)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the notebook was last updated.

Returns:

  • (Time)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#updated_byString

The identifier of the user who last updated the notebook.

Returns:

  • (String)


17028
17029
17030
17031
17032
17033
17034
17035
17036
17037
17038
17039
17040
17041
# File 'lib/aws-sdk-datazone/types.rb', line 17028

class NotebookSummary < Struct.new(
  :id,
  :name,
  :owning_project_id,
  :domain_id,
  :status,
  :description,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end