Class: Aws::DataZone::Types::NotificationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of a notification generated in Amazon DataZone.

Constant Summary collapse

SENSITIVE =
[:action_link, :message, :title]

Instance Attribute Summary collapse

Instance Attribute Details

The action link included in the notification.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#creation_timestampTime

The timestamp of when a notification was created.

Returns:

  • (Time)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#domain_identifierString

The identifier of a Amazon DataZone domain in which the notification exists.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#identifierString

The identifier of the notification.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#last_updated_timestampTime

The timestamp of when the notification was last updated.

Returns:

  • (Time)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#messageString

The message included in the notification.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#metadataHash<String,String>

The metadata included in the notification.

Returns:

  • (Hash<String,String>)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#statusString

The status included in the notification.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#titleString

The title of the notification.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#topicTypes::Topic

The topic of the notification.

Returns:



10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end

#typeString

The type of the notification.

Returns:

  • (String)


10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
# File 'lib/aws-sdk-datazone/types.rb', line 10474

class NotificationOutput < Struct.new(
  :action_link,
  :creation_timestamp,
  :domain_identifier,
  :identifier,
  :last_updated_timestamp,
  :message,
  :metadata,
  :status,
  :title,
  :topic,
  :type)
  SENSITIVE = [:action_link, :message, :title]
  include Aws::Structure
end