Class: Aws::DataZone::Types::NotificationResource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of the resource mentioned in a notification.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The ID of the resource mentioned in a notification.

Returns:

  • (String)


16138
16139
16140
16141
16142
16143
16144
# File 'lib/aws-sdk-datazone/types.rb', line 16138

class NotificationResource < Struct.new(
  :type,
  :id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the resource mentioned in a notification.

Returns:

  • (String)


16138
16139
16140
16141
16142
16143
16144
# File 'lib/aws-sdk-datazone/types.rb', line 16138

class NotificationResource < Struct.new(
  :type,
  :id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the resource mentioned in a notification.

Returns:

  • (String)


16138
16139
16140
16141
16142
16143
16144
# File 'lib/aws-sdk-datazone/types.rb', line 16138

class NotificationResource < Struct.new(
  :type,
  :id,
  :name)
  SENSITIVE = []
  include Aws::Structure
end