Class: Aws::DataZone::Types::OutputLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

OutputLocation is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OutputLocation corresponding to the set member.

The output location for a notebook export in Amazon SageMaker Unified Studio.

Direct Known Subclasses

S3, Unknown

Defined Under Namespace

Classes: S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3Types::S3Destination

The Amazon Simple Storage Service destination for the notebook export.



17238
17239
17240
17241
17242
17243
17244
17245
17246
17247
# File 'lib/aws-sdk-datazone/types.rb', line 17238

class OutputLocation < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < OutputLocation; end
  class Unknown < OutputLocation; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



17238
17239
17240
# File 'lib/aws-sdk-datazone/types.rb', line 17238

def unknown
  @unknown
end