Class: Aws::DataZone::Types::OwnerProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

OwnerProperties is a union - when making an API calls you must set exactly one of the members.

The properties of a domain unit’s owner.

Direct Known Subclasses

Group, Unknown, User

Defined Under Namespace

Classes: Group, Unknown, User

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#groupTypes::OwnerGroupProperties

Specifies that the domain unit owner is a group.



17319
17320
17321
17322
17323
17324
17325
17326
17327
17328
17329
17330
# File 'lib/aws-sdk-datazone/types.rb', line 17319

class OwnerProperties < Struct.new(
  :user,
  :group,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class User < OwnerProperties; end
  class Group < OwnerProperties; end
  class Unknown < OwnerProperties; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



17319
17320
17321
# File 'lib/aws-sdk-datazone/types.rb', line 17319

def unknown
  @unknown
end

#userTypes::OwnerUserProperties

Specifies that the domain unit owner is a user.



17319
17320
17321
17322
17323
17324
17325
17326
17327
17328
17329
17330
# File 'lib/aws-sdk-datazone/types.rb', line 17319

class OwnerProperties < Struct.new(
  :user,
  :group,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class User < OwnerProperties; end
  class Group < OwnerProperties; end
  class Unknown < OwnerProperties; end
end