Class: Aws::DataZone::Types::PackageConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::PackageConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The package configuration for a notebook run environment in Amazon DataZone.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#package_manager ⇒ String
The package manager for the notebook run environment.
-
#package_specification ⇒ String
The package specification content for the notebook run environment.
Instance Attribute Details
#package_manager ⇒ String
The package manager for the notebook run environment. The default value is ‘UV`.
16835 16836 16837 16838 16839 16840 |
# File 'lib/aws-sdk-datazone/types.rb', line 16835 class PackageConfig < Struct.new( :package_manager, :package_specification) SENSITIVE = [] include Aws::Structure end |
#package_specification ⇒ String
The package specification content for the notebook run environment. The maximum length is 10240 characters.
16835 16836 16837 16838 16839 16840 |
# File 'lib/aws-sdk-datazone/types.rb', line 16835 class PackageConfig < Struct.new( :package_manager, :package_specification) SENSITIVE = [] include Aws::Structure end |