Class: Aws::DataZone::Types::Permissions

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

Permissions is a union - when making an API calls you must set exactly one of the members.

Note:

Permissions is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Permissions corresponding to the set member.

The asset permissions.

Direct Known Subclasses

S3, Unknown

Defined Under Namespace

Classes: S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3Array<String>

The S3 details of the asset permissions.

Returns:

  • (Array<String>)


16453
16454
16455
16456
16457
16458
16459
16460
16461
16462
# File 'lib/aws-sdk-datazone/types.rb', line 16453

class Permissions < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < Permissions; end
  class Unknown < Permissions; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



16453
16454
16455
# File 'lib/aws-sdk-datazone/types.rb', line 16453

def unknown
  @unknown
end