Class: Aws::DataZone::Types::PhysicalEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::PhysicalEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The physical endpoints of a connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_location ⇒ Types::AwsLocation
The location of a connection.
-
#enable_trusted_identity_propagation ⇒ Boolean
Specified whether trusted identity propagation for the connection is enabled.
-
#glue_connection ⇒ Types::GlueConnection
The Amazon Web Services Glue connection.
-
#glue_connection_name ⇒ String
The Amazon Web Services Glue connection name.
-
#glue_connection_names ⇒ Array<String>
The Amazon Web Services Glue connection names in the physical endpoint.
-
#host ⇒ String
The host in the physical endpoints of a connection.
-
#port ⇒ Integer
The port in the physical endpoints of a connection.
-
#protocol ⇒ String
The protocol in the physical endpoints of a connection.
-
#stage ⇒ String
The stage in the physical endpoints of a connection.
Instance Attribute Details
#aws_location ⇒ Types::AwsLocation
The location of a connection.
16539 16540 16541 16542 16543 16544 16545 16546 16547 16548 16549 16550 16551 |
# File 'lib/aws-sdk-datazone/types.rb', line 16539 class PhysicalEndpoint < Struct.new( :aws_location, :glue_connection_name, :glue_connection_names, :glue_connection, :enable_trusted_identity_propagation, :host, :port, :protocol, :stage) SENSITIVE = [] include Aws::Structure end |
#enable_trusted_identity_propagation ⇒ Boolean
Specified whether trusted identity propagation for the connection is enabled.
16539 16540 16541 16542 16543 16544 16545 16546 16547 16548 16549 16550 16551 |
# File 'lib/aws-sdk-datazone/types.rb', line 16539 class PhysicalEndpoint < Struct.new( :aws_location, :glue_connection_name, :glue_connection_names, :glue_connection, :enable_trusted_identity_propagation, :host, :port, :protocol, :stage) SENSITIVE = [] include Aws::Structure end |
#glue_connection ⇒ Types::GlueConnection
The Amazon Web Services Glue connection.
16539 16540 16541 16542 16543 16544 16545 16546 16547 16548 16549 16550 16551 |
# File 'lib/aws-sdk-datazone/types.rb', line 16539 class PhysicalEndpoint < Struct.new( :aws_location, :glue_connection_name, :glue_connection_names, :glue_connection, :enable_trusted_identity_propagation, :host, :port, :protocol, :stage) SENSITIVE = [] include Aws::Structure end |
#glue_connection_name ⇒ String
The Amazon Web Services Glue connection name.
16539 16540 16541 16542 16543 16544 16545 16546 16547 16548 16549 16550 16551 |
# File 'lib/aws-sdk-datazone/types.rb', line 16539 class PhysicalEndpoint < Struct.new( :aws_location, :glue_connection_name, :glue_connection_names, :glue_connection, :enable_trusted_identity_propagation, :host, :port, :protocol, :stage) SENSITIVE = [] include Aws::Structure end |
#glue_connection_names ⇒ Array<String>
The Amazon Web Services Glue connection names in the physical endpoint.
16539 16540 16541 16542 16543 16544 16545 16546 16547 16548 16549 16550 16551 |
# File 'lib/aws-sdk-datazone/types.rb', line 16539 class PhysicalEndpoint < Struct.new( :aws_location, :glue_connection_name, :glue_connection_names, :glue_connection, :enable_trusted_identity_propagation, :host, :port, :protocol, :stage) SENSITIVE = [] include Aws::Structure end |
#host ⇒ String
The host in the physical endpoints of a connection.
16539 16540 16541 16542 16543 16544 16545 16546 16547 16548 16549 16550 16551 |
# File 'lib/aws-sdk-datazone/types.rb', line 16539 class PhysicalEndpoint < Struct.new( :aws_location, :glue_connection_name, :glue_connection_names, :glue_connection, :enable_trusted_identity_propagation, :host, :port, :protocol, :stage) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port in the physical endpoints of a connection.
16539 16540 16541 16542 16543 16544 16545 16546 16547 16548 16549 16550 16551 |
# File 'lib/aws-sdk-datazone/types.rb', line 16539 class PhysicalEndpoint < Struct.new( :aws_location, :glue_connection_name, :glue_connection_names, :glue_connection, :enable_trusted_identity_propagation, :host, :port, :protocol, :stage) SENSITIVE = [] include Aws::Structure end |
#protocol ⇒ String
The protocol in the physical endpoints of a connection.
16539 16540 16541 16542 16543 16544 16545 16546 16547 16548 16549 16550 16551 |
# File 'lib/aws-sdk-datazone/types.rb', line 16539 class PhysicalEndpoint < Struct.new( :aws_location, :glue_connection_name, :glue_connection_names, :glue_connection, :enable_trusted_identity_propagation, :host, :port, :protocol, :stage) SENSITIVE = [] include Aws::Structure end |
#stage ⇒ String
The stage in the physical endpoints of a connection.
16539 16540 16541 16542 16543 16544 16545 16546 16547 16548 16549 16550 16551 |
# File 'lib/aws-sdk-datazone/types.rb', line 16539 class PhysicalEndpoint < Struct.new( :aws_location, :glue_connection_name, :glue_connection_names, :glue_connection, :enable_trusted_identity_propagation, :host, :port, :protocol, :stage) SENSITIVE = [] include Aws::Structure end |