Class: Aws::DataZone::Types::PolicyGrantDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

PolicyGrantDetail is a union - when making an API calls you must set exactly one of the members.

Note:

PolicyGrantDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PolicyGrantDetail corresponding to the set member.

The details of the policy grant.

Defined Under Namespace

Classes: AddToProjectMemberPool, CreateAssetType, CreateDomainUnit, CreateEnvironment, CreateEnvironmentFromBlueprint, CreateEnvironmentProfile, CreateFormType, CreateGlossary, CreateProject, CreateProjectFromProjectProfile, DelegateCreateEnvironmentProfile, OverrideDomainUnitOwners, OverrideProjectOwners, Unknown, UseAssetType

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_to_project_member_poolTypes::AddToProjectMemberPoolPolicyGrantDetail

Specifies that the policy grant is to be added to the members of the project.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#create_asset_typeTypes::CreateAssetTypePolicyGrantDetail

Specifies that this is a create asset type policy.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#create_domain_unitTypes::CreateDomainUnitPolicyGrantDetail

Specifies that this is a create domain unit policy.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#create_environmentTypes::Unit

Specifies that this is a create environment policy.

Returns:



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#create_environment_from_blueprintTypes::Unit

The details of the policy of creating an environment.

Returns:



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#create_environment_profileTypes::CreateEnvironmentProfilePolicyGrantDetail

Specifies that this is a create environment profile policy.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#create_form_typeTypes::CreateFormTypePolicyGrantDetail

Specifies that this is a create form type policy.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#create_glossaryTypes::CreateGlossaryPolicyGrantDetail

Specifies that this is a create glossary policy.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#create_projectTypes::CreateProjectPolicyGrantDetail

Specifies that this is a create project policy.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#create_project_from_project_profileTypes::CreateProjectFromProjectProfilePolicyGrantDetail

Specifies whether to create a project from project profile.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#delegate_create_environment_profileTypes::Unit

Specifies that this is the delegation of the create environment profile policy.

Returns:



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#override_domain_unit_ownersTypes::OverrideDomainUnitOwnersPolicyGrantDetail

Specifies whether to override domain unit owners.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#override_project_ownersTypes::OverrideProjectOwnersPolicyGrantDetail

Specifies whether to override project owners.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



17588
17589
17590
# File 'lib/aws-sdk-datazone/types.rb', line 17588

def unknown
  @unknown
end

#use_asset_typeTypes::UseAssetTypePolicyGrantDetail

Specifies the domain unit(s) whose projects can use this asset type while creating asset or asset revisions.



17588
17589
17590
17591
17592
17593
17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
17617
17618
17619
17620
17621
17622
17623
# File 'lib/aws-sdk-datazone/types.rb', line 17588

class PolicyGrantDetail < Struct.new(
  :create_domain_unit,
  :override_domain_unit_owners,
  :add_to_project_member_pool,
  :override_project_owners,
  :create_glossary,
  :create_form_type,
  :create_asset_type,
  :create_project,
  :create_environment_profile,
  :delegate_create_environment_profile,
  :create_environment,
  :create_environment_from_blueprint,
  :create_project_from_project_profile,
  :use_asset_type,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CreateDomainUnit < PolicyGrantDetail; end
  class OverrideDomainUnitOwners < PolicyGrantDetail; end
  class AddToProjectMemberPool < PolicyGrantDetail; end
  class OverrideProjectOwners < PolicyGrantDetail; end
  class CreateGlossary < PolicyGrantDetail; end
  class CreateFormType < PolicyGrantDetail; end
  class CreateAssetType < PolicyGrantDetail; end
  class CreateProject < PolicyGrantDetail; end
  class CreateEnvironmentProfile < PolicyGrantDetail; end
  class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end
  class CreateEnvironment < PolicyGrantDetail; end
  class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end
  class CreateProjectFromProjectProfile < PolicyGrantDetail; end
  class UseAssetType < PolicyGrantDetail; end
  class Unknown < PolicyGrantDetail; end
end