Class: Aws::DataZone::Types::PolicyGrantDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::PolicyGrantDetail
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
PolicyGrantDetail is a union - when making an API calls you must set exactly one of the members.
PolicyGrantDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PolicyGrantDetail corresponding to the set member.
The details of the policy grant.
Direct Known Subclasses
AddToProjectMemberPool, CreateAssetType, CreateDomainUnit, CreateEnvironment, CreateEnvironmentFromBlueprint, CreateEnvironmentProfile, CreateFormType, CreateGlossary, CreateProject, CreateProjectFromProjectProfile, DelegateCreateEnvironmentProfile, OverrideDomainUnitOwners, OverrideProjectOwners, Unknown, UseAssetType
Defined Under Namespace
Classes: AddToProjectMemberPool, CreateAssetType, CreateDomainUnit, CreateEnvironment, CreateEnvironmentFromBlueprint, CreateEnvironmentProfile, CreateFormType, CreateGlossary, CreateProject, CreateProjectFromProjectProfile, DelegateCreateEnvironmentProfile, OverrideDomainUnitOwners, OverrideProjectOwners, Unknown, UseAssetType
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_to_project_member_pool ⇒ Types::AddToProjectMemberPoolPolicyGrantDetail
Specifies that the policy grant is to be added to the members of the project.
-
#create_asset_type ⇒ Types::CreateAssetTypePolicyGrantDetail
Specifies that this is a create asset type policy.
-
#create_domain_unit ⇒ Types::CreateDomainUnitPolicyGrantDetail
Specifies that this is a create domain unit policy.
-
#create_environment ⇒ Types::Unit
Specifies that this is a create environment policy.
-
#create_environment_from_blueprint ⇒ Types::Unit
The details of the policy of creating an environment.
-
#create_environment_profile ⇒ Types::CreateEnvironmentProfilePolicyGrantDetail
Specifies that this is a create environment profile policy.
-
#create_form_type ⇒ Types::CreateFormTypePolicyGrantDetail
Specifies that this is a create form type policy.
-
#create_glossary ⇒ Types::CreateGlossaryPolicyGrantDetail
Specifies that this is a create glossary policy.
-
#create_project ⇒ Types::CreateProjectPolicyGrantDetail
Specifies that this is a create project policy.
-
#create_project_from_project_profile ⇒ Types::CreateProjectFromProjectProfilePolicyGrantDetail
Specifies whether to create a project from project profile.
-
#delegate_create_environment_profile ⇒ Types::Unit
Specifies that this is the delegation of the create environment profile policy.
-
#override_domain_unit_owners ⇒ Types::OverrideDomainUnitOwnersPolicyGrantDetail
Specifies whether to override domain unit owners.
-
#override_project_owners ⇒ Types::OverrideProjectOwnersPolicyGrantDetail
Specifies whether to override project owners.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#use_asset_type ⇒ Types::UseAssetTypePolicyGrantDetail
Specifies the domain unit(s) whose projects can use this asset type while creating asset or asset revisions.
Instance Attribute Details
#add_to_project_member_pool ⇒ Types::AddToProjectMemberPoolPolicyGrantDetail
Specifies that the policy grant is to be added to the members of the project.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_asset_type ⇒ Types::CreateAssetTypePolicyGrantDetail
Specifies that this is a create asset type policy.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_domain_unit ⇒ Types::CreateDomainUnitPolicyGrantDetail
Specifies that this is a create domain unit policy.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_environment ⇒ Types::Unit
Specifies that this is a create environment policy.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_environment_from_blueprint ⇒ Types::Unit
The details of the policy of creating an environment.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_environment_profile ⇒ Types::CreateEnvironmentProfilePolicyGrantDetail
Specifies that this is a create environment profile policy.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_form_type ⇒ Types::CreateFormTypePolicyGrantDetail
Specifies that this is a create form type policy.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_glossary ⇒ Types::CreateGlossaryPolicyGrantDetail
Specifies that this is a create glossary policy.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_project ⇒ Types::CreateProjectPolicyGrantDetail
Specifies that this is a create project policy.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_project_from_project_profile ⇒ Types::CreateProjectFromProjectProfilePolicyGrantDetail
Specifies whether to create a project from project profile.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#delegate_create_environment_profile ⇒ Types::Unit
Specifies that this is the delegation of the create environment profile policy.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#override_domain_unit_owners ⇒ Types::OverrideDomainUnitOwnersPolicyGrantDetail
Specifies whether to override domain unit owners.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#override_project_owners ⇒ Types::OverrideProjectOwnersPolicyGrantDetail
Specifies whether to override project owners.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
17021 17022 17023 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 def unknown @unknown end |
#use_asset_type ⇒ Types::UseAssetTypePolicyGrantDetail
Specifies the domain unit(s) whose projects can use this asset type while creating asset or asset revisions.
17021 17022 17023 17024 17025 17026 17027 17028 17029 17030 17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 17047 17048 17049 17050 17051 17052 17053 17054 17055 17056 |
# File 'lib/aws-sdk-datazone/types.rb', line 17021 class PolicyGrantDetail < Struct.new( :create_domain_unit, :override_domain_unit_owners, :add_to_project_member_pool, :override_project_owners, :create_glossary, :create_form_type, :create_asset_type, :create_project, :create_environment_profile, :delegate_create_environment_profile, :create_environment, :create_environment_from_blueprint, :create_project_from_project_profile, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CreateDomainUnit < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class AddToProjectMemberPool < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |