Class: Aws::DataZone::Types::PolicyGrantDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::PolicyGrantDetail
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
PolicyGrantDetail is a union - when making an API calls you must set exactly one of the members.
PolicyGrantDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PolicyGrantDetail corresponding to the set member.
The details of the policy grant.
Direct Known Subclasses
AddToProjectMemberPool, CreateAssetType, CreateDomainUnit, CreateEnvironment, CreateEnvironmentFromBlueprint, CreateEnvironmentProfile, CreateFormType, CreateGlossary, CreateProject, CreateProjectFromProjectProfile, DelegateCreateEnvironmentProfile, OverrideDomainUnitOwners, OverrideProjectOwners, Unknown, UseAssetType
Defined Under Namespace
Classes: AddToProjectMemberPool, CreateAssetType, CreateDomainUnit, CreateEnvironment, CreateEnvironmentFromBlueprint, CreateEnvironmentProfile, CreateFormType, CreateGlossary, CreateProject, CreateProjectFromProjectProfile, DelegateCreateEnvironmentProfile, OverrideDomainUnitOwners, OverrideProjectOwners, Unknown, UseAssetType
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_to_project_member_pool ⇒ Types::AddToProjectMemberPoolPolicyGrantDetail
Specifies that the policy grant is to be added to the members of the project.
-
#create_asset_type ⇒ Types::CreateAssetTypePolicyGrantDetail
Specifies that this is a create asset type policy.
-
#create_domain_unit ⇒ Types::CreateDomainUnitPolicyGrantDetail
Specifies that this is a create domain unit policy.
-
#create_environment ⇒ Types::Unit
Specifies that this is a create environment policy.
-
#create_environment_from_blueprint ⇒ Types::Unit
The details of the policy of creating an environment.
-
#create_environment_profile ⇒ Types::CreateEnvironmentProfilePolicyGrantDetail
Specifies that this is a create environment profile policy.
-
#create_form_type ⇒ Types::CreateFormTypePolicyGrantDetail
Specifies that this is a create form type policy.
-
#create_glossary ⇒ Types::CreateGlossaryPolicyGrantDetail
Specifies that this is a create glossary policy.
-
#create_project ⇒ Types::CreateProjectPolicyGrantDetail
Specifies that this is a create project policy.
-
#create_project_from_project_profile ⇒ Types::CreateProjectFromProjectProfilePolicyGrantDetail
Specifies whether to create a project from project profile.
-
#delegate_create_environment_profile ⇒ Types::Unit
Specifies that this is the delegation of the create environment profile policy.
-
#override_domain_unit_owners ⇒ Types::OverrideDomainUnitOwnersPolicyGrantDetail
Specifies whether to override domain unit owners.
-
#override_project_owners ⇒ Types::OverrideProjectOwnersPolicyGrantDetail
Specifies whether to override project owners.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#use_asset_type ⇒ Types::UseAssetTypePolicyGrantDetail
Specifies the domain unit(s) whose projects can use this asset type while creating asset or asset revisions.
Instance Attribute Details
#add_to_project_member_pool ⇒ Types::AddToProjectMemberPoolPolicyGrantDetail
Specifies that the policy grant is to be added to the members of the project.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_asset_type ⇒ Types::CreateAssetTypePolicyGrantDetail
Specifies that this is a create asset type policy.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_domain_unit ⇒ Types::CreateDomainUnitPolicyGrantDetail
Specifies that this is a create domain unit policy.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_environment ⇒ Types::Unit
Specifies that this is a create environment policy.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_environment_from_blueprint ⇒ Types::Unit
The details of the policy of creating an environment.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_environment_profile ⇒ Types::CreateEnvironmentProfilePolicyGrantDetail
Specifies that this is a create environment profile policy.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_form_type ⇒ Types::CreateFormTypePolicyGrantDetail
Specifies that this is a create form type policy.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_glossary ⇒ Types::CreateGlossaryPolicyGrantDetail
Specifies that this is a create glossary policy.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_project ⇒ Types::CreateProjectPolicyGrantDetail
Specifies that this is a create project policy.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_project_from_project_profile ⇒ Types::CreateProjectFromProjectProfilePolicyGrantDetail
Specifies whether to create a project from project profile.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#delegate_create_environment_profile ⇒ Types::Unit
Specifies that this is the delegation of the create environment profile policy.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#override_domain_unit_owners ⇒ Types::OverrideDomainUnitOwnersPolicyGrantDetail
Specifies whether to override domain unit owners.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#override_project_owners ⇒ Types::OverrideProjectOwnersPolicyGrantDetail
Specifies whether to override project owners.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
14509 14510 14511 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 def unknown @unknown end |
#use_asset_type ⇒ Types::UseAssetTypePolicyGrantDetail
Specifies the domain unit(s) whose projects can use this asset type while creating asset or asset revisions.
14509 14510 14511 14512 14513 14514 14515 14516 14517 14518 14519 14520 14521 14522 14523 14524 14525 14526 14527 14528 14529 14530 14531 14532 14533 14534 14535 14536 14537 14538 14539 14540 14541 14542 14543 14544 |
# File 'lib/aws-sdk-datazone/types.rb', line 14509 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_from_blueprint, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :create_project_from_project_profile, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :use_asset_type, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentFromBlueprint < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class CreateProjectFromProjectProfile < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class UseAssetType < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |