Class: Aws::DataZone::Types::PolicyGrantDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::PolicyGrantDetail
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
PolicyGrantDetail is a union - when making an API calls you must set exactly one of the members.
PolicyGrantDetail is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PolicyGrantDetail corresponding to the set member.
The details of the policy grant.
Direct Known Subclasses
AddToProjectMemberPool, CreateAssetType, CreateDomainUnit, CreateEnvironment, CreateEnvironmentProfile, CreateFormType, CreateGlossary, CreateProject, DelegateCreateEnvironmentProfile, OverrideDomainUnitOwners, OverrideProjectOwners, Unknown
Defined Under Namespace
Classes: AddToProjectMemberPool, CreateAssetType, CreateDomainUnit, CreateEnvironment, CreateEnvironmentProfile, CreateFormType, CreateGlossary, CreateProject, DelegateCreateEnvironmentProfile, OverrideDomainUnitOwners, OverrideProjectOwners, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_to_project_member_pool ⇒ Types::AddToProjectMemberPoolPolicyGrantDetail
Specifies that the policy grant is to be added to the members of the project.
-
#create_asset_type ⇒ Types::CreateAssetTypePolicyGrantDetail
Specifies that this is a create asset type policy.
-
#create_domain_unit ⇒ Types::CreateDomainUnitPolicyGrantDetail
Specifies that this is a create domain unit policy.
-
#create_environment ⇒ Types::Unit
Specifies that this is a create environment policy.
-
#create_environment_profile ⇒ Types::CreateEnvironmentProfilePolicyGrantDetail
Specifies that this is a create environment profile policy.
-
#create_form_type ⇒ Types::CreateFormTypePolicyGrantDetail
Specifies that this is a create form type policy.
-
#create_glossary ⇒ Types::CreateGlossaryPolicyGrantDetail
Specifies that this is a create glossary policy.
-
#create_project ⇒ Types::CreateProjectPolicyGrantDetail
Specifies that this is a create project policy.
-
#delegate_create_environment_profile ⇒ Types::Unit
Specifies that this is the delegation of the create environment profile policy.
-
#override_domain_unit_owners ⇒ Types::OverrideDomainUnitOwnersPolicyGrantDetail
Specifies whether to override domain unit owners.
-
#override_project_owners ⇒ Types::OverrideProjectOwnersPolicyGrantDetail
Specifies whether to override project owners.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#add_to_project_member_pool ⇒ Types::AddToProjectMemberPoolPolicyGrantDetail
Specifies that the policy grant is to be added to the members of the project.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_asset_type ⇒ Types::CreateAssetTypePolicyGrantDetail
Specifies that this is a create asset type policy.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_domain_unit ⇒ Types::CreateDomainUnitPolicyGrantDetail
Specifies that this is a create domain unit policy.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_environment ⇒ Types::Unit
Specifies that this is a create environment policy.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_environment_profile ⇒ Types::CreateEnvironmentProfilePolicyGrantDetail
Specifies that this is a create environment profile policy.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_form_type ⇒ Types::CreateFormTypePolicyGrantDetail
Specifies that this is a create form type policy.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_glossary ⇒ Types::CreateGlossaryPolicyGrantDetail
Specifies that this is a create glossary policy.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#create_project ⇒ Types::CreateProjectPolicyGrantDetail
Specifies that this is a create project policy.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#delegate_create_environment_profile ⇒ Types::Unit
Specifies that this is the delegation of the create environment profile policy.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#override_domain_unit_owners ⇒ Types::OverrideDomainUnitOwnersPolicyGrantDetail
Specifies whether to override domain unit owners.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#override_project_owners ⇒ Types::OverrideProjectOwnersPolicyGrantDetail
Specifies whether to override project owners.
11476 11477 11478 11479 11480 11481 11482 11483 11484 11485 11486 11487 11488 11489 11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 class PolicyGrantDetail < Struct.new( :add_to_project_member_pool, :create_asset_type, :create_domain_unit, :create_environment, :create_environment_profile, :create_form_type, :create_glossary, :create_project, :delegate_create_environment_profile, :override_domain_unit_owners, :override_project_owners, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AddToProjectMemberPool < PolicyGrantDetail; end class CreateAssetType < PolicyGrantDetail; end class CreateDomainUnit < PolicyGrantDetail; end class CreateEnvironment < PolicyGrantDetail; end class CreateEnvironmentProfile < PolicyGrantDetail; end class CreateFormType < PolicyGrantDetail; end class CreateGlossary < PolicyGrantDetail; end class CreateProject < PolicyGrantDetail; end class DelegateCreateEnvironmentProfile < PolicyGrantDetail; end class OverrideDomainUnitOwners < PolicyGrantDetail; end class OverrideProjectOwners < PolicyGrantDetail; end class Unknown < PolicyGrantDetail; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
11476 11477 11478 |
# File 'lib/aws-sdk-datazone/types.rb', line 11476 def unknown @unknown end |