Class: Aws::DataZone::Types::ProjectMembershipAssignment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

A map of user or group profiles to designations that need to be assigned in the project.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#designationString

The designation of the project membership.

Returns:

  • (String)


16869
16870
16871
16872
16873
16874
# File 'lib/aws-sdk-datazone/types.rb', line 16869

class ProjectMembershipAssignment < Struct.new(
  :member,
  :designation)
  SENSITIVE = []
  include Aws::Structure
end

#memberTypes::Member

The details about a project member.

Returns:



16869
16870
16871
16872
16873
16874
# File 'lib/aws-sdk-datazone/types.rb', line 16869

class ProjectMembershipAssignment < Struct.new(
  :member,
  :designation)
  SENSITIVE = []
  include Aws::Structure
end