Class: Aws::DataZone::Types::PutDataExportConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::PutDataExportConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#domain_identifier ⇒ String
The domain ID for which you want to create data export configuration details.
-
#enable_export ⇒ Boolean
Specifies that the export is to be enabled as part of creating data export configuration details.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration as part of creating data export configuration details.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
A suitable default value is auto-generated. You should normally not need to pass this option.
18582 18583 18584 18585 18586 18587 18588 18589 |
# File 'lib/aws-sdk-datazone/types.rb', line 18582 class PutDataExportConfigurationInput < Struct.new( :domain_identifier, :enable_export, :encryption_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The domain ID for which you want to create data export configuration details.
18582 18583 18584 18585 18586 18587 18588 18589 |
# File 'lib/aws-sdk-datazone/types.rb', line 18582 class PutDataExportConfigurationInput < Struct.new( :domain_identifier, :enable_export, :encryption_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#enable_export ⇒ Boolean
Specifies that the export is to be enabled as part of creating data export configuration details.
18582 18583 18584 18585 18586 18587 18588 18589 |
# File 'lib/aws-sdk-datazone/types.rb', line 18582 class PutDataExportConfigurationInput < Struct.new( :domain_identifier, :enable_export, :encryption_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration as part of creating data export configuration details.
The KMS key provided here as part of encryptionConfiguration must have the required permissions as described in KMS permissions for exporting asset metadata in Amazon SageMaker Unified Studio.
18582 18583 18584 18585 18586 18587 18588 18589 |
# File 'lib/aws-sdk-datazone/types.rb', line 18582 class PutDataExportConfigurationInput < Struct.new( :domain_identifier, :enable_export, :encryption_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |