Class: Aws::DataZone::Types::PutResourceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::PutResourceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The resource configuration that is used to configure the environment blueprint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the resource configuration.
-
#name ⇒ String
The name of the resource configuration.
-
#parameters ⇒ Hash<String,String>
The parameters of the resource configuration.
-
#region ⇒ String
The Amazon Web Services Region of the resource configuration.
Instance Attribute Details
#description ⇒ String
The description of the resource configuration.
18354 18355 18356 18357 18358 18359 18360 18361 |
# File 'lib/aws-sdk-datazone/types.rb', line 18354 class PutResourceConfiguration < Struct.new( :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource configuration.
18354 18355 18356 18357 18358 18359 18360 18361 |
# File 'lib/aws-sdk-datazone/types.rb', line 18354 class PutResourceConfiguration < Struct.new( :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
The parameters of the resource configuration.
18354 18355 18356 18357 18358 18359 18360 18361 |
# File 'lib/aws-sdk-datazone/types.rb', line 18354 class PutResourceConfiguration < Struct.new( :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region of the resource configuration.
18354 18355 18356 18357 18358 18359 18360 18361 |
# File 'lib/aws-sdk-datazone/types.rb', line 18354 class PutResourceConfiguration < Struct.new( :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |