Class: Aws::DataZone::Types::QueryGraphInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_attributesTypes::AdditionalAttributes

Additional details on the queried entity that can be requested in the response.



17272
17273
17274
17275
17276
17277
17278
17279
17280
# File 'lib/aws-sdk-datazone/types.rb', line 17272

class QueryGraphInput < Struct.new(
  :domain_identifier,
  :match,
  :max_results,
  :next_token,
  :additional_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain.

Returns:

  • (String)


17272
17273
17274
17275
17276
17277
17278
17279
17280
# File 'lib/aws-sdk-datazone/types.rb', line 17272

class QueryGraphInput < Struct.new(
  :domain_identifier,
  :match,
  :max_results,
  :next_token,
  :additional_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#matchArray<Types::MatchClause>

List of query match clauses.

Returns:



17272
17273
17274
17275
17276
17277
17278
17279
17280
# File 'lib/aws-sdk-datazone/types.rb', line 17272

class QueryGraphInput < Struct.new(
  :domain_identifier,
  :match,
  :max_results,
  :next_token,
  :additional_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of entities to return in a single call to ‘QueryGraph`. When the number of entities to be listed is greater than the value of `MaxResults`, the response contains a `NextToken` value that you can use in a subsequent call to `QueryGraph` to list the next set of entities.

Returns:

  • (Integer)


17272
17273
17274
17275
17276
17277
17278
17279
17280
# File 'lib/aws-sdk-datazone/types.rb', line 17272

class QueryGraphInput < Struct.new(
  :domain_identifier,
  :match,
  :max_results,
  :next_token,
  :additional_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

When the number of entities is greater than the default value for the ‘MaxResults` parameter, or if you explicitly specify a value for `MaxResults` that is less than the number of entities, the response includes a pagination token named `NextToken`. You can specify this `NextToken` value in a subsequent call to `QueryGraph` to list the next set of entities.

Returns:

  • (String)


17272
17273
17274
17275
17276
17277
17278
17279
17280
# File 'lib/aws-sdk-datazone/types.rb', line 17272

class QueryGraphInput < Struct.new(
  :domain_identifier,
  :match,
  :max_results,
  :next_token,
  :additional_attributes)
  SENSITIVE = []
  include Aws::Structure
end