Class: Aws::DataZone::Types::QueryGraphOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#itemsArray<Types::ResultItem>

The results of the ‘QueryGraph` action.

Returns:



17360
17361
17362
17363
17364
17365
# File 'lib/aws-sdk-datazone/types.rb', line 17360

class QueryGraphOutput < Struct.new(
  :items,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

When the number of entities is greater than the default value for the ‘MaxResults` parameter, or if you explicitly specify a value for `MaxResults` that is less than the number of entities, the response includes a pagination token named `NextToken`. You can specify this `NextToken` value in a subsequent call to `QueryGraph` to list the next set of entities.

Returns:

  • (String)


17360
17361
17362
17363
17364
17365
# File 'lib/aws-sdk-datazone/types.rb', line 17360

class QueryGraphOutput < Struct.new(
  :items,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end