Class: Aws::DataZone::Types::RedshiftLineageSyncConfigurationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::RedshiftLineageSyncConfigurationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The Amaon Redshift lineage sync configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Specifies whether the Amaon Redshift lineage sync configuration is enabled.
-
#lineage_job_id ⇒ String
The lineage job ID of the Amaon Redshift lineage sync configuration.
-
#schedule ⇒ Types::LineageSyncSchedule
The schedule of teh Amaon Redshift lineage sync configuration.
Instance Attribute Details
#enabled ⇒ Boolean
Specifies whether the Amaon Redshift lineage sync configuration is enabled.
18539 18540 18541 18542 18543 18544 18545 |
# File 'lib/aws-sdk-datazone/types.rb', line 18539 class RedshiftLineageSyncConfigurationOutput < Struct.new( :lineage_job_id, :enabled, :schedule) SENSITIVE = [] include Aws::Structure end |
#lineage_job_id ⇒ String
The lineage job ID of the Amaon Redshift lineage sync configuration.
18539 18540 18541 18542 18543 18544 18545 |
# File 'lib/aws-sdk-datazone/types.rb', line 18539 class RedshiftLineageSyncConfigurationOutput < Struct.new( :lineage_job_id, :enabled, :schedule) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ Types::LineageSyncSchedule
The schedule of teh Amaon Redshift lineage sync configuration.
18539 18540 18541 18542 18543 18544 18545 |
# File 'lib/aws-sdk-datazone/types.rb', line 18539 class RedshiftLineageSyncConfigurationOutput < Struct.new( :lineage_job_id, :enabled, :schedule) SENSITIVE = [] include Aws::Structure end |