Class: Aws::DataZone::Types::RedshiftPropertiesPatch
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::RedshiftPropertiesPatch
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Amazon Redshift properties patch.
Constant Summary collapse
- SENSITIVE =
[:credentials]
Instance Attribute Summary collapse
-
#credentials ⇒ Types::RedshiftCredentials
The credentials in the Amazon Redshift properties patch.
-
#database_name ⇒ String
The name in the Amazon Redshift properties patch.
-
#host ⇒ String
The host in the Amazon Redshift properties patch.
-
#lineage_sync ⇒ Types::RedshiftLineageSyncConfigurationInput
The lineage sync in the Amazon Redshift properties patch.
-
#port ⇒ Integer
The port in the Amazon Redshift properties patch.
-
#storage ⇒ Types::RedshiftStorageProperties
The storage in the Amazon Redshift properties patch.
Instance Attribute Details
#credentials ⇒ Types::RedshiftCredentials
The credentials in the Amazon Redshift properties patch.
17546 17547 17548 17549 17550 17551 17552 17553 17554 17555 |
# File 'lib/aws-sdk-datazone/types.rb', line 17546 class RedshiftPropertiesPatch < Struct.new( :storage, :database_name, :host, :port, :credentials, :lineage_sync) SENSITIVE = [:credentials] include Aws::Structure end |
#database_name ⇒ String
The name in the Amazon Redshift properties patch.
17546 17547 17548 17549 17550 17551 17552 17553 17554 17555 |
# File 'lib/aws-sdk-datazone/types.rb', line 17546 class RedshiftPropertiesPatch < Struct.new( :storage, :database_name, :host, :port, :credentials, :lineage_sync) SENSITIVE = [:credentials] include Aws::Structure end |
#host ⇒ String
The host in the Amazon Redshift properties patch.
17546 17547 17548 17549 17550 17551 17552 17553 17554 17555 |
# File 'lib/aws-sdk-datazone/types.rb', line 17546 class RedshiftPropertiesPatch < Struct.new( :storage, :database_name, :host, :port, :credentials, :lineage_sync) SENSITIVE = [:credentials] include Aws::Structure end |
#lineage_sync ⇒ Types::RedshiftLineageSyncConfigurationInput
The lineage sync in the Amazon Redshift properties patch.
17546 17547 17548 17549 17550 17551 17552 17553 17554 17555 |
# File 'lib/aws-sdk-datazone/types.rb', line 17546 class RedshiftPropertiesPatch < Struct.new( :storage, :database_name, :host, :port, :credentials, :lineage_sync) SENSITIVE = [:credentials] include Aws::Structure end |
#port ⇒ Integer
The port in the Amazon Redshift properties patch.
17546 17547 17548 17549 17550 17551 17552 17553 17554 17555 |
# File 'lib/aws-sdk-datazone/types.rb', line 17546 class RedshiftPropertiesPatch < Struct.new( :storage, :database_name, :host, :port, :credentials, :lineage_sync) SENSITIVE = [:credentials] include Aws::Structure end |
#storage ⇒ Types::RedshiftStorageProperties
The storage in the Amazon Redshift properties patch.
17546 17547 17548 17549 17550 17551 17552 17553 17554 17555 |
# File 'lib/aws-sdk-datazone/types.rb', line 17546 class RedshiftPropertiesPatch < Struct.new( :storage, :database_name, :host, :port, :credentials, :lineage_sync) SENSITIVE = [:credentials] include Aws::Structure end |