Class: Aws::DataZone::Types::RedshiftStorage

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

RedshiftStorage is a union - when making an API calls you must set exactly one of the members.

Note:

RedshiftStorage is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RedshiftStorage corresponding to the set member.

The details of the Amazon Redshift storage as part of the configuration of an Amazon Redshift data source run.

Defined Under Namespace

Classes: RedshiftClusterSource, RedshiftServerlessSource, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#redshift_cluster_sourceTypes::RedshiftClusterStorage

The details of the Amazon Redshift cluster source.



10238
10239
10240
10241
10242
10243
10244
10245
10246
10247
10248
10249
# File 'lib/aws-sdk-datazone/types.rb', line 10238

class RedshiftStorage < Struct.new(
  :redshift_cluster_source,
  :redshift_serverless_source,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RedshiftClusterSource < RedshiftStorage; end
  class RedshiftServerlessSource < RedshiftStorage; end
  class Unknown < RedshiftStorage; end
end

#redshift_serverless_sourceTypes::RedshiftServerlessStorage

The details of the Amazon Redshift Serverless workgroup source.



10238
10239
10240
10241
10242
10243
10244
10245
10246
10247
10248
10249
# File 'lib/aws-sdk-datazone/types.rb', line 10238

class RedshiftStorage < Struct.new(
  :redshift_cluster_source,
  :redshift_serverless_source,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RedshiftClusterSource < RedshiftStorage; end
  class RedshiftServerlessSource < RedshiftStorage; end
  class Unknown < RedshiftStorage; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



10238
10239
10240
# File 'lib/aws-sdk-datazone/types.rb', line 10238

def unknown
  @unknown
end