Class: Aws::DataZone::Types::RedshiftStorage
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::RedshiftStorage
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
RedshiftStorage is a union - when making an API calls you must set exactly one of the members.
RedshiftStorage is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RedshiftStorage corresponding to the set member.
The details of the Amazon Redshift storage as part of the configuration of an Amazon Redshift data source run.
Direct Known Subclasses
Defined Under Namespace
Classes: RedshiftClusterSource, RedshiftServerlessSource, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#redshift_cluster_source ⇒ Types::RedshiftClusterStorage
The details of the Amazon Redshift cluster source.
-
#redshift_serverless_source ⇒ Types::RedshiftServerlessStorage
The details of the Amazon Redshift Serverless workgroup source.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#redshift_cluster_source ⇒ Types::RedshiftClusterStorage
The details of the Amazon Redshift cluster source.
10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 10269 10270 |
# File 'lib/aws-sdk-datazone/types.rb', line 10259 class RedshiftStorage < Struct.new( :redshift_cluster_source, :redshift_serverless_source, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RedshiftClusterSource < RedshiftStorage; end class RedshiftServerlessSource < RedshiftStorage; end class Unknown < RedshiftStorage; end end |
#redshift_serverless_source ⇒ Types::RedshiftServerlessStorage
The details of the Amazon Redshift Serverless workgroup source.
10259 10260 10261 10262 10263 10264 10265 10266 10267 10268 10269 10270 |
# File 'lib/aws-sdk-datazone/types.rb', line 10259 class RedshiftStorage < Struct.new( :redshift_cluster_source, :redshift_serverless_source, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RedshiftClusterSource < RedshiftStorage; end class RedshiftServerlessSource < RedshiftStorage; end class Unknown < RedshiftStorage; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10259 10260 10261 |
# File 'lib/aws-sdk-datazone/types.rb', line 10259 def unknown @unknown end |