Class: Aws::DataZone::Types::RejectPredictionsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-datazone/types.rb', line 8274

class RejectPredictionsInput < Struct.new(
  :client_token,
  :domain_identifier,
  :identifier,
  :reject_choices,
  :reject_rule,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain.

Returns:

  • (String)


8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-datazone/types.rb', line 8274

class RejectPredictionsInput < Struct.new(
  :client_token,
  :domain_identifier,
  :identifier,
  :reject_choices,
  :reject_rule,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the prediction.

Returns:

  • (String)


8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-datazone/types.rb', line 8274

class RejectPredictionsInput < Struct.new(
  :client_token,
  :domain_identifier,
  :identifier,
  :reject_choices,
  :reject_rule,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#reject_choicesArray<Types::RejectChoice>

Returns:



8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-datazone/types.rb', line 8274

class RejectPredictionsInput < Struct.new(
  :client_token,
  :domain_identifier,
  :identifier,
  :reject_choices,
  :reject_rule,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#reject_ruleTypes::RejectRule

Returns:



8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-datazone/types.rb', line 8274

class RejectPredictionsInput < Struct.new(
  :client_token,
  :domain_identifier,
  :identifier,
  :reject_choices,
  :reject_rule,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#revisionString

Returns:

  • (String)


8274
8275
8276
8277
8278
8279
8280
8281
8282
8283
# File 'lib/aws-sdk-datazone/types.rb', line 8274

class RejectPredictionsInput < Struct.new(
  :client_token,
  :domain_identifier,
  :identifier,
  :reject_choices,
  :reject_rule,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end