Class: Aws::DataZone::Types::RejectPredictionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::RejectPredictionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain.
-
#identifier ⇒ String
The identifier of the prediction.
- #reject_choices ⇒ Array<Types::RejectChoice>
- #reject_rule ⇒ Types::RejectRule
- #revision ⇒ String
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 |
# File 'lib/aws-sdk-datazone/types.rb', line 8214 class RejectPredictionsInput < Struct.new( :client_token, :domain_identifier, :identifier, :reject_choices, :reject_rule, :revision) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain.
8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 |
# File 'lib/aws-sdk-datazone/types.rb', line 8214 class RejectPredictionsInput < Struct.new( :client_token, :domain_identifier, :identifier, :reject_choices, :reject_rule, :revision) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the prediction.
8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 |
# File 'lib/aws-sdk-datazone/types.rb', line 8214 class RejectPredictionsInput < Struct.new( :client_token, :domain_identifier, :identifier, :reject_choices, :reject_rule, :revision) SENSITIVE = [] include Aws::Structure end |
#reject_choices ⇒ Array<Types::RejectChoice>
8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 |
# File 'lib/aws-sdk-datazone/types.rb', line 8214 class RejectPredictionsInput < Struct.new( :client_token, :domain_identifier, :identifier, :reject_choices, :reject_rule, :revision) SENSITIVE = [] include Aws::Structure end |
#reject_rule ⇒ Types::RejectRule
8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 |
# File 'lib/aws-sdk-datazone/types.rb', line 8214 class RejectPredictionsInput < Struct.new( :client_token, :domain_identifier, :identifier, :reject_choices, :reject_rule, :revision) SENSITIVE = [] include Aws::Structure end |
#revision ⇒ String
8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 |
# File 'lib/aws-sdk-datazone/types.rb', line 8214 class RejectPredictionsInput < Struct.new( :client_token, :domain_identifier, :identifier, :reject_choices, :reject_rule, :revision) SENSITIVE = [] include Aws::Structure end |