Class: Aws::DataZone::Types::ResourceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::ResourceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the resource configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the resource configuration.
-
#identifier ⇒ String
The identifier of the resource configuration.
-
#name ⇒ String
The name of the resource configuration.
-
#parameters ⇒ Hash<String,String>
The parameters of the resource configuration.
-
#region ⇒ String
The Amazon Web Services Region of the resource configuration.
Instance Attribute Details
#description ⇒ String
The description of the resource configuration.
19288 19289 19290 19291 19292 19293 19294 19295 19296 |
# File 'lib/aws-sdk-datazone/types.rb', line 19288 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the resource configuration.
19288 19289 19290 19291 19292 19293 19294 19295 19296 |
# File 'lib/aws-sdk-datazone/types.rb', line 19288 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the resource configuration.
19288 19289 19290 19291 19292 19293 19294 19295 19296 |
# File 'lib/aws-sdk-datazone/types.rb', line 19288 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
The parameters of the resource configuration.
19288 19289 19290 19291 19292 19293 19294 19295 19296 |
# File 'lib/aws-sdk-datazone/types.rb', line 19288 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region of the resource configuration.
19288 19289 19290 19291 19292 19293 19294 19295 19296 |
# File 'lib/aws-sdk-datazone/types.rb', line 19288 class ResourceConfiguration < Struct.new( :identifier, :name, :description, :region, :parameters) SENSITIVE = [] include Aws::Structure end |