Class: Aws::DataZone::Types::ResultItem

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

ResultItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ResultItem corresponding to the set member.

Resulting entity from the query.

Direct Known Subclasses

LineageNode, Unknown

Defined Under Namespace

Classes: LineageNode, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lineage_nodeTypes::LineageNodeItem

Resulting data lineage node from the query.



18213
18214
18215
18216
18217
18218
18219
18220
18221
18222
# File 'lib/aws-sdk-datazone/types.rb', line 18213

class ResultItem < Struct.new(
  :lineage_node,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class LineageNode < ResultItem; end
  class Unknown < ResultItem; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



18213
18214
18215
# File 'lib/aws-sdk-datazone/types.rb', line 18213

def unknown
  @unknown
end