Class: Aws::DataZone::Types::SearchInventoryResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SearchInventoryResultItem
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
SearchInventoryResultItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SearchInventoryResultItem corresponding to the set member.
The details of the search results.
Direct Known Subclasses
Defined Under Namespace
Classes: AssetItem, GlossaryItem, GlossaryTermItem, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_item ⇒ Types::AssetItem
The asset item included in the search results.
-
#glossary_item ⇒ Types::GlossaryItem
The glossary item included in the search results.
-
#glossary_term_item ⇒ Types::GlossaryTermItem
The glossary term item included in the search results.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#asset_item ⇒ Types::AssetItem
The asset item included in the search results.
10928 10929 10930 10931 10932 10933 10934 10935 10936 10937 10938 10939 10940 10941 |
# File 'lib/aws-sdk-datazone/types.rb', line 10928 class SearchInventoryResultItem < Struct.new( :asset_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#glossary_item ⇒ Types::GlossaryItem
The glossary item included in the search results.
10928 10929 10930 10931 10932 10933 10934 10935 10936 10937 10938 10939 10940 10941 |
# File 'lib/aws-sdk-datazone/types.rb', line 10928 class SearchInventoryResultItem < Struct.new( :asset_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#glossary_term_item ⇒ Types::GlossaryTermItem
The glossary term item included in the search results.
10928 10929 10930 10931 10932 10933 10934 10935 10936 10937 10938 10939 10940 10941 |
# File 'lib/aws-sdk-datazone/types.rb', line 10928 class SearchInventoryResultItem < Struct.new( :asset_item, :glossary_item, :glossary_term_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetItem < SearchInventoryResultItem; end class GlossaryItem < SearchInventoryResultItem; end class GlossaryTermItem < SearchInventoryResultItem; end class Unknown < SearchInventoryResultItem; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10928 10929 10930 |
# File 'lib/aws-sdk-datazone/types.rb', line 10928 def unknown @unknown end |