Class: Aws::DataZone::Types::SearchResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SearchResultItem
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
SearchResultItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SearchResultItem corresponding to the set member.
The details of the results of the ‘SearchListings` action.
Direct Known Subclasses
Defined Under Namespace
Classes: AssetListing, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_listing ⇒ Types::AssetListingItem
The asset listing included in the results of the ‘SearchListings` action.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#asset_listing ⇒ Types::AssetListingItem
The asset listing included in the results of the ‘SearchListings` action.
10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 |
# File 'lib/aws-sdk-datazone/types.rb', line 10334 class SearchResultItem < Struct.new( :asset_listing, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetListing < SearchResultItem; end class Unknown < SearchResultItem; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10334 10335 10336 |
# File 'lib/aws-sdk-datazone/types.rb', line 10334 def unknown @unknown end |