Class: Aws::DataZone::Types::SearchResultItem

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

SearchResultItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SearchResultItem corresponding to the set member.

The details of the results of the ‘SearchListings` action.

Direct Known Subclasses

AssetListing, Unknown

Defined Under Namespace

Classes: AssetListing, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_listingTypes::AssetListingItem

The asset listing included in the results of the ‘SearchListings` action.



8935
8936
8937
8938
8939
8940
8941
8942
8943
8944
# File 'lib/aws-sdk-datazone/types.rb', line 8935

class SearchResultItem < Struct.new(
  :asset_listing,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AssetListing < SearchResultItem; end
  class Unknown < SearchResultItem; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



8935
8936
8937
# File 'lib/aws-sdk-datazone/types.rb', line 8935

def unknown
  @unknown
end