Class: Aws::DataZone::Types::SearchTypesResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SearchTypesResultItem
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
SearchTypesResultItem is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SearchTypesResultItem corresponding to the set member.
The details of the results of the ‘SearchTypes` action.
Direct Known Subclasses
Defined Under Namespace
Classes: AssetTypeItem, FormTypeItem, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_type_item ⇒ Types::AssetTypeItem
The asset type included in the results of the ‘SearchTypes` action.
-
#form_type_item ⇒ Types::FormTypeData
The form type included in the results of the ‘SearchTypes` action.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#asset_type_item ⇒ Types::AssetTypeItem
The asset type included in the results of the ‘SearchTypes` action.
10099 10100 10101 10102 10103 10104 10105 10106 10107 10108 10109 10110 |
# File 'lib/aws-sdk-datazone/types.rb', line 10099 class SearchTypesResultItem < Struct.new( :asset_type_item, :form_type_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetTypeItem < SearchTypesResultItem; end class FormTypeItem < SearchTypesResultItem; end class Unknown < SearchTypesResultItem; end end |
#form_type_item ⇒ Types::FormTypeData
The form type included in the results of the ‘SearchTypes` action.
10099 10100 10101 10102 10103 10104 10105 10106 10107 10108 10109 10110 |
# File 'lib/aws-sdk-datazone/types.rb', line 10099 class SearchTypesResultItem < Struct.new( :asset_type_item, :form_type_item, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AssetTypeItem < SearchTypesResultItem; end class FormTypeItem < SearchTypesResultItem; end class Unknown < SearchTypesResultItem; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10099 10100 10101 |
# File 'lib/aws-sdk-datazone/types.rb', line 10099 def unknown @unknown end |