Class: Aws::DataZone::Types::SourceLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SourceLocation
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
SourceLocation is a union - when making an API calls you must set exactly one of the members.
Note:
SourceLocation is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SourceLocation corresponding to the set member.
The source location for a notebook import in Amazon SageMaker Unified Studio.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[:s3]
Instance Attribute Summary collapse
-
#s3 ⇒ String
The Amazon Simple Storage Service URI of the notebook source file.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#s3 ⇒ String
The Amazon Simple Storage Service URI of the notebook source file.
20462 20463 20464 20465 20466 20467 20468 20469 20470 20471 |
# File 'lib/aws-sdk-datazone/types.rb', line 20462 class SourceLocation < Struct.new( :s3, :unknown) SENSITIVE = [:s3] include Aws::Structure include Aws::Structure::Union class S3 < SourceLocation; end class Unknown < SourceLocation; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
20462 20463 20464 |
# File 'lib/aws-sdk-datazone/types.rb', line 20462 def unknown @unknown end |