Class: Aws::DataZone::Types::StartDataSourceRunOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartDataSourceRunOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when data source run was created.
-
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source that is being run.
-
#data_source_id ⇒ String
The identifier of the data source.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which to start a data source run.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of the data source run.
-
#project_id ⇒ String
The identifier of the project.
-
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
Specifies run statistics for assets.
-
#started_at ⇒ Time
The timestamp of when the data source run was started.
-
#status ⇒ String
The status of the data source run.
-
#stopped_at ⇒ Time
The timestamp of when the data source run was stopped.
-
#type ⇒ String
The type of the data source run.
-
#updated_at ⇒ Time
The timestamp of when the data source run was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when data source run was created.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source that is being run.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The identifier of the data source.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which to start a data source run.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the data source run.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
Specifies run statistics for assets.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when the data source run was started.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data source run.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The timestamp of when the data source run was stopped.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the data source run.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source run was updated.
21507 21508 21509 21510 21511 21512 21513 21514 21515 21516 21517 21518 21519 21520 21521 21522 21523 |
# File 'lib/aws-sdk-datazone/types.rb', line 21507 class StartDataSourceRunOutput < Struct.new( :domain_id, :data_source_id, :id, :project_id, :status, :type, :data_source_configuration_snapshot, :run_statistics_for_assets, :error_message, :created_at, :updated_at, :started_at, :stopped_at) SENSITIVE = [] include Aws::Structure end |