Class: Aws::DataZone::Types::StartDataSourceRunOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when data source run was created.

Returns:

  • (Time)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_configuration_snapshotString

The configuration snapshot of the data source that is being run.

Returns:

  • (String)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_idString

The identifier of the data source.

Returns:

  • (String)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon DataZone domain in which to start a data source run.

Returns:

  • (String)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageTypes::DataSourceErrorMessage

Specifies the error message that is returned if the operation cannot be successfully completed.



17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the data source run.

Returns:

  • (String)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#project_idString

The identifier of the project.

Returns:

  • (String)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#run_statistics_for_assetsTypes::RunStatisticsForAssets

Specifies run statistics for assets.



17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp of when the data source run was started.

Returns:

  • (Time)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the data source run.

Returns:

  • (String)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atTime

The timestamp of when the data source run was stopped.

Returns:

  • (Time)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the data source run.

Returns:

  • (String)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp of when the data source run was updated.

Returns:

  • (Time)


17460
17461
17462
17463
17464
17465
17466
17467
17468
17469
17470
17471
17472
17473
17474
17475
17476
# File 'lib/aws-sdk-datazone/types.rb', line 17460

class StartDataSourceRunOutput < Struct.new(
  :created_at,
  :data_source_configuration_snapshot,
  :data_source_id,
  :domain_id,
  :error_message,
  :id,
  :project_id,
  :run_statistics_for_assets,
  :started_at,
  :status,
  :stopped_at,
  :type,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end