Class: Aws::DataZone::Types::StartDataSourceRunOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartDataSourceRunOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when data source run was created.
-
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source that is being run.
-
#data_source_id ⇒ String
The identifier of the data source.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which to start a data source run.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of the data source run.
-
#project_id ⇒ String
The identifier of the project.
-
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
Specifies run statistics for assets.
-
#started_at ⇒ Time
The timestamp of when the data source run was started.
-
#status ⇒ String
The status of the data source run.
-
#stopped_at ⇒ Time
The timestamp of when the data source run was stopped.
-
#type ⇒ String
The type of the data source run.
-
#updated_at ⇒ Time
The timestamp of when the data source run was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when data source run was created.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source that is being run.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The identifier of the data source.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which to start a data source run.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the data source run.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
Specifies run statistics for assets.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when the data source run was started.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data source run.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The timestamp of when the data source run was stopped.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the data source run.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source run was updated.
12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 |
# File 'lib/aws-sdk-datazone/types.rb', line 12327 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |