Class: Aws::DataZone::Types::StartDataSourceRunOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartDataSourceRunOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when data source run was created.
-
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source that is being run.
-
#data_source_id ⇒ String
The identifier of the data source.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which to start a data source run.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of the data source run.
-
#project_id ⇒ String
The identifier of the project.
-
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
Specifies run statistics for assets.
-
#started_at ⇒ Time
The timestamp of when the data source run was started.
-
#status ⇒ String
The status of the data source run.
-
#stopped_at ⇒ Time
The timestamp of when the data source run was stopped.
-
#type ⇒ String
The type of the data source run.
-
#updated_at ⇒ Time
The timestamp of when the data source run was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when data source run was created.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#data_source_configuration_snapshot ⇒ String
The configuration snapshot of the data source that is being run.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#data_source_id ⇒ String
The identifier of the data source.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which to start a data source run.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the data source run.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#run_statistics_for_assets ⇒ Types::RunStatisticsForAssets
Specifies run statistics for assets.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when the data source run was started.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data source run.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The timestamp of when the data source run was stopped.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the data source run.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source run was updated.
10749 10750 10751 10752 10753 10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 |
# File 'lib/aws-sdk-datazone/types.rb', line 10749 class StartDataSourceRunOutput < Struct.new( :created_at, :data_source_configuration_snapshot, :data_source_id, :domain_id, :error_message, :id, :project_id, :run_statistics_for_assets, :started_at, :status, :stopped_at, :type, :updated_at) SENSITIVE = [] include Aws::Structure end |