Class: Aws::DataZone::Types::StartNotebookExportInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartNotebookExportInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which to export the notebook.
-
#file_format ⇒ String
The file format for the notebook export.
-
#notebook_identifier ⇒ String
The identifier of the notebook to export.
-
#owning_project_identifier ⇒ String
The identifier of the project that owns the notebook.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
21033 21034 21035 21036 21037 21038 21039 21040 21041 |
# File 'lib/aws-sdk-datazone/types.rb', line 21033 class StartNotebookExportInput < Struct.new( :domain_identifier, :notebook_identifier, :owning_project_identifier, :file_format, :client_token) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which to export the notebook.
21033 21034 21035 21036 21037 21038 21039 21040 21041 |
# File 'lib/aws-sdk-datazone/types.rb', line 21033 class StartNotebookExportInput < Struct.new( :domain_identifier, :notebook_identifier, :owning_project_identifier, :file_format, :client_token) SENSITIVE = [] include Aws::Structure end |
#file_format ⇒ String
The file format for the notebook export. Valid values are ‘PDF` and `IPYNB`.
21033 21034 21035 21036 21037 21038 21039 21040 21041 |
# File 'lib/aws-sdk-datazone/types.rb', line 21033 class StartNotebookExportInput < Struct.new( :domain_identifier, :notebook_identifier, :owning_project_identifier, :file_format, :client_token) SENSITIVE = [] include Aws::Structure end |
#notebook_identifier ⇒ String
The identifier of the notebook to export.
21033 21034 21035 21036 21037 21038 21039 21040 21041 |
# File 'lib/aws-sdk-datazone/types.rb', line 21033 class StartNotebookExportInput < Struct.new( :domain_identifier, :notebook_identifier, :owning_project_identifier, :file_format, :client_token) SENSITIVE = [] include Aws::Structure end |
#owning_project_identifier ⇒ String
The identifier of the project that owns the notebook.
21033 21034 21035 21036 21037 21038 21039 21040 21041 |
# File 'lib/aws-sdk-datazone/types.rb', line 21033 class StartNotebookExportInput < Struct.new( :domain_identifier, :notebook_identifier, :owning_project_identifier, :file_format, :client_token) SENSITIVE = [] include Aws::Structure end |