Class: Aws::DataZone::Types::StartNotebookExportOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartNotebookExportOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the notebook export was started.
-
#created_by ⇒ String
The identifier of the user who started the notebook export.
-
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
-
#file_format ⇒ String
The file format of the notebook export.
-
#id ⇒ String
The identifier of the notebook export.
-
#notebook_id ⇒ String
The identifier of the notebook.
-
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
-
#status ⇒ String
The status of the notebook export.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the notebook export was started.
21077 21078 21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-datazone/types.rb', line 21077 class StartNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who started the notebook export.
21077 21078 21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-datazone/types.rb', line 21077 class StartNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
21077 21078 21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-datazone/types.rb', line 21077 class StartNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#file_format ⇒ String
The file format of the notebook export.
21077 21078 21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-datazone/types.rb', line 21077 class StartNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the notebook export.
21077 21078 21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-datazone/types.rb', line 21077 class StartNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#notebook_id ⇒ String
The identifier of the notebook.
21077 21078 21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-datazone/types.rb', line 21077 class StartNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
21077 21078 21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-datazone/types.rb', line 21077 class StartNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the notebook export.
21077 21078 21079 21080 21081 21082 21083 21084 21085 21086 21087 21088 |
# File 'lib/aws-sdk-datazone/types.rb', line 21077 class StartNotebookExportOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :file_format, :status, :created_at, :created_by) SENSITIVE = [] include Aws::Structure end |