Class: Aws::DataZone::Types::StartNotebookImportInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


21630
21631
21632
21633
21634
21635
21636
21637
21638
21639
# File 'lib/aws-sdk-datazone/types.rb', line 21630

class StartNotebookImportInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :source_location,
  :name,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description of the imported notebook.

Returns:

  • (String)


21630
21631
21632
21633
21634
21635
21636
21637
21638
21639
# File 'lib/aws-sdk-datazone/types.rb', line 21630

class StartNotebookImportInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :source_location,
  :name,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon SageMaker Unified Studio domain in which to import the notebook.

Returns:

  • (String)


21630
21631
21632
21633
21634
21635
21636
21637
21638
21639
# File 'lib/aws-sdk-datazone/types.rb', line 21630

class StartNotebookImportInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :source_location,
  :name,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name of the imported notebook. The name must be between 1 and 256 characters.

Returns:

  • (String)


21630
21631
21632
21633
21634
21635
21636
21637
21638
21639
# File 'lib/aws-sdk-datazone/types.rb', line 21630

class StartNotebookImportInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :source_location,
  :name,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#owning_project_identifierString

The identifier of the project that will own the imported notebook.

Returns:

  • (String)


21630
21631
21632
21633
21634
21635
21636
21637
21638
21639
# File 'lib/aws-sdk-datazone/types.rb', line 21630

class StartNotebookImportInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :source_location,
  :name,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#source_locationTypes::SourceLocation

The source location of the notebook to import. This specifies the Amazon Simple Storage Service URI of the notebook file.



21630
21631
21632
21633
21634
21635
21636
21637
21638
21639
# File 'lib/aws-sdk-datazone/types.rb', line 21630

class StartNotebookImportInput < Struct.new(
  :domain_identifier,
  :owning_project_identifier,
  :source_location,
  :name,
  :description,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end