Class: Aws::DataZone::Types::StartNotebookImportInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartNotebookImportInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#description ⇒ String
The description of the imported notebook.
-
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which to import the notebook.
-
#name ⇒ String
The name of the imported notebook.
-
#owning_project_identifier ⇒ String
The identifier of the project that will own the imported notebook.
-
#source_location ⇒ Types::SourceLocation
The source location of the notebook to import.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
21123 21124 21125 21126 21127 21128 21129 21130 21131 21132 |
# File 'lib/aws-sdk-datazone/types.rb', line 21123 class StartNotebookImportInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the imported notebook.
21123 21124 21125 21126 21127 21128 21129 21130 21131 21132 |
# File 'lib/aws-sdk-datazone/types.rb', line 21123 class StartNotebookImportInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which to import the notebook.
21123 21124 21125 21126 21127 21128 21129 21130 21131 21132 |
# File 'lib/aws-sdk-datazone/types.rb', line 21123 class StartNotebookImportInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the imported notebook. The name must be between 1 and 256 characters.
21123 21124 21125 21126 21127 21128 21129 21130 21131 21132 |
# File 'lib/aws-sdk-datazone/types.rb', line 21123 class StartNotebookImportInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#owning_project_identifier ⇒ String
The identifier of the project that will own the imported notebook.
21123 21124 21125 21126 21127 21128 21129 21130 21131 21132 |
# File 'lib/aws-sdk-datazone/types.rb', line 21123 class StartNotebookImportInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#source_location ⇒ Types::SourceLocation
The source location of the notebook to import. This specifies the Amazon Simple Storage Service URI of the notebook file.
21123 21124 21125 21126 21127 21128 21129 21130 21131 21132 |
# File 'lib/aws-sdk-datazone/types.rb', line 21123 class StartNotebookImportInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |