Class: Aws::DataZone::Types::StartNotebookImportOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartNotebookImportOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the notebook import was started.
-
#created_by ⇒ String
The identifier of the user who started the notebook import.
-
#description ⇒ String
The description of the imported notebook.
-
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
-
#name ⇒ String
The name of the imported notebook.
-
#notebook_id ⇒ String
The identifier of the imported notebook.
-
#owning_project_id ⇒ String
The identifier of the project that owns the imported notebook.
-
#source_location ⇒ Types::SourceLocation
The source location from which the notebook was imported.
-
#status ⇒ String
The status of the notebook import.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the notebook import was started.
21172 21173 21174 21175 21176 21177 21178 21179 21180 21181 21182 21183 21184 |
# File 'lib/aws-sdk-datazone/types.rb', line 21172 class StartNotebookImportOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :name, :description, :source_location, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who started the notebook import.
21172 21173 21174 21175 21176 21177 21178 21179 21180 21181 21182 21183 21184 |
# File 'lib/aws-sdk-datazone/types.rb', line 21172 class StartNotebookImportOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :name, :description, :source_location, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the imported notebook.
21172 21173 21174 21175 21176 21177 21178 21179 21180 21181 21182 21183 21184 |
# File 'lib/aws-sdk-datazone/types.rb', line 21172 class StartNotebookImportOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :name, :description, :source_location, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
21172 21173 21174 21175 21176 21177 21178 21179 21180 21181 21182 21183 21184 |
# File 'lib/aws-sdk-datazone/types.rb', line 21172 class StartNotebookImportOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :name, :description, :source_location, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the imported notebook.
21172 21173 21174 21175 21176 21177 21178 21179 21180 21181 21182 21183 21184 |
# File 'lib/aws-sdk-datazone/types.rb', line 21172 class StartNotebookImportOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :name, :description, :source_location, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#notebook_id ⇒ String
The identifier of the imported notebook.
21172 21173 21174 21175 21176 21177 21178 21179 21180 21181 21182 21183 21184 |
# File 'lib/aws-sdk-datazone/types.rb', line 21172 class StartNotebookImportOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :name, :description, :source_location, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the imported notebook.
21172 21173 21174 21175 21176 21177 21178 21179 21180 21181 21182 21183 21184 |
# File 'lib/aws-sdk-datazone/types.rb', line 21172 class StartNotebookImportOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :name, :description, :source_location, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#source_location ⇒ Types::SourceLocation
The source location from which the notebook was imported.
21172 21173 21174 21175 21176 21177 21178 21179 21180 21181 21182 21183 21184 |
# File 'lib/aws-sdk-datazone/types.rb', line 21172 class StartNotebookImportOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :name, :description, :source_location, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |
#status ⇒ String
The status of the notebook import.
21172 21173 21174 21175 21176 21177 21178 21179 21180 21181 21182 21183 21184 |
# File 'lib/aws-sdk-datazone/types.rb', line 21172 class StartNotebookImportOutput < Struct.new( :notebook_id, :status, :domain_id, :owning_project_id, :name, :description, :source_location, :created_at, :created_by) SENSITIVE = [:name, :description] include Aws::Structure end |