Class: Aws::DataZone::Types::StartNotebookRunInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartNotebookRunInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:metadata, :parameters]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#compute_configuration ⇒ Types::ComputeConfig
The compute configuration for the notebook run, including instance type and environment version.
-
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which the notebook run is started.
-
#metadata ⇒ Hash<String,String>
The metadata for the notebook run, specified as key-value pairs.
-
#network_configuration ⇒ Types::NetworkConfig
The network configuration for the notebook run, including network access type and optional VPC settings.
-
#notebook_identifier ⇒ String
The identifier of the notebook to run.
-
#owning_project_identifier ⇒ String
The identifier of the project that owns the notebook run.
-
#parameters ⇒ Hash<String,String>
The sensitive parameters for the notebook run, specified as key-value pairs.
-
#schedule_identifier ⇒ String
The identifier of the schedule associated with the notebook run.
-
#timeout_configuration ⇒ Types::TimeoutConfig
The timeout configuration for the notebook run.
-
#trigger_source ⇒ Types::TriggerSource
The source that triggered the notebook run.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#compute_configuration ⇒ Types::ComputeConfig
The compute configuration for the notebook run, including instance type and environment version.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which the notebook run is started.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The metadata for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfig
The network configuration for the notebook run, including network access type and optional VPC settings.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#notebook_identifier ⇒ String
The identifier of the notebook to run.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#owning_project_identifier ⇒ String
The identifier of the project that owns the notebook run.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
The sensitive parameters for the notebook run, specified as key-value pairs. You can specify up to 50 entries, with keys up to 128 characters and values up to 1024 characters.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#schedule_identifier ⇒ String
The identifier of the schedule associated with the notebook run.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#timeout_configuration ⇒ Types::TimeoutConfig
The timeout configuration for the notebook run. The default timeout is 720 minutes (12 hours) and the maximum is 1440 minutes (24 hours).
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#trigger_source ⇒ Types::TriggerSource
The source that triggered the notebook run.
21245 21246 21247 21248 21249 21250 21251 21252 21253 21254 21255 21256 21257 21258 21259 |
# File 'lib/aws-sdk-datazone/types.rb', line 21245 class StartNotebookRunInput < Struct.new( :domain_identifier, :owning_project_identifier, :notebook_identifier, :schedule_identifier, :compute_configuration, :network_configuration, :timeout_configuration, :trigger_source, :metadata, :parameters, :client_token) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |