Class: Aws::DataZone::Types::StartNotebookRunOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:metadata, :parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#cell_orderArray<Types::CellInformation>

The ordered list of cells in the notebook run.

Returns:



21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#completed_atTime

The timestamp of when the notebook run completed.

Returns:

  • (Time)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#compute_configurationTypes::ComputeConfig

The compute configuration of the notebook run.



21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#created_atTime

The timestamp of when the notebook run was created.

Returns:

  • (Time)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#created_byString

The identifier of the user who created the notebook run.

Returns:

  • (String)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon SageMaker Unified Studio domain.

Returns:

  • (String)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#environment_configurationTypes::EnvironmentConfig

The environment configuration of the notebook run, including image version and package settings.



21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#errorTypes::NotebookRunError

The error details if the notebook run failed.



21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#idString

The identifier of the notebook run.

Returns:

  • (String)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#metadataHash<String,String>

The metadata of the notebook run.

Returns:

  • (Hash<String,String>)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#network_configurationTypes::NetworkConfig

The network configuration of the notebook run.



21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#notebook_idString

The identifier of the notebook.

Returns:

  • (String)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#owning_project_idString

The identifier of the project that owns the notebook run.

Returns:

  • (String)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#parametersHash<String,String>

The sensitive parameters of the notebook run.

Returns:

  • (Hash<String,String>)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#schedule_idString

The identifier of the schedule associated with the notebook run.

Returns:

  • (String)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#started_atTime

The timestamp of when the notebook run started executing.

Returns:

  • (Time)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#statusString

The status of the notebook run.

Returns:

  • (String)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#storage_configurationTypes::StorageConfig

The storage configuration of the notebook run, including the Amazon Simple Storage Service path and KMS key ARN.



21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#timeout_configurationTypes::TimeoutConfig

The timeout configuration of the notebook run.



21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#trigger_sourceTypes::TriggerSource

The source that triggered the notebook run.



21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the notebook run was last updated.

Returns:

  • (Time)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end

#updated_byString

The identifier of the user who last updated the notebook run.

Returns:

  • (String)


21353
21354
21355
21356
21357
21358
21359
21360
21361
21362
21363
21364
21365
21366
21367
21368
21369
21370
21371
21372
21373
21374
21375
21376
21377
21378
# File 'lib/aws-sdk-datazone/types.rb', line 21353

class StartNotebookRunOutput < Struct.new(
  :id,
  :domain_id,
  :owning_project_id,
  :notebook_id,
  :schedule_id,
  :status,
  :cell_order,
  :metadata,
  :parameters,
  :compute_configuration,
  :network_configuration,
  :timeout_configuration,
  :environment_configuration,
  :storage_configuration,
  :trigger_source,
  :error,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :completed_at)
  SENSITIVE = [:metadata, :parameters]
  include Aws::Structure
end