Class: Aws::DataZone::Types::StartNotebookRunOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartNotebookRunOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:metadata, :parameters]
Instance Attribute Summary collapse
-
#cell_order ⇒ Array<Types::CellInformation>
The ordered list of cells in the notebook run.
-
#completed_at ⇒ Time
The timestamp of when the notebook run completed.
-
#compute_configuration ⇒ Types::ComputeConfig
The compute configuration of the notebook run.
-
#created_at ⇒ Time
The timestamp of when the notebook run was created.
-
#created_by ⇒ String
The identifier of the user who created the notebook run.
-
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
-
#environment_configuration ⇒ Types::EnvironmentConfig
The environment configuration of the notebook run, including image version and package settings.
-
#error ⇒ Types::NotebookRunError
The error details if the notebook run failed.
-
#id ⇒ String
The identifier of the notebook run.
-
#metadata ⇒ Hash<String,String>
The metadata of the notebook run.
-
#network_configuration ⇒ Types::NetworkConfig
The network configuration of the notebook run.
-
#notebook_id ⇒ String
The identifier of the notebook.
-
#owning_project_id ⇒ String
The identifier of the project that owns the notebook run.
-
#parameters ⇒ Hash<String,String>
The sensitive parameters of the notebook run.
-
#schedule_id ⇒ String
The identifier of the schedule associated with the notebook run.
-
#started_at ⇒ Time
The timestamp of when the notebook run started executing.
-
#status ⇒ String
The status of the notebook run.
-
#storage_configuration ⇒ Types::StorageConfig
The storage configuration of the notebook run, including the Amazon Simple Storage Service path and KMS key ARN.
-
#timeout_configuration ⇒ Types::TimeoutConfig
The timeout configuration of the notebook run.
-
#trigger_source ⇒ Types::TriggerSource
The source that triggered the notebook run.
-
#updated_at ⇒ Time
The timestamp of when the notebook run was last updated.
-
#updated_by ⇒ String
The identifier of the user who last updated the notebook run.
Instance Attribute Details
#cell_order ⇒ Array<Types::CellInformation>
The ordered list of cells in the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#completed_at ⇒ Time
The timestamp of when the notebook run completed.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#compute_configuration ⇒ Types::ComputeConfig
The compute configuration of the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the notebook run was created.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who created the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#environment_configuration ⇒ Types::EnvironmentConfig
The environment configuration of the notebook run, including image version and package settings.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#error ⇒ Types::NotebookRunError
The error details if the notebook run failed.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#id ⇒ String
The identifier of the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The metadata of the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#network_configuration ⇒ Types::NetworkConfig
The network configuration of the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#notebook_id ⇒ String
The identifier of the notebook.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
The sensitive parameters of the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#schedule_id ⇒ String
The identifier of the schedule associated with the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#started_at ⇒ Time
The timestamp of when the notebook run started executing.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#status ⇒ String
The status of the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#storage_configuration ⇒ Types::StorageConfig
The storage configuration of the notebook run, including the Amazon Simple Storage Service path and KMS key ARN.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#timeout_configuration ⇒ Types::TimeoutConfig
The timeout configuration of the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#trigger_source ⇒ Types::TriggerSource
The source that triggered the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the notebook run was last updated.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |
#updated_by ⇒ String
The identifier of the user who last updated the notebook run.
21353 21354 21355 21356 21357 21358 21359 21360 21361 21362 21363 21364 21365 21366 21367 21368 21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 |
# File 'lib/aws-sdk-datazone/types.rb', line 21353 class StartNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :notebook_id, :schedule_id, :status, :cell_order, :metadata, :parameters, :compute_configuration, :network_configuration, :timeout_configuration, :environment_configuration, :storage_configuration, :trigger_source, :error, :created_at, :created_by, :updated_at, :updated_by, :started_at, :completed_at) SENSITIVE = [:metadata, :parameters] include Aws::Structure end |