Class: Aws::DataZone::Types::StartNotebookSyncInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StartNotebookSyncInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#description ⇒ String
The description of the notebook.
-
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which to sync the notebook.
-
#git_metadata ⇒ Types::GitMetadata
The Git metadata for the notebook sync, including repository, branch, and commit information.
-
#name ⇒ String
The name of the notebook.
-
#notebook_id ⇒ String
The identifier of an existing notebook to sync.
-
#owning_project_identifier ⇒ String
The identifier of the project that will own the synced notebook.
-
#source_location ⇒ Types::SourceLocation
The source location of the notebook to sync.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
A suitable default value is auto-generated. You should normally not need to pass this option.
21930 21931 21932 21933 21934 21935 21936 21937 21938 21939 21940 21941 |
# File 'lib/aws-sdk-datazone/types.rb', line 21930 class StartNotebookSyncInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :git_metadata, :notebook_id, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the notebook.
21930 21931 21932 21933 21934 21935 21936 21937 21938 21939 21940 21941 |
# File 'lib/aws-sdk-datazone/types.rb', line 21930 class StartNotebookSyncInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :git_metadata, :notebook_id, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which to sync the notebook.
21930 21931 21932 21933 21934 21935 21936 21937 21938 21939 21940 21941 |
# File 'lib/aws-sdk-datazone/types.rb', line 21930 class StartNotebookSyncInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :git_metadata, :notebook_id, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#git_metadata ⇒ Types::GitMetadata
The Git metadata for the notebook sync, including repository, branch, and commit information.
21930 21931 21932 21933 21934 21935 21936 21937 21938 21939 21940 21941 |
# File 'lib/aws-sdk-datazone/types.rb', line 21930 class StartNotebookSyncInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :git_metadata, :notebook_id, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the notebook. The name must be between 1 and 256 characters.
21930 21931 21932 21933 21934 21935 21936 21937 21938 21939 21940 21941 |
# File 'lib/aws-sdk-datazone/types.rb', line 21930 class StartNotebookSyncInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :git_metadata, :notebook_id, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#notebook_id ⇒ String
The identifier of an existing notebook to sync. If not specified, a new notebook is created.
21930 21931 21932 21933 21934 21935 21936 21937 21938 21939 21940 21941 |
# File 'lib/aws-sdk-datazone/types.rb', line 21930 class StartNotebookSyncInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :git_metadata, :notebook_id, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#owning_project_identifier ⇒ String
The identifier of the project that will own the synced notebook.
21930 21931 21932 21933 21934 21935 21936 21937 21938 21939 21940 21941 |
# File 'lib/aws-sdk-datazone/types.rb', line 21930 class StartNotebookSyncInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :git_metadata, :notebook_id, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#source_location ⇒ Types::SourceLocation
The source location of the notebook to sync. This specifies the Amazon Simple Storage Service URI of the notebook file.
21930 21931 21932 21933 21934 21935 21936 21937 21938 21939 21940 21941 |
# File 'lib/aws-sdk-datazone/types.rb', line 21930 class StartNotebookSyncInput < Struct.new( :domain_identifier, :owning_project_identifier, :source_location, :git_metadata, :notebook_id, :name, :description, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |