Class: Aws::DataZone::Types::StopNotebookRunInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StopNotebookRunInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which the notebook run is stopped.
-
#identifier ⇒ String
The identifier of the notebook run to stop.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
20612 20613 20614 20615 20616 20617 20618 |
# File 'lib/aws-sdk-datazone/types.rb', line 20612 class StopNotebookRunInput < Struct.new( :domain_identifier, :identifier, :client_token) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which the notebook run is stopped.
20612 20613 20614 20615 20616 20617 20618 |
# File 'lib/aws-sdk-datazone/types.rb', line 20612 class StopNotebookRunInput < Struct.new( :domain_identifier, :identifier, :client_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the notebook run to stop.
20612 20613 20614 20615 20616 20617 20618 |
# File 'lib/aws-sdk-datazone/types.rb', line 20612 class StopNotebookRunInput < Struct.new( :domain_identifier, :identifier, :client_token) SENSITIVE = [] include Aws::Structure end |