Class: Aws::DataZone::Types::StopNotebookRunOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::StopNotebookRunOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain.
-
#id ⇒ String
The identifier of the notebook run.
-
#owning_project_id ⇒ String
The identifier of the project that owns the notebook run.
-
#status ⇒ String
The status of the notebook run.
Instance Attribute Details
#domain_id ⇒ String
The identifier of the Amazon DataZone domain.
20638 20639 20640 20641 20642 20643 20644 20645 |
# File 'lib/aws-sdk-datazone/types.rb', line 20638 class StopNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the notebook run.
20638 20639 20640 20641 20642 20643 20644 20645 |
# File 'lib/aws-sdk-datazone/types.rb', line 20638 class StopNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :status) SENSITIVE = [] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the notebook run.
20638 20639 20640 20641 20642 20643 20644 20645 |
# File 'lib/aws-sdk-datazone/types.rb', line 20638 class StopNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the notebook run.
20638 20639 20640 20641 20642 20643 20644 20645 |
# File 'lib/aws-sdk-datazone/types.rb', line 20638 class StopNotebookRunOutput < Struct.new( :id, :domain_id, :owning_project_id, :status) SENSITIVE = [] include Aws::Structure end |