Class: Aws::DataZone::Types::SubscribedAsset

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of the asset for which the subscription grant is created.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_idString

The identifier of the asset for which the subscription grant is created.

Returns:

  • (String)


20044
20045
20046
20047
20048
20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/aws-sdk-datazone/types.rb', line 20044

class SubscribedAsset < Struct.new(
  :asset_id,
  :asset_revision,
  :status,
  :target_name,
  :failure_cause,
  :granted_timestamp,
  :failure_timestamp,
  :asset_scope,
  :permissions)
  SENSITIVE = []
  include Aws::Structure
end

#asset_revisionString

The revision of the asset for which the subscription grant is created.

Returns:

  • (String)


20044
20045
20046
20047
20048
20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/aws-sdk-datazone/types.rb', line 20044

class SubscribedAsset < Struct.new(
  :asset_id,
  :asset_revision,
  :status,
  :target_name,
  :failure_cause,
  :granted_timestamp,
  :failure_timestamp,
  :asset_scope,
  :permissions)
  SENSITIVE = []
  include Aws::Structure
end

#asset_scopeTypes::AssetScope

The asset scope of the subscribed asset.

Returns:



20044
20045
20046
20047
20048
20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/aws-sdk-datazone/types.rb', line 20044

class SubscribedAsset < Struct.new(
  :asset_id,
  :asset_revision,
  :status,
  :target_name,
  :failure_cause,
  :granted_timestamp,
  :failure_timestamp,
  :asset_scope,
  :permissions)
  SENSITIVE = []
  include Aws::Structure
end

#failure_causeTypes::FailureCause

The failure cause included in the details of the asset for which the subscription grant is created.

Returns:



20044
20045
20046
20047
20048
20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/aws-sdk-datazone/types.rb', line 20044

class SubscribedAsset < Struct.new(
  :asset_id,
  :asset_revision,
  :status,
  :target_name,
  :failure_cause,
  :granted_timestamp,
  :failure_timestamp,
  :asset_scope,
  :permissions)
  SENSITIVE = []
  include Aws::Structure
end

#failure_timestampTime

The failure timestamp included in the details of the asset for which the subscription grant is created.

Returns:

  • (Time)


20044
20045
20046
20047
20048
20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/aws-sdk-datazone/types.rb', line 20044

class SubscribedAsset < Struct.new(
  :asset_id,
  :asset_revision,
  :status,
  :target_name,
  :failure_cause,
  :granted_timestamp,
  :failure_timestamp,
  :asset_scope,
  :permissions)
  SENSITIVE = []
  include Aws::Structure
end

#granted_timestampTime

The timestamp of when the subscription grant to the asset is created.

Returns:

  • (Time)


20044
20045
20046
20047
20048
20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/aws-sdk-datazone/types.rb', line 20044

class SubscribedAsset < Struct.new(
  :asset_id,
  :asset_revision,
  :status,
  :target_name,
  :failure_cause,
  :granted_timestamp,
  :failure_timestamp,
  :asset_scope,
  :permissions)
  SENSITIVE = []
  include Aws::Structure
end

#permissionsTypes::Permissions

The asset permissions.

Returns:



20044
20045
20046
20047
20048
20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/aws-sdk-datazone/types.rb', line 20044

class SubscribedAsset < Struct.new(
  :asset_id,
  :asset_revision,
  :status,
  :target_name,
  :failure_cause,
  :granted_timestamp,
  :failure_timestamp,
  :asset_scope,
  :permissions)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the asset for which the subscription grant is created.

Returns:

  • (String)


20044
20045
20046
20047
20048
20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/aws-sdk-datazone/types.rb', line 20044

class SubscribedAsset < Struct.new(
  :asset_id,
  :asset_revision,
  :status,
  :target_name,
  :failure_cause,
  :granted_timestamp,
  :failure_timestamp,
  :asset_scope,
  :permissions)
  SENSITIVE = []
  include Aws::Structure
end

#target_nameString

The target name of the asset for which the subscription grant is created.

Returns:

  • (String)


20044
20045
20046
20047
20048
20049
20050
20051
20052
20053
20054
20055
20056
# File 'lib/aws-sdk-datazone/types.rb', line 20044

class SubscribedAsset < Struct.new(
  :asset_id,
  :asset_revision,
  :status,
  :target_name,
  :failure_cause,
  :granted_timestamp,
  :failure_timestamp,
  :asset_scope,
  :permissions)
  SENSITIVE = []
  include Aws::Structure
end