Class: Aws::DataZone::Types::SubscribedPrincipal
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SubscribedPrincipal
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
SubscribedPrincipal is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SubscribedPrincipal corresponding to the set member.
The principal that has the subscription grant for the asset.
Defined Under Namespace
Classes: Group, Iam, Project, Unknown, User
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#group ⇒ Types::SubscribedGroup
The subscribed group.
-
#iam ⇒ Types::SubscribedIamPrincipal
The subscribed IAM principal.
-
#project ⇒ Types::SubscribedProject
The project that has the subscription grant.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#user ⇒ Types::SubscribedUser
The subscribed user.
Instance Attribute Details
#group ⇒ Types::SubscribedGroup
The subscribed group.
20221 20222 20223 20224 20225 20226 20227 20228 20229 20230 20231 20232 20233 20234 20235 20236 |
# File 'lib/aws-sdk-datazone/types.rb', line 20221 class SubscribedPrincipal < Struct.new( :project, :user, :group, :iam, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class User < SubscribedPrincipal; end class Group < SubscribedPrincipal; end class Iam < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |
#iam ⇒ Types::SubscribedIamPrincipal
The subscribed IAM principal.
20221 20222 20223 20224 20225 20226 20227 20228 20229 20230 20231 20232 20233 20234 20235 20236 |
# File 'lib/aws-sdk-datazone/types.rb', line 20221 class SubscribedPrincipal < Struct.new( :project, :user, :group, :iam, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class User < SubscribedPrincipal; end class Group < SubscribedPrincipal; end class Iam < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |
#project ⇒ Types::SubscribedProject
The project that has the subscription grant.
20221 20222 20223 20224 20225 20226 20227 20228 20229 20230 20231 20232 20233 20234 20235 20236 |
# File 'lib/aws-sdk-datazone/types.rb', line 20221 class SubscribedPrincipal < Struct.new( :project, :user, :group, :iam, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class User < SubscribedPrincipal; end class Group < SubscribedPrincipal; end class Iam < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
20221 20222 20223 |
# File 'lib/aws-sdk-datazone/types.rb', line 20221 def unknown @unknown end |
#user ⇒ Types::SubscribedUser
The subscribed user.
20221 20222 20223 20224 20225 20226 20227 20228 20229 20230 20231 20232 20233 20234 20235 20236 |
# File 'lib/aws-sdk-datazone/types.rb', line 20221 class SubscribedPrincipal < Struct.new( :project, :user, :group, :iam, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class User < SubscribedPrincipal; end class Group < SubscribedPrincipal; end class Iam < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |