Class: Aws::DataZone::Types::SubscribedPrincipal
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SubscribedPrincipal
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
SubscribedPrincipal is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SubscribedPrincipal corresponding to the set member.
The principal that has the subscription grant for the asset.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#project ⇒ Types::SubscribedProject
The project that has the subscription grant.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#project ⇒ Types::SubscribedProject
The project that has the subscription grant.
12620 12621 12622 12623 12624 12625 12626 12627 12628 12629 |
# File 'lib/aws-sdk-datazone/types.rb', line 12620 class SubscribedPrincipal < Struct.new( :project, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipal; end class Unknown < SubscribedPrincipal; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
12620 12621 12622 |
# File 'lib/aws-sdk-datazone/types.rb', line 12620 def unknown @unknown end |