Class: Aws::DataZone::Types::SubscribedPrincipalInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SubscribedPrincipalInput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
SubscribedPrincipalInput is a union - when making an API calls you must set exactly one of the members.
The principal that is to be given a subscriptiong grant.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#project ⇒ Types::SubscribedProjectInput
The project that is to be given a subscription grant.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#project ⇒ Types::SubscribedProjectInput
The project that is to be given a subscription grant.
9451 9452 9453 9454 9455 9456 9457 9458 9459 9460 |
# File 'lib/aws-sdk-datazone/types.rb', line 9451 class SubscribedPrincipalInput < Struct.new( :project, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Project < SubscribedPrincipalInput; end class Unknown < SubscribedPrincipalInput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9451 9452 9453 |
# File 'lib/aws-sdk-datazone/types.rb', line 9451 def unknown @unknown end |