Class: Aws::DataZone::Types::SubscriptionTargetForm
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SubscriptionTargetForm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the subscription target configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ String
The content of the subscription target configuration.
-
#form_name ⇒ String
The form name included in the subscription target configuration.
Instance Attribute Details
#content ⇒ String
The content of the subscription target configuration.
20611 20612 20613 20614 20615 20616 |
# File 'lib/aws-sdk-datazone/types.rb', line 20611 class SubscriptionTargetForm < Struct.new( :form_name, :content) SENSITIVE = [] include Aws::Structure end |
#form_name ⇒ String
The form name included in the subscription target configuration.
20611 20612 20613 20614 20615 20616 |
# File 'lib/aws-sdk-datazone/types.rb', line 20611 class SubscriptionTargetForm < Struct.new( :form_name, :content) SENSITIVE = [] include Aws::Structure end |