Class: Aws::DataZone::Types::SubscriptionTargetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::SubscriptionTargetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
The details of the subscription target.
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#applicable_asset_types ⇒ Array<String>
The asset types included in the subscription target.
-
#authorized_principals ⇒ Array<String>
The authorized principals included in the subscription target.
-
#created_at ⇒ Time
The timestamp of when the subscription target was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the subscription target.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the subscription target exists.
-
#environment_id ⇒ String
The identifier of the environment of the subscription target.
-
#id ⇒ String
The identifier of the subscription target.
-
#manage_access_role ⇒ String
The manage access role specified in the subscription target.
-
#name ⇒ String
The name of the subscription target.
-
#project_id ⇒ String
The identifier of the project specified in the subscription target.
-
#provider ⇒ String
The provider of the subscription target.
-
#subscription_target_config ⇒ Array<Types::SubscriptionTargetForm>
The configuration of the subscription target.
-
#type ⇒ String
The type of the subscription target.
-
#updated_at ⇒ Time
The timestamp of when the subscription target was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription target.
Instance Attribute Details
#applicable_asset_types ⇒ Array<String>
The asset types included in the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#authorized_principals ⇒ Array<String>
The authorized principals included in the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the subscription target was created.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the subscription target exists.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#environment_id ⇒ String
The identifier of the environment of the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#id ⇒ String
The identifier of the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#manage_access_role ⇒ String
The manage access role specified in the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
The name of the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project specified in the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#provider ⇒ String
The provider of the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#subscription_target_config ⇒ Array<Types::SubscriptionTargetForm>
The configuration of the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#type ⇒ String
The type of the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription target was updated.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription target.
14211 14212 14213 14214 14215 14216 14217 14218 14219 14220 14221 14222 14223 14224 14225 14226 14227 14228 14229 |
# File 'lib/aws-sdk-datazone/types.rb', line 14211 class SubscriptionTargetSummary < Struct.new( :applicable_asset_types, :authorized_principals, :created_at, :created_by, :domain_id, :environment_id, :id, :manage_access_role, :name, :project_id, :provider, :subscription_target_config, :type, :updated_at, :updated_by) SENSITIVE = [:name] include Aws::Structure end |