Class: Aws::DataZone::Types::SubscriptionTargetSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

The details of the subscription target.

Constant Summary collapse

SENSITIVE =
[:name]

Instance Attribute Summary collapse

Instance Attribute Details

#applicable_asset_typesArray<String>

The asset types included in the subscription target.

Returns:

  • (Array<String>)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#authorized_principalsArray<String>

The authorized principals included in the subscription target.

Returns:

  • (Array<String>)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#created_atTime

The timestamp of when the subscription target was created.

Returns:

  • (Time)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#created_byString

The Amazon DataZone user who created the subscription target.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#domain_idString

The identifier of the Amazon DataZone domain in which the subscription target exists.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#environment_idString

The identifier of the environment of the subscription target.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#idString

The identifier of the subscription target.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#manage_access_roleString

The manage access role specified in the subscription target.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#nameString

The name of the subscription target.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#project_idString

The identifier of the project specified in the subscription target.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#providerString

The provider of the subscription target.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#subscription_target_configArray<Types::SubscriptionTargetForm>

The configuration of the subscription target.

Returns:



9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#typeString

The type of the subscription target.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the subscription target was updated.

Returns:

  • (Time)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end

#updated_byString

The Amazon DataZone user who updated the subscription target.

Returns:

  • (String)


9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
9797
9798
9799
# File 'lib/aws-sdk-datazone/types.rb', line 9781

class SubscriptionTargetSummary < Struct.new(
  :applicable_asset_types,
  :authorized_principals,
  :created_at,
  :created_by,
  :domain_id,
  :environment_id,
  :id,
  :manage_access_role,
  :name,
  :project_id,
  :provider,
  :subscription_target_config,
  :type,
  :updated_at,
  :updated_by)
  SENSITIVE = [:name]
  include Aws::Structure
end