Class: Aws::DataZone::Types::UpdateConnectionOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationsArray<Types::Configuration>

The configurations of the connection.

Returns:



21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#connection_idString

The ID of the connection.

Returns:

  • (String)


21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The connection description.

Returns:

  • (String)


21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#domain_idString

The ID of the domain where a connection is to be updated.

Returns:

  • (String)


21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#domain_unit_idString

The ID of the domain unit where a connection is to be updated.

Returns:

  • (String)


21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#environment_idString

The ID of the environment where a connection is to be updated.

Returns:

  • (String)


21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name of the connection.

Returns:

  • (String)


21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#physical_endpointsArray<Types::PhysicalEndpoint>

The physical endpoints of the connection.

Returns:



21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#project_idString

The project ID of the connection.

Returns:

  • (String)


21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#propsTypes::ConnectionPropertiesOutput

The connection props.



21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#scopeString

The scope of the connection.

Returns:

  • (String)


21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end

#typeString

The connection type.

Returns:

  • (String)


21320
21321
21322
21323
21324
21325
21326
21327
21328
21329
21330
21331
21332
21333
21334
21335
# File 'lib/aws-sdk-datazone/types.rb', line 21320

class UpdateConnectionOutput < Struct.new(
  :configurations,
  :connection_id,
  :description,
  :domain_id,
  :domain_unit_id,
  :environment_id,
  :name,
  :physical_endpoints,
  :project_id,
  :props,
  :type,
  :scope)
  SENSITIVE = [:description]
  include Aws::Structure
end