Class: Aws::DataZone::Types::UpdateDataSourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateDataSourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name, :schedule]
Instance Attribute Summary collapse
-
#asset_forms_output ⇒ Array<Types::FormOutput>
The asset forms to be updated as part of the ‘UpdateDataSource` action.
-
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration to be updated as part of the ‘UpdateDataSource` action.
-
#created_at ⇒ Time
The timestamp of when the data source was updated.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateDataSource` action.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a data source is to be updated.
-
#enable_setting ⇒ String
The enable setting to be updated as part of the ‘UpdateDataSource` action.
-
#environment_id ⇒ String
The identifier of the environment in which a data source is to be updated.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of the data source to be updated.
-
#last_run_at ⇒ Time
The timestamp of when the data source was last run.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The last run error message of the data source.
-
#last_run_status ⇒ String
The last run status of the data source.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateDataSource` action.
-
#project_id ⇒ String
The identifier of the project where data source is to be updated.
-
#publish_on_import ⇒ Boolean
The publish on import setting to be updated as part of the ‘UpdateDataSource` action.
-
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation to be updated as part of the ‘UpdateDataSource` action.
-
#retain_permissions_on_revoke_failure ⇒ Boolean
Specifies that the granted permissions are retained in case of a self-subscribe functionality failure for a data source.
-
#schedule ⇒ Types::ScheduleConfiguration
The schedule to be updated as part of the ‘UpdateDataSource` action.
-
#self_grant_status ⇒ Types::SelfGrantStatusOutput
Specifies the status of the self-granting functionality.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateDataSource` action.
-
#type ⇒ String
The type to be updated as part of the ‘UpdateDataSource` action.
-
#updated_at ⇒ Time
The timestamp of when the data source was updated.
Instance Attribute Details
#asset_forms_output ⇒ Array<Types::FormOutput>
The asset forms to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the data source was updated.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a data source is to be updated.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
The enable setting to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#environment_id ⇒ String
The identifier of the environment in which a data source is to be updated.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#id ⇒ String
The identifier of the data source to be updated.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp of when the data source was last run.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The last run error message of the data source.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_status ⇒ String
The last run status of the data source.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project where data source is to be updated.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#publish_on_import ⇒ Boolean
The publish on import setting to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#retain_permissions_on_revoke_failure ⇒ Boolean
Specifies that the granted permissions are retained in case of a self-subscribe functionality failure for a data source.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The schedule to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#self_grant_status ⇒ Types::SelfGrantStatusOutput
Specifies the status of the self-granting functionality.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#type ⇒ String
The type to be updated as part of the ‘UpdateDataSource` action.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source was updated.
14731 14732 14733 14734 14735 14736 14737 14738 14739 14740 14741 14742 14743 14744 14745 14746 14747 14748 14749 14750 14751 14752 14753 14754 14755 14756 |
# File 'lib/aws-sdk-datazone/types.rb', line 14731 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :retain_permissions_on_revoke_failure, :schedule, :self_grant_status, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |