Class: Aws::DataZone::Types::UpdateDataSourceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateDataSourceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name, :schedule]
Instance Attribute Summary collapse
-
#asset_forms_output ⇒ Array<Types::FormOutput>
The asset forms to be updated as part of the ‘UpdateDataSource` action.
-
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration to be updated as part of the ‘UpdateDataSource` action.
-
#created_at ⇒ Time
The timestamp of when the data source was updated.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateDataSource` action.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a data source is to be updated.
-
#enable_setting ⇒ String
The enable setting to be updated as part of the ‘UpdateDataSource` action.
-
#environment_id ⇒ String
The identifier of the environment in which a data source is to be updated.
-
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#id ⇒ String
The identifier of the data source to be updated.
-
#last_run_at ⇒ Time
The timestamp of when the data source was last run.
-
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The last run error message of the data source.
-
#last_run_status ⇒ String
The last run status of the data source.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateDataSource` action.
-
#project_id ⇒ String
The identifier of the project where data source is to be updated.
-
#publish_on_import ⇒ Boolean
The publish on import setting to be updated as part of the ‘UpdateDataSource` action.
-
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation to be updated as part of the ‘UpdateDataSource` action.
-
#schedule ⇒ Types::ScheduleConfiguration
The schedule to be updated as part of the ‘UpdateDataSource` action.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateDataSource` action.
-
#type ⇒ String
The type to be updated as part of the ‘UpdateDataSource` action.
-
#updated_at ⇒ Time
The timestamp of when the data source was updated.
Instance Attribute Details
#asset_forms_output ⇒ Array<Types::FormOutput>
The asset forms to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#configuration ⇒ Types::DataSourceConfigurationOutput
The configuration to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the data source was updated.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a data source is to be updated.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#enable_setting ⇒ String
The enable setting to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#environment_id ⇒ String
The identifier of the environment in which a data source is to be updated.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#error_message ⇒ Types::DataSourceErrorMessage
Specifies the error message that is returned if the operation cannot be successfully completed.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#id ⇒ String
The identifier of the data source to be updated.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_at ⇒ Time
The timestamp of when the data source was last run.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_error_message ⇒ Types::DataSourceErrorMessage
The last run error message of the data source.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#last_run_status ⇒ String
The last run status of the data source.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project where data source is to be updated.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#publish_on_import ⇒ Boolean
The publish on import setting to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#recommendation ⇒ Types::RecommendationConfiguration
The recommendation to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#schedule ⇒ Types::ScheduleConfiguration
The schedule to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#type ⇒ String
The type to be updated as part of the ‘UpdateDataSource` action.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the data source was updated.
10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 10089 |
# File 'lib/aws-sdk-datazone/types.rb', line 10066 class UpdateDataSourceOutput < Struct.new( :asset_forms_output, :configuration, :created_at, :description, :domain_id, :enable_setting, :environment_id, :error_message, :id, :last_run_at, :last_run_error_message, :last_run_status, :name, :project_id, :publish_on_import, :recommendation, :schedule, :status, :type, :updated_at) SENSITIVE = [:description, :name, :schedule] include Aws::Structure end |