Class: Aws::DataZone::Types::UpdateDomainInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


19068
19069
19070
19071
19072
19073
19074
19075
19076
19077
19078
# File 'lib/aws-sdk-datazone/types.rb', line 19068

class UpdateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :identifier,
  :name,
  :service_role,
  :single_sign_on)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description to be updated as part of the ‘UpdateDomain` action.

Returns:

  • (String)


19068
19069
19070
19071
19072
19073
19074
19075
19076
19077
19078
# File 'lib/aws-sdk-datazone/types.rb', line 19068

class UpdateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :identifier,
  :name,
  :service_role,
  :single_sign_on)
  SENSITIVE = []
  include Aws::Structure
end

#domain_execution_roleString

The domain execution role to be updated as part of the ‘UpdateDomain` action.

Returns:

  • (String)


19068
19069
19070
19071
19072
19073
19074
19075
19076
19077
19078
# File 'lib/aws-sdk-datazone/types.rb', line 19068

class UpdateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :identifier,
  :name,
  :service_role,
  :single_sign_on)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The ID of the Amazon Web Services domain that is to be updated.

Returns:

  • (String)


19068
19069
19070
19071
19072
19073
19074
19075
19076
19077
19078
# File 'lib/aws-sdk-datazone/types.rb', line 19068

class UpdateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :identifier,
  :name,
  :service_role,
  :single_sign_on)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name to be updated as part of the ‘UpdateDomain` action.

Returns:

  • (String)


19068
19069
19070
19071
19072
19073
19074
19075
19076
19077
19078
# File 'lib/aws-sdk-datazone/types.rb', line 19068

class UpdateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :identifier,
  :name,
  :service_role,
  :single_sign_on)
  SENSITIVE = []
  include Aws::Structure
end

#service_roleString

The service role of the domain.

Returns:

  • (String)


19068
19069
19070
19071
19072
19073
19074
19075
19076
19077
19078
# File 'lib/aws-sdk-datazone/types.rb', line 19068

class UpdateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :identifier,
  :name,
  :service_role,
  :single_sign_on)
  SENSITIVE = []
  include Aws::Structure
end

#single_sign_onTypes::SingleSignOn

The single sign-on option to be updated as part of the ‘UpdateDomain` action.

Returns:



19068
19069
19070
19071
19072
19073
19074
19075
19076
19077
19078
# File 'lib/aws-sdk-datazone/types.rb', line 19068

class UpdateDomainInput < Struct.new(
  :client_token,
  :description,
  :domain_execution_role,
  :identifier,
  :name,
  :service_role,
  :single_sign_on)
  SENSITIVE = []
  include Aws::Structure
end