Class: Aws::DataZone::Types::UpdateEnvironmentBlueprintInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description to be updated as part of the UpdateEnvironmentBlueprint action.

Returns:

  • (String)


23933
23934
23935
23936
23937
23938
23939
23940
23941
# File 'lib/aws-sdk-datazone/types.rb', line 23933

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain in which an environment blueprint is to be updated.

Returns:

  • (String)


23933
23934
23935
23936
23937
23938
23939
23940
23941
# File 'lib/aws-sdk-datazone/types.rb', line 23933

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the environment blueprint to be updated.

Returns:

  • (String)


23933
23934
23935
23936
23937
23938
23939
23940
23941
# File 'lib/aws-sdk-datazone/types.rb', line 23933

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#provisioning_propertiesTypes::ProvisioningProperties

The provisioning properties to be updated as part of the UpdateEnvironmentBlueprint action.



23933
23934
23935
23936
23937
23938
23939
23940
23941
# File 'lib/aws-sdk-datazone/types.rb', line 23933

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end

#user_parametersArray<Types::CustomParameter>

The user parameters to be updated as part of the UpdateEnvironmentBlueprint action.

Returns:



23933
23934
23935
23936
23937
23938
23939
23940
23941
# File 'lib/aws-sdk-datazone/types.rb', line 23933

class UpdateEnvironmentBlueprintInput < Struct.new(
  :domain_identifier,
  :identifier,
  :description,
  :provisioning_properties,
  :user_parameters)
  SENSITIVE = []
  include Aws::Structure
end