Class: Aws::DataZone::Types::UpdateEnvironmentBlueprintInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentBlueprintInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which an environment blueprint is to be updated.
-
#identifier ⇒ String
The identifier of the environment blueprint to be updated.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
Instance Attribute Details
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
23313 23314 23315 23316 23317 23318 23319 23320 23321 |
# File 'lib/aws-sdk-datazone/types.rb', line 23313 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which an environment blueprint is to be updated.
23313 23314 23315 23316 23317 23318 23319 23320 23321 |
# File 'lib/aws-sdk-datazone/types.rb', line 23313 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the environment blueprint to be updated.
23313 23314 23315 23316 23317 23318 23319 23320 23321 |
# File 'lib/aws-sdk-datazone/types.rb', line 23313 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
23313 23314 23315 23316 23317 23318 23319 23320 23321 |
# File 'lib/aws-sdk-datazone/types.rb', line 23313 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
23313 23314 23315 23316 23317 23318 23319 23320 23321 |
# File 'lib/aws-sdk-datazone/types.rb', line 23313 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |