Class: Aws::DataZone::Types::UpdateEnvironmentBlueprintInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentBlueprintInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which an environment blueprint is to be updated.
-
#identifier ⇒ String
The identifier of the environment blueprint to be updated.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
Instance Attribute Details
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
22523 22524 22525 22526 22527 22528 22529 22530 22531 |
# File 'lib/aws-sdk-datazone/types.rb', line 22523 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which an environment blueprint is to be updated.
22523 22524 22525 22526 22527 22528 22529 22530 22531 |
# File 'lib/aws-sdk-datazone/types.rb', line 22523 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the environment blueprint to be updated.
22523 22524 22525 22526 22527 22528 22529 22530 22531 |
# File 'lib/aws-sdk-datazone/types.rb', line 22523 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
22523 22524 22525 22526 22527 22528 22529 22530 22531 |
# File 'lib/aws-sdk-datazone/types.rb', line 22523 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
22523 22524 22525 22526 22527 22528 22529 22530 22531 |
# File 'lib/aws-sdk-datazone/types.rb', line 22523 class UpdateEnvironmentBlueprintInput < Struct.new( :domain_identifier, :identifier, :description, :provisioning_properties, :user_parameters) SENSITIVE = [] include Aws::Structure end |