Class: Aws::DataZone::Types::UpdateEnvironmentBlueprintOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp of when the environment blueprint was created.

Returns:

  • (Time)


21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#deployment_propertiesTypes::DeploymentProperties

The deployment properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.



21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description to be updated as part of the ‘UpdateEnvironmentBlueprint` action.

Returns:

  • (String)


21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms to be updated as part of the ‘UpdateEnvironmentBlueprint` action.

Returns:

  • (Array<String>)


21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#idString

The identifier of the blueprint to be updated.

Returns:

  • (String)


21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name to be updated as part of the ‘UpdateEnvironmentBlueprint` action.

Returns:

  • (String)


21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#providerString

The provider of the blueprint to be udpated.

Returns:

  • (String)


21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#provisioning_propertiesTypes::ProvisioningProperties

The provisioning properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.



21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_atTime

The timestamp of when the blueprint was updated.

Returns:

  • (Time)


21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#user_parametersArray<Types::CustomParameter>

The user parameters to be updated as part of the ‘UpdateEnvironmentBlueprint` action.

Returns:



21814
21815
21816
21817
21818
21819
21820
21821
21822
21823
21824
21825
21826
21827
# File 'lib/aws-sdk-datazone/types.rb', line 21814

class UpdateEnvironmentBlueprintOutput < Struct.new(
  :id,
  :name,
  :description,
  :provider,
  :provisioning_properties,
  :deployment_properties,
  :user_parameters,
  :glossary_terms,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end