Class: Aws::DataZone::Types::UpdateEnvironmentBlueprintOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentBlueprintOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the environment blueprint was created.
-
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#id ⇒ String
The identifier of the blueprint to be updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#provider ⇒ String
The provider of the blueprint to be udpated.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
-
#updated_at ⇒ Time
The timestamp of when the blueprint was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the environment blueprint was created.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#id ⇒ String
The identifier of the blueprint to be updated.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#provider ⇒ String
The provider of the blueprint to be udpated.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the blueprint was updated.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentBlueprint` action.
21814 21815 21816 21817 21818 21819 21820 21821 21822 21823 21824 21825 21826 21827 |
# File 'lib/aws-sdk-datazone/types.rb', line 21814 class UpdateEnvironmentBlueprintOutput < Struct.new( :id, :name, :description, :provider, :provisioning_properties, :deployment_properties, :user_parameters, :glossary_terms, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |