Class: Aws::DataZone::Types::UpdateEnvironmentInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description to be updated as part of the ‘UpdateEnvironment` action.

Returns:

  • (String)


10197
10198
10199
10200
10201
10202
10203
10204
10205
# File 'lib/aws-sdk-datazone/types.rb', line 10197

class UpdateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#domain_identifierString

The identifier of the domain in which the environment is to be updated.

Returns:

  • (String)


10197
10198
10199
10200
10201
10202
10203
10204
10205
# File 'lib/aws-sdk-datazone/types.rb', line 10197

class UpdateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms to be updated as part of the ‘UpdateEnvironment` action.

Returns:

  • (Array<String>)


10197
10198
10199
10200
10201
10202
10203
10204
10205
# File 'lib/aws-sdk-datazone/types.rb', line 10197

class UpdateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier of the environment that is to be updated.

Returns:

  • (String)


10197
10198
10199
10200
10201
10202
10203
10204
10205
# File 'lib/aws-sdk-datazone/types.rb', line 10197

class UpdateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name to be updated as part of the ‘UpdateEnvironment` action.

Returns:

  • (String)


10197
10198
10199
10200
10201
10202
10203
10204
10205
# File 'lib/aws-sdk-datazone/types.rb', line 10197

class UpdateEnvironmentInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = []
  include Aws::Structure
end