Class: Aws::DataZone::Types::UpdateEnvironmentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironment` action.
-
#domain_identifier ⇒ String
The identifier of the domain in which the environment is to be updated.
-
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironment` action.
-
#identifier ⇒ String
The identifier of the environment that is to be updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironment` action.
Instance Attribute Details
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironment` action.
10197 10198 10199 10200 10201 10202 10203 10204 10205 |
# File 'lib/aws-sdk-datazone/types.rb', line 10197 class UpdateEnvironmentInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the domain in which the environment is to be updated.
10197 10198 10199 10200 10201 10202 10203 10204 10205 |
# File 'lib/aws-sdk-datazone/types.rb', line 10197 class UpdateEnvironmentInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironment` action.
10197 10198 10199 10200 10201 10202 10203 10204 10205 |
# File 'lib/aws-sdk-datazone/types.rb', line 10197 class UpdateEnvironmentInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The identifier of the environment that is to be updated.
10197 10198 10199 10200 10201 10202 10203 10204 10205 |
# File 'lib/aws-sdk-datazone/types.rb', line 10197 class UpdateEnvironmentInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironment` action.
10197 10198 10199 10200 10201 10202 10203 10204 10205 |
# File 'lib/aws-sdk-datazone/types.rb', line 10197 class UpdateEnvironmentInput < Struct.new( :description, :domain_identifier, :glossary_terms, :identifier, :name) SENSITIVE = [] include Aws::Structure end |