Class: Aws::DataZone::Types::UpdateEnvironmentOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :environment_configuration_id, :environment_configuration_name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which the environment is to be updated.
-
#aws_account_region ⇒ String
The Amazon Web Services Region in which the environment is updated.
-
#created_at ⇒ Time
The timestamp of when the environment was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the environment.
-
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the ‘UpdateEnvironment` action.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironment` action.
-
#domain_id ⇒ String
The identifier of the domain in which the environment is to be updated.
-
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The environment actions to be updated as part of the ‘UpdateEnvironment` action.
-
#environment_blueprint_id ⇒ String
The blueprint identifier of the environment.
-
#environment_configuration_id ⇒ String
The configuration ID of the environment.
-
#environment_configuration_name ⇒ String
The configuration name of the environment.
-
#environment_profile_id ⇒ String
The profile identifier of the environment.
-
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironment` action.
-
#id ⇒ String
The identifier of the environment that is to be updated.
-
#last_deployment ⇒ Types::Deployment
The last deployment of the environment.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironment` action.
-
#project_id ⇒ String
The project identifier of the environment.
-
#provider ⇒ String
The provider identifier of the environment.
-
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources to be updated as part of the ‘UpdateEnvironment` action.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironment` action.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateEnvironment` action.
-
#updated_at ⇒ Time
The timestamp of when the environment was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironment` action.
Instance Attribute Details
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which the environment is to be updated.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services Region in which the environment is updated.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the environment was created.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the environment.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the ‘UpdateEnvironment` action.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironment` action.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the domain in which the environment is to be updated.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The environment actions to be updated as part of the ‘UpdateEnvironment` action.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The blueprint identifier of the environment.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_configuration_id ⇒ String
The configuration ID of the environment.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_configuration_name ⇒ String
The configuration name of the environment.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#environment_profile_id ⇒ String
The profile identifier of the environment.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironment` action.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#id ⇒ String
The identifier of the environment that is to be updated.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#last_deployment ⇒ Types::Deployment
The last deployment of the environment.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironment` action.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#project_id ⇒ String
The project identifier of the environment.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provider ⇒ String
The provider identifier of the environment.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources to be updated as part of the ‘UpdateEnvironment` action.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironment` action.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateEnvironment` action.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the environment was updated.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironment` action.
21984 21985 21986 21987 21988 21989 21990 21991 21992 21993 21994 21995 21996 21997 21998 21999 22000 22001 22002 22003 22004 22005 22006 22007 22008 22009 22010 |
# File 'lib/aws-sdk-datazone/types.rb', line 21984 class UpdateEnvironmentOutput < Struct.new( :project_id, :id, :domain_id, :created_by, :created_at, :updated_at, :name, :description, :environment_profile_id, :aws_account_id, :aws_account_region, :provider, :provisioned_resources, :status, :environment_actions, :glossary_terms, :user_parameters, :last_deployment, :provisioning_properties, :deployment_properties, :environment_blueprint_id, :environment_configuration_id, :environment_configuration_name) SENSITIVE = [:name, :description, :environment_configuration_id, :environment_configuration_name] include Aws::Structure end |