Class: Aws::DataZone::Types::UpdateEnvironmentOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which the environment is to be updated.
-
#aws_account_region ⇒ String
The Amazon Web Services Region in which the environment is updated.
-
#created_at ⇒ Time
The timestamp of when the environment was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the environment.
-
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the ‘UpdateEnvironment` action.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironment` action.
-
#domain_id ⇒ String
The identifier of the domain in which the environment is to be updated.
-
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The environment actions to be updated as part of the ‘UpdateEnvironment` action.
-
#environment_blueprint_id ⇒ String
The blueprint identifier of the environment.
-
#environment_profile_id ⇒ String
The profile identifier of the environment.
-
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironment` action.
-
#id ⇒ String
The identifier of the environment that is to be updated.
-
#last_deployment ⇒ Types::Deployment
The last deployment of the environment.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironment` action.
-
#project_id ⇒ String
The project identifier of the environment.
-
#provider ⇒ String
The provider identifier of the environment.
-
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources to be updated as part of the ‘UpdateEnvironment` action.
-
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironment` action.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateEnvironment` action.
-
#updated_at ⇒ Time
The timestamp of when the environment was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironment` action.
Instance Attribute Details
#aws_account_id ⇒ String
The identifier of the Amazon Web Services account in which the environment is to be updated.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services Region in which the environment is updated.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the environment was created.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the environment.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#deployment_properties ⇒ Types::DeploymentProperties
The deployment properties to be updated as part of the ‘UpdateEnvironment` action.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironment` action.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the domain in which the environment is to be updated.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_actions ⇒ Array<Types::ConfigurableEnvironmentAction>
The environment actions to be updated as part of the ‘UpdateEnvironment` action.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The blueprint identifier of the environment.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_profile_id ⇒ String
The profile identifier of the environment.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms to be updated as part of the ‘UpdateEnvironment` action.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The identifier of the environment that is to be updated.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#last_deployment ⇒ Types::Deployment
The last deployment of the environment.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironment` action.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_id ⇒ String
The project identifier of the environment.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#provider ⇒ String
The provider identifier of the environment.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#provisioned_resources ⇒ Array<Types::Resource>
The provisioned resources to be updated as part of the ‘UpdateEnvironment` action.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#provisioning_properties ⇒ Types::ProvisioningProperties
The provisioning properties to be updated as part of the ‘UpdateEnvironment` action.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateEnvironment` action.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the environment was updated.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironment` action.
12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 12133 12134 12135 |
# File 'lib/aws-sdk-datazone/types.rb', line 12111 class UpdateEnvironmentOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :deployment_properties, :description, :domain_id, :environment_actions, :environment_blueprint_id, :environment_profile_id, :glossary_terms, :id, :last_deployment, :name, :project_id, :provider, :provisioned_resources, :provisioning_properties, :status, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |