Class: Aws::DataZone::Types::UpdateEnvironmentProfileInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentProfileInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account in which a specified environment profile is to be udpated.
-
#aws_account_region ⇒ String
The Amazon Web Services Region in which a specified environment profile is to be updated.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentProfile` action.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which an environment profile is to be updated.
-
#identifier ⇒ String
The identifier of the environment profile that is to be updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironmentProfile` action.
-
#user_parameters ⇒ Array<Types::EnvironmentParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentProfile` action.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account in which a specified environment profile is to be udpated.
22048 22049 22050 22051 22052 22053 22054 22055 22056 22057 22058 |
# File 'lib/aws-sdk-datazone/types.rb', line 22048 class UpdateEnvironmentProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :user_parameters, :aws_account_id, :aws_account_region) SENSITIVE = [:name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services Region in which a specified environment profile is to be updated.
22048 22049 22050 22051 22052 22053 22054 22055 22056 22057 22058 |
# File 'lib/aws-sdk-datazone/types.rb', line 22048 class UpdateEnvironmentProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :user_parameters, :aws_account_id, :aws_account_region) SENSITIVE = [:name] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentProfile` action.
22048 22049 22050 22051 22052 22053 22054 22055 22056 22057 22058 |
# File 'lib/aws-sdk-datazone/types.rb', line 22048 class UpdateEnvironmentProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :user_parameters, :aws_account_id, :aws_account_region) SENSITIVE = [:name] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which an environment profile is to be updated.
22048 22049 22050 22051 22052 22053 22054 22055 22056 22057 22058 |
# File 'lib/aws-sdk-datazone/types.rb', line 22048 class UpdateEnvironmentProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :user_parameters, :aws_account_id, :aws_account_region) SENSITIVE = [:name] include Aws::Structure end |
#identifier ⇒ String
The identifier of the environment profile that is to be updated.
22048 22049 22050 22051 22052 22053 22054 22055 22056 22057 22058 |
# File 'lib/aws-sdk-datazone/types.rb', line 22048 class UpdateEnvironmentProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :user_parameters, :aws_account_id, :aws_account_region) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironmentProfile` action.
22048 22049 22050 22051 22052 22053 22054 22055 22056 22057 22058 |
# File 'lib/aws-sdk-datazone/types.rb', line 22048 class UpdateEnvironmentProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :user_parameters, :aws_account_id, :aws_account_region) SENSITIVE = [:name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentProfile` action.
22048 22049 22050 22051 22052 22053 22054 22055 22056 22057 22058 |
# File 'lib/aws-sdk-datazone/types.rb', line 22048 class UpdateEnvironmentProfileInput < Struct.new( :domain_identifier, :identifier, :name, :description, :user_parameters, :aws_account_id, :aws_account_region) SENSITIVE = [:name] include Aws::Structure end |