Class: Aws::DataZone::Types::UpdateEnvironmentProfileOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateEnvironmentProfileOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account in which a specified environment profile is to be udpated.
-
#aws_account_region ⇒ String
The Amazon Web Services Region in which a specified environment profile is to be updated.
-
#created_at ⇒ Time
The timestamp of when the environment profile was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the environment profile.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentProfile` action.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the environment profile is to be updated.
-
#environment_blueprint_id ⇒ String
The identifier of the blueprint of the environment profile that is to be updated.
-
#id ⇒ String
The identifier of the environment profile that is to be udpated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironmentProfile` action.
-
#project_id ⇒ String
The identifier of the project of the environment profile that is to be updated.
-
#updated_at ⇒ Time
The timestamp of when the environment profile was updated.
-
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentProfile` action.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account in which a specified environment profile is to be udpated.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#aws_account_region ⇒ String
The Amazon Web Services Region in which a specified environment profile is to be updated.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the environment profile was created.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the environment profile.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateEnvironmentProfile` action.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which the environment profile is to be updated.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#environment_blueprint_id ⇒ String
The identifier of the blueprint of the environment profile that is to be updated.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The identifier of the environment profile that is to be udpated.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateEnvironmentProfile` action.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project of the environment profile that is to be updated.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the environment profile was updated.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |
#user_parameters ⇒ Array<Types::CustomParameter>
The user parameters to be updated as part of the ‘UpdateEnvironmentProfile` action.
19338 19339 19340 19341 19342 19343 19344 19345 19346 19347 19348 19349 19350 19351 19352 19353 |
# File 'lib/aws-sdk-datazone/types.rb', line 19338 class UpdateEnvironmentProfileOutput < Struct.new( :aws_account_id, :aws_account_region, :created_at, :created_by, :description, :domain_id, :environment_blueprint_id, :id, :name, :project_id, :updated_at, :user_parameters) SENSITIVE = [:description, :name] include Aws::Structure end |