Class: Aws::DataZone::Types::UpdateGlossaryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateGlossaryInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
-
#description ⇒ String
The description to be updated as part of the ‘UpdateGlossary` action.
-
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which a business glossary is to be updated.
-
#identifier ⇒ String
The identifier of the business glossary to be updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateGlossary` action.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateGlossary` action.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
22230 22231 22232 22233 22234 22235 22236 22237 22238 22239 |
# File 'lib/aws-sdk-datazone/types.rb', line 22230 class UpdateGlossaryInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description to be updated as part of the ‘UpdateGlossary` action.
22230 22231 22232 22233 22234 22235 22236 22237 22238 22239 |
# File 'lib/aws-sdk-datazone/types.rb', line 22230 class UpdateGlossaryInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon DataZone domain in which a business glossary is to be updated.
22230 22231 22232 22233 22234 22235 22236 22237 22238 22239 |
# File 'lib/aws-sdk-datazone/types.rb', line 22230 class UpdateGlossaryInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#identifier ⇒ String
The identifier of the business glossary to be updated.
22230 22231 22232 22233 22234 22235 22236 22237 22238 22239 |
# File 'lib/aws-sdk-datazone/types.rb', line 22230 class UpdateGlossaryInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateGlossary` action.
22230 22231 22232 22233 22234 22235 22236 22237 22238 22239 |
# File 'lib/aws-sdk-datazone/types.rb', line 22230 class UpdateGlossaryInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateGlossary` action.
22230 22231 22232 22233 22234 22235 22236 22237 22238 22239 |
# File 'lib/aws-sdk-datazone/types.rb', line 22230 class UpdateGlossaryInput < Struct.new( :domain_identifier, :identifier, :name, :description, :status, :client_token) SENSITIVE = [:name, :description] include Aws::Structure end |