Class: Aws::DataZone::Types::UpdateGlossaryInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that is provided to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
# File 'lib/aws-sdk-datazone/types.rb', line 22167

class UpdateGlossaryInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The description to be updated as part of the ‘UpdateGlossary` action.

Returns:

  • (String)


22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
# File 'lib/aws-sdk-datazone/types.rb', line 22167

class UpdateGlossaryInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain in which a business glossary is to be updated.

Returns:

  • (String)


22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
# File 'lib/aws-sdk-datazone/types.rb', line 22167

class UpdateGlossaryInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#identifierString

The identifier of the business glossary to be updated.

Returns:

  • (String)


22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
# File 'lib/aws-sdk-datazone/types.rb', line 22167

class UpdateGlossaryInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The name to be updated as part of the ‘UpdateGlossary` action.

Returns:

  • (String)


22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
# File 'lib/aws-sdk-datazone/types.rb', line 22167

class UpdateGlossaryInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#statusString

The status to be updated as part of the ‘UpdateGlossary` action.

Returns:

  • (String)


22167
22168
22169
22170
22171
22172
22173
22174
22175
22176
# File 'lib/aws-sdk-datazone/types.rb', line 22167

class UpdateGlossaryInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :client_token)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end