Class: Aws::DataZone::Types::UpdateGlossaryOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateGlossaryOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#description ⇒ String
The description to be updated as part of the ‘UpdateGlossary` action.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a business glossary is to be updated.
-
#id ⇒ String
The identifier of the business glossary that is to be updated.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateGlossary` action.
-
#owning_project_id ⇒ String
The identifier of the project in which to update a business glossary.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateGlossary` action.
Instance Attribute Details
#description ⇒ String
The description to be updated as part of the ‘UpdateGlossary` action.
19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 |
# File 'lib/aws-sdk-datazone/types.rb', line 19655 class UpdateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a business glossary is to be updated.
19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 |
# File 'lib/aws-sdk-datazone/types.rb', line 19655 class UpdateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The identifier of the business glossary that is to be updated.
19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 |
# File 'lib/aws-sdk-datazone/types.rb', line 19655 class UpdateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateGlossary` action.
19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 |
# File 'lib/aws-sdk-datazone/types.rb', line 19655 class UpdateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project in which to update a business glossary.
19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 |
# File 'lib/aws-sdk-datazone/types.rb', line 19655 class UpdateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateGlossary` action.
19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 |
# File 'lib/aws-sdk-datazone/types.rb', line 19655 class UpdateGlossaryOutput < Struct.new( :description, :domain_id, :id, :name, :owning_project_id, :status) SENSITIVE = [:description, :name] include Aws::Structure end |