Class: Aws::DataZone::Types::UpdateGlossaryTermOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateGlossaryTermOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:long_description, :name, :short_description]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a business glossary term is to be updated.
-
#glossary_id ⇒ String
The identifier of the business glossary in which a term is to be updated.
-
#id ⇒ String
The identifier of the business glossary term that is to be updated.
-
#long_description ⇒ String
The long description to be updated as part of the ‘UpdateGlossaryTerm` action.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateGlossaryTerm` action.
-
#short_description ⇒ String
The short description to be updated as part of the ‘UpdateGlossaryTerm` action.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateGlossaryTerm` action.
-
#term_relations ⇒ Types::TermRelations
The term relations to be updated as part of the ‘UpdateGlossaryTerm` action.
Instance Attribute Details
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a business glossary term is to be updated.
10625 10626 10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 |
# File 'lib/aws-sdk-datazone/types.rb', line 10625 class UpdateGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#glossary_id ⇒ String
The identifier of the business glossary in which a term is to be updated.
10625 10626 10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 |
# File 'lib/aws-sdk-datazone/types.rb', line 10625 class UpdateGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#id ⇒ String
The identifier of the business glossary term that is to be updated.
10625 10626 10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 |
# File 'lib/aws-sdk-datazone/types.rb', line 10625 class UpdateGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#long_description ⇒ String
The long description to be updated as part of the ‘UpdateGlossaryTerm` action.
10625 10626 10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 |
# File 'lib/aws-sdk-datazone/types.rb', line 10625 class UpdateGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateGlossaryTerm` action.
10625 10626 10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 |
# File 'lib/aws-sdk-datazone/types.rb', line 10625 class UpdateGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#short_description ⇒ String
The short description to be updated as part of the ‘UpdateGlossaryTerm` action.
10625 10626 10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 |
# File 'lib/aws-sdk-datazone/types.rb', line 10625 class UpdateGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateGlossaryTerm` action.
10625 10626 10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 |
# File 'lib/aws-sdk-datazone/types.rb', line 10625 class UpdateGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |
#term_relations ⇒ Types::TermRelations
The term relations to be updated as part of the ‘UpdateGlossaryTerm` action.
10625 10626 10627 10628 10629 10630 10631 10632 10633 10634 10635 10636 |
# File 'lib/aws-sdk-datazone/types.rb', line 10625 class UpdateGlossaryTermOutput < Struct.new( :domain_id, :glossary_id, :id, :long_description, :name, :short_description, :status, :term_relations) SENSITIVE = [:long_description, :name, :short_description] include Aws::Structure end |