Class: Aws::DataZone::Types::UpdateNotebookInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateNotebookInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name, :metadata, :parameters]
Instance Attribute Summary collapse
-
#cell_order ⇒ Array<Types::CellInformation>
The updated ordered list of cells in the notebook.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request.
-
#description ⇒ String
The updated description of the notebook.
-
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which the notebook exists.
-
#environment_configuration ⇒ Types::EnvironmentConfig
The updated environment configuration for the notebook.
-
#identifier ⇒ String
The identifier of the notebook to update.
-
#metadata ⇒ Hash<String,String>
The updated metadata for the notebook, specified as key-value pairs.
-
#name ⇒ String
The updated name of the notebook.
-
#parameters ⇒ Hash<String,String>
The updated sensitive parameters for the notebook, specified as key-value pairs.
-
#status ⇒ String
The updated status of the notebook.
Instance Attribute Details
#cell_order ⇒ Array<Types::CellInformation>
The updated ordered list of cells in the notebook.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure idempotency of the request. This field is automatically populated if not provided.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |
#description ⇒ String
The updated description of the notebook.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |
#domain_identifier ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain in which the notebook exists.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |
#environment_configuration ⇒ Types::EnvironmentConfig
The updated environment configuration for the notebook.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |
#identifier ⇒ String
The identifier of the notebook to update.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The updated metadata for the notebook, specified as key-value pairs.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |
#name ⇒ String
The updated name of the notebook.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
The updated sensitive parameters for the notebook, specified as key-value pairs.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |
#status ⇒ String
The updated status of the notebook.
24000 24001 24002 24003 24004 24005 24006 24007 24008 24009 24010 24011 24012 24013 |
# File 'lib/aws-sdk-datazone/types.rb', line 24000 class UpdateNotebookInput < Struct.new( :domain_identifier, :identifier, :description, :status, :name, :cell_order, :metadata, :parameters, :environment_configuration, :client_token) SENSITIVE = [:description, :name, :metadata, :parameters] include Aws::Structure end |