Class: Aws::DataZone::Types::UpdateNotebookOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateNotebookOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description, :metadata, :parameters]
Instance Attribute Summary collapse
-
#cell_order ⇒ Array<Types::CellInformation>
The ordered list of cells in the notebook.
-
#compute_id ⇒ String
The identifier of the compute associated with the notebook.
-
#created_at ⇒ Time
The timestamp of when the notebook was created.
-
#created_by ⇒ String
The identifier of the user who created the notebook.
-
#description ⇒ String
The description of the notebook.
-
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
-
#environment_configuration ⇒ Types::EnvironmentConfig
The environment configuration of the notebook.
-
#error ⇒ Types::NotebookError
The error details if the notebook is in a failed state.
-
#git_metadata ⇒ Types::GitMetadata
The Git metadata associated with the notebook.
-
#id ⇒ String
The identifier of the notebook.
-
#lock_expires_at ⇒ Time
The timestamp of when the notebook lock expires.
-
#locked_at ⇒ Time
The timestamp of when the notebook was locked.
-
#locked_by ⇒ String
The identifier of the user who locked the notebook.
-
#metadata ⇒ Hash<String,String>
The metadata of the notebook.
-
#name ⇒ String
The name of the notebook.
-
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
-
#parameters ⇒ Hash<String,String>
The sensitive parameters of the notebook.
-
#status ⇒ String
The status of the notebook.
-
#updated_at ⇒ Time
The timestamp of when the notebook was last updated.
-
#updated_by ⇒ String
The identifier of the user who last updated the notebook.
Instance Attribute Details
#cell_order ⇒ Array<Types::CellInformation>
The ordered list of cells in the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#compute_id ⇒ String
The identifier of the compute associated with the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the notebook was created.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#created_by ⇒ String
The identifier of the user who created the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#description ⇒ String
The description of the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon SageMaker Unified Studio domain.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#environment_configuration ⇒ Types::EnvironmentConfig
The environment configuration of the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#error ⇒ Types::NotebookError
The error details if the notebook is in a failed state.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#git_metadata ⇒ Types::GitMetadata
The Git metadata associated with the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#id ⇒ String
The identifier of the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#lock_expires_at ⇒ Time
The timestamp of when the notebook lock expires.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#locked_at ⇒ Time
The timestamp of when the notebook was locked.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#locked_by ⇒ String
The identifier of the user who locked the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#metadata ⇒ Hash<String,String>
The metadata of the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#name ⇒ String
The name of the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#owning_project_id ⇒ String
The identifier of the project that owns the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#parameters ⇒ Hash<String,String>
The sensitive parameters of the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#status ⇒ String
The status of the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the notebook was last updated.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |
#updated_by ⇒ String
The identifier of the user who last updated the notebook.
24822 24823 24824 24825 24826 24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 |
# File 'lib/aws-sdk-datazone/types.rb', line 24822 class UpdateNotebookOutput < Struct.new( :id, :name, :owning_project_id, :domain_id, :cell_order, :status, :description, :created_at, :created_by, :updated_at, :updated_by, :locked_by, :locked_at, :lock_expires_at, :compute_id, :metadata, :parameters, :environment_configuration, :error, :git_metadata) SENSITIVE = [:name, :description, :metadata, :parameters] include Aws::Structure end |