Class: Aws::DataZone::Types::UpdateProjectInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description to be updated as part of the ‘UpdateProject` action.

Returns:

  • (String)


10713
10714
10715
10716
10717
10718
10719
10720
10721
# File 'lib/aws-sdk-datazone/types.rb', line 10713

class UpdateProjectInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#domain_identifierString

The identifier of the Amazon DataZone domain in which a project is to be updated.

Returns:

  • (String)


10713
10714
10715
10716
10717
10718
10719
10720
10721
# File 'lib/aws-sdk-datazone/types.rb', line 10713

class UpdateProjectInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#glossary_termsArray<String>

The glossary terms to be updated as part of the ‘UpdateProject` action.

Returns:

  • (Array<String>)


10713
10714
10715
10716
10717
10718
10719
10720
10721
# File 'lib/aws-sdk-datazone/types.rb', line 10713

class UpdateProjectInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#identifierString

The identifier of the project that is to be updated.

Returns:

  • (String)


10713
10714
10715
10716
10717
10718
10719
10720
10721
# File 'lib/aws-sdk-datazone/types.rb', line 10713

class UpdateProjectInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end

#nameString

The name to be updated as part of the ‘UpdateProject` action.

Returns:

  • (String)


10713
10714
10715
10716
10717
10718
10719
10720
10721
# File 'lib/aws-sdk-datazone/types.rb', line 10713

class UpdateProjectInput < Struct.new(
  :description,
  :domain_identifier,
  :glossary_terms,
  :identifier,
  :name)
  SENSITIVE = [:description, :name]
  include Aws::Structure
end