Class: Aws::DataZone::Types::UpdateProjectOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateProjectOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the project was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the project.
-
#description ⇒ String
The description of the project that is to be updated.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a project is updated.
-
#domain_unit_id ⇒ String
The ID of the domain unit.
-
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment details of the project.
-
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
-
#glossary_terms ⇒ Array<String>
The glossary terms of the project that are to be updated.
-
#id ⇒ String
The identifier of the project that is to be updated.
-
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
-
#name ⇒ String
The name of the project that is to be updated.
-
#project_category ⇒ String
The category of the project.
-
#project_profile_id ⇒ String
The ID of the project profile.
-
#project_status ⇒ String
The status of the project.
-
#resource_tags ⇒ Array<Types::ResourceTag>
The resource tags of the project.
-
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of the project.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the project was created.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the project.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the project that is to be updated.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a project is updated.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#domain_unit_id ⇒ String
The ID of the domain unit.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#environment_deployment_details ⇒ Types::EnvironmentDeploymentDetails
The environment deployment details of the project.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Specifies the error message that is returned if the operation cannot be successfully completed.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms of the project that are to be updated.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#id ⇒ String
The identifier of the project that is to be updated.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the project that is to be updated.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_category ⇒ String
The category of the project.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_profile_id ⇒ String
The ID of the project profile.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#project_status ⇒ String
The status of the project.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#resource_tags ⇒ Array<Types::ResourceTag>
The resource tags of the project.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |
#user_parameters ⇒ Array<Types::EnvironmentConfigurationUserParameter>
The user parameters of the project.
22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 22599 22600 22601 22602 22603 22604 22605 22606 |
# File 'lib/aws-sdk-datazone/types.rb', line 22587 class UpdateProjectOutput < Struct.new( :domain_id, :id, :name, :description, :project_status, :failure_reasons, :created_by, :created_at, :last_updated_at, :resource_tags, :glossary_terms, :domain_unit_id, :project_profile_id, :user_parameters, :environment_deployment_details, :project_category) SENSITIVE = [:name, :description] include Aws::Structure end |