Class: Aws::DataZone::Types::UpdateProjectOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateProjectOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description, :name]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp of when the project was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the project.
-
#description ⇒ String
The description of the project that is to be updated.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a project is updated.
-
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Reasons for failed project deletion.
-
#glossary_terms ⇒ Array<String>
The glossary terms of the project that are to be updated.
-
#id ⇒ String
The identifier of the project that is to be updated.
-
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
-
#name ⇒ String
The name of the project that is to be updated.
-
#project_status ⇒ String
Status of the project.
Instance Attribute Details
#created_at ⇒ Time
The timestamp of when the project was created.
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the project.
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |
#description ⇒ String
The description of the project that is to be updated.
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a project is updated.
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |
#failure_reasons ⇒ Array<Types::ProjectDeletionError>
Reasons for failed project deletion
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |
#glossary_terms ⇒ Array<String>
The glossary terms of the project that are to be updated.
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |
#id ⇒ String
The identifier of the project that is to be updated.
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |
#last_updated_at ⇒ Time
The timestamp of when the project was last updated.
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |
#name ⇒ String
The name of the project that is to be updated.
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |
#project_status ⇒ String
Status of the project
10826 10827 10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/aws-sdk-datazone/types.rb', line 10826 class UpdateProjectOutput < Struct.new( :created_at, :created_by, :description, :domain_id, :failure_reasons, :glossary_terms, :id, :last_updated_at, :name, :project_status) SENSITIVE = [:description, :name] include Aws::Structure end |