Class: Aws::DataZone::Types::UpdateProjectProfileInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description, :project_resource_tags_description]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_custom_project_resource_tagsBoolean

Specifies whether custom project resource tags are supported.

Returns:

  • (Boolean)


22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end

#descriptionString

The description of a project profile.

Returns:

  • (String)


22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end

#domain_identifierString

The ID of the domain where a project profile is to be updated.

Returns:

  • (String)


22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end

#domain_unit_identifierString

The ID of the domain unit where a project profile is to be updated.

Returns:

  • (String)


22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end

#environment_configurationsArray<Types::EnvironmentConfiguration>

The environment configurations of a project profile.



22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end

#identifierString

The ID of a project profile that is to be updated.

Returns:

  • (String)


22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end

#nameString

The name of a project profile.

Returns:

  • (String)


22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end

#project_resource_tagsArray<Types::ResourceTagParameter>

The resource tags of the project profile.

Returns:



22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end

#project_resource_tags_descriptionString

Field viewable through the UI that provides a project user with the allowed resource tag specifications.

Returns:

  • (String)


22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end

#statusString

The status of a project profile.

Returns:

  • (String)


22651
22652
22653
22654
22655
22656
22657
22658
22659
22660
22661
22662
22663
22664
# File 'lib/aws-sdk-datazone/types.rb', line 22651

class UpdateProjectProfileInput < Struct.new(
  :domain_identifier,
  :identifier,
  :name,
  :description,
  :status,
  :project_resource_tags,
  :allow_custom_project_resource_tags,
  :project_resource_tags_description,
  :environment_configurations,
  :domain_unit_identifier)
  SENSITIVE = [:name, :description, :project_resource_tags_description]
  include Aws::Structure
end