Class: Aws::DataZone::Types::UpdateSubscriptionGrantStatusOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateSubscriptionGrantStatusOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assets ⇒ Array<Types::SubscribedAsset>
The details of the asset for which the subscription grant is created.
-
#created_at ⇒ Time
The timestamp of when the subscription grant status was created.
-
#created_by ⇒ String
The Amazon DataZone domain user who created the subscription grant status.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a subscription grant status is to be updated.
-
#environment_id ⇒ String
The ID of the environment in which the subscription grant is updated.
-
#granted_entity ⇒ Types::GrantedEntity
The granted entity to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
-
#id ⇒ String
The identifier of the subscription grant.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
-
#subscription_id ⇒ String
The identifier of the subscription.
-
#subscription_target_id ⇒ String
The identifier of the subscription target whose subscription grant status is to be updated.
-
#updated_at ⇒ Time
The timestamp of when the subscription grant status is to be updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant status.
Instance Attribute Details
#assets ⇒ Array<Types::SubscribedAsset>
The details of the asset for which the subscription grant is created.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the subscription grant status was created.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone domain user who created the subscription grant status.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a subscription grant status is to be updated.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The ID of the environment in which the subscription grant is updated.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#granted_entity ⇒ Types::GrantedEntity
The granted entity to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the subscription grant.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#subscription_id ⇒ String
The identifier of the subscription.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#subscription_target_id ⇒ String
The identifier of the subscription target whose subscription grant status is to be updated.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription grant status is to be updated.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant status.
24649 24650 24651 24652 24653 24654 24655 24656 24657 24658 24659 24660 24661 24662 24663 24664 |
# File 'lib/aws-sdk-datazone/types.rb', line 24649 class UpdateSubscriptionGrantStatusOutput < Struct.new( :id, :created_by, :updated_by, :domain_id, :created_at, :updated_at, :environment_id, :subscription_target_id, :granted_entity, :status, :assets, :subscription_id) SENSITIVE = [] include Aws::Structure end |