Class: Aws::DataZone::Types::UpdateSubscriptionGrantStatusOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateSubscriptionGrantStatusOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assets ⇒ Array<Types::SubscribedAsset>
The details of the asset for which the subscription grant is created.
-
#created_at ⇒ Time
The timestamp of when the subscription grant status was created.
-
#created_by ⇒ String
The Amazon DataZone domain user who created the subscription grant status.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a subscription grant status is to be updated.
-
#granted_entity ⇒ Types::GrantedEntity
The granted entity to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
-
#id ⇒ String
The identifier of the subscription grant.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
-
#subscription_id ⇒ String
The identifier of the subscription.
-
#subscription_target_id ⇒ String
The identifier of the subscription target whose subscription grant status is to be updated.
-
#updated_at ⇒ Time
The timestamp of when the subscription grant status is to be updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant status.
Instance Attribute Details
#assets ⇒ Array<Types::SubscribedAsset>
The details of the asset for which the subscription grant is created.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the subscription grant status was created.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone domain user who created the subscription grant status.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a subscription grant status is to be updated.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#granted_entity ⇒ Types::GrantedEntity
The granted entity to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the subscription grant.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#subscription_id ⇒ String
The identifier of the subscription.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#subscription_target_id ⇒ String
The identifier of the subscription target whose subscription grant status is to be updated.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription grant status is to be updated.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant status.
12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 12323 12324 12325 12326 12327 |
# File 'lib/aws-sdk-datazone/types.rb', line 12313 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |