Class: Aws::DataZone::Types::UpdateSubscriptionGrantStatusOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateSubscriptionGrantStatusOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #assets ⇒ Array<Types::SubscribedAsset>
-
#created_at ⇒ Time
The timestamp of when the subscription grant status was created.
-
#created_by ⇒ String
The Amazon DataZone domain user who created the subscription grant status.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a subscription grant status is to be updated.
-
#granted_entity ⇒ Types::GrantedEntity
The granted entity to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
-
#id ⇒ String
The identifier of the subscription grant.
-
#status ⇒ String
The status to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
-
#subscription_id ⇒ String
The identifier of the subscription.
-
#subscription_target_id ⇒ String
The identifier of the subscription target whose subscription grant status is to be updated.
-
#updated_at ⇒ Time
The timestamp of when the subscription grant status is to be updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant status.
Instance Attribute Details
#assets ⇒ Array<Types::SubscribedAsset>
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when the subscription grant status was created.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone domain user who created the subscription grant status.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a subscription grant status is to be updated.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#granted_entity ⇒ Types::GrantedEntity
The granted entity to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the subscription grant.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status to be updated as part of the ‘UpdateSubscriptionGrantStatus` action.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#subscription_id ⇒ String
The identifier of the subscription.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#subscription_target_id ⇒ String
The identifier of the subscription target whose subscription grant status is to be updated.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription grant status is to be updated.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription grant status.
10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 |
# File 'lib/aws-sdk-datazone/types.rb', line 10865 class UpdateSubscriptionGrantStatusOutput < Struct.new( :assets, :created_at, :created_by, :domain_id, :granted_entity, :id, :status, :subscription_id, :subscription_target_id, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |