Class: Aws::DataZone::Types::UpdateSubscriptionTargetOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UpdateSubscriptionTargetOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name]
Instance Attribute Summary collapse
-
#applicable_asset_types ⇒ Array<String>
The applicable asset types to be updated as part of the ‘UpdateSubscriptionTarget` action.
-
#authorized_principals ⇒ Array<String>
The authorized principals to be updated as part of the ‘UpdateSubscriptionTarget` action.
-
#created_at ⇒ Time
The timestamp of when a subscription target was created.
-
#created_by ⇒ String
The Amazon DataZone user who created the subscription target.
-
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a subscription target is to be updated.
-
#environment_id ⇒ String
The identifier of the environment in which a subscription target is to be updated.
-
#id ⇒ String
Identifier of the subscription target that is to be updated.
-
#manage_access_role ⇒ String
The manage access role to be updated as part of the ‘UpdateSubscriptionTarget` action.
-
#name ⇒ String
The name to be updated as part of the ‘UpdateSubscriptionTarget` action.
-
#project_id ⇒ String
The identifier of the project in which a subscription target is to be updated.
-
#provider ⇒ String
The provider to be updated as part of the ‘UpdateSubscriptionTarget` action.
-
#subscription_grant_creation_mode ⇒ String
Determines the subscription grant creation mode for this target, defining if grants are auto-created upon subscription approval or managed manually.
-
#subscription_target_config ⇒ Array<Types::SubscriptionTargetForm>
The configuration to be updated as part of the ‘UpdateSubscriptionTarget` action.
-
#type ⇒ String
The type to be updated as part of the ‘UpdateSubscriptionTarget` action.
-
#updated_at ⇒ Time
The timestamp of when the subscription target was updated.
-
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription target.
Instance Attribute Details
#applicable_asset_types ⇒ Array<String>
The applicable asset types to be updated as part of the ‘UpdateSubscriptionTarget` action.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#authorized_principals ⇒ Array<String>
The authorized principals to be updated as part of the ‘UpdateSubscriptionTarget` action. Updates are supported in batches of 5 at a time.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#created_at ⇒ Time
The timestamp of when a subscription target was created.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#created_by ⇒ String
The Amazon DataZone user who created the subscription target.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#domain_id ⇒ String
The identifier of the Amazon DataZone domain in which a subscription target is to be updated.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#environment_id ⇒ String
The identifier of the environment in which a subscription target is to be updated.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#id ⇒ String
Identifier of the subscription target that is to be updated.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#manage_access_role ⇒ String
The manage access role to be updated as part of the ‘UpdateSubscriptionTarget` action.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#name ⇒ String
The name to be updated as part of the ‘UpdateSubscriptionTarget` action.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#project_id ⇒ String
The identifier of the project in which a subscription target is to be updated.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#provider ⇒ String
The provider to be updated as part of the ‘UpdateSubscriptionTarget` action.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#subscription_grant_creation_mode ⇒ String
Determines the subscription grant creation mode for this target, defining if grants are auto-created upon subscription approval or managed manually.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#subscription_target_config ⇒ Array<Types::SubscriptionTargetForm>
The configuration to be updated as part of the ‘UpdateSubscriptionTarget` action.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#type ⇒ String
The type to be updated as part of the ‘UpdateSubscriptionTarget` action.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp of when the subscription target was updated.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |
#updated_by ⇒ String
The Amazon DataZone user who updated the subscription target.
23255 23256 23257 23258 23259 23260 23261 23262 23263 23264 23265 23266 23267 23268 23269 23270 23271 23272 23273 23274 |
# File 'lib/aws-sdk-datazone/types.rb', line 23255 class UpdateSubscriptionTargetOutput < Struct.new( :id, :authorized_principals, :domain_id, :project_id, :environment_id, :name, :type, :created_by, :updated_by, :created_at, :updated_at, :manage_access_role, :applicable_asset_types, :subscription_target_config, :provider, :subscription_grant_creation_mode) SENSITIVE = [:name] include Aws::Structure end |