Class: Aws::DataZone::Types::UserPolicyGrantPrincipal
- Inherits:
-
Struct
- Object
- Struct
- Aws::DataZone::Types::UserPolicyGrantPrincipal
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-datazone/types.rb
Overview
Note:
UserPolicyGrantPrincipal is a union - when making an API calls you must set exactly one of the members.
Note:
UserPolicyGrantPrincipal is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UserPolicyGrantPrincipal corresponding to the set member.
The user policy grant principal.
Direct Known Subclasses
Defined Under Namespace
Classes: AllUsersGrantFilter, Unknown, UserIdentifier
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all_users_grant_filter ⇒ Types::AllUsersGrantFilter
The all users grant filter of the user policy grant principal.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#user_identifier ⇒ String
The user ID of the user policy grant principal.
Instance Attribute Details
#all_users_grant_filter ⇒ Types::AllUsersGrantFilter
The all users grant filter of the user policy grant principal.
23324 23325 23326 23327 23328 23329 23330 23331 23332 23333 23334 23335 |
# File 'lib/aws-sdk-datazone/types.rb', line 23324 class UserPolicyGrantPrincipal < Struct.new( :user_identifier, :all_users_grant_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UserIdentifier < UserPolicyGrantPrincipal; end class AllUsersGrantFilter < UserPolicyGrantPrincipal; end class Unknown < UserPolicyGrantPrincipal; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
23324 23325 23326 |
# File 'lib/aws-sdk-datazone/types.rb', line 23324 def unknown @unknown end |
#user_identifier ⇒ String
The user ID of the user policy grant principal.
23324 23325 23326 23327 23328 23329 23330 23331 23332 23333 23334 23335 |
# File 'lib/aws-sdk-datazone/types.rb', line 23324 class UserPolicyGrantPrincipal < Struct.new( :user_identifier, :all_users_grant_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UserIdentifier < UserPolicyGrantPrincipal; end class AllUsersGrantFilter < UserPolicyGrantPrincipal; end class Unknown < UserPolicyGrantPrincipal; end end |