Class: Aws::DataZone::Types::UserProfileDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-datazone/types.rb

Overview

Note:

UserProfileDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UserProfileDetails corresponding to the set member.

The details of the user profile in Amazon DataZone.

Direct Known Subclasses

Iam, Sso, Unknown

Defined Under Namespace

Classes: Iam, Sso, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#iamTypes::IamUserProfileDetails

The IAM details included in the user profile details.



12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
# File 'lib/aws-sdk-datazone/types.rb', line 12662

class UserProfileDetails < Struct.new(
  :iam,
  :sso,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Iam < UserProfileDetails; end
  class Sso < UserProfileDetails; end
  class Unknown < UserProfileDetails; end
end

#ssoTypes::SsoUserProfileDetails

The single sign-on details included in the user profile details.



12662
12663
12664
12665
12666
12667
12668
12669
12670
12671
12672
12673
# File 'lib/aws-sdk-datazone/types.rb', line 12662

class UserProfileDetails < Struct.new(
  :iam,
  :sso,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Iam < UserProfileDetails; end
  class Sso < UserProfileDetails; end
  class Unknown < UserProfileDetails; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



12662
12663
12664
# File 'lib/aws-sdk-datazone/types.rb', line 12662

def unknown
  @unknown
end